// agriculture
message Agriculture
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional plantGrowthMed PlantGrowthMedEnum = 11
  optional soilHorizon SoilHorizonEnum = 12
  repeated photosyntActiv QuantityValue = 13
  repeated photosyntActivMeth String = 14
  optional sampCollectMethod String = 15
  optional enrichmentProtocol String = 16
  optional libraryPrepKit String = 17
  optional sequencingLocation String = 18
  optional soilPH Double = 19
  optional soilConductivity QuantityValue = 20
  optional relLocation String = 21
  optional soilCover String = 22
  optional porosity String = 23
  optional texture QuantityValue = 24
  optional textureMeth String = 25
  repeated hostSymbiont String = 26
  optional presAnimalInsect String = 27
  optional plantWaterMethod String = 28
  repeated animWaterMethod String = 29
  repeated farmWaterSource FarmWaterSourceEnum = 30
  repeated waterSourceShared WaterSourceSharedEnum = 31
  optional waterPH Double = 32
  optional season String = 33
  optional solarIrradiance QuantityValue = 34
  optional cropYield String = 35
  optional seasonHumidity QuantityValue = 36
  optional humidity QuantityValue = 37
  repeated adjacentEnvironment String = 38
  repeated chemAdministration String = 39
  repeated foodProd String = 40
  repeated lotNumber String = 41
  optional fertilizerAdmin String = 42
  optional sampStorTemp QuantityValue = 43
  repeated foodTravMode String = 44
  repeated foodTravVehic String = 45
  repeated farmEquipSan String = 46
  repeated farmEquip String = 47
  repeated farmEquipShared String = 48
  repeated foodHarvestProc String = 49
  optional plantStruc String = 50
  optional hostDryMass QuantityValue = 51
  optional ancesData String = 52
  optional geneticMod String = 53
  optional foodProductType String = 54
  foodSource String = 55
  repeated spikeinStrain String = 56
  repeated organismCount OrganismCountEnum = 57
  optional sizeFracLow QuantityValue = 58
  optional sizeFracUp QuantityValue = 59
  optional cultIsolDate Date = 60
  repeated sampPooling String = 61
  optional rootMedMacronutr String = 62
  optional rootMedCarbon String = 63
  optional rootMedPh Double = 64
  repeated waterTempRegm String = 65
  repeated wateringRegm String = 66
  repeated standingWaterRegm String = 67
  repeated gaseousEnvironment String = 68
  repeated fungicideRegm String = 69
  repeated climateEnvironment String = 70
  repeated herbicideRegm String = 71
  repeated nonMineralNutrRegm String = 72
  repeated pesticideRegm String = 73
  repeated phRegm String = 74
  repeated saltRegm String = 75
  repeated seasonEnvironment String = 76
  repeated perturbation String = 77
  sampStoreDur String = 78
  sampStoreLoc String = 79
  sampCollectDevice String = 80
  hostAge QuantityValue = 81
  hostCommonName String = 82
  hostGenotype String = 83
  hostHeight QuantityValue = 84
  repeated hostSubspecfGenlin String = 85
  hostLength QuantityValue = 86
  hostLifeStage String = 87
  hostPhenotype String = 88
  hostTaxid String = 89
  hostTotMass QuantityValue = 90
  optional plantProduct String = 91
  optional oxyStatSamp OxyStatSampEnum = 92
  optional assemblyQuality String = 93
  repeated url String = 94
  optional faoClass FaoClassEnum = 95
  optional localClass String = 96
  optional localClassMeth String = 97
  soilType String = 98
  soilTypeMeth String = 99
  optional horizon HorizonEnum = 100
  optional horizonMeth String = 101
  optional linkClassInfo String = 102
  optional previousLandUse String = 103
  optional previousLandUseMeth String = 104
  optional cropRotation String = 105
  repeated agrochemAddition String = 106
  repeated tillage TillageEnum = 107
  optional fire Date = 108
  optional flooding Date = 109
  optional extremeEvent Date = 110
  optional linkClimateInfo String = 111
  optional annualTemp QuantityValue = 112
  optional seasonTemp QuantityValue = 113
  optional annualPrecpt QuantityValue = 114
  optional seasonPrecpt QuantityValue = 115
  optional curLandUse CurLandUseEnum = 116
  optional slopeGradient QuantityValue = 117
  optional slopeAspect QuantityValue = 118
  optional profilePosition ProfilePositionEnum = 119
  optional drainageClass DrainageClassEnum = 120
  storeCond String = 121
  optional phMeth String = 122
  optional curVegetation String = 123
  optional curVegetationMeth String = 124
  optional totOrgCarb QuantityValue = 125
  optional totOrgCMeth String = 126
  optional totNitro QuantityValue = 127
  optional totNMeth String = 128
  microbialBiomass QuantityValue = 129
  microbialBiomassMeth String = 130
  optional heavyMetalsMeth String = 131
  optional totCar QuantityValue = 132
  optional totPhos QuantityValue = 133
  sieving String = 134
  poolDnaExtracts String = 135
  repeated miscParam String = 136
  optional hostDiseaseStat String = 137
  specificHost String = 138
  pathogenicity String = 139
  optional bioticRelationship BioticRelationshipEnum = 140
  optional isolGrowthCondt String = 141
  sampMatProcess String = 142
  hostSpecRange Integer = 143
  optional trophicLevel TrophicLevelEnum = 144
  sampSize QuantityValue = 145
  seqMeth String = 146
  sampVolWeDnaExt QuantityValue = 147
  pcrPrimers String = 148
  nuclAcidExt String = 149
  nuclAcidAmp String = 150
  optional libSize Integer = 151
  libReadsSeqd Integer = 152
  optional libLayout LibLayoutEnum = 153
  libVector String = 154
  libScreen String = 155
  targetGene String = 156
  targetSubfragment String = 157
  mid String = 158
  adapters String = 159
  pcrCond String = 160
  optional seqQualityCheck String = 161
  chimeraCheck String = 162
  assemblyName String = 163
  optional assemblySoftware String = 164
  optional annot String = 165
  optional sop String = 166
  optional sourceMatId String = 167
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package agriculture
message AgricultureMIGSBacteria
 {
  optional latLon String = 1
  optional alt QuantityValue = 2
  optional elev QuantityValue = 3
  optional geoLocName String = 4
  optional collectionDate Date = 5
  optional envBroadScale String = 6
  optional envLocalScale String = 7
  optional envMedium String = 8
  optional plantGrowthMed PlantGrowthMedEnum = 9
  optional soilHorizon SoilHorizonEnum = 10
  repeated photosyntActiv QuantityValue = 11
  repeated photosyntActivMeth String = 12
  optional sampCollectMethod String = 13
  optional enrichmentProtocol String = 14
  optional libraryPrepKit String = 15
  optional sequencingLocation String = 16
  optional temp QuantityValue = 17
  optional soilPH Double = 18
  optional soilConductivity QuantityValue = 19
  optional relLocation String = 20
  optional soilCover String = 21
  optional porosity String = 22
  optional texture QuantityValue = 23
  optional textureMeth String = 24
  repeated hostSymbiont String = 25
  optional presAnimalInsect String = 26
  optional plantWaterMethod String = 27
  repeated animWaterMethod String = 28
  repeated farmWaterSource FarmWaterSourceEnum = 29
  repeated waterSourceShared WaterSourceSharedEnum = 30
  optional waterPH Double = 31
  optional season String = 32
  optional solarIrradiance QuantityValue = 33
  optional cropYield String = 34
  optional seasonHumidity QuantityValue = 35
  optional humidity QuantityValue = 36
  repeated adjacentEnvironment String = 37
  repeated chemAdministration String = 38
  repeated foodProd String = 39
  repeated lotNumber String = 40
  optional fertilizerAdmin String = 41
  optional sampStorTemp QuantityValue = 42
  repeated foodTravMode String = 43
  repeated foodTravVehic String = 44
  repeated farmEquipSan String = 45
  repeated farmEquip String = 46
  repeated farmEquipShared String = 47
  repeated foodHarvestProc String = 48
  optional plantStruc String = 49
  optional hostDryMass QuantityValue = 50
  optional ancesData String = 51
  optional geneticMod String = 52
  optional foodProductType String = 53
  foodSource String = 54
  repeated spikeinStrain String = 55
  repeated organismCount OrganismCountEnum = 56
  optional sizeFracLow QuantityValue = 57
  optional sizeFracUp QuantityValue = 58
  optional cultIsolDate Date = 59
  repeated sampPooling String = 60
  optional rootMedMacronutr String = 61
  optional rootMedCarbon String = 62
  optional rootMedPh Double = 63
  depth QuantityValue = 64
  repeated waterTempRegm String = 65
  repeated wateringRegm String = 66
  repeated standingWaterRegm String = 67
  repeated gaseousEnvironment String = 68
  repeated fungicideRegm String = 69
  repeated climateEnvironment String = 70
  repeated herbicideRegm String = 71
  repeated nonMineralNutrRegm String = 72
  repeated pesticideRegm String = 73
  repeated phRegm String = 74
  repeated saltRegm String = 75
  repeated seasonEnvironment String = 76
  repeated perturbation String = 77
  sampStoreDur String = 78
  sampStoreLoc String = 79
  sampCollectDevice String = 80
  hostAge QuantityValue = 81
  hostCommonName String = 82
  hostGenotype String = 83
  hostHeight QuantityValue = 84
  repeated hostSubspecfGenlin String = 85
  hostLength QuantityValue = 86
  hostLifeStage String = 87
  hostPhenotype String = 88
  hostTaxid String = 89
  hostTotMass QuantityValue = 90
  optional plantProduct String = 91
  optional oxyStatSamp OxyStatSampEnum = 92
  optional assemblyQuality String = 93
  repeated url String = 94
  optional faoClass FaoClassEnum = 95
  optional localClass String = 96
  optional localClassMeth String = 97
  soilType String = 98
  soilTypeMeth String = 99
  optional horizon HorizonEnum = 100
  optional horizonMeth String = 101
  optional linkClassInfo String = 102
  optional previousLandUse String = 103
  optional previousLandUseMeth String = 104
  optional cropRotation String = 105
  repeated agrochemAddition String = 106
  repeated tillage TillageEnum = 107
  optional fire Date = 108
  optional flooding Date = 109
  optional extremeEvent Date = 110
  optional linkClimateInfo String = 111
  optional annualTemp QuantityValue = 112
  optional seasonTemp QuantityValue = 113
  optional annualPrecpt QuantityValue = 114
  optional seasonPrecpt QuantityValue = 115
  optional curLandUse CurLandUseEnum = 116
  optional slopeGradient QuantityValue = 117
  optional slopeAspect QuantityValue = 118
  optional profilePosition ProfilePositionEnum = 119
  optional drainageClass DrainageClassEnum = 120
  storeCond String = 121
  optional phMeth String = 122
  optional curVegetation String = 123
  optional curVegetationMeth String = 124
  optional totOrgCarb QuantityValue = 125
  optional totOrgCMeth String = 126
  optional totNitro QuantityValue = 127
  optional totNMeth String = 128
  microbialBiomass QuantityValue = 129
  microbialBiomassMeth String = 130
  optional heavyMetalsMeth String = 131
  optional totCar QuantityValue = 132
  optional totPhos QuantityValue = 133
  sieving String = 134
  poolDnaExtracts String = 135
  repeated miscParam String = 136
  optional hostDiseaseStat String = 137
  specificHost String = 138
  pathogenicity String = 139
  optional bioticRelationship BioticRelationshipEnum = 140
  optional isolGrowthCondt String = 141
  sampMatProcess String = 142
  hostSpecRange Integer = 143
  optional trophicLevel TrophicLevelEnum = 144
  sampSize QuantityValue = 145
  seqMeth String = 146
  sampVolWeDnaExt QuantityValue = 147
  pcrPrimers String = 148
  nuclAcidExt String = 149
  nuclAcidAmp String = 150
  optional libSize Integer = 151
  libReadsSeqd Integer = 152
  optional libLayout LibLayoutEnum = 153
  libVector String = 154
  libScreen String = 155
  targetGene String = 156
  targetSubfragment String = 157
  mid String = 158
  adapters String = 159
  pcrCond String = 160
  optional seqQualityCheck String = 161
  chimeraCheck String = 162
  assemblyName String = 163
  optional assemblySoftware String = 164
  optional annot String = 165
  optional sop String = 166
  optional sourceMatId String = 167
  sampName String = 168
  sampTaxonId String = 169
  projectName String = 170
  optional experimentalFactor String = 171
  optional negContType NegContTypeEnum = 172
  optional posContType String = 173
  optional subspecfGenLin String = 174
  numReplicons Integer = 175
  optional extrachromElements Integer = 176
  optional estimatedSize String = 177
  refBiomaterial String = 178
  optional encodedTraits String = 179
  optional relToOxygen RelToOxygenEnum = 180
  optional sampCollecDevice String = 181
  optional sampCollecMethod String = 182
  optional taxIdent TaxIdentEnum = 183
  assemblyQual AssemblyQualEnum = 184
  numberContig Integer = 185
  optional featPred String = 186
  optional refDb String = 187
  optional simSearchMeth String = 188
  optional taxClass String = 189
  optional complScore String = 190
  optional complSoftware String = 191
  optional associatedResource String = 192
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: eukaryote with environmental package agriculture
message AgricultureMIGSEukaryote
 {
  optional latLon String = 1
  optional alt QuantityValue = 2
  optional elev QuantityValue = 3
  optional geoLocName String = 4
  optional collectionDate Date = 5
  optional envBroadScale String = 6
  optional envLocalScale String = 7
  optional envMedium String = 8
  optional plantGrowthMed PlantGrowthMedEnum = 9
  optional soilHorizon SoilHorizonEnum = 10
  repeated photosyntActiv QuantityValue = 11
  repeated photosyntActivMeth String = 12
  optional sampCollectMethod String = 13
  optional enrichmentProtocol String = 14
  optional libraryPrepKit String = 15
  optional sequencingLocation String = 16
  optional temp QuantityValue = 17
  optional soilPH Double = 18
  optional soilConductivity QuantityValue = 19
  optional relLocation String = 20
  optional soilCover String = 21
  optional porosity String = 22
  optional texture QuantityValue = 23
  optional textureMeth String = 24
  repeated hostSymbiont String = 25
  optional presAnimalInsect String = 26
  optional plantWaterMethod String = 27
  repeated animWaterMethod String = 28
  repeated farmWaterSource FarmWaterSourceEnum = 29
  repeated waterSourceShared WaterSourceSharedEnum = 30
  optional waterPH Double = 31
  optional season String = 32
  optional solarIrradiance QuantityValue = 33
  optional cropYield String = 34
  optional seasonHumidity QuantityValue = 35
  optional humidity QuantityValue = 36
  repeated adjacentEnvironment String = 37
  repeated chemAdministration String = 38
  repeated foodProd String = 39
  repeated lotNumber String = 40
  optional fertilizerAdmin String = 41
  optional sampStorTemp QuantityValue = 42
  repeated foodTravMode String = 43
  repeated foodTravVehic String = 44
  repeated farmEquipSan String = 45
  repeated farmEquip String = 46
  repeated farmEquipShared String = 47
  repeated foodHarvestProc String = 48
  optional plantStruc String = 49
  optional hostDryMass QuantityValue = 50
  optional ancesData String = 51
  optional geneticMod String = 52
  optional foodProductType String = 53
  foodSource String = 54
  repeated spikeinStrain String = 55
  repeated organismCount OrganismCountEnum = 56
  optional sizeFracLow QuantityValue = 57
  optional sizeFracUp QuantityValue = 58
  optional cultIsolDate Date = 59
  repeated sampPooling String = 60
  optional rootMedMacronutr String = 61
  optional rootMedCarbon String = 62
  optional rootMedPh Double = 63
  depth QuantityValue = 64
  repeated waterTempRegm String = 65
  repeated wateringRegm String = 66
  repeated standingWaterRegm String = 67
  repeated gaseousEnvironment String = 68
  repeated fungicideRegm String = 69
  repeated climateEnvironment String = 70
  repeated herbicideRegm String = 71
  repeated nonMineralNutrRegm String = 72
  repeated pesticideRegm String = 73
  repeated phRegm String = 74
  repeated saltRegm String = 75
  repeated seasonEnvironment String = 76
  repeated perturbation String = 77
  sampStoreDur String = 78
  sampStoreLoc String = 79
  sampCollectDevice String = 80
  hostAge QuantityValue = 81
  hostCommonName String = 82
  hostGenotype String = 83
  hostHeight QuantityValue = 84
  repeated hostSubspecfGenlin String = 85
  hostLength QuantityValue = 86
  hostLifeStage String = 87
  hostPhenotype String = 88
  hostTaxid String = 89
  hostTotMass QuantityValue = 90
  optional plantProduct String = 91
  optional oxyStatSamp OxyStatSampEnum = 92
  optional assemblyQuality String = 93
  repeated url String = 94
  optional faoClass FaoClassEnum = 95
  optional localClass String = 96
  optional localClassMeth String = 97
  soilType String = 98
  soilTypeMeth String = 99
  optional horizon HorizonEnum = 100
  optional horizonMeth String = 101
  optional linkClassInfo String = 102
  optional previousLandUse String = 103
  optional previousLandUseMeth String = 104
  optional cropRotation String = 105
  repeated agrochemAddition String = 106
  repeated tillage TillageEnum = 107
  optional fire Date = 108
  optional flooding Date = 109
  optional extremeEvent Date = 110
  optional linkClimateInfo String = 111
  optional annualTemp QuantityValue = 112
  optional seasonTemp QuantityValue = 113
  optional annualPrecpt QuantityValue = 114
  optional seasonPrecpt QuantityValue = 115
  optional curLandUse CurLandUseEnum = 116
  optional slopeGradient QuantityValue = 117
  optional slopeAspect QuantityValue = 118
  optional profilePosition ProfilePositionEnum = 119
  optional drainageClass DrainageClassEnum = 120
  storeCond String = 121
  optional phMeth String = 122
  optional curVegetation String = 123
  optional curVegetationMeth String = 124
  optional totOrgCarb QuantityValue = 125
  optional totOrgCMeth String = 126
  optional totNitro QuantityValue = 127
  optional totNMeth String = 128
  microbialBiomass QuantityValue = 129
  microbialBiomassMeth String = 130
  optional heavyMetalsMeth String = 131
  optional totCar QuantityValue = 132
  optional totPhos QuantityValue = 133
  sieving String = 134
  poolDnaExtracts String = 135
  repeated miscParam String = 136
  optional hostDiseaseStat String = 137
  specificHost String = 138
  pathogenicity String = 139
  optional bioticRelationship BioticRelationshipEnum = 140
  optional isolGrowthCondt String = 141
  sampMatProcess String = 142
  hostSpecRange Integer = 143
  optional trophicLevel TrophicLevelEnum = 144
  sampSize QuantityValue = 145
  seqMeth String = 146
  sampVolWeDnaExt QuantityValue = 147
  pcrPrimers String = 148
  nuclAcidExt String = 149
  nuclAcidAmp String = 150
  optional libSize Integer = 151
  libReadsSeqd Integer = 152
  optional libLayout LibLayoutEnum = 153
  libVector String = 154
  libScreen String = 155
  targetGene String = 156
  targetSubfragment String = 157
  mid String = 158
  adapters String = 159
  pcrCond String = 160
  optional seqQualityCheck String = 161
  chimeraCheck String = 162
  assemblyName String = 163
  optional assemblySoftware String = 164
  optional annot String = 165
  optional sop String = 166
  optional sourceMatId String = 167
  sampName String = 168
  sampTaxonId String = 169
  projectName String = 170
  optional experimentalFactor String = 171
  optional negContType NegContTypeEnum = 172
  optional posContType String = 173
  optional subspecfGenLin String = 174
  optional ploidy String = 175
  optional numReplicons Integer = 176
  optional extrachromElements Integer = 177
  optional estimatedSize String = 178
  optional refBiomaterial String = 179
  optional propagation String = 180
  optional sampCollecDevice String = 181
  optional sampCollecMethod String = 182
  optional taxIdent TaxIdentEnum = 183
  assemblyQual AssemblyQualEnum = 184
  numberContig Integer = 185
  optional featPred String = 186
  optional refDb String = 187
  optional simSearchMeth String = 188
  optional taxClass String = 189
  optional complScore String = 190
  optional complSoftware String = 191
  optional associatedResource String = 192
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: org with environmental package agriculture
message AgricultureMIGSOrg
 {
  optional latLon String = 1
  optional alt QuantityValue = 2
  optional elev QuantityValue = 3
  optional geoLocName String = 4
  optional collectionDate Date = 5
  optional envBroadScale String = 6
  optional envLocalScale String = 7
  optional envMedium String = 8
  optional plantGrowthMed PlantGrowthMedEnum = 9
  optional soilHorizon SoilHorizonEnum = 10
  repeated photosyntActiv QuantityValue = 11
  repeated photosyntActivMeth String = 12
  optional sampCollectMethod String = 13
  optional enrichmentProtocol String = 14
  optional libraryPrepKit String = 15
  optional sequencingLocation String = 16
  optional temp QuantityValue = 17
  optional soilPH Double = 18
  optional soilConductivity QuantityValue = 19
  optional relLocation String = 20
  optional soilCover String = 21
  optional porosity String = 22
  optional texture QuantityValue = 23
  optional textureMeth String = 24
  repeated hostSymbiont String = 25
  optional presAnimalInsect String = 26
  optional plantWaterMethod String = 27
  repeated animWaterMethod String = 28
  repeated farmWaterSource FarmWaterSourceEnum = 29
  repeated waterSourceShared WaterSourceSharedEnum = 30
  optional waterPH Double = 31
  optional season String = 32
  optional solarIrradiance QuantityValue = 33
  optional cropYield String = 34
  optional seasonHumidity QuantityValue = 35
  optional humidity QuantityValue = 36
  repeated adjacentEnvironment String = 37
  repeated chemAdministration String = 38
  repeated foodProd String = 39
  repeated lotNumber String = 40
  optional fertilizerAdmin String = 41
  optional sampStorTemp QuantityValue = 42
  repeated foodTravMode String = 43
  repeated foodTravVehic String = 44
  repeated farmEquipSan String = 45
  repeated farmEquip String = 46
  repeated farmEquipShared String = 47
  repeated foodHarvestProc String = 48
  optional plantStruc String = 49
  optional hostDryMass QuantityValue = 50
  optional ancesData String = 51
  optional geneticMod String = 52
  optional foodProductType String = 53
  foodSource String = 54
  repeated spikeinStrain String = 55
  repeated organismCount OrganismCountEnum = 56
  optional sizeFracLow QuantityValue = 57
  optional sizeFracUp QuantityValue = 58
  optional cultIsolDate Date = 59
  repeated sampPooling String = 60
  optional rootMedMacronutr String = 61
  optional rootMedCarbon String = 62
  optional rootMedPh Double = 63
  depth QuantityValue = 64
  repeated waterTempRegm String = 65
  repeated wateringRegm String = 66
  repeated standingWaterRegm String = 67
  repeated gaseousEnvironment String = 68
  repeated fungicideRegm String = 69
  repeated climateEnvironment String = 70
  repeated herbicideRegm String = 71
  repeated nonMineralNutrRegm String = 72
  repeated pesticideRegm String = 73
  repeated phRegm String = 74
  repeated saltRegm String = 75
  repeated seasonEnvironment String = 76
  repeated perturbation String = 77
  sampStoreDur String = 78
  sampStoreLoc String = 79
  sampCollectDevice String = 80
  hostAge QuantityValue = 81
  hostCommonName String = 82
  hostGenotype String = 83
  hostHeight QuantityValue = 84
  repeated hostSubspecfGenlin String = 85
  hostLength QuantityValue = 86
  hostLifeStage String = 87
  hostPhenotype String = 88
  hostTaxid String = 89
  hostTotMass QuantityValue = 90
  optional plantProduct String = 91
  optional oxyStatSamp OxyStatSampEnum = 92
  optional assemblyQuality String = 93
  repeated url String = 94
  optional faoClass FaoClassEnum = 95
  optional localClass String = 96
  optional localClassMeth String = 97
  soilType String = 98
  soilTypeMeth String = 99
  optional horizon HorizonEnum = 100
  optional horizonMeth String = 101
  optional linkClassInfo String = 102
  optional previousLandUse String = 103
  optional previousLandUseMeth String = 104
  optional cropRotation String = 105
  repeated agrochemAddition String = 106
  repeated tillage TillageEnum = 107
  optional fire Date = 108
  optional flooding Date = 109
  optional extremeEvent Date = 110
  optional linkClimateInfo String = 111
  optional annualTemp QuantityValue = 112
  optional seasonTemp QuantityValue = 113
  optional annualPrecpt QuantityValue = 114
  optional seasonPrecpt QuantityValue = 115
  optional curLandUse CurLandUseEnum = 116
  optional slopeGradient QuantityValue = 117
  optional slopeAspect QuantityValue = 118
  optional profilePosition ProfilePositionEnum = 119
  optional drainageClass DrainageClassEnum = 120
  storeCond String = 121
  optional phMeth String = 122
  optional curVegetation String = 123
  optional curVegetationMeth String = 124
  optional totOrgCarb QuantityValue = 125
  optional totOrgCMeth String = 126
  optional totNitro QuantityValue = 127
  optional totNMeth String = 128
  microbialBiomass QuantityValue = 129
  microbialBiomassMeth String = 130
  optional heavyMetalsMeth String = 131
  optional totCar QuantityValue = 132
  optional totPhos QuantityValue = 133
  sieving String = 134
  poolDnaExtracts String = 135
  repeated miscParam String = 136
  optional hostDiseaseStat String = 137
  specificHost String = 138
  pathogenicity String = 139
  optional bioticRelationship BioticRelationshipEnum = 140
  optional isolGrowthCondt String = 141
  sampMatProcess String = 142
  hostSpecRange Integer = 143
  optional trophicLevel TrophicLevelEnum = 144
  sampSize QuantityValue = 145
  seqMeth String = 146
  sampVolWeDnaExt QuantityValue = 147
  pcrPrimers String = 148
  nuclAcidExt String = 149
  nuclAcidAmp String = 150
  optional libSize Integer = 151
  libReadsSeqd Integer = 152
  optional libLayout LibLayoutEnum = 153
  libVector String = 154
  libScreen String = 155
  targetGene String = 156
  targetSubfragment String = 157
  mid String = 158
  adapters String = 159
  pcrCond String = 160
  optional seqQualityCheck String = 161
  chimeraCheck String = 162
  assemblyName String = 163
  optional assemblySoftware String = 164
  optional annot String = 165
  optional sop String = 166
  optional sourceMatId String = 167
  sampName String = 168
  sampTaxonId String = 169
  projectName String = 170
  optional experimentalFactor String = 171
  optional negContType NegContTypeEnum = 172
  optional posContType String = 173
  optional subspecfGenLin String = 174
  optional extrachromElements Integer = 175
  optional estimatedSize String = 176
  optional refBiomaterial String = 177
  optional sampCollecDevice String = 178
  optional sampCollecMethod String = 179
  optional taxIdent TaxIdentEnum = 180
  optional assemblyQual AssemblyQualEnum = 181
  optional numberContig Integer = 182
  optional featPred String = 183
  optional refDb String = 184
  optional simSearchMeth String = 185
  optional taxClass String = 186
  optional complScore String = 187
  optional complSoftware String = 188
  optional associatedResource String = 189
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: plant with environmental package agriculture
message AgricultureMIGSPlant
 {
  optional latLon String = 1
  optional alt QuantityValue = 2
  optional elev QuantityValue = 3
  optional geoLocName String = 4
  optional collectionDate Date = 5
  optional envBroadScale String = 6
  optional envLocalScale String = 7
  optional envMedium String = 8
  optional plantGrowthMed PlantGrowthMedEnum = 9
  optional soilHorizon SoilHorizonEnum = 10
  repeated photosyntActiv QuantityValue = 11
  repeated photosyntActivMeth String = 12
  optional sampCollectMethod String = 13
  optional enrichmentProtocol String = 14
  optional libraryPrepKit String = 15
  optional sequencingLocation String = 16
  optional temp QuantityValue = 17
  optional soilPH Double = 18
  optional soilConductivity QuantityValue = 19
  optional relLocation String = 20
  optional soilCover String = 21
  optional porosity String = 22
  optional texture QuantityValue = 23
  optional textureMeth String = 24
  repeated hostSymbiont String = 25
  optional presAnimalInsect String = 26
  optional plantWaterMethod String = 27
  repeated animWaterMethod String = 28
  repeated farmWaterSource FarmWaterSourceEnum = 29
  repeated waterSourceShared WaterSourceSharedEnum = 30
  optional waterPH Double = 31
  optional season String = 32
  optional solarIrradiance QuantityValue = 33
  optional cropYield String = 34
  optional seasonHumidity QuantityValue = 35
  optional humidity QuantityValue = 36
  repeated adjacentEnvironment String = 37
  repeated chemAdministration String = 38
  repeated foodProd String = 39
  repeated lotNumber String = 40
  optional fertilizerAdmin String = 41
  optional sampStorTemp QuantityValue = 42
  repeated foodTravMode String = 43
  repeated foodTravVehic String = 44
  repeated farmEquipSan String = 45
  repeated farmEquip String = 46
  repeated farmEquipShared String = 47
  repeated foodHarvestProc String = 48
  optional plantStruc String = 49
  optional hostDryMass QuantityValue = 50
  optional ancesData String = 51
  optional geneticMod String = 52
  optional foodProductType String = 53
  foodSource String = 54
  repeated spikeinStrain String = 55
  repeated organismCount OrganismCountEnum = 56
  optional sizeFracLow QuantityValue = 57
  optional sizeFracUp QuantityValue = 58
  optional cultIsolDate Date = 59
  repeated sampPooling String = 60
  optional rootMedMacronutr String = 61
  optional rootMedCarbon String = 62
  optional rootMedPh Double = 63
  depth QuantityValue = 64
  repeated waterTempRegm String = 65
  repeated wateringRegm String = 66
  repeated standingWaterRegm String = 67
  repeated gaseousEnvironment String = 68
  repeated fungicideRegm String = 69
  repeated climateEnvironment String = 70
  repeated herbicideRegm String = 71
  repeated nonMineralNutrRegm String = 72
  repeated pesticideRegm String = 73
  repeated phRegm String = 74
  repeated saltRegm String = 75
  repeated seasonEnvironment String = 76
  repeated perturbation String = 77
  sampStoreDur String = 78
  sampStoreLoc String = 79
  sampCollectDevice String = 80
  hostAge QuantityValue = 81
  hostCommonName String = 82
  hostGenotype String = 83
  hostHeight QuantityValue = 84
  repeated hostSubspecfGenlin String = 85
  hostLength QuantityValue = 86
  hostLifeStage String = 87
  hostPhenotype String = 88
  hostTaxid String = 89
  hostTotMass QuantityValue = 90
  optional plantProduct String = 91
  optional oxyStatSamp OxyStatSampEnum = 92
  optional assemblyQuality String = 93
  repeated url String = 94
  optional faoClass FaoClassEnum = 95
  optional localClass String = 96
  optional localClassMeth String = 97
  soilType String = 98
  soilTypeMeth String = 99
  optional horizon HorizonEnum = 100
  optional horizonMeth String = 101
  optional linkClassInfo String = 102
  optional previousLandUse String = 103
  optional previousLandUseMeth String = 104
  optional cropRotation String = 105
  repeated agrochemAddition String = 106
  repeated tillage TillageEnum = 107
  optional fire Date = 108
  optional flooding Date = 109
  optional extremeEvent Date = 110
  optional linkClimateInfo String = 111
  optional annualTemp QuantityValue = 112
  optional seasonTemp QuantityValue = 113
  optional annualPrecpt QuantityValue = 114
  optional seasonPrecpt QuantityValue = 115
  optional curLandUse CurLandUseEnum = 116
  optional slopeGradient QuantityValue = 117
  optional slopeAspect QuantityValue = 118
  optional profilePosition ProfilePositionEnum = 119
  optional drainageClass DrainageClassEnum = 120
  storeCond String = 121
  optional phMeth String = 122
  optional curVegetation String = 123
  optional curVegetationMeth String = 124
  optional totOrgCarb QuantityValue = 125
  optional totOrgCMeth String = 126
  optional totNitro QuantityValue = 127
  optional totNMeth String = 128
  microbialBiomass QuantityValue = 129
  microbialBiomassMeth String = 130
  optional heavyMetalsMeth String = 131
  optional totCar QuantityValue = 132
  optional totPhos QuantityValue = 133
  sieving String = 134
  poolDnaExtracts String = 135
  repeated miscParam String = 136
  optional hostDiseaseStat String = 137
  specificHost String = 138
  pathogenicity String = 139
  optional bioticRelationship BioticRelationshipEnum = 140
  optional isolGrowthCondt String = 141
  sampMatProcess String = 142
  hostSpecRange Integer = 143
  optional trophicLevel TrophicLevelEnum = 144
  sampSize QuantityValue = 145
  seqMeth String = 146
  sampVolWeDnaExt QuantityValue = 147
  pcrPrimers String = 148
  nuclAcidExt String = 149
  nuclAcidAmp String = 150
  optional libSize Integer = 151
  libReadsSeqd Integer = 152
  optional libLayout LibLayoutEnum = 153
  libVector String = 154
  libScreen String = 155
  targetGene String = 156
  targetSubfragment String = 157
  mid String = 158
  adapters String = 159
  pcrCond String = 160
  optional seqQualityCheck String = 161
  chimeraCheck String = 162
  assemblyName String = 163
  optional assemblySoftware String = 164
  optional annot String = 165
  optional sop String = 166
  optional sourceMatId String = 167
  sampName String = 168
  sampTaxonId String = 169
  projectName String = 170
  optional experimentalFactor String = 171
  optional negContType NegContTypeEnum = 172
  optional posContType String = 173
  optional subspecfGenLin String = 174
  optional estimatedSize String = 175
  optional refBiomaterial String = 176
  propagation String = 177
  optional encodedTraits String = 178
  optional sampCollecDevice String = 179
  optional sampCollecMethod String = 180
  optional taxIdent TaxIdentEnum = 181
  optional assemblyQual AssemblyQualEnum = 182
  optional numberContig Integer = 183
  optional featPred String = 184
  optional refDb String = 185
  optional simSearchMeth String = 186
  optional taxClass String = 187
  optional complScore String = 188
  optional complSoftware String = 189
  optional associatedResource String = 190
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package agriculture
message AgricultureMIGSVirus
 {
  optional latLon String = 1
  optional alt QuantityValue = 2
  optional elev QuantityValue = 3
  optional geoLocName String = 4
  optional collectionDate Date = 5
  optional envBroadScale String = 6
  optional envLocalScale String = 7
  optional envMedium String = 8
  optional plantGrowthMed PlantGrowthMedEnum = 9
  optional soilHorizon SoilHorizonEnum = 10
  repeated photosyntActiv QuantityValue = 11
  repeated photosyntActivMeth String = 12
  optional sampCollectMethod String = 13
  optional enrichmentProtocol String = 14
  optional libraryPrepKit String = 15
  optional sequencingLocation String = 16
  optional temp QuantityValue = 17
  optional soilPH Double = 18
  optional soilConductivity QuantityValue = 19
  optional relLocation String = 20
  optional soilCover String = 21
  optional porosity String = 22
  optional texture QuantityValue = 23
  optional textureMeth String = 24
  repeated hostSymbiont String = 25
  optional presAnimalInsect String = 26
  optional plantWaterMethod String = 27
  repeated animWaterMethod String = 28
  repeated farmWaterSource FarmWaterSourceEnum = 29
  repeated waterSourceShared WaterSourceSharedEnum = 30
  optional waterPH Double = 31
  optional season String = 32
  optional solarIrradiance QuantityValue = 33
  optional cropYield String = 34
  optional seasonHumidity QuantityValue = 35
  optional humidity QuantityValue = 36
  repeated adjacentEnvironment String = 37
  repeated chemAdministration String = 38
  repeated foodProd String = 39
  repeated lotNumber String = 40
  optional fertilizerAdmin String = 41
  optional sampStorTemp QuantityValue = 42
  repeated foodTravMode String = 43
  repeated foodTravVehic String = 44
  repeated farmEquipSan String = 45
  repeated farmEquip String = 46
  repeated farmEquipShared String = 47
  repeated foodHarvestProc String = 48
  optional plantStruc String = 49
  optional hostDryMass QuantityValue = 50
  optional ancesData String = 51
  optional geneticMod String = 52
  optional foodProductType String = 53
  foodSource String = 54
  repeated spikeinStrain String = 55
  repeated organismCount OrganismCountEnum = 56
  optional sizeFracLow QuantityValue = 57
  optional sizeFracUp QuantityValue = 58
  optional cultIsolDate Date = 59
  repeated sampPooling String = 60
  optional rootMedMacronutr String = 61
  optional rootMedCarbon String = 62
  optional rootMedPh Double = 63
  depth QuantityValue = 64
  repeated waterTempRegm String = 65
  repeated wateringRegm String = 66
  repeated standingWaterRegm String = 67
  repeated gaseousEnvironment String = 68
  repeated fungicideRegm String = 69
  repeated climateEnvironment String = 70
  repeated herbicideRegm String = 71
  repeated nonMineralNutrRegm String = 72
  repeated pesticideRegm String = 73
  repeated phRegm String = 74
  repeated saltRegm String = 75
  repeated seasonEnvironment String = 76
  repeated perturbation String = 77
  sampStoreDur String = 78
  sampStoreLoc String = 79
  sampCollectDevice String = 80
  hostAge QuantityValue = 81
  hostCommonName String = 82
  hostGenotype String = 83
  hostHeight QuantityValue = 84
  repeated hostSubspecfGenlin String = 85
  hostLength QuantityValue = 86
  hostLifeStage String = 87
  hostPhenotype String = 88
  hostTaxid String = 89
  hostTotMass QuantityValue = 90
  optional plantProduct String = 91
  optional oxyStatSamp OxyStatSampEnum = 92
  optional assemblyQuality String = 93
  repeated url String = 94
  optional faoClass FaoClassEnum = 95
  optional localClass String = 96
  optional localClassMeth String = 97
  soilType String = 98
  soilTypeMeth String = 99
  optional horizon HorizonEnum = 100
  optional horizonMeth String = 101
  optional linkClassInfo String = 102
  optional previousLandUse String = 103
  optional previousLandUseMeth String = 104
  optional cropRotation String = 105
  repeated agrochemAddition String = 106
  repeated tillage TillageEnum = 107
  optional fire Date = 108
  optional flooding Date = 109
  optional extremeEvent Date = 110
  optional linkClimateInfo String = 111
  optional annualTemp QuantityValue = 112
  optional seasonTemp QuantityValue = 113
  optional annualPrecpt QuantityValue = 114
  optional seasonPrecpt QuantityValue = 115
  optional curLandUse CurLandUseEnum = 116
  optional slopeGradient QuantityValue = 117
  optional slopeAspect QuantityValue = 118
  optional profilePosition ProfilePositionEnum = 119
  optional drainageClass DrainageClassEnum = 120
  storeCond String = 121
  optional phMeth String = 122
  optional curVegetation String = 123
  optional curVegetationMeth String = 124
  optional totOrgCarb QuantityValue = 125
  optional totOrgCMeth String = 126
  optional totNitro QuantityValue = 127
  optional totNMeth String = 128
  microbialBiomass QuantityValue = 129
  microbialBiomassMeth String = 130
  optional heavyMetalsMeth String = 131
  optional totCar QuantityValue = 132
  optional totPhos QuantityValue = 133
  sieving String = 134
  poolDnaExtracts String = 135
  repeated miscParam String = 136
  optional hostDiseaseStat String = 137
  specificHost String = 138
  pathogenicity String = 139
  optional bioticRelationship BioticRelationshipEnum = 140
  optional isolGrowthCondt String = 141
  sampMatProcess String = 142
  hostSpecRange Integer = 143
  optional trophicLevel TrophicLevelEnum = 144
  sampSize QuantityValue = 145
  seqMeth String = 146
  sampVolWeDnaExt QuantityValue = 147
  pcrPrimers String = 148
  nuclAcidExt String = 149
  nuclAcidAmp String = 150
  optional libSize Integer = 151
  libReadsSeqd Integer = 152
  optional libLayout LibLayoutEnum = 153
  libVector String = 154
  libScreen String = 155
  targetGene String = 156
  targetSubfragment String = 157
  mid String = 158
  adapters String = 159
  pcrCond String = 160
  optional seqQualityCheck String = 161
  chimeraCheck String = 162
  assemblyName String = 163
  optional assemblySoftware String = 164
  optional annot String = 165
  optional sop String = 166
  optional sourceMatId String = 167
  sampName String = 168
  sampTaxonId String = 169
  projectName String = 170
  optional experimentalFactor String = 171
  optional negContType NegContTypeEnum = 172
  optional posContType String = 173
  optional subspecfGenLin String = 174
  optional numReplicons Integer = 175
  optional estimatedSize String = 176
  optional refBiomaterial String = 177
  propagation String = 178
  optional encodedTraits String = 179
  optional sampCollecDevice String = 180
  optional sampCollecMethod String = 181
  optional virusEnrichAppr VirusEnrichApprEnum = 182
  optional taxIdent TaxIdentEnum = 183
  optional assemblyQual AssemblyQualEnum = 184
  optional numberContig Integer = 185
  optional featPred String = 186
  optional refDb String = 187
  optional simSearchMeth String = 188
  optional taxClass String = 189
  optional complScore String = 190
  optional complSoftware String = 191
  optional associatedResource String = 192
 }
// Combinatorial checklist Minimum Information About a Metagenome-Assembled Genome with environmental package agriculture
message AgricultureMIMAG
 {
  optional latLon String = 1
  optional alt QuantityValue = 2
  optional elev QuantityValue = 3
  optional geoLocName String = 4
  optional collectionDate Date = 5
  optional envBroadScale String = 6
  optional envLocalScale String = 7
  optional envMedium String = 8
  optional plantGrowthMed PlantGrowthMedEnum = 9
  optional soilHorizon SoilHorizonEnum = 10
  repeated photosyntActiv QuantityValue = 11
  repeated photosyntActivMeth String = 12
  optional sampCollectMethod String = 13
  optional enrichmentProtocol String = 14
  optional libraryPrepKit String = 15
  optional sequencingLocation String = 16
  optional temp QuantityValue = 17
  optional soilPH Double = 18
  optional soilConductivity QuantityValue = 19
  optional relLocation String = 20
  optional soilCover String = 21
  optional porosity String = 22
  optional texture QuantityValue = 23
  optional textureMeth String = 24
  repeated hostSymbiont String = 25
  optional presAnimalInsect String = 26
  optional plantWaterMethod String = 27
  repeated animWaterMethod String = 28
  repeated farmWaterSource FarmWaterSourceEnum = 29
  repeated waterSourceShared WaterSourceSharedEnum = 30
  optional waterPH Double = 31
  optional season String = 32
  optional solarIrradiance QuantityValue = 33
  optional cropYield String = 34
  optional seasonHumidity QuantityValue = 35
  optional humidity QuantityValue = 36
  repeated adjacentEnvironment String = 37
  repeated chemAdministration String = 38
  repeated foodProd String = 39
  repeated lotNumber String = 40
  optional fertilizerAdmin String = 41
  optional sampStorTemp QuantityValue = 42
  repeated foodTravMode String = 43
  repeated foodTravVehic String = 44
  repeated farmEquipSan String = 45
  repeated farmEquip String = 46
  repeated farmEquipShared String = 47
  repeated foodHarvestProc String = 48
  optional plantStruc String = 49
  optional hostDryMass QuantityValue = 50
  optional ancesData String = 51
  optional geneticMod String = 52
  optional foodProductType String = 53
  foodSource String = 54
  repeated spikeinStrain String = 55
  repeated organismCount OrganismCountEnum = 56
  optional sizeFracLow QuantityValue = 57
  optional sizeFracUp QuantityValue = 58
  optional cultIsolDate Date = 59
  repeated sampPooling String = 60
  optional rootMedMacronutr String = 61
  optional rootMedCarbon String = 62
  optional rootMedPh Double = 63
  depth QuantityValue = 64
  repeated waterTempRegm String = 65
  repeated wateringRegm String = 66
  repeated standingWaterRegm String = 67
  repeated gaseousEnvironment String = 68
  repeated fungicideRegm String = 69
  repeated climateEnvironment String = 70
  repeated herbicideRegm String = 71
  repeated nonMineralNutrRegm String = 72
  repeated pesticideRegm String = 73
  repeated phRegm String = 74
  repeated saltRegm String = 75
  repeated seasonEnvironment String = 76
  repeated perturbation String = 77
  sampStoreDur String = 78
  sampStoreLoc String = 79
  sampCollectDevice String = 80
  hostAge QuantityValue = 81
  hostCommonName String = 82
  hostGenotype String = 83
  hostHeight QuantityValue = 84
  repeated hostSubspecfGenlin String = 85
  hostLength QuantityValue = 86
  hostLifeStage String = 87
  hostPhenotype String = 88
  hostTaxid String = 89
  hostTotMass QuantityValue = 90
  optional plantProduct String = 91
  optional oxyStatSamp OxyStatSampEnum = 92
  optional assemblyQuality String = 93
  repeated url String = 94
  optional faoClass FaoClassEnum = 95
  optional localClass String = 96
  optional localClassMeth String = 97
  soilType String = 98
  soilTypeMeth String = 99
  optional horizon HorizonEnum = 100
  optional horizonMeth String = 101
  optional linkClassInfo String = 102
  optional previousLandUse String = 103
  optional previousLandUseMeth String = 104
  optional cropRotation String = 105
  repeated agrochemAddition String = 106
  repeated tillage TillageEnum = 107
  optional fire Date = 108
  optional flooding Date = 109
  optional extremeEvent Date = 110
  optional linkClimateInfo String = 111
  optional annualTemp QuantityValue = 112
  optional seasonTemp QuantityValue = 113
  optional annualPrecpt QuantityValue = 114
  optional seasonPrecpt QuantityValue = 115
  optional curLandUse CurLandUseEnum = 116
  optional slopeGradient QuantityValue = 117
  optional slopeAspect QuantityValue = 118
  optional profilePosition ProfilePositionEnum = 119
  optional drainageClass DrainageClassEnum = 120
  storeCond String = 121
  optional phMeth String = 122
  optional curVegetation String = 123
  optional curVegetationMeth String = 124
  optional totOrgCarb QuantityValue = 125
  optional totOrgCMeth String = 126
  optional totNitro QuantityValue = 127
  optional totNMeth String = 128
  microbialBiomass QuantityValue = 129
  microbialBiomassMeth String = 130
  optional heavyMetalsMeth String = 131
  optional totCar QuantityValue = 132
  optional totPhos QuantityValue = 133
  sieving String = 134
  poolDnaExtracts String = 135
  repeated miscParam String = 136
  optional hostDiseaseStat String = 137
  specificHost String = 138
  pathogenicity String = 139
  optional bioticRelationship BioticRelationshipEnum = 140
  optional isolGrowthCondt String = 141
  sampMatProcess String = 142
  hostSpecRange Integer = 143
  optional trophicLevel TrophicLevelEnum = 144
  sampSize QuantityValue = 145
  seqMeth String = 146
  sampVolWeDnaExt QuantityValue = 147
  pcrPrimers String = 148
  nuclAcidExt String = 149
  nuclAcidAmp String = 150
  optional libSize Integer = 151
  libReadsSeqd Integer = 152
  optional libLayout LibLayoutEnum = 153
  libVector String = 154
  libScreen String = 155
  targetGene String = 156
  targetSubfragment String = 157
  mid String = 158
  adapters String = 159
  pcrCond String = 160
  optional seqQualityCheck String = 161
  chimeraCheck String = 162
  assemblyName String = 163
  optional assemblySoftware String = 164
  optional annot String = 165
  optional sop String = 166
  optional sourceMatId String = 167
  sampName String = 168
  sampTaxonId String = 169
  projectName String = 170
  optional experimentalFactor String = 171
  optional negContType NegContTypeEnum = 172
  optional posContType String = 173
  optional refBiomaterial String = 174
  optional relToOxygen RelToOxygenEnum = 175
  optional sampCollecDevice String = 176
  optional sampCollecMethod String = 177
  optional sizeFrac String = 178
  taxIdent TaxIdentEnum = 179
  assemblyQual AssemblyQualEnum = 180
  optional numberContig Integer = 181
  optional featPred String = 182
  optional refDb String = 183
  optional simSearchMeth String = 184
  optional taxClass String = 185
  optional x16sRecover String = 186
  optional x16sRecoverSoftware String = 187
  optional trnas Integer = 188
  optional trnaExtSoftware String = 189
  complScore String = 190
  complSoftware String = 191
  optional complAppr ComplApprEnum = 192
  contamScore String = 193
  optional contamScreenInput String = 194
  optional contamScreenParam String = 195
  optional decontamSoftware DecontamSoftwareEnum = 196
  binParam BinParamEnum = 197
  binSoftware String = 198
  optional reassemblyBin String = 199
  optional magCovSoftware MagCovSoftwareEnum = 200
  optional associatedResource String = 201
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: specimen with environmental package agriculture
message AgricultureMIMARKSSpecimen
 {
  optional latLon String = 1
  optional alt QuantityValue = 2
  optional elev QuantityValue = 3
  optional geoLocName String = 4
  optional collectionDate Date = 5
  optional envBroadScale String = 6
  optional envLocalScale String = 7
  optional envMedium String = 8
  optional plantGrowthMed PlantGrowthMedEnum = 9
  optional soilHorizon SoilHorizonEnum = 10
  repeated photosyntActiv QuantityValue = 11
  repeated photosyntActivMeth String = 12
  optional sampCollectMethod String = 13
  optional enrichmentProtocol String = 14
  optional libraryPrepKit String = 15
  optional sequencingLocation String = 16
  optional temp QuantityValue = 17
  optional soilPH Double = 18
  optional soilConductivity QuantityValue = 19
  optional relLocation String = 20
  optional soilCover String = 21
  optional porosity String = 22
  optional texture QuantityValue = 23
  optional textureMeth String = 24
  repeated hostSymbiont String = 25
  optional presAnimalInsect String = 26
  optional plantWaterMethod String = 27
  repeated animWaterMethod String = 28
  repeated farmWaterSource FarmWaterSourceEnum = 29
  repeated waterSourceShared WaterSourceSharedEnum = 30
  optional waterPH Double = 31
  optional season String = 32
  optional solarIrradiance QuantityValue = 33
  optional cropYield String = 34
  optional seasonHumidity QuantityValue = 35
  optional humidity QuantityValue = 36
  repeated adjacentEnvironment String = 37
  repeated chemAdministration String = 38
  repeated foodProd String = 39
  repeated lotNumber String = 40
  optional fertilizerAdmin String = 41
  optional sampStorTemp QuantityValue = 42
  repeated foodTravMode String = 43
  repeated foodTravVehic String = 44
  repeated farmEquipSan String = 45
  repeated farmEquip String = 46
  repeated farmEquipShared String = 47
  repeated foodHarvestProc String = 48
  optional plantStruc String = 49
  optional hostDryMass QuantityValue = 50
  optional ancesData String = 51
  optional geneticMod String = 52
  optional foodProductType String = 53
  foodSource String = 54
  repeated spikeinStrain String = 55
  repeated organismCount OrganismCountEnum = 56
  optional sizeFracLow QuantityValue = 57
  optional sizeFracUp QuantityValue = 58
  optional cultIsolDate Date = 59
  repeated sampPooling String = 60
  optional rootMedMacronutr String = 61
  optional rootMedCarbon String = 62
  optional rootMedPh Double = 63
  depth QuantityValue = 64
  repeated waterTempRegm String = 65
  repeated wateringRegm String = 66
  repeated standingWaterRegm String = 67
  repeated gaseousEnvironment String = 68
  repeated fungicideRegm String = 69
  repeated climateEnvironment String = 70
  repeated herbicideRegm String = 71
  repeated nonMineralNutrRegm String = 72
  repeated pesticideRegm String = 73
  repeated phRegm String = 74
  repeated saltRegm String = 75
  repeated seasonEnvironment String = 76
  repeated perturbation String = 77
  sampStoreDur String = 78
  sampStoreLoc String = 79
  sampCollectDevice String = 80
  hostAge QuantityValue = 81
  hostCommonName String = 82
  hostGenotype String = 83
  hostHeight QuantityValue = 84
  repeated hostSubspecfGenlin String = 85
  hostLength QuantityValue = 86
  hostLifeStage String = 87
  hostPhenotype String = 88
  hostTaxid String = 89
  hostTotMass QuantityValue = 90
  optional plantProduct String = 91
  optional oxyStatSamp OxyStatSampEnum = 92
  optional assemblyQuality String = 93
  repeated url String = 94
  optional faoClass FaoClassEnum = 95
  optional localClass String = 96
  optional localClassMeth String = 97
  soilType String = 98
  soilTypeMeth String = 99
  optional horizon HorizonEnum = 100
  optional horizonMeth String = 101
  optional linkClassInfo String = 102
  optional previousLandUse String = 103
  optional previousLandUseMeth String = 104
  optional cropRotation String = 105
  repeated agrochemAddition String = 106
  repeated tillage TillageEnum = 107
  optional fire Date = 108
  optional flooding Date = 109
  optional extremeEvent Date = 110
  optional linkClimateInfo String = 111
  optional annualTemp QuantityValue = 112
  optional seasonTemp QuantityValue = 113
  optional annualPrecpt QuantityValue = 114
  optional seasonPrecpt QuantityValue = 115
  optional curLandUse CurLandUseEnum = 116
  optional slopeGradient QuantityValue = 117
  optional slopeAspect QuantityValue = 118
  optional profilePosition ProfilePositionEnum = 119
  optional drainageClass DrainageClassEnum = 120
  storeCond String = 121
  optional phMeth String = 122
  optional curVegetation String = 123
  optional curVegetationMeth String = 124
  optional totOrgCarb QuantityValue = 125
  optional totOrgCMeth String = 126
  optional totNitro QuantityValue = 127
  optional totNMeth String = 128
  microbialBiomass QuantityValue = 129
  microbialBiomassMeth String = 130
  optional heavyMetalsMeth String = 131
  optional totCar QuantityValue = 132
  optional totPhos QuantityValue = 133
  sieving String = 134
  poolDnaExtracts String = 135
  repeated miscParam String = 136
  optional hostDiseaseStat String = 137
  specificHost String = 138
  pathogenicity String = 139
  optional bioticRelationship BioticRelationshipEnum = 140
  optional isolGrowthCondt String = 141
  sampMatProcess String = 142
  hostSpecRange Integer = 143
  optional trophicLevel TrophicLevelEnum = 144
  sampSize QuantityValue = 145
  seqMeth String = 146
  sampVolWeDnaExt QuantityValue = 147
  pcrPrimers String = 148
  nuclAcidExt String = 149
  nuclAcidAmp String = 150
  optional libSize Integer = 151
  libReadsSeqd Integer = 152
  optional libLayout LibLayoutEnum = 153
  libVector String = 154
  libScreen String = 155
  targetGene String = 156
  targetSubfragment String = 157
  mid String = 158
  adapters String = 159
  pcrCond String = 160
  optional seqQualityCheck String = 161
  chimeraCheck String = 162
  assemblyName String = 163
  optional assemblySoftware String = 164
  optional annot String = 165
  optional sop String = 166
  optional sourceMatId String = 167
  sampName String = 168
  sampTaxonId String = 169
  projectName String = 170
  optional experimentalFactor String = 171
  optional negContType NegContTypeEnum = 172
  optional posContType String = 173
  optional relToOxygen RelToOxygenEnum = 174
  optional sampCollecDevice String = 175
  optional sampCollecMethod String = 176
  optional sizeFrac String = 177
  optional associatedResource String = 178
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: survey with environmental package agriculture
message AgricultureMIMARKSSurvey
 {
  optional latLon String = 1
  optional alt QuantityValue = 2
  optional elev QuantityValue = 3
  optional geoLocName String = 4
  optional collectionDate Date = 5
  optional envBroadScale String = 6
  optional envLocalScale String = 7
  optional envMedium String = 8
  optional plantGrowthMed PlantGrowthMedEnum = 9
  optional soilHorizon SoilHorizonEnum = 10
  repeated photosyntActiv QuantityValue = 11
  repeated photosyntActivMeth String = 12
  optional sampCollectMethod String = 13
  optional enrichmentProtocol String = 14
  optional libraryPrepKit String = 15
  optional sequencingLocation String = 16
  optional temp QuantityValue = 17
  optional soilPH Double = 18
  optional soilConductivity QuantityValue = 19
  optional relLocation String = 20
  optional soilCover String = 21
  optional porosity String = 22
  optional texture QuantityValue = 23
  optional textureMeth String = 24
  repeated hostSymbiont String = 25
  optional presAnimalInsect String = 26
  optional plantWaterMethod String = 27
  repeated animWaterMethod String = 28
  repeated farmWaterSource FarmWaterSourceEnum = 29
  repeated waterSourceShared WaterSourceSharedEnum = 30
  optional waterPH Double = 31
  optional season String = 32
  optional solarIrradiance QuantityValue = 33
  optional cropYield String = 34
  optional seasonHumidity QuantityValue = 35
  optional humidity QuantityValue = 36
  repeated adjacentEnvironment String = 37
  repeated chemAdministration String = 38
  repeated foodProd String = 39
  repeated lotNumber String = 40
  optional fertilizerAdmin String = 41
  optional sampStorTemp QuantityValue = 42
  repeated foodTravMode String = 43
  repeated foodTravVehic String = 44
  repeated farmEquipSan String = 45
  repeated farmEquip String = 46
  repeated farmEquipShared String = 47
  repeated foodHarvestProc String = 48
  optional plantStruc String = 49
  optional hostDryMass QuantityValue = 50
  optional ancesData String = 51
  optional geneticMod String = 52
  optional foodProductType String = 53
  foodSource String = 54
  repeated spikeinStrain String = 55
  repeated organismCount OrganismCountEnum = 56
  optional sizeFracLow QuantityValue = 57
  optional sizeFracUp QuantityValue = 58
  optional cultIsolDate Date = 59
  repeated sampPooling String = 60
  optional rootMedMacronutr String = 61
  optional rootMedCarbon String = 62
  optional rootMedPh Double = 63
  depth QuantityValue = 64
  repeated waterTempRegm String = 65
  repeated wateringRegm String = 66
  repeated standingWaterRegm String = 67
  repeated gaseousEnvironment String = 68
  repeated fungicideRegm String = 69
  repeated climateEnvironment String = 70
  repeated herbicideRegm String = 71
  repeated nonMineralNutrRegm String = 72
  repeated pesticideRegm String = 73
  repeated phRegm String = 74
  repeated saltRegm String = 75
  repeated seasonEnvironment String = 76
  repeated perturbation String = 77
  sampStoreDur String = 78
  sampStoreLoc String = 79
  sampCollectDevice String = 80
  hostAge QuantityValue = 81
  hostCommonName String = 82
  hostGenotype String = 83
  hostHeight QuantityValue = 84
  repeated hostSubspecfGenlin String = 85
  hostLength QuantityValue = 86
  hostLifeStage String = 87
  hostPhenotype String = 88
  hostTaxid String = 89
  hostTotMass QuantityValue = 90
  optional plantProduct String = 91
  optional oxyStatSamp OxyStatSampEnum = 92
  optional assemblyQuality String = 93
  repeated url String = 94
  optional faoClass FaoClassEnum = 95
  optional localClass String = 96
  optional localClassMeth String = 97
  soilType String = 98
  soilTypeMeth String = 99
  optional horizon HorizonEnum = 100
  optional horizonMeth String = 101
  optional linkClassInfo String = 102
  optional previousLandUse String = 103
  optional previousLandUseMeth String = 104
  optional cropRotation String = 105
  repeated agrochemAddition String = 106
  repeated tillage TillageEnum = 107
  optional fire Date = 108
  optional flooding Date = 109
  optional extremeEvent Date = 110
  optional linkClimateInfo String = 111
  optional annualTemp QuantityValue = 112
  optional seasonTemp QuantityValue = 113
  optional annualPrecpt QuantityValue = 114
  optional seasonPrecpt QuantityValue = 115
  optional curLandUse CurLandUseEnum = 116
  optional slopeGradient QuantityValue = 117
  optional slopeAspect QuantityValue = 118
  optional profilePosition ProfilePositionEnum = 119
  optional drainageClass DrainageClassEnum = 120
  storeCond String = 121
  optional phMeth String = 122
  optional curVegetation String = 123
  optional curVegetationMeth String = 124
  optional totOrgCarb QuantityValue = 125
  optional totOrgCMeth String = 126
  optional totNitro QuantityValue = 127
  optional totNMeth String = 128
  microbialBiomass QuantityValue = 129
  microbialBiomassMeth String = 130
  optional heavyMetalsMeth String = 131
  optional totCar QuantityValue = 132
  optional totPhos QuantityValue = 133
  sieving String = 134
  poolDnaExtracts String = 135
  repeated miscParam String = 136
  optional hostDiseaseStat String = 137
  specificHost String = 138
  pathogenicity String = 139
  optional bioticRelationship BioticRelationshipEnum = 140
  optional isolGrowthCondt String = 141
  sampMatProcess String = 142
  hostSpecRange Integer = 143
  optional trophicLevel TrophicLevelEnum = 144
  sampSize QuantityValue = 145
  seqMeth String = 146
  sampVolWeDnaExt QuantityValue = 147
  pcrPrimers String = 148
  nuclAcidExt String = 149
  nuclAcidAmp String = 150
  optional libSize Integer = 151
  libReadsSeqd Integer = 152
  optional libLayout LibLayoutEnum = 153
  libVector String = 154
  libScreen String = 155
  targetGene String = 156
  targetSubfragment String = 157
  mid String = 158
  adapters String = 159
  pcrCond String = 160
  optional seqQualityCheck String = 161
  chimeraCheck String = 162
  assemblyName String = 163
  optional assemblySoftware String = 164
  optional annot String = 165
  optional sop String = 166
  optional sourceMatId String = 167
  sampName String = 168
  sampTaxonId String = 169
  projectName String = 170
  optional experimentalFactor String = 171
  optional negContType NegContTypeEnum = 172
  optional posContType String = 173
  optional subspecfGenLin String = 174
  optional extrachromElements Integer = 175
  optional relToOxygen RelToOxygenEnum = 176
  optional sampCollecDevice String = 177
  optional sampCollecMethod String = 178
  optional associatedResource String = 179
 }
// Combinatorial checklist Metagenome or Environmental with environmental package agriculture
message AgricultureMIMS
 {
  optional latLon String = 1
  optional alt QuantityValue = 2
  optional elev QuantityValue = 3
  optional geoLocName String = 4
  optional collectionDate Date = 5
  optional envBroadScale String = 6
  optional envLocalScale String = 7
  optional envMedium String = 8
  optional plantGrowthMed PlantGrowthMedEnum = 9
  optional soilHorizon SoilHorizonEnum = 10
  repeated photosyntActiv QuantityValue = 11
  repeated photosyntActivMeth String = 12
  optional sampCollectMethod String = 13
  optional enrichmentProtocol String = 14
  optional libraryPrepKit String = 15
  optional sequencingLocation String = 16
  optional temp QuantityValue = 17
  optional soilPH Double = 18
  optional soilConductivity QuantityValue = 19
  optional relLocation String = 20
  optional soilCover String = 21
  optional porosity String = 22
  optional texture QuantityValue = 23
  optional textureMeth String = 24
  repeated hostSymbiont String = 25
  optional presAnimalInsect String = 26
  optional plantWaterMethod String = 27
  repeated animWaterMethod String = 28
  repeated farmWaterSource FarmWaterSourceEnum = 29
  repeated waterSourceShared WaterSourceSharedEnum = 30
  optional waterPH Double = 31
  optional season String = 32
  optional solarIrradiance QuantityValue = 33
  optional cropYield String = 34
  optional seasonHumidity QuantityValue = 35
  optional humidity QuantityValue = 36
  repeated adjacentEnvironment String = 37
  repeated chemAdministration String = 38
  repeated foodProd String = 39
  repeated lotNumber String = 40
  optional fertilizerAdmin String = 41
  optional sampStorTemp QuantityValue = 42
  repeated foodTravMode String = 43
  repeated foodTravVehic String = 44
  repeated farmEquipSan String = 45
  repeated farmEquip String = 46
  repeated farmEquipShared String = 47
  repeated foodHarvestProc String = 48
  optional plantStruc String = 49
  optional hostDryMass QuantityValue = 50
  optional ancesData String = 51
  optional geneticMod String = 52
  optional foodProductType String = 53
  foodSource String = 54
  repeated spikeinStrain String = 55
  repeated organismCount OrganismCountEnum = 56
  optional sizeFracLow QuantityValue = 57
  optional sizeFracUp QuantityValue = 58
  optional cultIsolDate Date = 59
  repeated sampPooling String = 60
  optional rootMedMacronutr String = 61
  optional rootMedCarbon String = 62
  optional rootMedPh Double = 63
  depth QuantityValue = 64
  repeated waterTempRegm String = 65
  repeated wateringRegm String = 66
  repeated standingWaterRegm String = 67
  repeated gaseousEnvironment String = 68
  repeated fungicideRegm String = 69
  repeated climateEnvironment String = 70
  repeated herbicideRegm String = 71
  repeated nonMineralNutrRegm String = 72
  repeated pesticideRegm String = 73
  repeated phRegm String = 74
  repeated saltRegm String = 75
  repeated seasonEnvironment String = 76
  repeated perturbation String = 77
  sampStoreDur String = 78
  sampStoreLoc String = 79
  sampCollectDevice String = 80
  hostAge QuantityValue = 81
  hostCommonName String = 82
  hostGenotype String = 83
  hostHeight QuantityValue = 84
  repeated hostSubspecfGenlin String = 85
  hostLength QuantityValue = 86
  hostLifeStage String = 87
  hostPhenotype String = 88
  hostTaxid String = 89
  hostTotMass QuantityValue = 90
  optional plantProduct String = 91
  optional oxyStatSamp OxyStatSampEnum = 92
  optional assemblyQuality String = 93
  repeated url String = 94
  optional faoClass FaoClassEnum = 95
  optional localClass String = 96
  optional localClassMeth String = 97
  soilType String = 98
  soilTypeMeth String = 99
  optional horizon HorizonEnum = 100
  optional horizonMeth String = 101
  optional linkClassInfo String = 102
  optional previousLandUse String = 103
  optional previousLandUseMeth String = 104
  optional cropRotation String = 105
  repeated agrochemAddition String = 106
  repeated tillage TillageEnum = 107
  optional fire Date = 108
  optional flooding Date = 109
  optional extremeEvent Date = 110
  optional linkClimateInfo String = 111
  optional annualTemp QuantityValue = 112
  optional seasonTemp QuantityValue = 113
  optional annualPrecpt QuantityValue = 114
  optional seasonPrecpt QuantityValue = 115
  optional curLandUse CurLandUseEnum = 116
  optional slopeGradient QuantityValue = 117
  optional slopeAspect QuantityValue = 118
  optional profilePosition ProfilePositionEnum = 119
  optional drainageClass DrainageClassEnum = 120
  storeCond String = 121
  optional phMeth String = 122
  optional curVegetation String = 123
  optional curVegetationMeth String = 124
  optional totOrgCarb QuantityValue = 125
  optional totOrgCMeth String = 126
  optional totNitro QuantityValue = 127
  optional totNMeth String = 128
  microbialBiomass QuantityValue = 129
  microbialBiomassMeth String = 130
  optional heavyMetalsMeth String = 131
  optional totCar QuantityValue = 132
  optional totPhos QuantityValue = 133
  sieving String = 134
  poolDnaExtracts String = 135
  repeated miscParam String = 136
  optional hostDiseaseStat String = 137
  specificHost String = 138
  pathogenicity String = 139
  optional bioticRelationship BioticRelationshipEnum = 140
  optional isolGrowthCondt String = 141
  sampMatProcess String = 142
  hostSpecRange Integer = 143
  optional trophicLevel TrophicLevelEnum = 144
  sampSize QuantityValue = 145
  seqMeth String = 146
  sampVolWeDnaExt QuantityValue = 147
  pcrPrimers String = 148
  nuclAcidExt String = 149
  nuclAcidAmp String = 150
  optional libSize Integer = 151
  libReadsSeqd Integer = 152
  optional libLayout LibLayoutEnum = 153
  libVector String = 154
  libScreen String = 155
  targetGene String = 156
  targetSubfragment String = 157
  mid String = 158
  adapters String = 159
  pcrCond String = 160
  optional seqQualityCheck String = 161
  chimeraCheck String = 162
  assemblyName String = 163
  optional assemblySoftware String = 164
  optional annot String = 165
  optional sop String = 166
  optional sourceMatId String = 167
  sampName String = 168
  sampTaxonId String = 169
  projectName String = 170
  optional experimentalFactor String = 171
  optional negContType NegContTypeEnum = 172
  optional posContType String = 173
  optional refBiomaterial String = 174
  optional relToOxygen RelToOxygenEnum = 175
  optional sampCollecDevice String = 176
  optional sampCollecMethod String = 177
  optional sizeFrac String = 178
  optional assemblyQual AssemblyQualEnum = 179
  optional numberContig Integer = 180
  optional featPred String = 181
  optional refDb String = 182
  optional simSearchMeth String = 183
  optional taxClass String = 184
  optional associatedResource String = 185
 }
// Combinatorial checklist Minimum Information About a Single Amplified Genome with environmental package agriculture
message AgricultureMISAG
 {
  optional latLon String = 1
  optional alt QuantityValue = 2
  optional elev QuantityValue = 3
  optional geoLocName String = 4
  optional collectionDate Date = 5
  optional envBroadScale String = 6
  optional envLocalScale String = 7
  optional envMedium String = 8
  optional plantGrowthMed PlantGrowthMedEnum = 9
  optional soilHorizon SoilHorizonEnum = 10
  repeated photosyntActiv QuantityValue = 11
  repeated photosyntActivMeth String = 12
  optional sampCollectMethod String = 13
  optional enrichmentProtocol String = 14
  optional libraryPrepKit String = 15
  optional sequencingLocation String = 16
  optional temp QuantityValue = 17
  optional soilPH Double = 18
  optional soilConductivity QuantityValue = 19
  optional relLocation String = 20
  optional soilCover String = 21
  optional porosity String = 22
  optional texture QuantityValue = 23
  optional textureMeth String = 24
  repeated hostSymbiont String = 25
  optional presAnimalInsect String = 26
  optional plantWaterMethod String = 27
  repeated animWaterMethod String = 28
  repeated farmWaterSource FarmWaterSourceEnum = 29
  repeated waterSourceShared WaterSourceSharedEnum = 30
  optional waterPH Double = 31
  optional season String = 32
  optional solarIrradiance QuantityValue = 33
  optional cropYield String = 34
  optional seasonHumidity QuantityValue = 35
  optional humidity QuantityValue = 36
  repeated adjacentEnvironment String = 37
  repeated chemAdministration String = 38
  repeated foodProd String = 39
  repeated lotNumber String = 40
  optional fertilizerAdmin String = 41
  optional sampStorTemp QuantityValue = 42
  repeated foodTravMode String = 43
  repeated foodTravVehic String = 44
  repeated farmEquipSan String = 45
  repeated farmEquip String = 46
  repeated farmEquipShared String = 47
  repeated foodHarvestProc String = 48
  optional plantStruc String = 49
  optional hostDryMass QuantityValue = 50
  optional ancesData String = 51
  optional geneticMod String = 52
  optional foodProductType String = 53
  foodSource String = 54
  repeated spikeinStrain String = 55
  repeated organismCount OrganismCountEnum = 56
  optional sizeFracLow QuantityValue = 57
  optional sizeFracUp QuantityValue = 58
  optional cultIsolDate Date = 59
  repeated sampPooling String = 60
  optional rootMedMacronutr String = 61
  optional rootMedCarbon String = 62
  optional rootMedPh Double = 63
  depth QuantityValue = 64
  repeated waterTempRegm String = 65
  repeated wateringRegm String = 66
  repeated standingWaterRegm String = 67
  repeated gaseousEnvironment String = 68
  repeated fungicideRegm String = 69
  repeated climateEnvironment String = 70
  repeated herbicideRegm String = 71
  repeated nonMineralNutrRegm String = 72
  repeated pesticideRegm String = 73
  repeated phRegm String = 74
  repeated saltRegm String = 75
  repeated seasonEnvironment String = 76
  repeated perturbation String = 77
  sampStoreDur String = 78
  sampStoreLoc String = 79
  sampCollectDevice String = 80
  hostAge QuantityValue = 81
  hostCommonName String = 82
  hostGenotype String = 83
  hostHeight QuantityValue = 84
  repeated hostSubspecfGenlin String = 85
  hostLength QuantityValue = 86
  hostLifeStage String = 87
  hostPhenotype String = 88
  hostTaxid String = 89
  hostTotMass QuantityValue = 90
  optional plantProduct String = 91
  optional oxyStatSamp OxyStatSampEnum = 92
  optional assemblyQuality String = 93
  repeated url String = 94
  optional faoClass FaoClassEnum = 95
  optional localClass String = 96
  optional localClassMeth String = 97
  soilType String = 98
  soilTypeMeth String = 99
  optional horizon HorizonEnum = 100
  optional horizonMeth String = 101
  optional linkClassInfo String = 102
  optional previousLandUse String = 103
  optional previousLandUseMeth String = 104
  optional cropRotation String = 105
  repeated agrochemAddition String = 106
  repeated tillage TillageEnum = 107
  optional fire Date = 108
  optional flooding Date = 109
  optional extremeEvent Date = 110
  optional linkClimateInfo String = 111
  optional annualTemp QuantityValue = 112
  optional seasonTemp QuantityValue = 113
  optional annualPrecpt QuantityValue = 114
  optional seasonPrecpt QuantityValue = 115
  optional curLandUse CurLandUseEnum = 116
  optional slopeGradient QuantityValue = 117
  optional slopeAspect QuantityValue = 118
  optional profilePosition ProfilePositionEnum = 119
  optional drainageClass DrainageClassEnum = 120
  storeCond String = 121
  optional phMeth String = 122
  optional curVegetation String = 123
  optional curVegetationMeth String = 124
  optional totOrgCarb QuantityValue = 125
  optional totOrgCMeth String = 126
  optional totNitro QuantityValue = 127
  optional totNMeth String = 128
  microbialBiomass QuantityValue = 129
  microbialBiomassMeth String = 130
  optional heavyMetalsMeth String = 131
  optional totCar QuantityValue = 132
  optional totPhos QuantityValue = 133
  sieving String = 134
  poolDnaExtracts String = 135
  repeated miscParam String = 136
  optional hostDiseaseStat String = 137
  specificHost String = 138
  pathogenicity String = 139
  optional bioticRelationship BioticRelationshipEnum = 140
  optional isolGrowthCondt String = 141
  sampMatProcess String = 142
  hostSpecRange Integer = 143
  optional trophicLevel TrophicLevelEnum = 144
  sampSize QuantityValue = 145
  seqMeth String = 146
  sampVolWeDnaExt QuantityValue = 147
  pcrPrimers String = 148
  nuclAcidExt String = 149
  nuclAcidAmp String = 150
  optional libSize Integer = 151
  libReadsSeqd Integer = 152
  optional libLayout LibLayoutEnum = 153
  libVector String = 154
  libScreen String = 155
  targetGene String = 156
  targetSubfragment String = 157
  mid String = 158
  adapters String = 159
  pcrCond String = 160
  optional seqQualityCheck String = 161
  chimeraCheck String = 162
  assemblyName String = 163
  optional assemblySoftware String = 164
  optional annot String = 165
  optional sop String = 166
  optional sourceMatId String = 167
  sampName String = 168
  sampTaxonId String = 169
  projectName String = 170
  optional experimentalFactor String = 171
  optional negContType NegContTypeEnum = 172
  optional posContType String = 173
  optional refBiomaterial String = 174
  optional relToOxygen RelToOxygenEnum = 175
  optional sampCollecDevice String = 176
  optional sampCollecMethod String = 177
  optional sizeFrac String = 178
  taxIdent TaxIdentEnum = 179
  assemblyQual AssemblyQualEnum = 180
  optional numberContig Integer = 181
  optional featPred String = 182
  optional refDb String = 183
  optional simSearchMeth String = 184
  optional taxClass String = 185
  optional x16sRecover String = 186
  optional x16sRecoverSoftware String = 187
  optional trnas Integer = 188
  optional trnaExtSoftware String = 189
  complScore String = 190
  complSoftware String = 191
  optional complAppr ComplApprEnum = 192
  contamScore String = 193
  optional contamScreenInput String = 194
  optional contamScreenParam String = 195
  optional decontamSoftware DecontamSoftwareEnum = 196
  sortTech SortTechEnum = 197
  singleCellLysisAppr SingleCellLysisApprEnum = 198
  optional singleCellLysisProt String = 199
  wgaAmpAppr String = 200
  optional wgaAmpKit String = 201
  optional associatedResource String = 202
 }
// Combinatorial checklist Minimum Information About an Uncultivated Virus Genome with environmental package agriculture
message AgricultureMIUVIG
 {
  optional latLon String = 1
  optional alt QuantityValue = 2
  optional elev QuantityValue = 3
  optional geoLocName String = 4
  optional collectionDate Date = 5
  optional envBroadScale String = 6
  optional envLocalScale String = 7
  optional envMedium String = 8
  optional plantGrowthMed PlantGrowthMedEnum = 9
  optional soilHorizon SoilHorizonEnum = 10
  repeated photosyntActiv QuantityValue = 11
  repeated photosyntActivMeth String = 12
  optional sampCollectMethod String = 13
  optional enrichmentProtocol String = 14
  optional libraryPrepKit String = 15
  optional sequencingLocation String = 16
  optional temp QuantityValue = 17
  optional soilPH Double = 18
  optional soilConductivity QuantityValue = 19
  optional relLocation String = 20
  optional soilCover String = 21
  optional porosity String = 22
  optional texture QuantityValue = 23
  optional textureMeth String = 24
  repeated hostSymbiont String = 25
  optional presAnimalInsect String = 26
  optional plantWaterMethod String = 27
  repeated animWaterMethod String = 28
  repeated farmWaterSource FarmWaterSourceEnum = 29
  repeated waterSourceShared WaterSourceSharedEnum = 30
  optional waterPH Double = 31
  optional season String = 32
  optional solarIrradiance QuantityValue = 33
  optional cropYield String = 34
  optional seasonHumidity QuantityValue = 35
  optional humidity QuantityValue = 36
  repeated adjacentEnvironment String = 37
  repeated chemAdministration String = 38
  repeated foodProd String = 39
  repeated lotNumber String = 40
  optional fertilizerAdmin String = 41
  optional sampStorTemp QuantityValue = 42
  repeated foodTravMode String = 43
  repeated foodTravVehic String = 44
  repeated farmEquipSan String = 45
  repeated farmEquip String = 46
  repeated farmEquipShared String = 47
  repeated foodHarvestProc String = 48
  optional plantStruc String = 49
  optional hostDryMass QuantityValue = 50
  optional ancesData String = 51
  optional geneticMod String = 52
  optional foodProductType String = 53
  foodSource String = 54
  repeated spikeinStrain String = 55
  repeated organismCount OrganismCountEnum = 56
  optional sizeFracLow QuantityValue = 57
  optional sizeFracUp QuantityValue = 58
  optional cultIsolDate Date = 59
  repeated sampPooling String = 60
  optional rootMedMacronutr String = 61
  optional rootMedCarbon String = 62
  optional rootMedPh Double = 63
  depth QuantityValue = 64
  repeated waterTempRegm String = 65
  repeated wateringRegm String = 66
  repeated standingWaterRegm String = 67
  repeated gaseousEnvironment String = 68
  repeated fungicideRegm String = 69
  repeated climateEnvironment String = 70
  repeated herbicideRegm String = 71
  repeated nonMineralNutrRegm String = 72
  repeated pesticideRegm String = 73
  repeated phRegm String = 74
  repeated saltRegm String = 75
  repeated seasonEnvironment String = 76
  repeated perturbation String = 77
  sampStoreDur String = 78
  sampStoreLoc String = 79
  sampCollectDevice String = 80
  hostAge QuantityValue = 81
  hostCommonName String = 82
  hostGenotype String = 83
  hostHeight QuantityValue = 84
  repeated hostSubspecfGenlin String = 85
  hostLength QuantityValue = 86
  hostLifeStage String = 87
  hostPhenotype String = 88
  hostTaxid String = 89
  hostTotMass QuantityValue = 90
  optional plantProduct String = 91
  optional oxyStatSamp OxyStatSampEnum = 92
  optional assemblyQuality String = 93
  repeated url String = 94
  optional faoClass FaoClassEnum = 95
  optional localClass String = 96
  optional localClassMeth String = 97
  soilType String = 98
  soilTypeMeth String = 99
  optional horizon HorizonEnum = 100
  optional horizonMeth String = 101
  optional linkClassInfo String = 102
  optional previousLandUse String = 103
  optional previousLandUseMeth String = 104
  optional cropRotation String = 105
  repeated agrochemAddition String = 106
  repeated tillage TillageEnum = 107
  optional fire Date = 108
  optional flooding Date = 109
  optional extremeEvent Date = 110
  optional linkClimateInfo String = 111
  optional annualTemp QuantityValue = 112
  optional seasonTemp QuantityValue = 113
  optional annualPrecpt QuantityValue = 114
  optional seasonPrecpt QuantityValue = 115
  optional curLandUse CurLandUseEnum = 116
  optional slopeGradient QuantityValue = 117
  optional slopeAspect QuantityValue = 118
  optional profilePosition ProfilePositionEnum = 119
  optional drainageClass DrainageClassEnum = 120
  storeCond String = 121
  optional phMeth String = 122
  optional curVegetation String = 123
  optional curVegetationMeth String = 124
  optional totOrgCarb QuantityValue = 125
  optional totOrgCMeth String = 126
  optional totNitro QuantityValue = 127
  optional totNMeth String = 128
  microbialBiomass QuantityValue = 129
  microbialBiomassMeth String = 130
  optional heavyMetalsMeth String = 131
  optional totCar QuantityValue = 132
  optional totPhos QuantityValue = 133
  sieving String = 134
  poolDnaExtracts String = 135
  repeated miscParam String = 136
  optional hostDiseaseStat String = 137
  specificHost String = 138
  pathogenicity String = 139
  optional bioticRelationship BioticRelationshipEnum = 140
  optional isolGrowthCondt String = 141
  sampMatProcess String = 142
  hostSpecRange Integer = 143
  optional trophicLevel TrophicLevelEnum = 144
  sampSize QuantityValue = 145
  seqMeth String = 146
  sampVolWeDnaExt QuantityValue = 147
  pcrPrimers String = 148
  nuclAcidExt String = 149
  nuclAcidAmp String = 150
  optional libSize Integer = 151
  libReadsSeqd Integer = 152
  optional libLayout LibLayoutEnum = 153
  libVector String = 154
  libScreen String = 155
  targetGene String = 156
  targetSubfragment String = 157
  mid String = 158
  adapters String = 159
  pcrCond String = 160
  optional seqQualityCheck String = 161
  chimeraCheck String = 162
  assemblyName String = 163
  optional assemblySoftware String = 164
  optional annot String = 165
  optional sop String = 166
  optional sourceMatId String = 167
  sampName String = 168
  sampTaxonId String = 169
  projectName String = 170
  optional experimentalFactor String = 171
  optional negContType NegContTypeEnum = 172
  optional posContType String = 173
  optional estimatedSize String = 174
  optional refBiomaterial String = 175
  optional sampCollecDevice String = 176
  optional sampCollecMethod String = 177
  optional sizeFrac String = 178
  sourceUvig SourceUvigEnum = 179
  virusEnrichAppr VirusEnrichApprEnum = 180
  optional taxIdent TaxIdentEnum = 181
  assemblyQual AssemblyQualEnum = 182
  numberContig Integer = 183
  optional featPred String = 184
  optional refDb String = 185
  optional simSearchMeth String = 186
  optional taxClass String = 187
  optional trnas Integer = 188
  optional trnaExtSoftware String = 189
  optional complScore String = 190
  optional complSoftware String = 191
  optional complAppr ComplApprEnum = 192
  optional sortTech SortTechEnum = 193
  optional singleCellLysisAppr SingleCellLysisApprEnum = 194
  optional singleCellLysisProt String = 195
  optional wgaAmpAppr String = 196
  optional wgaAmpKit String = 197
  optional binParam BinParamEnum = 198
  optional binSoftware String = 199
  optional reassemblyBin String = 200
  optional magCovSoftware MagCovSoftwareEnum = 201
  virIdentSoftware String = 202
  predGenomeType PredGenomeTypeEnum = 203
  predGenomeStruc PredGenomeStrucEnum = 204
  detecType String = 205
  optional otuClassAppr String = 206
  optional otuSeqCompAppr String = 207
  optional otuDb String = 208
  optional hostPredAppr HostPredApprEnum = 209
  optional hostPredEstAcc String = 210
  optional associatedResource String = 211
 }
// air
message Air
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional barometricPress QuantityValue = 11
  optional carbDioxide QuantityValue = 12
  optional carbMonoxide QuantityValue = 13
  repeated chemAdministration String = 14
  optional humidity QuantityValue = 15
  optional methane QuantityValue = 16
  repeated organismCount OrganismCountEnum = 17
  optional oxygen QuantityValue = 18
  optional oxyStatSamp OxyStatSampEnum = 19
  repeated perturbation String = 20
  repeated pollutants String = 21
  repeated airParticulateMatterConcentration String = 22
  optional salinity QuantityValue = 23
  optional sampStoreDur String = 24
  optional sampStoreLoc String = 25
  optional sampStoreTemp QuantityValue = 26
  optional solarIrradiance QuantityValue = 27
  optional ventilationRate QuantityValue = 28
  optional ventilationType String = 29
  repeated volatileOrgComp String = 30
  optional windDirection String = 31
  optional windSpeed QuantityValue = 32
  repeated miscParam String = 33
  sampName String = 34
  projectName String = 35
  optional sampVolWeDnaExt QuantityValue = 36
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package air
message AirMIGSBacteria
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional barometricPress QuantityValue = 11
  optional carbDioxide QuantityValue = 12
  optional carbMonoxide QuantityValue = 13
  repeated chemAdministration String = 14
  optional humidity QuantityValue = 15
  optional methane QuantityValue = 16
  repeated organismCount OrganismCountEnum = 17
  optional oxygen QuantityValue = 18
  optional oxyStatSamp OxyStatSampEnum = 19
  repeated perturbation String = 20
  repeated pollutants String = 21
  repeated airParticulateMatterConcentration String = 22
  optional salinity QuantityValue = 23
  optional sampStoreDur String = 24
  optional sampStoreLoc String = 25
  optional sampStoreTemp QuantityValue = 26
  optional solarIrradiance QuantityValue = 27
  optional ventilationRate QuantityValue = 28
  optional ventilationType String = 29
  repeated volatileOrgComp String = 30
  optional windDirection String = 31
  optional windSpeed QuantityValue = 32
  repeated miscParam String = 33
  sampName String = 34
  projectName String = 35
  optional sampVolWeDnaExt QuantityValue = 36
  sampTaxonId String = 37
  optional experimentalFactor String = 38
  optional negContType NegContTypeEnum = 39
  optional posContType String = 40
  optional subspecfGenLin String = 41
  numReplicons Integer = 42
  optional extrachromElements Integer = 43
  optional estimatedSize String = 44
  refBiomaterial String = 45
  optional sourceMatId String = 46
  optional pathogenicity String = 47
  optional bioticRelationship BioticRelationshipEnum = 48
  optional specificHost String = 49
  optional hostSpecRange Integer = 50
  optional hostDiseaseStat String = 51
  optional trophicLevel TrophicLevelEnum = 52
  optional encodedTraits String = 53
  optional relToOxygen RelToOxygenEnum = 54
  isolGrowthCondt String = 55
  optional sampCollecDevice String = 56
  optional sampCollecMethod String = 57
  optional sampMatProcess String = 58
  optional sampSize QuantityValue = 59
  optional nuclAcidExt String = 60
  optional nuclAcidAmp String = 61
  optional libSize Integer = 62
  optional libReadsSeqd Integer = 63
  optional libLayout LibLayoutEnum = 64
  optional libVector String = 65
  optional libScreen String = 66
  optional adapters String = 67
  seqMeth String = 68
  optional taxIdent TaxIdentEnum = 69
  assemblyQual AssemblyQualEnum = 70
  optional assemblyName String = 71
  assemblySoftware String = 72
  optional annot String = 73
  numberContig Integer = 74
  optional featPred String = 75
  optional refDb String = 76
  optional simSearchMeth String = 77
  optional taxClass String = 78
  optional complScore String = 79
  optional complSoftware String = 80
  optional associatedResource String = 81
  optional sop String = 82
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: eukaryote with environmental package air
message AirMIGSEukaryote
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional barometricPress QuantityValue = 11
  optional carbDioxide QuantityValue = 12
  optional carbMonoxide QuantityValue = 13
  repeated chemAdministration String = 14
  optional humidity QuantityValue = 15
  optional methane QuantityValue = 16
  repeated organismCount OrganismCountEnum = 17
  optional oxygen QuantityValue = 18
  optional oxyStatSamp OxyStatSampEnum = 19
  repeated perturbation String = 20
  repeated pollutants String = 21
  repeated airParticulateMatterConcentration String = 22
  optional salinity QuantityValue = 23
  optional sampStoreDur String = 24
  optional sampStoreLoc String = 25
  optional sampStoreTemp QuantityValue = 26
  optional solarIrradiance QuantityValue = 27
  optional ventilationRate QuantityValue = 28
  optional ventilationType String = 29
  repeated volatileOrgComp String = 30
  optional windDirection String = 31
  optional windSpeed QuantityValue = 32
  repeated miscParam String = 33
  sampName String = 34
  projectName String = 35
  optional sampVolWeDnaExt QuantityValue = 36
  sampTaxonId String = 37
  optional experimentalFactor String = 38
  optional negContType NegContTypeEnum = 39
  optional posContType String = 40
  optional subspecfGenLin String = 41
  optional ploidy String = 42
  optional numReplicons Integer = 43
  optional extrachromElements Integer = 44
  optional estimatedSize String = 45
  optional refBiomaterial String = 46
  optional sourceMatId String = 47
  optional pathogenicity String = 48
  optional bioticRelationship BioticRelationshipEnum = 49
  optional specificHost String = 50
  optional hostSpecRange Integer = 51
  optional hostDiseaseStat String = 52
  optional trophicLevel TrophicLevelEnum = 53
  optional propagation String = 54
  isolGrowthCondt String = 55
  optional sampCollecDevice String = 56
  optional sampCollecMethod String = 57
  optional sampMatProcess String = 58
  optional sampSize QuantityValue = 59
  optional nuclAcidExt String = 60
  optional nuclAcidAmp String = 61
  optional libSize Integer = 62
  optional libReadsSeqd Integer = 63
  optional libLayout LibLayoutEnum = 64
  optional libVector String = 65
  optional libScreen String = 66
  optional adapters String = 67
  seqMeth String = 68
  optional taxIdent TaxIdentEnum = 69
  assemblyQual AssemblyQualEnum = 70
  optional assemblyName String = 71
  assemblySoftware String = 72
  optional annot String = 73
  numberContig Integer = 74
  optional featPred String = 75
  optional refDb String = 76
  optional simSearchMeth String = 77
  optional taxClass String = 78
  optional complScore String = 79
  optional complSoftware String = 80
  optional associatedResource String = 81
  optional sop String = 82
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: org with environmental package air
message AirMIGSOrg
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional barometricPress QuantityValue = 11
  optional carbDioxide QuantityValue = 12
  optional carbMonoxide QuantityValue = 13
  repeated chemAdministration String = 14
  optional humidity QuantityValue = 15
  optional methane QuantityValue = 16
  repeated organismCount OrganismCountEnum = 17
  optional oxygen QuantityValue = 18
  optional oxyStatSamp OxyStatSampEnum = 19
  repeated perturbation String = 20
  repeated pollutants String = 21
  repeated airParticulateMatterConcentration String = 22
  optional salinity QuantityValue = 23
  optional sampStoreDur String = 24
  optional sampStoreLoc String = 25
  optional sampStoreTemp QuantityValue = 26
  optional solarIrradiance QuantityValue = 27
  optional ventilationRate QuantityValue = 28
  optional ventilationType String = 29
  repeated volatileOrgComp String = 30
  optional windDirection String = 31
  optional windSpeed QuantityValue = 32
  repeated miscParam String = 33
  sampName String = 34
  projectName String = 35
  optional sampVolWeDnaExt QuantityValue = 36
  sampTaxonId String = 37
  optional experimentalFactor String = 38
  optional negContType NegContTypeEnum = 39
  optional posContType String = 40
  optional subspecfGenLin String = 41
  optional extrachromElements Integer = 42
  optional estimatedSize String = 43
  optional refBiomaterial String = 44
  optional sourceMatId String = 45
  isolGrowthCondt String = 46
  optional sampCollecDevice String = 47
  optional sampCollecMethod String = 48
  optional sampMatProcess String = 49
  optional sampSize QuantityValue = 50
  optional nuclAcidExt String = 51
  optional nuclAcidAmp String = 52
  optional libSize Integer = 53
  optional libReadsSeqd Integer = 54
  optional libLayout LibLayoutEnum = 55
  optional libVector String = 56
  optional libScreen String = 57
  optional adapters String = 58
  seqMeth String = 59
  optional taxIdent TaxIdentEnum = 60
  optional assemblyQual AssemblyQualEnum = 61
  optional assemblyName String = 62
  assemblySoftware String = 63
  optional annot String = 64
  optional numberContig Integer = 65
  optional featPred String = 66
  optional refDb String = 67
  optional simSearchMeth String = 68
  optional taxClass String = 69
  optional complScore String = 70
  optional complSoftware String = 71
  optional associatedResource String = 72
  optional sop String = 73
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: plant with environmental package air
message AirMIGSPlant
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional barometricPress QuantityValue = 11
  optional carbDioxide QuantityValue = 12
  optional carbMonoxide QuantityValue = 13
  repeated chemAdministration String = 14
  optional humidity QuantityValue = 15
  optional methane QuantityValue = 16
  repeated organismCount OrganismCountEnum = 17
  optional oxygen QuantityValue = 18
  optional oxyStatSamp OxyStatSampEnum = 19
  repeated perturbation String = 20
  repeated pollutants String = 21
  repeated airParticulateMatterConcentration String = 22
  optional salinity QuantityValue = 23
  optional sampStoreDur String = 24
  optional sampStoreLoc String = 25
  optional sampStoreTemp QuantityValue = 26
  optional solarIrradiance QuantityValue = 27
  optional ventilationRate QuantityValue = 28
  optional ventilationType String = 29
  repeated volatileOrgComp String = 30
  optional windDirection String = 31
  optional windSpeed QuantityValue = 32
  repeated miscParam String = 33
  sampName String = 34
  projectName String = 35
  optional sampVolWeDnaExt QuantityValue = 36
  sampTaxonId String = 37
  optional experimentalFactor String = 38
  optional negContType NegContTypeEnum = 39
  optional posContType String = 40
  optional subspecfGenLin String = 41
  optional estimatedSize String = 42
  optional refBiomaterial String = 43
  optional sourceMatId String = 44
  optional specificHost String = 45
  optional hostSpecRange Integer = 46
  propagation String = 47
  optional encodedTraits String = 48
  isolGrowthCondt String = 49
  optional sampCollecDevice String = 50
  optional sampCollecMethod String = 51
  optional sampMatProcess String = 52
  optional sampSize QuantityValue = 53
  optional nuclAcidExt String = 54
  optional nuclAcidAmp String = 55
  optional libSize Integer = 56
  optional libReadsSeqd Integer = 57
  optional libLayout LibLayoutEnum = 58
  optional libVector String = 59
  optional libScreen String = 60
  optional adapters String = 61
  seqMeth String = 62
  optional taxIdent TaxIdentEnum = 63
  optional assemblyQual AssemblyQualEnum = 64
  optional assemblyName String = 65
  assemblySoftware String = 66
  optional annot String = 67
  optional numberContig Integer = 68
  optional featPred String = 69
  optional refDb String = 70
  optional simSearchMeth String = 71
  optional taxClass String = 72
  optional complScore String = 73
  optional complSoftware String = 74
  optional associatedResource String = 75
  optional sop String = 76
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package air
message AirMIGSVirus
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional barometricPress QuantityValue = 11
  optional carbDioxide QuantityValue = 12
  optional carbMonoxide QuantityValue = 13
  repeated chemAdministration String = 14
  optional humidity QuantityValue = 15
  optional methane QuantityValue = 16
  repeated organismCount OrganismCountEnum = 17
  optional oxygen QuantityValue = 18
  optional oxyStatSamp OxyStatSampEnum = 19
  repeated perturbation String = 20
  repeated pollutants String = 21
  repeated airParticulateMatterConcentration String = 22
  optional salinity QuantityValue = 23
  optional sampStoreDur String = 24
  optional sampStoreLoc String = 25
  optional sampStoreTemp QuantityValue = 26
  optional solarIrradiance QuantityValue = 27
  optional ventilationRate QuantityValue = 28
  optional ventilationType String = 29
  repeated volatileOrgComp String = 30
  optional windDirection String = 31
  optional windSpeed QuantityValue = 32
  repeated miscParam String = 33
  sampName String = 34
  projectName String = 35
  optional sampVolWeDnaExt QuantityValue = 36
  sampTaxonId String = 37
  optional experimentalFactor String = 38
  optional negContType NegContTypeEnum = 39
  optional posContType String = 40
  optional subspecfGenLin String = 41
  optional numReplicons Integer = 42
  optional estimatedSize String = 43
  optional refBiomaterial String = 44
  optional sourceMatId String = 45
  optional pathogenicity String = 46
  optional bioticRelationship BioticRelationshipEnum = 47
  optional specificHost String = 48
  optional hostSpecRange Integer = 49
  optional hostDiseaseStat String = 50
  propagation String = 51
  optional encodedTraits String = 52
  isolGrowthCondt String = 53
  optional sampCollecDevice String = 54
  optional sampCollecMethod String = 55
  optional sampMatProcess String = 56
  optional sampSize QuantityValue = 57
  optional virusEnrichAppr VirusEnrichApprEnum = 58
  optional nuclAcidExt String = 59
  optional nuclAcidAmp String = 60
  optional libSize Integer = 61
  optional libReadsSeqd Integer = 62
  optional libLayout LibLayoutEnum = 63
  optional libVector String = 64
  optional libScreen String = 65
  optional adapters String = 66
  seqMeth String = 67
  optional taxIdent TaxIdentEnum = 68
  optional assemblyQual AssemblyQualEnum = 69
  optional assemblyName String = 70
  assemblySoftware String = 71
  optional annot String = 72
  optional numberContig Integer = 73
  optional featPred String = 74
  optional refDb String = 75
  optional simSearchMeth String = 76
  optional taxClass String = 77
  optional complScore String = 78
  optional complSoftware String = 79
  optional associatedResource String = 80
  optional sop String = 81
 }
// Combinatorial checklist Minimum Information About a Metagenome-Assembled Genome with environmental package air
message AirMIMAG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional barometricPress QuantityValue = 11
  optional carbDioxide QuantityValue = 12
  optional carbMonoxide QuantityValue = 13
  repeated chemAdministration String = 14
  optional humidity QuantityValue = 15
  optional methane QuantityValue = 16
  repeated organismCount OrganismCountEnum = 17
  optional oxygen QuantityValue = 18
  optional oxyStatSamp OxyStatSampEnum = 19
  repeated perturbation String = 20
  repeated pollutants String = 21
  repeated airParticulateMatterConcentration String = 22
  optional salinity QuantityValue = 23
  optional sampStoreDur String = 24
  optional sampStoreLoc String = 25
  optional sampStoreTemp QuantityValue = 26
  optional solarIrradiance QuantityValue = 27
  optional ventilationRate QuantityValue = 28
  optional ventilationType String = 29
  repeated volatileOrgComp String = 30
  optional windDirection String = 31
  optional windSpeed QuantityValue = 32
  repeated miscParam String = 33
  sampName String = 34
  projectName String = 35
  optional sampVolWeDnaExt QuantityValue = 36
  sampTaxonId String = 37
  optional experimentalFactor String = 38
  optional negContType NegContTypeEnum = 39
  optional posContType String = 40
  optional refBiomaterial String = 41
  optional sourceMatId String = 42
  optional relToOxygen RelToOxygenEnum = 43
  optional sampCollecDevice String = 44
  optional sampCollecMethod String = 45
  optional sampMatProcess String = 46
  optional sizeFrac String = 47
  optional sampSize QuantityValue = 48
  optional nuclAcidExt String = 49
  optional nuclAcidAmp String = 50
  optional libSize Integer = 51
  optional libReadsSeqd Integer = 52
  optional libLayout LibLayoutEnum = 53
  optional libVector String = 54
  optional libScreen String = 55
  optional mid String = 56
  optional adapters String = 57
  seqMeth String = 58
  taxIdent TaxIdentEnum = 59
  assemblyQual AssemblyQualEnum = 60
  optional assemblyName String = 61
  assemblySoftware String = 62
  optional annot String = 63
  optional numberContig Integer = 64
  optional featPred String = 65
  optional refDb String = 66
  optional simSearchMeth String = 67
  optional taxClass String = 68
  optional x16sRecover String = 69
  optional x16sRecoverSoftware String = 70
  optional trnas Integer = 71
  optional trnaExtSoftware String = 72
  complScore String = 73
  complSoftware String = 74
  optional complAppr ComplApprEnum = 75
  contamScore String = 76
  optional contamScreenInput String = 77
  optional contamScreenParam String = 78
  optional decontamSoftware DecontamSoftwareEnum = 79
  binParam BinParamEnum = 80
  binSoftware String = 81
  optional reassemblyBin String = 82
  optional magCovSoftware MagCovSoftwareEnum = 83
  optional associatedResource String = 84
  optional sop String = 85
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: specimen with environmental package air
message AirMIMARKSSpecimen
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional barometricPress QuantityValue = 11
  optional carbDioxide QuantityValue = 12
  optional carbMonoxide QuantityValue = 13
  repeated chemAdministration String = 14
  optional humidity QuantityValue = 15
  optional methane QuantityValue = 16
  repeated organismCount OrganismCountEnum = 17
  optional oxygen QuantityValue = 18
  optional oxyStatSamp OxyStatSampEnum = 19
  repeated perturbation String = 20
  repeated pollutants String = 21
  repeated airParticulateMatterConcentration String = 22
  optional salinity QuantityValue = 23
  optional sampStoreDur String = 24
  optional sampStoreLoc String = 25
  optional sampStoreTemp QuantityValue = 26
  optional solarIrradiance QuantityValue = 27
  optional ventilationRate QuantityValue = 28
  optional ventilationType String = 29
  repeated volatileOrgComp String = 30
  optional windDirection String = 31
  optional windSpeed QuantityValue = 32
  repeated miscParam String = 33
  sampName String = 34
  projectName String = 35
  optional sampVolWeDnaExt QuantityValue = 36
  sampTaxonId String = 37
  optional experimentalFactor String = 38
  optional negContType NegContTypeEnum = 39
  optional posContType String = 40
  optional sourceMatId String = 41
  optional relToOxygen RelToOxygenEnum = 42
  optional sampCollecDevice String = 43
  optional sampCollecMethod String = 44
  optional sampMatProcess String = 45
  optional sizeFrac String = 46
  optional sampSize QuantityValue = 47
  optional nuclAcidExt String = 48
  optional nuclAcidAmp String = 49
  optional libSize Integer = 50
  optional libReadsSeqd Integer = 51
  optional libLayout LibLayoutEnum = 52
  optional libVector String = 53
  optional libScreen String = 54
  targetGene String = 55
  optional targetSubfragment String = 56
  optional pcrPrimers String = 57
  optional mid String = 58
  optional adapters String = 59
  optional pcrCond String = 60
  seqMeth String = 61
  optional seqQualityCheck String = 62
  optional chimeraCheck String = 63
  optional assemblySoftware String = 64
  optional associatedResource String = 65
  optional sop String = 66
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: survey with environmental package air
message AirMIMARKSSurvey
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional barometricPress QuantityValue = 11
  optional carbDioxide QuantityValue = 12
  optional carbMonoxide QuantityValue = 13
  repeated chemAdministration String = 14
  optional humidity QuantityValue = 15
  optional methane QuantityValue = 16
  repeated organismCount OrganismCountEnum = 17
  optional oxygen QuantityValue = 18
  optional oxyStatSamp OxyStatSampEnum = 19
  repeated perturbation String = 20
  repeated pollutants String = 21
  repeated airParticulateMatterConcentration String = 22
  optional salinity QuantityValue = 23
  optional sampStoreDur String = 24
  optional sampStoreLoc String = 25
  optional sampStoreTemp QuantityValue = 26
  optional solarIrradiance QuantityValue = 27
  optional ventilationRate QuantityValue = 28
  optional ventilationType String = 29
  repeated volatileOrgComp String = 30
  optional windDirection String = 31
  optional windSpeed QuantityValue = 32
  repeated miscParam String = 33
  sampName String = 34
  projectName String = 35
  optional sampVolWeDnaExt QuantityValue = 36
  sampTaxonId String = 37
  optional experimentalFactor String = 38
  optional negContType NegContTypeEnum = 39
  optional posContType String = 40
  optional subspecfGenLin String = 41
  optional extrachromElements Integer = 42
  optional sourceMatId String = 43
  optional bioticRelationship BioticRelationshipEnum = 44
  optional trophicLevel TrophicLevelEnum = 45
  optional relToOxygen RelToOxygenEnum = 46
  isolGrowthCondt String = 47
  optional sampCollecDevice String = 48
  optional sampCollecMethod String = 49
  optional sampMatProcess String = 50
  optional sampSize QuantityValue = 51
  optional nuclAcidExt String = 52
  optional nuclAcidAmp String = 53
  targetGene String = 54
  optional targetSubfragment String = 55
  optional pcrPrimers String = 56
  optional pcrCond String = 57
  seqMeth String = 58
  optional seqQualityCheck String = 59
  optional chimeraCheck String = 60
  optional associatedResource String = 61
  optional sop String = 62
 }
// Combinatorial checklist Metagenome or Environmental with environmental package air
message AirMIMS
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional barometricPress QuantityValue = 11
  optional carbDioxide QuantityValue = 12
  optional carbMonoxide QuantityValue = 13
  repeated chemAdministration String = 14
  optional humidity QuantityValue = 15
  optional methane QuantityValue = 16
  repeated organismCount OrganismCountEnum = 17
  optional oxygen QuantityValue = 18
  optional oxyStatSamp OxyStatSampEnum = 19
  repeated perturbation String = 20
  repeated pollutants String = 21
  repeated airParticulateMatterConcentration String = 22
  optional salinity QuantityValue = 23
  optional sampStoreDur String = 24
  optional sampStoreLoc String = 25
  optional sampStoreTemp QuantityValue = 26
  optional solarIrradiance QuantityValue = 27
  optional ventilationRate QuantityValue = 28
  optional ventilationType String = 29
  repeated volatileOrgComp String = 30
  optional windDirection String = 31
  optional windSpeed QuantityValue = 32
  repeated miscParam String = 33
  sampName String = 34
  projectName String = 35
  optional sampVolWeDnaExt QuantityValue = 36
  sampTaxonId String = 37
  optional experimentalFactor String = 38
  optional negContType NegContTypeEnum = 39
  optional posContType String = 40
  optional refBiomaterial String = 41
  optional sourceMatId String = 42
  optional relToOxygen RelToOxygenEnum = 43
  optional sampCollecDevice String = 44
  optional sampCollecMethod String = 45
  optional sampMatProcess String = 46
  optional sizeFrac String = 47
  optional sampSize QuantityValue = 48
  optional nuclAcidExt String = 49
  optional nuclAcidAmp String = 50
  optional libSize Integer = 51
  optional libReadsSeqd Integer = 52
  optional libLayout LibLayoutEnum = 53
  optional libVector String = 54
  optional libScreen String = 55
  optional mid String = 56
  optional adapters String = 57
  seqMeth String = 58
  optional assemblyQual AssemblyQualEnum = 59
  optional assemblyName String = 60
  optional assemblySoftware String = 61
  optional annot String = 62
  optional numberContig Integer = 63
  optional featPred String = 64
  optional refDb String = 65
  optional simSearchMeth String = 66
  optional taxClass String = 67
  optional associatedResource String = 68
  optional sop String = 69
 }
// Combinatorial checklist Minimum Information About a Single Amplified Genome with environmental package air
message AirMISAG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional barometricPress QuantityValue = 11
  optional carbDioxide QuantityValue = 12
  optional carbMonoxide QuantityValue = 13
  repeated chemAdministration String = 14
  optional humidity QuantityValue = 15
  optional methane QuantityValue = 16
  repeated organismCount OrganismCountEnum = 17
  optional oxygen QuantityValue = 18
  optional oxyStatSamp OxyStatSampEnum = 19
  repeated perturbation String = 20
  repeated pollutants String = 21
  repeated airParticulateMatterConcentration String = 22
  optional salinity QuantityValue = 23
  optional sampStoreDur String = 24
  optional sampStoreLoc String = 25
  optional sampStoreTemp QuantityValue = 26
  optional solarIrradiance QuantityValue = 27
  optional ventilationRate QuantityValue = 28
  optional ventilationType String = 29
  repeated volatileOrgComp String = 30
  optional windDirection String = 31
  optional windSpeed QuantityValue = 32
  repeated miscParam String = 33
  sampName String = 34
  projectName String = 35
  optional sampVolWeDnaExt QuantityValue = 36
  sampTaxonId String = 37
  optional experimentalFactor String = 38
  optional negContType NegContTypeEnum = 39
  optional posContType String = 40
  optional refBiomaterial String = 41
  optional sourceMatId String = 42
  optional relToOxygen RelToOxygenEnum = 43
  optional sampCollecDevice String = 44
  optional sampCollecMethod String = 45
  optional sampMatProcess String = 46
  optional sizeFrac String = 47
  optional sampSize QuantityValue = 48
  optional nuclAcidExt String = 49
  optional nuclAcidAmp String = 50
  optional libSize Integer = 51
  optional libReadsSeqd Integer = 52
  optional libLayout LibLayoutEnum = 53
  optional libVector String = 54
  optional libScreen String = 55
  optional mid String = 56
  optional adapters String = 57
  seqMeth String = 58
  taxIdent TaxIdentEnum = 59
  assemblyQual AssemblyQualEnum = 60
  optional assemblyName String = 61
  assemblySoftware String = 62
  optional annot String = 63
  optional numberContig Integer = 64
  optional featPred String = 65
  optional refDb String = 66
  optional simSearchMeth String = 67
  optional taxClass String = 68
  optional x16sRecover String = 69
  optional x16sRecoverSoftware String = 70
  optional trnas Integer = 71
  optional trnaExtSoftware String = 72
  complScore String = 73
  complSoftware String = 74
  optional complAppr ComplApprEnum = 75
  contamScore String = 76
  optional contamScreenInput String = 77
  optional contamScreenParam String = 78
  optional decontamSoftware DecontamSoftwareEnum = 79
  sortTech SortTechEnum = 80
  singleCellLysisAppr SingleCellLysisApprEnum = 81
  optional singleCellLysisProt String = 82
  wgaAmpAppr String = 83
  optional wgaAmpKit String = 84
  optional associatedResource String = 85
  optional sop String = 86
 }
// Combinatorial checklist Minimum Information About an Uncultivated Virus Genome with environmental package air
message AirMIUVIG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional barometricPress QuantityValue = 11
  optional carbDioxide QuantityValue = 12
  optional carbMonoxide QuantityValue = 13
  repeated chemAdministration String = 14
  optional humidity QuantityValue = 15
  optional methane QuantityValue = 16
  repeated organismCount OrganismCountEnum = 17
  optional oxygen QuantityValue = 18
  optional oxyStatSamp OxyStatSampEnum = 19
  repeated perturbation String = 20
  repeated pollutants String = 21
  repeated airParticulateMatterConcentration String = 22
  optional salinity QuantityValue = 23
  optional sampStoreDur String = 24
  optional sampStoreLoc String = 25
  optional sampStoreTemp QuantityValue = 26
  optional solarIrradiance QuantityValue = 27
  optional ventilationRate QuantityValue = 28
  optional ventilationType String = 29
  repeated volatileOrgComp String = 30
  optional windDirection String = 31
  optional windSpeed QuantityValue = 32
  repeated miscParam String = 33
  sampName String = 34
  projectName String = 35
  optional sampVolWeDnaExt QuantityValue = 36
  sampTaxonId String = 37
  optional experimentalFactor String = 38
  optional negContType NegContTypeEnum = 39
  optional posContType String = 40
  optional estimatedSize String = 41
  optional refBiomaterial String = 42
  optional sourceMatId String = 43
  optional pathogenicity String = 44
  optional bioticRelationship BioticRelationshipEnum = 45
  optional specificHost String = 46
  optional hostSpecRange Integer = 47
  optional hostDiseaseStat String = 48
  optional sampCollecDevice String = 49
  optional sampCollecMethod String = 50
  optional sampMatProcess String = 51
  optional sizeFrac String = 52
  optional sampSize QuantityValue = 53
  sourceUvig SourceUvigEnum = 54
  virusEnrichAppr VirusEnrichApprEnum = 55
  optional nuclAcidExt String = 56
  optional nuclAcidAmp String = 57
  optional libSize Integer = 58
  optional libReadsSeqd Integer = 59
  optional libLayout LibLayoutEnum = 60
  optional libVector String = 61
  optional libScreen String = 62
  optional mid String = 63
  optional adapters String = 64
  seqMeth String = 65
  optional taxIdent TaxIdentEnum = 66
  assemblyQual AssemblyQualEnum = 67
  optional assemblyName String = 68
  assemblySoftware String = 69
  optional annot String = 70
  numberContig Integer = 71
  optional featPred String = 72
  optional refDb String = 73
  optional simSearchMeth String = 74
  optional taxClass String = 75
  optional trnas Integer = 76
  optional trnaExtSoftware String = 77
  optional complScore String = 78
  optional complSoftware String = 79
  optional complAppr ComplApprEnum = 80
  optional sortTech SortTechEnum = 81
  optional singleCellLysisAppr SingleCellLysisApprEnum = 82
  optional singleCellLysisProt String = 83
  optional wgaAmpAppr String = 84
  optional wgaAmpKit String = 85
  optional binParam BinParamEnum = 86
  optional binSoftware String = 87
  optional reassemblyBin String = 88
  optional magCovSoftware MagCovSoftwareEnum = 89
  virIdentSoftware String = 90
  predGenomeType PredGenomeTypeEnum = 91
  predGenomeStruc PredGenomeStrucEnum = 92
  detecType String = 93
  optional otuClassAppr String = 94
  optional otuSeqCompAppr String = 95
  optional otuDb String = 96
  optional hostPredAppr HostPredApprEnum = 97
  optional hostPredEstAcc String = 98
  optional associatedResource String = 99
  optional sop String = 100
 }
// built environment
message BuiltEnvironment
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional surfMaterial SurfMaterialEnum = 11
  repeated surfAirCont SurfAirContEnum = 12
  relAirHumidity QuantityValue = 13
  absAirHumidity QuantityValue = 14
  optional surfHumidity QuantityValue = 15
  optional surfTemp QuantityValue = 16
  optional surfMoisturePh Double = 17
  repeated buildOccupType BuildOccupTypeEnum = 18
  optional surfMoisture QuantityValue = 19
  optional dewPoint QuantityValue = 20
  carbDioxide QuantityValue = 21
  ventilationType String = 22
  repeated organismCount OrganismCountEnum = 23
  indoorSpace IndoorSpaceEnum = 24
  optional indoorSurf IndoorSurfEnum = 25
  repeated filterType FilterTypeEnum = 26
  repeated heatCoolType HeatCoolTypeEnum = 27
  repeated substructureType SubstructureTypeEnum = 28
  buildingSetting BuildingSettingEnum = 29
  repeated lightType LightTypeEnum = 30
  repeated sampSortMeth String = 31
  spaceTypState String = 32
  typOccupDensity Double = 33
  occupSamp Integer = 34
  occupDensitySamp Double = 35
  optional address String = 36
  optional adjRoom String = 37
  optional aeroStruc String = 38
  optional amountLight QuantityValue = 39
  optional archStruc ArchStrucEnum = 40
  optional avgOccup Double = 41
  optional avgDewPoint QuantityValue = 42
  optional avgTemp QuantityValue = 43
  optional bathroomCount Integer = 44
  optional bedroomCount Integer = 45
  optional builtStrucAge QuantityValue = 46
  optional builtStrucSet String = 47
  optional builtStrucType String = 48
  optional ceilArea QuantityValue = 49
  optional ceilCond CeilCondEnum = 50
  optional ceilFinishMat CeilFinishMatEnum = 51
  optional ceilWaterMold String = 52
  optional ceilStruc String = 53
  optional ceilTexture CeilTextureEnum = 54
  optional ceilThermalMass QuantityValue = 55
  optional ceilType CeilTypeEnum = 56
  optional coolSystId Integer = 57
  optional dateLastRain Date = 58
  optional buildDocs BuildDocsEnum = 59
  optional doorSize QuantityValue = 60
  optional doorCond DoorCondEnum = 61
  optional doorDirect DoorDirectEnum = 62
  optional doorLoc DoorLocEnum = 63
  optional doorMat DoorMatEnum = 64
  optional doorMove DoorMoveEnum = 65
  optional doorWaterMold String = 66
  optional doorType DoorTypeEnum = 67
  optional doorCompType DoorCompTypeEnum = 68
  optional doorTypeMetal DoorTypeMetalEnum = 69
  optional doorTypeWood DoorTypeWoodEnum = 70
  optional drawings DrawingsEnum = 71
  optional elevator Integer = 72
  optional escalator Integer = 73
  optional expDuct QuantityValue = 74
  optional expPipe Integer = 75
  optional extDoor Integer = 76
  optional fireplaceType String = 77
  optional floorAge QuantityValue = 78
  optional floorArea QuantityValue = 79
  optional floorCond FloorCondEnum = 80
  optional floorCount Integer = 81
  optional floorFinishMat FloorFinishMatEnum = 82
  optional floorWaterMold FloorWaterMoldEnum = 83
  optional floorStruc FloorStrucEnum = 84
  optional floorThermalMass QuantityValue = 85
  optional freqClean FreqCleanEnum = 86
  optional freqCook Integer = 87
  optional furniture FurnitureEnum = 88
  optional genderRestroom GenderRestroomEnum = 89
  optional hallCount Integer = 90
  optional handidness HandidnessEnum = 91
  optional heatDelivLoc HeatDelivLocEnum = 92
  optional heatSysDelivMeth String = 93
  optional heatSystemId Integer = 94
  optional heightCarperFiber QuantityValue = 95
  optional insideLux QuantityValue = 96
  optional intWallCond IntWallCondEnum = 97
  optional lastClean Date = 98
  optional maxOccup Integer = 99
  optional mechStruc MechStrucEnum = 100
  optional numberPlants Integer = 101
  optional numberPets Integer = 102
  optional numberResident Integer = 103
  optional occupDocument OccupDocumentEnum = 104
  optional extWallOrient ExtWallOrientEnum = 105
  optional extWindowOrient ExtWindowOrientEnum = 106
  optional relHumidityOut QuantityValue = 107
  optional presAnimalInsect String = 108
  optional quadPos QuadPosEnum = 109
  optional relSampLoc RelSampLocEnum = 110
  optional roomAirExchRate QuantityValue = 111
  optional roomArchitecElem String = 112
  optional roomCondt RoomCondtEnum = 113
  optional roomCount Integer = 114
  optional roomDim String = 115
  optional roomDoorDist String = 116
  optional roomLoc RoomLocEnum = 117
  optional roomMoistDamHist Integer = 118
  optional roomNetArea String = 119
  optional roomOccup Integer = 120
  optional roomSampPos RoomSampPosEnum = 121
  optional roomType RoomTypeEnum = 122
  optional roomVol String = 123
  optional roomWindowCount Integer = 124
  optional roomConnected RoomConnectedEnum = 125
  optional roomHallway String = 126
  optional roomDoorShare String = 127
  optional roomWallShare String = 128
  optional sampWeather SampWeatherEnum = 129
  optional sampFloor SampFloorEnum = 130
  optional sampRoomId Integer = 131
  optional sampTimeOut Double = 132
  optional season String = 133
  optional seasonUse SeasonUseEnum = 134
  optional shadingDeviceCond ShadingDeviceCondEnum = 135
  optional shadingDeviceLoc String = 136
  optional shadingDeviceMat String = 137
  optional shadDevWaterMold String = 138
  optional shadingDeviceType ShadingDeviceTypeEnum = 139
  optional specificHumidity QuantityValue = 140
  optional specific SpecificEnum = 141
  optional tempOut QuantityValue = 142
  optional trainLine TrainLineEnum = 143
  optional trainStatLoc TrainStatLocEnum = 144
  optional trainStopLoc TrainStopLocEnum = 145
  optional visMedia VisMediaEnum = 146
  optional wallArea QuantityValue = 147
  optional wallConstType WallConstTypeEnum = 148
  optional wallFinishMat WallFinishMatEnum = 149
  optional wallHeight QuantityValue = 150
  optional wallLoc WallLocEnum = 151
  optional wallWaterMold String = 152
  optional wallSurfTreatment WallSurfTreatmentEnum = 153
  optional wallTexture WallTextureEnum = 154
  optional wallThermalMass QuantityValue = 155
  optional waterFeatSize QuantityValue = 156
  optional waterFeatType WaterFeatTypeEnum = 157
  optional weekday WeekdayEnum = 158
  optional windowSize String = 159
  optional windowCond WindowCondEnum = 160
  optional windowCover WindowCoverEnum = 161
  optional windowHorizPos WindowHorizPosEnum = 162
  optional windowLoc WindowLocEnum = 163
  optional windowMat WindowMatEnum = 164
  optional windowOpenFreq Integer = 165
  optional windowWaterMold String = 166
  optional windowStatus String = 167
  optional windowType WindowTypeEnum = 168
  optional windowVertPos WindowVertPosEnum = 169
  sampName String = 170
  projectName String = 171
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package built environment
message BuiltEnvironmentMIGSBacteria
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional geoLocName String = 5
  optional collectionDate Date = 6
  optional envBroadScale String = 7
  optional envLocalScale String = 8
  optional envMedium String = 9
  optional surfMaterial SurfMaterialEnum = 10
  repeated surfAirCont SurfAirContEnum = 11
  relAirHumidity QuantityValue = 12
  absAirHumidity QuantityValue = 13
  optional surfHumidity QuantityValue = 14
  temp QuantityValue = 15
  optional surfTemp QuantityValue = 16
  optional surfMoisturePh Double = 17
  repeated buildOccupType BuildOccupTypeEnum = 18
  optional surfMoisture QuantityValue = 19
  optional dewPoint QuantityValue = 20
  carbDioxide QuantityValue = 21
  ventilationType String = 22
  repeated organismCount OrganismCountEnum = 23
  indoorSpace IndoorSpaceEnum = 24
  optional indoorSurf IndoorSurfEnum = 25
  repeated filterType FilterTypeEnum = 26
  repeated heatCoolType HeatCoolTypeEnum = 27
  repeated substructureType SubstructureTypeEnum = 28
  buildingSetting BuildingSettingEnum = 29
  repeated lightType LightTypeEnum = 30
  repeated sampSortMeth String = 31
  spaceTypState String = 32
  typOccupDensity Double = 33
  occupSamp Integer = 34
  occupDensitySamp Double = 35
  optional address String = 36
  optional adjRoom String = 37
  optional aeroStruc String = 38
  optional amountLight QuantityValue = 39
  optional archStruc ArchStrucEnum = 40
  optional avgOccup Double = 41
  optional avgDewPoint QuantityValue = 42
  optional avgTemp QuantityValue = 43
  optional bathroomCount Integer = 44
  optional bedroomCount Integer = 45
  optional builtStrucAge QuantityValue = 46
  optional builtStrucSet String = 47
  optional builtStrucType String = 48
  optional ceilArea QuantityValue = 49
  optional ceilCond CeilCondEnum = 50
  optional ceilFinishMat CeilFinishMatEnum = 51
  optional ceilWaterMold String = 52
  optional ceilStruc String = 53
  optional ceilTexture CeilTextureEnum = 54
  optional ceilThermalMass QuantityValue = 55
  optional ceilType CeilTypeEnum = 56
  optional coolSystId Integer = 57
  optional dateLastRain Date = 58
  optional buildDocs BuildDocsEnum = 59
  optional doorSize QuantityValue = 60
  optional doorCond DoorCondEnum = 61
  optional doorDirect DoorDirectEnum = 62
  optional doorLoc DoorLocEnum = 63
  optional doorMat DoorMatEnum = 64
  optional doorMove DoorMoveEnum = 65
  optional doorWaterMold String = 66
  optional doorType DoorTypeEnum = 67
  optional doorCompType DoorCompTypeEnum = 68
  optional doorTypeMetal DoorTypeMetalEnum = 69
  optional doorTypeWood DoorTypeWoodEnum = 70
  optional drawings DrawingsEnum = 71
  optional elevator Integer = 72
  optional escalator Integer = 73
  optional expDuct QuantityValue = 74
  optional expPipe Integer = 75
  optional extDoor Integer = 76
  optional fireplaceType String = 77
  optional floorAge QuantityValue = 78
  optional floorArea QuantityValue = 79
  optional floorCond FloorCondEnum = 80
  optional floorCount Integer = 81
  optional floorFinishMat FloorFinishMatEnum = 82
  optional floorWaterMold FloorWaterMoldEnum = 83
  optional floorStruc FloorStrucEnum = 84
  optional floorThermalMass QuantityValue = 85
  optional freqClean FreqCleanEnum = 86
  optional freqCook Integer = 87
  optional furniture FurnitureEnum = 88
  optional genderRestroom GenderRestroomEnum = 89
  optional hallCount Integer = 90
  optional handidness HandidnessEnum = 91
  optional heatDelivLoc HeatDelivLocEnum = 92
  optional heatSysDelivMeth String = 93
  optional heatSystemId Integer = 94
  optional heightCarperFiber QuantityValue = 95
  optional insideLux QuantityValue = 96
  optional intWallCond IntWallCondEnum = 97
  optional lastClean Date = 98
  optional maxOccup Integer = 99
  optional mechStruc MechStrucEnum = 100
  optional numberPlants Integer = 101
  optional numberPets Integer = 102
  optional numberResident Integer = 103
  optional occupDocument OccupDocumentEnum = 104
  optional extWallOrient ExtWallOrientEnum = 105
  optional extWindowOrient ExtWindowOrientEnum = 106
  optional relHumidityOut QuantityValue = 107
  optional presAnimalInsect String = 108
  optional quadPos QuadPosEnum = 109
  optional relSampLoc RelSampLocEnum = 110
  optional roomAirExchRate QuantityValue = 111
  optional roomArchitecElem String = 112
  optional roomCondt RoomCondtEnum = 113
  optional roomCount Integer = 114
  optional roomDim String = 115
  optional roomDoorDist String = 116
  optional roomLoc RoomLocEnum = 117
  optional roomMoistDamHist Integer = 118
  optional roomNetArea String = 119
  optional roomOccup Integer = 120
  optional roomSampPos RoomSampPosEnum = 121
  optional roomType RoomTypeEnum = 122
  optional roomVol String = 123
  optional roomWindowCount Integer = 124
  optional roomConnected RoomConnectedEnum = 125
  optional roomHallway String = 126
  optional roomDoorShare String = 127
  optional roomWallShare String = 128
  optional sampWeather SampWeatherEnum = 129
  optional sampFloor SampFloorEnum = 130
  optional sampRoomId Integer = 131
  optional sampTimeOut Double = 132
  optional season String = 133
  optional seasonUse SeasonUseEnum = 134
  optional shadingDeviceCond ShadingDeviceCondEnum = 135
  optional shadingDeviceLoc String = 136
  optional shadingDeviceMat String = 137
  optional shadDevWaterMold String = 138
  optional shadingDeviceType ShadingDeviceTypeEnum = 139
  optional specificHumidity QuantityValue = 140
  optional specific SpecificEnum = 141
  optional tempOut QuantityValue = 142
  optional trainLine TrainLineEnum = 143
  optional trainStatLoc TrainStatLocEnum = 144
  optional trainStopLoc TrainStopLocEnum = 145
  optional visMedia VisMediaEnum = 146
  optional wallArea QuantityValue = 147
  optional wallConstType WallConstTypeEnum = 148
  optional wallFinishMat WallFinishMatEnum = 149
  optional wallHeight QuantityValue = 150
  optional wallLoc WallLocEnum = 151
  optional wallWaterMold String = 152
  optional wallSurfTreatment WallSurfTreatmentEnum = 153
  optional wallTexture WallTextureEnum = 154
  optional wallThermalMass QuantityValue = 155
  optional waterFeatSize QuantityValue = 156
  optional waterFeatType WaterFeatTypeEnum = 157
  optional weekday WeekdayEnum = 158
  optional windowSize String = 159
  optional windowCond WindowCondEnum = 160
  optional windowCover WindowCoverEnum = 161
  optional windowHorizPos WindowHorizPosEnum = 162
  optional windowLoc WindowLocEnum = 163
  optional windowMat WindowMatEnum = 164
  optional windowOpenFreq Integer = 165
  optional windowWaterMold String = 166
  optional windowStatus String = 167
  optional windowType WindowTypeEnum = 168
  optional windowVertPos WindowVertPosEnum = 169
  sampName String = 170
  projectName String = 171
  sampTaxonId String = 172
  optional experimentalFactor String = 173
  optional negContType NegContTypeEnum = 174
  optional posContType String = 175
  optional subspecfGenLin String = 176
  numReplicons Integer = 177
  optional extrachromElements Integer = 178
  optional estimatedSize String = 179
  refBiomaterial String = 180
  optional sourceMatId String = 181
  optional pathogenicity String = 182
  optional bioticRelationship BioticRelationshipEnum = 183
  optional specificHost String = 184
  optional hostSpecRange Integer = 185
  optional hostDiseaseStat String = 186
  optional trophicLevel TrophicLevelEnum = 187
  optional encodedTraits String = 188
  optional relToOxygen RelToOxygenEnum = 189
  isolGrowthCondt String = 190
  optional sampCollecDevice String = 191
  optional sampCollecMethod String = 192
  optional sampMatProcess String = 193
  optional sampSize QuantityValue = 194
  optional sampVolWeDnaExt QuantityValue = 195
  optional nuclAcidExt String = 196
  optional nuclAcidAmp String = 197
  optional libSize Integer = 198
  optional libReadsSeqd Integer = 199
  optional libLayout LibLayoutEnum = 200
  optional libVector String = 201
  optional libScreen String = 202
  optional adapters String = 203
  seqMeth String = 204
  optional taxIdent TaxIdentEnum = 205
  assemblyQual AssemblyQualEnum = 206
  optional assemblyName String = 207
  assemblySoftware String = 208
  optional annot String = 209
  numberContig Integer = 210
  optional featPred String = 211
  optional refDb String = 212
  optional simSearchMeth String = 213
  optional taxClass String = 214
  optional complScore String = 215
  optional complSoftware String = 216
  optional associatedResource String = 217
  optional sop String = 218
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: eukaryote with environmental package built environment
message BuiltEnvironmentMIGSEukaryote
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional geoLocName String = 5
  optional collectionDate Date = 6
  optional envBroadScale String = 7
  optional envLocalScale String = 8
  optional envMedium String = 9
  optional surfMaterial SurfMaterialEnum = 10
  repeated surfAirCont SurfAirContEnum = 11
  relAirHumidity QuantityValue = 12
  absAirHumidity QuantityValue = 13
  optional surfHumidity QuantityValue = 14
  temp QuantityValue = 15
  optional surfTemp QuantityValue = 16
  optional surfMoisturePh Double = 17
  repeated buildOccupType BuildOccupTypeEnum = 18
  optional surfMoisture QuantityValue = 19
  optional dewPoint QuantityValue = 20
  carbDioxide QuantityValue = 21
  ventilationType String = 22
  repeated organismCount OrganismCountEnum = 23
  indoorSpace IndoorSpaceEnum = 24
  optional indoorSurf IndoorSurfEnum = 25
  repeated filterType FilterTypeEnum = 26
  repeated heatCoolType HeatCoolTypeEnum = 27
  repeated substructureType SubstructureTypeEnum = 28
  buildingSetting BuildingSettingEnum = 29
  repeated lightType LightTypeEnum = 30
  repeated sampSortMeth String = 31
  spaceTypState String = 32
  typOccupDensity Double = 33
  occupSamp Integer = 34
  occupDensitySamp Double = 35
  optional address String = 36
  optional adjRoom String = 37
  optional aeroStruc String = 38
  optional amountLight QuantityValue = 39
  optional archStruc ArchStrucEnum = 40
  optional avgOccup Double = 41
  optional avgDewPoint QuantityValue = 42
  optional avgTemp QuantityValue = 43
  optional bathroomCount Integer = 44
  optional bedroomCount Integer = 45
  optional builtStrucAge QuantityValue = 46
  optional builtStrucSet String = 47
  optional builtStrucType String = 48
  optional ceilArea QuantityValue = 49
  optional ceilCond CeilCondEnum = 50
  optional ceilFinishMat CeilFinishMatEnum = 51
  optional ceilWaterMold String = 52
  optional ceilStruc String = 53
  optional ceilTexture CeilTextureEnum = 54
  optional ceilThermalMass QuantityValue = 55
  optional ceilType CeilTypeEnum = 56
  optional coolSystId Integer = 57
  optional dateLastRain Date = 58
  optional buildDocs BuildDocsEnum = 59
  optional doorSize QuantityValue = 60
  optional doorCond DoorCondEnum = 61
  optional doorDirect DoorDirectEnum = 62
  optional doorLoc DoorLocEnum = 63
  optional doorMat DoorMatEnum = 64
  optional doorMove DoorMoveEnum = 65
  optional doorWaterMold String = 66
  optional doorType DoorTypeEnum = 67
  optional doorCompType DoorCompTypeEnum = 68
  optional doorTypeMetal DoorTypeMetalEnum = 69
  optional doorTypeWood DoorTypeWoodEnum = 70
  optional drawings DrawingsEnum = 71
  optional elevator Integer = 72
  optional escalator Integer = 73
  optional expDuct QuantityValue = 74
  optional expPipe Integer = 75
  optional extDoor Integer = 76
  optional fireplaceType String = 77
  optional floorAge QuantityValue = 78
  optional floorArea QuantityValue = 79
  optional floorCond FloorCondEnum = 80
  optional floorCount Integer = 81
  optional floorFinishMat FloorFinishMatEnum = 82
  optional floorWaterMold FloorWaterMoldEnum = 83
  optional floorStruc FloorStrucEnum = 84
  optional floorThermalMass QuantityValue = 85
  optional freqClean FreqCleanEnum = 86
  optional freqCook Integer = 87
  optional furniture FurnitureEnum = 88
  optional genderRestroom GenderRestroomEnum = 89
  optional hallCount Integer = 90
  optional handidness HandidnessEnum = 91
  optional heatDelivLoc HeatDelivLocEnum = 92
  optional heatSysDelivMeth String = 93
  optional heatSystemId Integer = 94
  optional heightCarperFiber QuantityValue = 95
  optional insideLux QuantityValue = 96
  optional intWallCond IntWallCondEnum = 97
  optional lastClean Date = 98
  optional maxOccup Integer = 99
  optional mechStruc MechStrucEnum = 100
  optional numberPlants Integer = 101
  optional numberPets Integer = 102
  optional numberResident Integer = 103
  optional occupDocument OccupDocumentEnum = 104
  optional extWallOrient ExtWallOrientEnum = 105
  optional extWindowOrient ExtWindowOrientEnum = 106
  optional relHumidityOut QuantityValue = 107
  optional presAnimalInsect String = 108
  optional quadPos QuadPosEnum = 109
  optional relSampLoc RelSampLocEnum = 110
  optional roomAirExchRate QuantityValue = 111
  optional roomArchitecElem String = 112
  optional roomCondt RoomCondtEnum = 113
  optional roomCount Integer = 114
  optional roomDim String = 115
  optional roomDoorDist String = 116
  optional roomLoc RoomLocEnum = 117
  optional roomMoistDamHist Integer = 118
  optional roomNetArea String = 119
  optional roomOccup Integer = 120
  optional roomSampPos RoomSampPosEnum = 121
  optional roomType RoomTypeEnum = 122
  optional roomVol String = 123
  optional roomWindowCount Integer = 124
  optional roomConnected RoomConnectedEnum = 125
  optional roomHallway String = 126
  optional roomDoorShare String = 127
  optional roomWallShare String = 128
  optional sampWeather SampWeatherEnum = 129
  optional sampFloor SampFloorEnum = 130
  optional sampRoomId Integer = 131
  optional sampTimeOut Double = 132
  optional season String = 133
  optional seasonUse SeasonUseEnum = 134
  optional shadingDeviceCond ShadingDeviceCondEnum = 135
  optional shadingDeviceLoc String = 136
  optional shadingDeviceMat String = 137
  optional shadDevWaterMold String = 138
  optional shadingDeviceType ShadingDeviceTypeEnum = 139
  optional specificHumidity QuantityValue = 140
  optional specific SpecificEnum = 141
  optional tempOut QuantityValue = 142
  optional trainLine TrainLineEnum = 143
  optional trainStatLoc TrainStatLocEnum = 144
  optional trainStopLoc TrainStopLocEnum = 145
  optional visMedia VisMediaEnum = 146
  optional wallArea QuantityValue = 147
  optional wallConstType WallConstTypeEnum = 148
  optional wallFinishMat WallFinishMatEnum = 149
  optional wallHeight QuantityValue = 150
  optional wallLoc WallLocEnum = 151
  optional wallWaterMold String = 152
  optional wallSurfTreatment WallSurfTreatmentEnum = 153
  optional wallTexture WallTextureEnum = 154
  optional wallThermalMass QuantityValue = 155
  optional waterFeatSize QuantityValue = 156
  optional waterFeatType WaterFeatTypeEnum = 157
  optional weekday WeekdayEnum = 158
  optional windowSize String = 159
  optional windowCond WindowCondEnum = 160
  optional windowCover WindowCoverEnum = 161
  optional windowHorizPos WindowHorizPosEnum = 162
  optional windowLoc WindowLocEnum = 163
  optional windowMat WindowMatEnum = 164
  optional windowOpenFreq Integer = 165
  optional windowWaterMold String = 166
  optional windowStatus String = 167
  optional windowType WindowTypeEnum = 168
  optional windowVertPos WindowVertPosEnum = 169
  sampName String = 170
  projectName String = 171
  sampTaxonId String = 172
  optional experimentalFactor String = 173
  optional negContType NegContTypeEnum = 174
  optional posContType String = 175
  optional subspecfGenLin String = 176
  optional ploidy String = 177
  optional numReplicons Integer = 178
  optional extrachromElements Integer = 179
  optional estimatedSize String = 180
  optional refBiomaterial String = 181
  optional sourceMatId String = 182
  optional pathogenicity String = 183
  optional bioticRelationship BioticRelationshipEnum = 184
  optional specificHost String = 185
  optional hostSpecRange Integer = 186
  optional hostDiseaseStat String = 187
  optional trophicLevel TrophicLevelEnum = 188
  optional propagation String = 189
  isolGrowthCondt String = 190
  optional sampCollecDevice String = 191
  optional sampCollecMethod String = 192
  optional sampMatProcess String = 193
  optional sampSize QuantityValue = 194
  optional sampVolWeDnaExt QuantityValue = 195
  optional nuclAcidExt String = 196
  optional nuclAcidAmp String = 197
  optional libSize Integer = 198
  optional libReadsSeqd Integer = 199
  optional libLayout LibLayoutEnum = 200
  optional libVector String = 201
  optional libScreen String = 202
  optional adapters String = 203
  seqMeth String = 204
  optional taxIdent TaxIdentEnum = 205
  assemblyQual AssemblyQualEnum = 206
  optional assemblyName String = 207
  assemblySoftware String = 208
  optional annot String = 209
  numberContig Integer = 210
  optional featPred String = 211
  optional refDb String = 212
  optional simSearchMeth String = 213
  optional taxClass String = 214
  optional complScore String = 215
  optional complSoftware String = 216
  optional associatedResource String = 217
  optional sop String = 218
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: org with environmental package built environment
message BuiltEnvironmentMIGSOrg
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional geoLocName String = 5
  optional collectionDate Date = 6
  optional envBroadScale String = 7
  optional envLocalScale String = 8
  optional envMedium String = 9
  optional surfMaterial SurfMaterialEnum = 10
  repeated surfAirCont SurfAirContEnum = 11
  relAirHumidity QuantityValue = 12
  absAirHumidity QuantityValue = 13
  optional surfHumidity QuantityValue = 14
  temp QuantityValue = 15
  optional surfTemp QuantityValue = 16
  optional surfMoisturePh Double = 17
  repeated buildOccupType BuildOccupTypeEnum = 18
  optional surfMoisture QuantityValue = 19
  optional dewPoint QuantityValue = 20
  carbDioxide QuantityValue = 21
  ventilationType String = 22
  repeated organismCount OrganismCountEnum = 23
  indoorSpace IndoorSpaceEnum = 24
  optional indoorSurf IndoorSurfEnum = 25
  repeated filterType FilterTypeEnum = 26
  repeated heatCoolType HeatCoolTypeEnum = 27
  repeated substructureType SubstructureTypeEnum = 28
  buildingSetting BuildingSettingEnum = 29
  repeated lightType LightTypeEnum = 30
  repeated sampSortMeth String = 31
  spaceTypState String = 32
  typOccupDensity Double = 33
  occupSamp Integer = 34
  occupDensitySamp Double = 35
  optional address String = 36
  optional adjRoom String = 37
  optional aeroStruc String = 38
  optional amountLight QuantityValue = 39
  optional archStruc ArchStrucEnum = 40
  optional avgOccup Double = 41
  optional avgDewPoint QuantityValue = 42
  optional avgTemp QuantityValue = 43
  optional bathroomCount Integer = 44
  optional bedroomCount Integer = 45
  optional builtStrucAge QuantityValue = 46
  optional builtStrucSet String = 47
  optional builtStrucType String = 48
  optional ceilArea QuantityValue = 49
  optional ceilCond CeilCondEnum = 50
  optional ceilFinishMat CeilFinishMatEnum = 51
  optional ceilWaterMold String = 52
  optional ceilStruc String = 53
  optional ceilTexture CeilTextureEnum = 54
  optional ceilThermalMass QuantityValue = 55
  optional ceilType CeilTypeEnum = 56
  optional coolSystId Integer = 57
  optional dateLastRain Date = 58
  optional buildDocs BuildDocsEnum = 59
  optional doorSize QuantityValue = 60
  optional doorCond DoorCondEnum = 61
  optional doorDirect DoorDirectEnum = 62
  optional doorLoc DoorLocEnum = 63
  optional doorMat DoorMatEnum = 64
  optional doorMove DoorMoveEnum = 65
  optional doorWaterMold String = 66
  optional doorType DoorTypeEnum = 67
  optional doorCompType DoorCompTypeEnum = 68
  optional doorTypeMetal DoorTypeMetalEnum = 69
  optional doorTypeWood DoorTypeWoodEnum = 70
  optional drawings DrawingsEnum = 71
  optional elevator Integer = 72
  optional escalator Integer = 73
  optional expDuct QuantityValue = 74
  optional expPipe Integer = 75
  optional extDoor Integer = 76
  optional fireplaceType String = 77
  optional floorAge QuantityValue = 78
  optional floorArea QuantityValue = 79
  optional floorCond FloorCondEnum = 80
  optional floorCount Integer = 81
  optional floorFinishMat FloorFinishMatEnum = 82
  optional floorWaterMold FloorWaterMoldEnum = 83
  optional floorStruc FloorStrucEnum = 84
  optional floorThermalMass QuantityValue = 85
  optional freqClean FreqCleanEnum = 86
  optional freqCook Integer = 87
  optional furniture FurnitureEnum = 88
  optional genderRestroom GenderRestroomEnum = 89
  optional hallCount Integer = 90
  optional handidness HandidnessEnum = 91
  optional heatDelivLoc HeatDelivLocEnum = 92
  optional heatSysDelivMeth String = 93
  optional heatSystemId Integer = 94
  optional heightCarperFiber QuantityValue = 95
  optional insideLux QuantityValue = 96
  optional intWallCond IntWallCondEnum = 97
  optional lastClean Date = 98
  optional maxOccup Integer = 99
  optional mechStruc MechStrucEnum = 100
  optional numberPlants Integer = 101
  optional numberPets Integer = 102
  optional numberResident Integer = 103
  optional occupDocument OccupDocumentEnum = 104
  optional extWallOrient ExtWallOrientEnum = 105
  optional extWindowOrient ExtWindowOrientEnum = 106
  optional relHumidityOut QuantityValue = 107
  optional presAnimalInsect String = 108
  optional quadPos QuadPosEnum = 109
  optional relSampLoc RelSampLocEnum = 110
  optional roomAirExchRate QuantityValue = 111
  optional roomArchitecElem String = 112
  optional roomCondt RoomCondtEnum = 113
  optional roomCount Integer = 114
  optional roomDim String = 115
  optional roomDoorDist String = 116
  optional roomLoc RoomLocEnum = 117
  optional roomMoistDamHist Integer = 118
  optional roomNetArea String = 119
  optional roomOccup Integer = 120
  optional roomSampPos RoomSampPosEnum = 121
  optional roomType RoomTypeEnum = 122
  optional roomVol String = 123
  optional roomWindowCount Integer = 124
  optional roomConnected RoomConnectedEnum = 125
  optional roomHallway String = 126
  optional roomDoorShare String = 127
  optional roomWallShare String = 128
  optional sampWeather SampWeatherEnum = 129
  optional sampFloor SampFloorEnum = 130
  optional sampRoomId Integer = 131
  optional sampTimeOut Double = 132
  optional season String = 133
  optional seasonUse SeasonUseEnum = 134
  optional shadingDeviceCond ShadingDeviceCondEnum = 135
  optional shadingDeviceLoc String = 136
  optional shadingDeviceMat String = 137
  optional shadDevWaterMold String = 138
  optional shadingDeviceType ShadingDeviceTypeEnum = 139
  optional specificHumidity QuantityValue = 140
  optional specific SpecificEnum = 141
  optional tempOut QuantityValue = 142
  optional trainLine TrainLineEnum = 143
  optional trainStatLoc TrainStatLocEnum = 144
  optional trainStopLoc TrainStopLocEnum = 145
  optional visMedia VisMediaEnum = 146
  optional wallArea QuantityValue = 147
  optional wallConstType WallConstTypeEnum = 148
  optional wallFinishMat WallFinishMatEnum = 149
  optional wallHeight QuantityValue = 150
  optional wallLoc WallLocEnum = 151
  optional wallWaterMold String = 152
  optional wallSurfTreatment WallSurfTreatmentEnum = 153
  optional wallTexture WallTextureEnum = 154
  optional wallThermalMass QuantityValue = 155
  optional waterFeatSize QuantityValue = 156
  optional waterFeatType WaterFeatTypeEnum = 157
  optional weekday WeekdayEnum = 158
  optional windowSize String = 159
  optional windowCond WindowCondEnum = 160
  optional windowCover WindowCoverEnum = 161
  optional windowHorizPos WindowHorizPosEnum = 162
  optional windowLoc WindowLocEnum = 163
  optional windowMat WindowMatEnum = 164
  optional windowOpenFreq Integer = 165
  optional windowWaterMold String = 166
  optional windowStatus String = 167
  optional windowType WindowTypeEnum = 168
  optional windowVertPos WindowVertPosEnum = 169
  sampName String = 170
  projectName String = 171
  sampTaxonId String = 172
  optional experimentalFactor String = 173
  optional negContType NegContTypeEnum = 174
  optional posContType String = 175
  optional subspecfGenLin String = 176
  optional extrachromElements Integer = 177
  optional estimatedSize String = 178
  optional refBiomaterial String = 179
  optional sourceMatId String = 180
  isolGrowthCondt String = 181
  optional sampCollecDevice String = 182
  optional sampCollecMethod String = 183
  optional sampMatProcess String = 184
  optional sampSize QuantityValue = 185
  optional sampVolWeDnaExt QuantityValue = 186
  optional nuclAcidExt String = 187
  optional nuclAcidAmp String = 188
  optional libSize Integer = 189
  optional libReadsSeqd Integer = 190
  optional libLayout LibLayoutEnum = 191
  optional libVector String = 192
  optional libScreen String = 193
  optional adapters String = 194
  seqMeth String = 195
  optional taxIdent TaxIdentEnum = 196
  optional assemblyQual AssemblyQualEnum = 197
  optional assemblyName String = 198
  assemblySoftware String = 199
  optional annot String = 200
  optional numberContig Integer = 201
  optional featPred String = 202
  optional refDb String = 203
  optional simSearchMeth String = 204
  optional taxClass String = 205
  optional complScore String = 206
  optional complSoftware String = 207
  optional associatedResource String = 208
  optional sop String = 209
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: plant with environmental package built environment
message BuiltEnvironmentMIGSPlant
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional geoLocName String = 5
  optional collectionDate Date = 6
  optional envBroadScale String = 7
  optional envLocalScale String = 8
  optional envMedium String = 9
  optional surfMaterial SurfMaterialEnum = 10
  repeated surfAirCont SurfAirContEnum = 11
  relAirHumidity QuantityValue = 12
  absAirHumidity QuantityValue = 13
  optional surfHumidity QuantityValue = 14
  temp QuantityValue = 15
  optional surfTemp QuantityValue = 16
  optional surfMoisturePh Double = 17
  repeated buildOccupType BuildOccupTypeEnum = 18
  optional surfMoisture QuantityValue = 19
  optional dewPoint QuantityValue = 20
  carbDioxide QuantityValue = 21
  ventilationType String = 22
  repeated organismCount OrganismCountEnum = 23
  indoorSpace IndoorSpaceEnum = 24
  optional indoorSurf IndoorSurfEnum = 25
  repeated filterType FilterTypeEnum = 26
  repeated heatCoolType HeatCoolTypeEnum = 27
  repeated substructureType SubstructureTypeEnum = 28
  buildingSetting BuildingSettingEnum = 29
  repeated lightType LightTypeEnum = 30
  repeated sampSortMeth String = 31
  spaceTypState String = 32
  typOccupDensity Double = 33
  occupSamp Integer = 34
  occupDensitySamp Double = 35
  optional address String = 36
  optional adjRoom String = 37
  optional aeroStruc String = 38
  optional amountLight QuantityValue = 39
  optional archStruc ArchStrucEnum = 40
  optional avgOccup Double = 41
  optional avgDewPoint QuantityValue = 42
  optional avgTemp QuantityValue = 43
  optional bathroomCount Integer = 44
  optional bedroomCount Integer = 45
  optional builtStrucAge QuantityValue = 46
  optional builtStrucSet String = 47
  optional builtStrucType String = 48
  optional ceilArea QuantityValue = 49
  optional ceilCond CeilCondEnum = 50
  optional ceilFinishMat CeilFinishMatEnum = 51
  optional ceilWaterMold String = 52
  optional ceilStruc String = 53
  optional ceilTexture CeilTextureEnum = 54
  optional ceilThermalMass QuantityValue = 55
  optional ceilType CeilTypeEnum = 56
  optional coolSystId Integer = 57
  optional dateLastRain Date = 58
  optional buildDocs BuildDocsEnum = 59
  optional doorSize QuantityValue = 60
  optional doorCond DoorCondEnum = 61
  optional doorDirect DoorDirectEnum = 62
  optional doorLoc DoorLocEnum = 63
  optional doorMat DoorMatEnum = 64
  optional doorMove DoorMoveEnum = 65
  optional doorWaterMold String = 66
  optional doorType DoorTypeEnum = 67
  optional doorCompType DoorCompTypeEnum = 68
  optional doorTypeMetal DoorTypeMetalEnum = 69
  optional doorTypeWood DoorTypeWoodEnum = 70
  optional drawings DrawingsEnum = 71
  optional elevator Integer = 72
  optional escalator Integer = 73
  optional expDuct QuantityValue = 74
  optional expPipe Integer = 75
  optional extDoor Integer = 76
  optional fireplaceType String = 77
  optional floorAge QuantityValue = 78
  optional floorArea QuantityValue = 79
  optional floorCond FloorCondEnum = 80
  optional floorCount Integer = 81
  optional floorFinishMat FloorFinishMatEnum = 82
  optional floorWaterMold FloorWaterMoldEnum = 83
  optional floorStruc FloorStrucEnum = 84
  optional floorThermalMass QuantityValue = 85
  optional freqClean FreqCleanEnum = 86
  optional freqCook Integer = 87
  optional furniture FurnitureEnum = 88
  optional genderRestroom GenderRestroomEnum = 89
  optional hallCount Integer = 90
  optional handidness HandidnessEnum = 91
  optional heatDelivLoc HeatDelivLocEnum = 92
  optional heatSysDelivMeth String = 93
  optional heatSystemId Integer = 94
  optional heightCarperFiber QuantityValue = 95
  optional insideLux QuantityValue = 96
  optional intWallCond IntWallCondEnum = 97
  optional lastClean Date = 98
  optional maxOccup Integer = 99
  optional mechStruc MechStrucEnum = 100
  optional numberPlants Integer = 101
  optional numberPets Integer = 102
  optional numberResident Integer = 103
  optional occupDocument OccupDocumentEnum = 104
  optional extWallOrient ExtWallOrientEnum = 105
  optional extWindowOrient ExtWindowOrientEnum = 106
  optional relHumidityOut QuantityValue = 107
  optional presAnimalInsect String = 108
  optional quadPos QuadPosEnum = 109
  optional relSampLoc RelSampLocEnum = 110
  optional roomAirExchRate QuantityValue = 111
  optional roomArchitecElem String = 112
  optional roomCondt RoomCondtEnum = 113
  optional roomCount Integer = 114
  optional roomDim String = 115
  optional roomDoorDist String = 116
  optional roomLoc RoomLocEnum = 117
  optional roomMoistDamHist Integer = 118
  optional roomNetArea String = 119
  optional roomOccup Integer = 120
  optional roomSampPos RoomSampPosEnum = 121
  optional roomType RoomTypeEnum = 122
  optional roomVol String = 123
  optional roomWindowCount Integer = 124
  optional roomConnected RoomConnectedEnum = 125
  optional roomHallway String = 126
  optional roomDoorShare String = 127
  optional roomWallShare String = 128
  optional sampWeather SampWeatherEnum = 129
  optional sampFloor SampFloorEnum = 130
  optional sampRoomId Integer = 131
  optional sampTimeOut Double = 132
  optional season String = 133
  optional seasonUse SeasonUseEnum = 134
  optional shadingDeviceCond ShadingDeviceCondEnum = 135
  optional shadingDeviceLoc String = 136
  optional shadingDeviceMat String = 137
  optional shadDevWaterMold String = 138
  optional shadingDeviceType ShadingDeviceTypeEnum = 139
  optional specificHumidity QuantityValue = 140
  optional specific SpecificEnum = 141
  optional tempOut QuantityValue = 142
  optional trainLine TrainLineEnum = 143
  optional trainStatLoc TrainStatLocEnum = 144
  optional trainStopLoc TrainStopLocEnum = 145
  optional visMedia VisMediaEnum = 146
  optional wallArea QuantityValue = 147
  optional wallConstType WallConstTypeEnum = 148
  optional wallFinishMat WallFinishMatEnum = 149
  optional wallHeight QuantityValue = 150
  optional wallLoc WallLocEnum = 151
  optional wallWaterMold String = 152
  optional wallSurfTreatment WallSurfTreatmentEnum = 153
  optional wallTexture WallTextureEnum = 154
  optional wallThermalMass QuantityValue = 155
  optional waterFeatSize QuantityValue = 156
  optional waterFeatType WaterFeatTypeEnum = 157
  optional weekday WeekdayEnum = 158
  optional windowSize String = 159
  optional windowCond WindowCondEnum = 160
  optional windowCover WindowCoverEnum = 161
  optional windowHorizPos WindowHorizPosEnum = 162
  optional windowLoc WindowLocEnum = 163
  optional windowMat WindowMatEnum = 164
  optional windowOpenFreq Integer = 165
  optional windowWaterMold String = 166
  optional windowStatus String = 167
  optional windowType WindowTypeEnum = 168
  optional windowVertPos WindowVertPosEnum = 169
  sampName String = 170
  projectName String = 171
  sampTaxonId String = 172
  optional experimentalFactor String = 173
  optional negContType NegContTypeEnum = 174
  optional posContType String = 175
  optional subspecfGenLin String = 176
  optional estimatedSize String = 177
  optional refBiomaterial String = 178
  optional sourceMatId String = 179
  optional specificHost String = 180
  optional hostSpecRange Integer = 181
  propagation String = 182
  optional encodedTraits String = 183
  isolGrowthCondt String = 184
  optional sampCollecDevice String = 185
  optional sampCollecMethod String = 186
  optional sampMatProcess String = 187
  optional sampSize QuantityValue = 188
  optional sampVolWeDnaExt QuantityValue = 189
  optional nuclAcidExt String = 190
  optional nuclAcidAmp String = 191
  optional libSize Integer = 192
  optional libReadsSeqd Integer = 193
  optional libLayout LibLayoutEnum = 194
  optional libVector String = 195
  optional libScreen String = 196
  optional adapters String = 197
  seqMeth String = 198
  optional taxIdent TaxIdentEnum = 199
  optional assemblyQual AssemblyQualEnum = 200
  optional assemblyName String = 201
  assemblySoftware String = 202
  optional annot String = 203
  optional numberContig Integer = 204
  optional featPred String = 205
  optional refDb String = 206
  optional simSearchMeth String = 207
  optional taxClass String = 208
  optional complScore String = 209
  optional complSoftware String = 210
  optional associatedResource String = 211
  optional sop String = 212
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package built environment
message BuiltEnvironmentMIGSVirus
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional geoLocName String = 5
  optional collectionDate Date = 6
  optional envBroadScale String = 7
  optional envLocalScale String = 8
  optional envMedium String = 9
  optional surfMaterial SurfMaterialEnum = 10
  repeated surfAirCont SurfAirContEnum = 11
  relAirHumidity QuantityValue = 12
  absAirHumidity QuantityValue = 13
  optional surfHumidity QuantityValue = 14
  temp QuantityValue = 15
  optional surfTemp QuantityValue = 16
  optional surfMoisturePh Double = 17
  repeated buildOccupType BuildOccupTypeEnum = 18
  optional surfMoisture QuantityValue = 19
  optional dewPoint QuantityValue = 20
  carbDioxide QuantityValue = 21
  ventilationType String = 22
  repeated organismCount OrganismCountEnum = 23
  indoorSpace IndoorSpaceEnum = 24
  optional indoorSurf IndoorSurfEnum = 25
  repeated filterType FilterTypeEnum = 26
  repeated heatCoolType HeatCoolTypeEnum = 27
  repeated substructureType SubstructureTypeEnum = 28
  buildingSetting BuildingSettingEnum = 29
  repeated lightType LightTypeEnum = 30
  repeated sampSortMeth String = 31
  spaceTypState String = 32
  typOccupDensity Double = 33
  occupSamp Integer = 34
  occupDensitySamp Double = 35
  optional address String = 36
  optional adjRoom String = 37
  optional aeroStruc String = 38
  optional amountLight QuantityValue = 39
  optional archStruc ArchStrucEnum = 40
  optional avgOccup Double = 41
  optional avgDewPoint QuantityValue = 42
  optional avgTemp QuantityValue = 43
  optional bathroomCount Integer = 44
  optional bedroomCount Integer = 45
  optional builtStrucAge QuantityValue = 46
  optional builtStrucSet String = 47
  optional builtStrucType String = 48
  optional ceilArea QuantityValue = 49
  optional ceilCond CeilCondEnum = 50
  optional ceilFinishMat CeilFinishMatEnum = 51
  optional ceilWaterMold String = 52
  optional ceilStruc String = 53
  optional ceilTexture CeilTextureEnum = 54
  optional ceilThermalMass QuantityValue = 55
  optional ceilType CeilTypeEnum = 56
  optional coolSystId Integer = 57
  optional dateLastRain Date = 58
  optional buildDocs BuildDocsEnum = 59
  optional doorSize QuantityValue = 60
  optional doorCond DoorCondEnum = 61
  optional doorDirect DoorDirectEnum = 62
  optional doorLoc DoorLocEnum = 63
  optional doorMat DoorMatEnum = 64
  optional doorMove DoorMoveEnum = 65
  optional doorWaterMold String = 66
  optional doorType DoorTypeEnum = 67
  optional doorCompType DoorCompTypeEnum = 68
  optional doorTypeMetal DoorTypeMetalEnum = 69
  optional doorTypeWood DoorTypeWoodEnum = 70
  optional drawings DrawingsEnum = 71
  optional elevator Integer = 72
  optional escalator Integer = 73
  optional expDuct QuantityValue = 74
  optional expPipe Integer = 75
  optional extDoor Integer = 76
  optional fireplaceType String = 77
  optional floorAge QuantityValue = 78
  optional floorArea QuantityValue = 79
  optional floorCond FloorCondEnum = 80
  optional floorCount Integer = 81
  optional floorFinishMat FloorFinishMatEnum = 82
  optional floorWaterMold FloorWaterMoldEnum = 83
  optional floorStruc FloorStrucEnum = 84
  optional floorThermalMass QuantityValue = 85
  optional freqClean FreqCleanEnum = 86
  optional freqCook Integer = 87
  optional furniture FurnitureEnum = 88
  optional genderRestroom GenderRestroomEnum = 89
  optional hallCount Integer = 90
  optional handidness HandidnessEnum = 91
  optional heatDelivLoc HeatDelivLocEnum = 92
  optional heatSysDelivMeth String = 93
  optional heatSystemId Integer = 94
  optional heightCarperFiber QuantityValue = 95
  optional insideLux QuantityValue = 96
  optional intWallCond IntWallCondEnum = 97
  optional lastClean Date = 98
  optional maxOccup Integer = 99
  optional mechStruc MechStrucEnum = 100
  optional numberPlants Integer = 101
  optional numberPets Integer = 102
  optional numberResident Integer = 103
  optional occupDocument OccupDocumentEnum = 104
  optional extWallOrient ExtWallOrientEnum = 105
  optional extWindowOrient ExtWindowOrientEnum = 106
  optional relHumidityOut QuantityValue = 107
  optional presAnimalInsect String = 108
  optional quadPos QuadPosEnum = 109
  optional relSampLoc RelSampLocEnum = 110
  optional roomAirExchRate QuantityValue = 111
  optional roomArchitecElem String = 112
  optional roomCondt RoomCondtEnum = 113
  optional roomCount Integer = 114
  optional roomDim String = 115
  optional roomDoorDist String = 116
  optional roomLoc RoomLocEnum = 117
  optional roomMoistDamHist Integer = 118
  optional roomNetArea String = 119
  optional roomOccup Integer = 120
  optional roomSampPos RoomSampPosEnum = 121
  optional roomType RoomTypeEnum = 122
  optional roomVol String = 123
  optional roomWindowCount Integer = 124
  optional roomConnected RoomConnectedEnum = 125
  optional roomHallway String = 126
  optional roomDoorShare String = 127
  optional roomWallShare String = 128
  optional sampWeather SampWeatherEnum = 129
  optional sampFloor SampFloorEnum = 130
  optional sampRoomId Integer = 131
  optional sampTimeOut Double = 132
  optional season String = 133
  optional seasonUse SeasonUseEnum = 134
  optional shadingDeviceCond ShadingDeviceCondEnum = 135
  optional shadingDeviceLoc String = 136
  optional shadingDeviceMat String = 137
  optional shadDevWaterMold String = 138
  optional shadingDeviceType ShadingDeviceTypeEnum = 139
  optional specificHumidity QuantityValue = 140
  optional specific SpecificEnum = 141
  optional tempOut QuantityValue = 142
  optional trainLine TrainLineEnum = 143
  optional trainStatLoc TrainStatLocEnum = 144
  optional trainStopLoc TrainStopLocEnum = 145
  optional visMedia VisMediaEnum = 146
  optional wallArea QuantityValue = 147
  optional wallConstType WallConstTypeEnum = 148
  optional wallFinishMat WallFinishMatEnum = 149
  optional wallHeight QuantityValue = 150
  optional wallLoc WallLocEnum = 151
  optional wallWaterMold String = 152
  optional wallSurfTreatment WallSurfTreatmentEnum = 153
  optional wallTexture WallTextureEnum = 154
  optional wallThermalMass QuantityValue = 155
  optional waterFeatSize QuantityValue = 156
  optional waterFeatType WaterFeatTypeEnum = 157
  optional weekday WeekdayEnum = 158
  optional windowSize String = 159
  optional windowCond WindowCondEnum = 160
  optional windowCover WindowCoverEnum = 161
  optional windowHorizPos WindowHorizPosEnum = 162
  optional windowLoc WindowLocEnum = 163
  optional windowMat WindowMatEnum = 164
  optional windowOpenFreq Integer = 165
  optional windowWaterMold String = 166
  optional windowStatus String = 167
  optional windowType WindowTypeEnum = 168
  optional windowVertPos WindowVertPosEnum = 169
  sampName String = 170
  projectName String = 171
  sampTaxonId String = 172
  optional experimentalFactor String = 173
  optional negContType NegContTypeEnum = 174
  optional posContType String = 175
  optional subspecfGenLin String = 176
  optional numReplicons Integer = 177
  optional estimatedSize String = 178
  optional refBiomaterial String = 179
  optional sourceMatId String = 180
  optional pathogenicity String = 181
  optional bioticRelationship BioticRelationshipEnum = 182
  optional specificHost String = 183
  optional hostSpecRange Integer = 184
  optional hostDiseaseStat String = 185
  propagation String = 186
  optional encodedTraits String = 187
  isolGrowthCondt String = 188
  optional sampCollecDevice String = 189
  optional sampCollecMethod String = 190
  optional sampMatProcess String = 191
  optional sampSize QuantityValue = 192
  optional sampVolWeDnaExt QuantityValue = 193
  optional virusEnrichAppr VirusEnrichApprEnum = 194
  optional nuclAcidExt String = 195
  optional nuclAcidAmp String = 196
  optional libSize Integer = 197
  optional libReadsSeqd Integer = 198
  optional libLayout LibLayoutEnum = 199
  optional libVector String = 200
  optional libScreen String = 201
  optional adapters String = 202
  seqMeth String = 203
  optional taxIdent TaxIdentEnum = 204
  optional assemblyQual AssemblyQualEnum = 205
  optional assemblyName String = 206
  assemblySoftware String = 207
  optional annot String = 208
  optional numberContig Integer = 209
  optional featPred String = 210
  optional refDb String = 211
  optional simSearchMeth String = 212
  optional taxClass String = 213
  optional complScore String = 214
  optional complSoftware String = 215
  optional associatedResource String = 216
  optional sop String = 217
 }
// Combinatorial checklist Minimum Information About a Metagenome-Assembled Genome with environmental package built environment
message BuiltEnvironmentMIMAG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional geoLocName String = 5
  optional collectionDate Date = 6
  optional envBroadScale String = 7
  optional envLocalScale String = 8
  optional envMedium String = 9
  optional surfMaterial SurfMaterialEnum = 10
  repeated surfAirCont SurfAirContEnum = 11
  relAirHumidity QuantityValue = 12
  absAirHumidity QuantityValue = 13
  optional surfHumidity QuantityValue = 14
  temp QuantityValue = 15
  optional surfTemp QuantityValue = 16
  optional surfMoisturePh Double = 17
  repeated buildOccupType BuildOccupTypeEnum = 18
  optional surfMoisture QuantityValue = 19
  optional dewPoint QuantityValue = 20
  carbDioxide QuantityValue = 21
  ventilationType String = 22
  repeated organismCount OrganismCountEnum = 23
  indoorSpace IndoorSpaceEnum = 24
  optional indoorSurf IndoorSurfEnum = 25
  repeated filterType FilterTypeEnum = 26
  repeated heatCoolType HeatCoolTypeEnum = 27
  repeated substructureType SubstructureTypeEnum = 28
  buildingSetting BuildingSettingEnum = 29
  repeated lightType LightTypeEnum = 30
  repeated sampSortMeth String = 31
  spaceTypState String = 32
  typOccupDensity Double = 33
  occupSamp Integer = 34
  occupDensitySamp Double = 35
  optional address String = 36
  optional adjRoom String = 37
  optional aeroStruc String = 38
  optional amountLight QuantityValue = 39
  optional archStruc ArchStrucEnum = 40
  optional avgOccup Double = 41
  optional avgDewPoint QuantityValue = 42
  optional avgTemp QuantityValue = 43
  optional bathroomCount Integer = 44
  optional bedroomCount Integer = 45
  optional builtStrucAge QuantityValue = 46
  optional builtStrucSet String = 47
  optional builtStrucType String = 48
  optional ceilArea QuantityValue = 49
  optional ceilCond CeilCondEnum = 50
  optional ceilFinishMat CeilFinishMatEnum = 51
  optional ceilWaterMold String = 52
  optional ceilStruc String = 53
  optional ceilTexture CeilTextureEnum = 54
  optional ceilThermalMass QuantityValue = 55
  optional ceilType CeilTypeEnum = 56
  optional coolSystId Integer = 57
  optional dateLastRain Date = 58
  optional buildDocs BuildDocsEnum = 59
  optional doorSize QuantityValue = 60
  optional doorCond DoorCondEnum = 61
  optional doorDirect DoorDirectEnum = 62
  optional doorLoc DoorLocEnum = 63
  optional doorMat DoorMatEnum = 64
  optional doorMove DoorMoveEnum = 65
  optional doorWaterMold String = 66
  optional doorType DoorTypeEnum = 67
  optional doorCompType DoorCompTypeEnum = 68
  optional doorTypeMetal DoorTypeMetalEnum = 69
  optional doorTypeWood DoorTypeWoodEnum = 70
  optional drawings DrawingsEnum = 71
  optional elevator Integer = 72
  optional escalator Integer = 73
  optional expDuct QuantityValue = 74
  optional expPipe Integer = 75
  optional extDoor Integer = 76
  optional fireplaceType String = 77
  optional floorAge QuantityValue = 78
  optional floorArea QuantityValue = 79
  optional floorCond FloorCondEnum = 80
  optional floorCount Integer = 81
  optional floorFinishMat FloorFinishMatEnum = 82
  optional floorWaterMold FloorWaterMoldEnum = 83
  optional floorStruc FloorStrucEnum = 84
  optional floorThermalMass QuantityValue = 85
  optional freqClean FreqCleanEnum = 86
  optional freqCook Integer = 87
  optional furniture FurnitureEnum = 88
  optional genderRestroom GenderRestroomEnum = 89
  optional hallCount Integer = 90
  optional handidness HandidnessEnum = 91
  optional heatDelivLoc HeatDelivLocEnum = 92
  optional heatSysDelivMeth String = 93
  optional heatSystemId Integer = 94
  optional heightCarperFiber QuantityValue = 95
  optional insideLux QuantityValue = 96
  optional intWallCond IntWallCondEnum = 97
  optional lastClean Date = 98
  optional maxOccup Integer = 99
  optional mechStruc MechStrucEnum = 100
  optional numberPlants Integer = 101
  optional numberPets Integer = 102
  optional numberResident Integer = 103
  optional occupDocument OccupDocumentEnum = 104
  optional extWallOrient ExtWallOrientEnum = 105
  optional extWindowOrient ExtWindowOrientEnum = 106
  optional relHumidityOut QuantityValue = 107
  optional presAnimalInsect String = 108
  optional quadPos QuadPosEnum = 109
  optional relSampLoc RelSampLocEnum = 110
  optional roomAirExchRate QuantityValue = 111
  optional roomArchitecElem String = 112
  optional roomCondt RoomCondtEnum = 113
  optional roomCount Integer = 114
  optional roomDim String = 115
  optional roomDoorDist String = 116
  optional roomLoc RoomLocEnum = 117
  optional roomMoistDamHist Integer = 118
  optional roomNetArea String = 119
  optional roomOccup Integer = 120
  optional roomSampPos RoomSampPosEnum = 121
  optional roomType RoomTypeEnum = 122
  optional roomVol String = 123
  optional roomWindowCount Integer = 124
  optional roomConnected RoomConnectedEnum = 125
  optional roomHallway String = 126
  optional roomDoorShare String = 127
  optional roomWallShare String = 128
  optional sampWeather SampWeatherEnum = 129
  optional sampFloor SampFloorEnum = 130
  optional sampRoomId Integer = 131
  optional sampTimeOut Double = 132
  optional season String = 133
  optional seasonUse SeasonUseEnum = 134
  optional shadingDeviceCond ShadingDeviceCondEnum = 135
  optional shadingDeviceLoc String = 136
  optional shadingDeviceMat String = 137
  optional shadDevWaterMold String = 138
  optional shadingDeviceType ShadingDeviceTypeEnum = 139
  optional specificHumidity QuantityValue = 140
  optional specific SpecificEnum = 141
  optional tempOut QuantityValue = 142
  optional trainLine TrainLineEnum = 143
  optional trainStatLoc TrainStatLocEnum = 144
  optional trainStopLoc TrainStopLocEnum = 145
  optional visMedia VisMediaEnum = 146
  optional wallArea QuantityValue = 147
  optional wallConstType WallConstTypeEnum = 148
  optional wallFinishMat WallFinishMatEnum = 149
  optional wallHeight QuantityValue = 150
  optional wallLoc WallLocEnum = 151
  optional wallWaterMold String = 152
  optional wallSurfTreatment WallSurfTreatmentEnum = 153
  optional wallTexture WallTextureEnum = 154
  optional wallThermalMass QuantityValue = 155
  optional waterFeatSize QuantityValue = 156
  optional waterFeatType WaterFeatTypeEnum = 157
  optional weekday WeekdayEnum = 158
  optional windowSize String = 159
  optional windowCond WindowCondEnum = 160
  optional windowCover WindowCoverEnum = 161
  optional windowHorizPos WindowHorizPosEnum = 162
  optional windowLoc WindowLocEnum = 163
  optional windowMat WindowMatEnum = 164
  optional windowOpenFreq Integer = 165
  optional windowWaterMold String = 166
  optional windowStatus String = 167
  optional windowType WindowTypeEnum = 168
  optional windowVertPos WindowVertPosEnum = 169
  sampName String = 170
  projectName String = 171
  sampTaxonId String = 172
  optional experimentalFactor String = 173
  optional negContType NegContTypeEnum = 174
  optional posContType String = 175
  optional refBiomaterial String = 176
  optional sourceMatId String = 177
  optional relToOxygen RelToOxygenEnum = 178
  optional sampCollecDevice String = 179
  optional sampCollecMethod String = 180
  optional sampMatProcess String = 181
  optional sizeFrac String = 182
  optional sampSize QuantityValue = 183
  optional sampVolWeDnaExt QuantityValue = 184
  optional nuclAcidExt String = 185
  optional nuclAcidAmp String = 186
  optional libSize Integer = 187
  optional libReadsSeqd Integer = 188
  optional libLayout LibLayoutEnum = 189
  optional libVector String = 190
  optional libScreen String = 191
  optional mid String = 192
  optional adapters String = 193
  seqMeth String = 194
  taxIdent TaxIdentEnum = 195
  assemblyQual AssemblyQualEnum = 196
  optional assemblyName String = 197
  assemblySoftware String = 198
  optional annot String = 199
  optional numberContig Integer = 200
  optional featPred String = 201
  optional refDb String = 202
  optional simSearchMeth String = 203
  optional taxClass String = 204
  optional x16sRecover String = 205
  optional x16sRecoverSoftware String = 206
  optional trnas Integer = 207
  optional trnaExtSoftware String = 208
  complScore String = 209
  complSoftware String = 210
  optional complAppr ComplApprEnum = 211
  contamScore String = 212
  optional contamScreenInput String = 213
  optional contamScreenParam String = 214
  optional decontamSoftware DecontamSoftwareEnum = 215
  binParam BinParamEnum = 216
  binSoftware String = 217
  optional reassemblyBin String = 218
  optional magCovSoftware MagCovSoftwareEnum = 219
  optional associatedResource String = 220
  optional sop String = 221
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: specimen with environmental package built environment
message BuiltEnvironmentMIMARKSSpecimen
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional geoLocName String = 5
  optional collectionDate Date = 6
  optional envBroadScale String = 7
  optional envLocalScale String = 8
  optional envMedium String = 9
  optional surfMaterial SurfMaterialEnum = 10
  repeated surfAirCont SurfAirContEnum = 11
  relAirHumidity QuantityValue = 12
  absAirHumidity QuantityValue = 13
  optional surfHumidity QuantityValue = 14
  temp QuantityValue = 15
  optional surfTemp QuantityValue = 16
  optional surfMoisturePh Double = 17
  repeated buildOccupType BuildOccupTypeEnum = 18
  optional surfMoisture QuantityValue = 19
  optional dewPoint QuantityValue = 20
  carbDioxide QuantityValue = 21
  ventilationType String = 22
  repeated organismCount OrganismCountEnum = 23
  indoorSpace IndoorSpaceEnum = 24
  optional indoorSurf IndoorSurfEnum = 25
  repeated filterType FilterTypeEnum = 26
  repeated heatCoolType HeatCoolTypeEnum = 27
  repeated substructureType SubstructureTypeEnum = 28
  buildingSetting BuildingSettingEnum = 29
  repeated lightType LightTypeEnum = 30
  repeated sampSortMeth String = 31
  spaceTypState String = 32
  typOccupDensity Double = 33
  occupSamp Integer = 34
  occupDensitySamp Double = 35
  optional address String = 36
  optional adjRoom String = 37
  optional aeroStruc String = 38
  optional amountLight QuantityValue = 39
  optional archStruc ArchStrucEnum = 40
  optional avgOccup Double = 41
  optional avgDewPoint QuantityValue = 42
  optional avgTemp QuantityValue = 43
  optional bathroomCount Integer = 44
  optional bedroomCount Integer = 45
  optional builtStrucAge QuantityValue = 46
  optional builtStrucSet String = 47
  optional builtStrucType String = 48
  optional ceilArea QuantityValue = 49
  optional ceilCond CeilCondEnum = 50
  optional ceilFinishMat CeilFinishMatEnum = 51
  optional ceilWaterMold String = 52
  optional ceilStruc String = 53
  optional ceilTexture CeilTextureEnum = 54
  optional ceilThermalMass QuantityValue = 55
  optional ceilType CeilTypeEnum = 56
  optional coolSystId Integer = 57
  optional dateLastRain Date = 58
  optional buildDocs BuildDocsEnum = 59
  optional doorSize QuantityValue = 60
  optional doorCond DoorCondEnum = 61
  optional doorDirect DoorDirectEnum = 62
  optional doorLoc DoorLocEnum = 63
  optional doorMat DoorMatEnum = 64
  optional doorMove DoorMoveEnum = 65
  optional doorWaterMold String = 66
  optional doorType DoorTypeEnum = 67
  optional doorCompType DoorCompTypeEnum = 68
  optional doorTypeMetal DoorTypeMetalEnum = 69
  optional doorTypeWood DoorTypeWoodEnum = 70
  optional drawings DrawingsEnum = 71
  optional elevator Integer = 72
  optional escalator Integer = 73
  optional expDuct QuantityValue = 74
  optional expPipe Integer = 75
  optional extDoor Integer = 76
  optional fireplaceType String = 77
  optional floorAge QuantityValue = 78
  optional floorArea QuantityValue = 79
  optional floorCond FloorCondEnum = 80
  optional floorCount Integer = 81
  optional floorFinishMat FloorFinishMatEnum = 82
  optional floorWaterMold FloorWaterMoldEnum = 83
  optional floorStruc FloorStrucEnum = 84
  optional floorThermalMass QuantityValue = 85
  optional freqClean FreqCleanEnum = 86
  optional freqCook Integer = 87
  optional furniture FurnitureEnum = 88
  optional genderRestroom GenderRestroomEnum = 89
  optional hallCount Integer = 90
  optional handidness HandidnessEnum = 91
  optional heatDelivLoc HeatDelivLocEnum = 92
  optional heatSysDelivMeth String = 93
  optional heatSystemId Integer = 94
  optional heightCarperFiber QuantityValue = 95
  optional insideLux QuantityValue = 96
  optional intWallCond IntWallCondEnum = 97
  optional lastClean Date = 98
  optional maxOccup Integer = 99
  optional mechStruc MechStrucEnum = 100
  optional numberPlants Integer = 101
  optional numberPets Integer = 102
  optional numberResident Integer = 103
  optional occupDocument OccupDocumentEnum = 104
  optional extWallOrient ExtWallOrientEnum = 105
  optional extWindowOrient ExtWindowOrientEnum = 106
  optional relHumidityOut QuantityValue = 107
  optional presAnimalInsect String = 108
  optional quadPos QuadPosEnum = 109
  optional relSampLoc RelSampLocEnum = 110
  optional roomAirExchRate QuantityValue = 111
  optional roomArchitecElem String = 112
  optional roomCondt RoomCondtEnum = 113
  optional roomCount Integer = 114
  optional roomDim String = 115
  optional roomDoorDist String = 116
  optional roomLoc RoomLocEnum = 117
  optional roomMoistDamHist Integer = 118
  optional roomNetArea String = 119
  optional roomOccup Integer = 120
  optional roomSampPos RoomSampPosEnum = 121
  optional roomType RoomTypeEnum = 122
  optional roomVol String = 123
  optional roomWindowCount Integer = 124
  optional roomConnected RoomConnectedEnum = 125
  optional roomHallway String = 126
  optional roomDoorShare String = 127
  optional roomWallShare String = 128
  optional sampWeather SampWeatherEnum = 129
  optional sampFloor SampFloorEnum = 130
  optional sampRoomId Integer = 131
  optional sampTimeOut Double = 132
  optional season String = 133
  optional seasonUse SeasonUseEnum = 134
  optional shadingDeviceCond ShadingDeviceCondEnum = 135
  optional shadingDeviceLoc String = 136
  optional shadingDeviceMat String = 137
  optional shadDevWaterMold String = 138
  optional shadingDeviceType ShadingDeviceTypeEnum = 139
  optional specificHumidity QuantityValue = 140
  optional specific SpecificEnum = 141
  optional tempOut QuantityValue = 142
  optional trainLine TrainLineEnum = 143
  optional trainStatLoc TrainStatLocEnum = 144
  optional trainStopLoc TrainStopLocEnum = 145
  optional visMedia VisMediaEnum = 146
  optional wallArea QuantityValue = 147
  optional wallConstType WallConstTypeEnum = 148
  optional wallFinishMat WallFinishMatEnum = 149
  optional wallHeight QuantityValue = 150
  optional wallLoc WallLocEnum = 151
  optional wallWaterMold String = 152
  optional wallSurfTreatment WallSurfTreatmentEnum = 153
  optional wallTexture WallTextureEnum = 154
  optional wallThermalMass QuantityValue = 155
  optional waterFeatSize QuantityValue = 156
  optional waterFeatType WaterFeatTypeEnum = 157
  optional weekday WeekdayEnum = 158
  optional windowSize String = 159
  optional windowCond WindowCondEnum = 160
  optional windowCover WindowCoverEnum = 161
  optional windowHorizPos WindowHorizPosEnum = 162
  optional windowLoc WindowLocEnum = 163
  optional windowMat WindowMatEnum = 164
  optional windowOpenFreq Integer = 165
  optional windowWaterMold String = 166
  optional windowStatus String = 167
  optional windowType WindowTypeEnum = 168
  optional windowVertPos WindowVertPosEnum = 169
  sampName String = 170
  projectName String = 171
  sampTaxonId String = 172
  optional experimentalFactor String = 173
  optional negContType NegContTypeEnum = 174
  optional posContType String = 175
  optional sourceMatId String = 176
  optional relToOxygen RelToOxygenEnum = 177
  optional sampCollecDevice String = 178
  optional sampCollecMethod String = 179
  optional sampMatProcess String = 180
  optional sizeFrac String = 181
  optional sampSize QuantityValue = 182
  optional sampVolWeDnaExt QuantityValue = 183
  optional nuclAcidExt String = 184
  optional nuclAcidAmp String = 185
  optional libSize Integer = 186
  optional libReadsSeqd Integer = 187
  optional libLayout LibLayoutEnum = 188
  optional libVector String = 189
  optional libScreen String = 190
  targetGene String = 191
  optional targetSubfragment String = 192
  optional pcrPrimers String = 193
  optional mid String = 194
  optional adapters String = 195
  optional pcrCond String = 196
  seqMeth String = 197
  optional seqQualityCheck String = 198
  optional chimeraCheck String = 199
  optional assemblySoftware String = 200
  optional associatedResource String = 201
  optional sop String = 202
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: survey with environmental package built environment
message BuiltEnvironmentMIMARKSSurvey
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional geoLocName String = 5
  optional collectionDate Date = 6
  optional envBroadScale String = 7
  optional envLocalScale String = 8
  optional envMedium String = 9
  optional surfMaterial SurfMaterialEnum = 10
  repeated surfAirCont SurfAirContEnum = 11
  relAirHumidity QuantityValue = 12
  absAirHumidity QuantityValue = 13
  optional surfHumidity QuantityValue = 14
  temp QuantityValue = 15
  optional surfTemp QuantityValue = 16
  optional surfMoisturePh Double = 17
  repeated buildOccupType BuildOccupTypeEnum = 18
  optional surfMoisture QuantityValue = 19
  optional dewPoint QuantityValue = 20
  carbDioxide QuantityValue = 21
  ventilationType String = 22
  repeated organismCount OrganismCountEnum = 23
  indoorSpace IndoorSpaceEnum = 24
  optional indoorSurf IndoorSurfEnum = 25
  repeated filterType FilterTypeEnum = 26
  repeated heatCoolType HeatCoolTypeEnum = 27
  repeated substructureType SubstructureTypeEnum = 28
  buildingSetting BuildingSettingEnum = 29
  repeated lightType LightTypeEnum = 30
  repeated sampSortMeth String = 31
  spaceTypState String = 32
  typOccupDensity Double = 33
  occupSamp Integer = 34
  occupDensitySamp Double = 35
  optional address String = 36
  optional adjRoom String = 37
  optional aeroStruc String = 38
  optional amountLight QuantityValue = 39
  optional archStruc ArchStrucEnum = 40
  optional avgOccup Double = 41
  optional avgDewPoint QuantityValue = 42
  optional avgTemp QuantityValue = 43
  optional bathroomCount Integer = 44
  optional bedroomCount Integer = 45
  optional builtStrucAge QuantityValue = 46
  optional builtStrucSet String = 47
  optional builtStrucType String = 48
  optional ceilArea QuantityValue = 49
  optional ceilCond CeilCondEnum = 50
  optional ceilFinishMat CeilFinishMatEnum = 51
  optional ceilWaterMold String = 52
  optional ceilStruc String = 53
  optional ceilTexture CeilTextureEnum = 54
  optional ceilThermalMass QuantityValue = 55
  optional ceilType CeilTypeEnum = 56
  optional coolSystId Integer = 57
  optional dateLastRain Date = 58
  optional buildDocs BuildDocsEnum = 59
  optional doorSize QuantityValue = 60
  optional doorCond DoorCondEnum = 61
  optional doorDirect DoorDirectEnum = 62
  optional doorLoc DoorLocEnum = 63
  optional doorMat DoorMatEnum = 64
  optional doorMove DoorMoveEnum = 65
  optional doorWaterMold String = 66
  optional doorType DoorTypeEnum = 67
  optional doorCompType DoorCompTypeEnum = 68
  optional doorTypeMetal DoorTypeMetalEnum = 69
  optional doorTypeWood DoorTypeWoodEnum = 70
  optional drawings DrawingsEnum = 71
  optional elevator Integer = 72
  optional escalator Integer = 73
  optional expDuct QuantityValue = 74
  optional expPipe Integer = 75
  optional extDoor Integer = 76
  optional fireplaceType String = 77
  optional floorAge QuantityValue = 78
  optional floorArea QuantityValue = 79
  optional floorCond FloorCondEnum = 80
  optional floorCount Integer = 81
  optional floorFinishMat FloorFinishMatEnum = 82
  optional floorWaterMold FloorWaterMoldEnum = 83
  optional floorStruc FloorStrucEnum = 84
  optional floorThermalMass QuantityValue = 85
  optional freqClean FreqCleanEnum = 86
  optional freqCook Integer = 87
  optional furniture FurnitureEnum = 88
  optional genderRestroom GenderRestroomEnum = 89
  optional hallCount Integer = 90
  optional handidness HandidnessEnum = 91
  optional heatDelivLoc HeatDelivLocEnum = 92
  optional heatSysDelivMeth String = 93
  optional heatSystemId Integer = 94
  optional heightCarperFiber QuantityValue = 95
  optional insideLux QuantityValue = 96
  optional intWallCond IntWallCondEnum = 97
  optional lastClean Date = 98
  optional maxOccup Integer = 99
  optional mechStruc MechStrucEnum = 100
  optional numberPlants Integer = 101
  optional numberPets Integer = 102
  optional numberResident Integer = 103
  optional occupDocument OccupDocumentEnum = 104
  optional extWallOrient ExtWallOrientEnum = 105
  optional extWindowOrient ExtWindowOrientEnum = 106
  optional relHumidityOut QuantityValue = 107
  optional presAnimalInsect String = 108
  optional quadPos QuadPosEnum = 109
  optional relSampLoc RelSampLocEnum = 110
  optional roomAirExchRate QuantityValue = 111
  optional roomArchitecElem String = 112
  optional roomCondt RoomCondtEnum = 113
  optional roomCount Integer = 114
  optional roomDim String = 115
  optional roomDoorDist String = 116
  optional roomLoc RoomLocEnum = 117
  optional roomMoistDamHist Integer = 118
  optional roomNetArea String = 119
  optional roomOccup Integer = 120
  optional roomSampPos RoomSampPosEnum = 121
  optional roomType RoomTypeEnum = 122
  optional roomVol String = 123
  optional roomWindowCount Integer = 124
  optional roomConnected RoomConnectedEnum = 125
  optional roomHallway String = 126
  optional roomDoorShare String = 127
  optional roomWallShare String = 128
  optional sampWeather SampWeatherEnum = 129
  optional sampFloor SampFloorEnum = 130
  optional sampRoomId Integer = 131
  optional sampTimeOut Double = 132
  optional season String = 133
  optional seasonUse SeasonUseEnum = 134
  optional shadingDeviceCond ShadingDeviceCondEnum = 135
  optional shadingDeviceLoc String = 136
  optional shadingDeviceMat String = 137
  optional shadDevWaterMold String = 138
  optional shadingDeviceType ShadingDeviceTypeEnum = 139
  optional specificHumidity QuantityValue = 140
  optional specific SpecificEnum = 141
  optional tempOut QuantityValue = 142
  optional trainLine TrainLineEnum = 143
  optional trainStatLoc TrainStatLocEnum = 144
  optional trainStopLoc TrainStopLocEnum = 145
  optional visMedia VisMediaEnum = 146
  optional wallArea QuantityValue = 147
  optional wallConstType WallConstTypeEnum = 148
  optional wallFinishMat WallFinishMatEnum = 149
  optional wallHeight QuantityValue = 150
  optional wallLoc WallLocEnum = 151
  optional wallWaterMold String = 152
  optional wallSurfTreatment WallSurfTreatmentEnum = 153
  optional wallTexture WallTextureEnum = 154
  optional wallThermalMass QuantityValue = 155
  optional waterFeatSize QuantityValue = 156
  optional waterFeatType WaterFeatTypeEnum = 157
  optional weekday WeekdayEnum = 158
  optional windowSize String = 159
  optional windowCond WindowCondEnum = 160
  optional windowCover WindowCoverEnum = 161
  optional windowHorizPos WindowHorizPosEnum = 162
  optional windowLoc WindowLocEnum = 163
  optional windowMat WindowMatEnum = 164
  optional windowOpenFreq Integer = 165
  optional windowWaterMold String = 166
  optional windowStatus String = 167
  optional windowType WindowTypeEnum = 168
  optional windowVertPos WindowVertPosEnum = 169
  sampName String = 170
  projectName String = 171
  sampTaxonId String = 172
  optional experimentalFactor String = 173
  optional negContType NegContTypeEnum = 174
  optional posContType String = 175
  optional subspecfGenLin String = 176
  optional extrachromElements Integer = 177
  optional sourceMatId String = 178
  optional bioticRelationship BioticRelationshipEnum = 179
  optional trophicLevel TrophicLevelEnum = 180
  optional relToOxygen RelToOxygenEnum = 181
  isolGrowthCondt String = 182
  optional sampCollecDevice String = 183
  optional sampCollecMethod String = 184
  optional sampMatProcess String = 185
  optional sampSize QuantityValue = 186
  optional sampVolWeDnaExt QuantityValue = 187
  optional nuclAcidExt String = 188
  optional nuclAcidAmp String = 189
  targetGene String = 190
  optional targetSubfragment String = 191
  optional pcrPrimers String = 192
  optional pcrCond String = 193
  seqMeth String = 194
  optional seqQualityCheck String = 195
  optional chimeraCheck String = 196
  optional associatedResource String = 197
  optional sop String = 198
 }
// Combinatorial checklist Metagenome or Environmental with environmental package built environment
message BuiltEnvironmentMIMS
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional geoLocName String = 5
  optional collectionDate Date = 6
  optional envBroadScale String = 7
  optional envLocalScale String = 8
  optional envMedium String = 9
  optional surfMaterial SurfMaterialEnum = 10
  repeated surfAirCont SurfAirContEnum = 11
  relAirHumidity QuantityValue = 12
  absAirHumidity QuantityValue = 13
  optional surfHumidity QuantityValue = 14
  temp QuantityValue = 15
  optional surfTemp QuantityValue = 16
  optional surfMoisturePh Double = 17
  repeated buildOccupType BuildOccupTypeEnum = 18
  optional surfMoisture QuantityValue = 19
  optional dewPoint QuantityValue = 20
  carbDioxide QuantityValue = 21
  ventilationType String = 22
  repeated organismCount OrganismCountEnum = 23
  indoorSpace IndoorSpaceEnum = 24
  optional indoorSurf IndoorSurfEnum = 25
  repeated filterType FilterTypeEnum = 26
  repeated heatCoolType HeatCoolTypeEnum = 27
  repeated substructureType SubstructureTypeEnum = 28
  buildingSetting BuildingSettingEnum = 29
  repeated lightType LightTypeEnum = 30
  repeated sampSortMeth String = 31
  spaceTypState String = 32
  typOccupDensity Double = 33
  occupSamp Integer = 34
  occupDensitySamp Double = 35
  optional address String = 36
  optional adjRoom String = 37
  optional aeroStruc String = 38
  optional amountLight QuantityValue = 39
  optional archStruc ArchStrucEnum = 40
  optional avgOccup Double = 41
  optional avgDewPoint QuantityValue = 42
  optional avgTemp QuantityValue = 43
  optional bathroomCount Integer = 44
  optional bedroomCount Integer = 45
  optional builtStrucAge QuantityValue = 46
  optional builtStrucSet String = 47
  optional builtStrucType String = 48
  optional ceilArea QuantityValue = 49
  optional ceilCond CeilCondEnum = 50
  optional ceilFinishMat CeilFinishMatEnum = 51
  optional ceilWaterMold String = 52
  optional ceilStruc String = 53
  optional ceilTexture CeilTextureEnum = 54
  optional ceilThermalMass QuantityValue = 55
  optional ceilType CeilTypeEnum = 56
  optional coolSystId Integer = 57
  optional dateLastRain Date = 58
  optional buildDocs BuildDocsEnum = 59
  optional doorSize QuantityValue = 60
  optional doorCond DoorCondEnum = 61
  optional doorDirect DoorDirectEnum = 62
  optional doorLoc DoorLocEnum = 63
  optional doorMat DoorMatEnum = 64
  optional doorMove DoorMoveEnum = 65
  optional doorWaterMold String = 66
  optional doorType DoorTypeEnum = 67
  optional doorCompType DoorCompTypeEnum = 68
  optional doorTypeMetal DoorTypeMetalEnum = 69
  optional doorTypeWood DoorTypeWoodEnum = 70
  optional drawings DrawingsEnum = 71
  optional elevator Integer = 72
  optional escalator Integer = 73
  optional expDuct QuantityValue = 74
  optional expPipe Integer = 75
  optional extDoor Integer = 76
  optional fireplaceType String = 77
  optional floorAge QuantityValue = 78
  optional floorArea QuantityValue = 79
  optional floorCond FloorCondEnum = 80
  optional floorCount Integer = 81
  optional floorFinishMat FloorFinishMatEnum = 82
  optional floorWaterMold FloorWaterMoldEnum = 83
  optional floorStruc FloorStrucEnum = 84
  optional floorThermalMass QuantityValue = 85
  optional freqClean FreqCleanEnum = 86
  optional freqCook Integer = 87
  optional furniture FurnitureEnum = 88
  optional genderRestroom GenderRestroomEnum = 89
  optional hallCount Integer = 90
  optional handidness HandidnessEnum = 91
  optional heatDelivLoc HeatDelivLocEnum = 92
  optional heatSysDelivMeth String = 93
  optional heatSystemId Integer = 94
  optional heightCarperFiber QuantityValue = 95
  optional insideLux QuantityValue = 96
  optional intWallCond IntWallCondEnum = 97
  optional lastClean Date = 98
  optional maxOccup Integer = 99
  optional mechStruc MechStrucEnum = 100
  optional numberPlants Integer = 101
  optional numberPets Integer = 102
  optional numberResident Integer = 103
  optional occupDocument OccupDocumentEnum = 104
  optional extWallOrient ExtWallOrientEnum = 105
  optional extWindowOrient ExtWindowOrientEnum = 106
  optional relHumidityOut QuantityValue = 107
  optional presAnimalInsect String = 108
  optional quadPos QuadPosEnum = 109
  optional relSampLoc RelSampLocEnum = 110
  optional roomAirExchRate QuantityValue = 111
  optional roomArchitecElem String = 112
  optional roomCondt RoomCondtEnum = 113
  optional roomCount Integer = 114
  optional roomDim String = 115
  optional roomDoorDist String = 116
  optional roomLoc RoomLocEnum = 117
  optional roomMoistDamHist Integer = 118
  optional roomNetArea String = 119
  optional roomOccup Integer = 120
  optional roomSampPos RoomSampPosEnum = 121
  optional roomType RoomTypeEnum = 122
  optional roomVol String = 123
  optional roomWindowCount Integer = 124
  optional roomConnected RoomConnectedEnum = 125
  optional roomHallway String = 126
  optional roomDoorShare String = 127
  optional roomWallShare String = 128
  optional sampWeather SampWeatherEnum = 129
  optional sampFloor SampFloorEnum = 130
  optional sampRoomId Integer = 131
  optional sampTimeOut Double = 132
  optional season String = 133
  optional seasonUse SeasonUseEnum = 134
  optional shadingDeviceCond ShadingDeviceCondEnum = 135
  optional shadingDeviceLoc String = 136
  optional shadingDeviceMat String = 137
  optional shadDevWaterMold String = 138
  optional shadingDeviceType ShadingDeviceTypeEnum = 139
  optional specificHumidity QuantityValue = 140
  optional specific SpecificEnum = 141
  optional tempOut QuantityValue = 142
  optional trainLine TrainLineEnum = 143
  optional trainStatLoc TrainStatLocEnum = 144
  optional trainStopLoc TrainStopLocEnum = 145
  optional visMedia VisMediaEnum = 146
  optional wallArea QuantityValue = 147
  optional wallConstType WallConstTypeEnum = 148
  optional wallFinishMat WallFinishMatEnum = 149
  optional wallHeight QuantityValue = 150
  optional wallLoc WallLocEnum = 151
  optional wallWaterMold String = 152
  optional wallSurfTreatment WallSurfTreatmentEnum = 153
  optional wallTexture WallTextureEnum = 154
  optional wallThermalMass QuantityValue = 155
  optional waterFeatSize QuantityValue = 156
  optional waterFeatType WaterFeatTypeEnum = 157
  optional weekday WeekdayEnum = 158
  optional windowSize String = 159
  optional windowCond WindowCondEnum = 160
  optional windowCover WindowCoverEnum = 161
  optional windowHorizPos WindowHorizPosEnum = 162
  optional windowLoc WindowLocEnum = 163
  optional windowMat WindowMatEnum = 164
  optional windowOpenFreq Integer = 165
  optional windowWaterMold String = 166
  optional windowStatus String = 167
  optional windowType WindowTypeEnum = 168
  optional windowVertPos WindowVertPosEnum = 169
  sampName String = 170
  projectName String = 171
  sampTaxonId String = 172
  optional experimentalFactor String = 173
  optional negContType NegContTypeEnum = 174
  optional posContType String = 175
  optional refBiomaterial String = 176
  optional sourceMatId String = 177
  optional relToOxygen RelToOxygenEnum = 178
  optional sampCollecDevice String = 179
  optional sampCollecMethod String = 180
  optional sampMatProcess String = 181
  optional sizeFrac String = 182
  optional sampSize QuantityValue = 183
  optional sampVolWeDnaExt QuantityValue = 184
  optional nuclAcidExt String = 185
  optional nuclAcidAmp String = 186
  optional libSize Integer = 187
  optional libReadsSeqd Integer = 188
  optional libLayout LibLayoutEnum = 189
  optional libVector String = 190
  optional libScreen String = 191
  optional mid String = 192
  optional adapters String = 193
  seqMeth String = 194
  optional assemblyQual AssemblyQualEnum = 195
  optional assemblyName String = 196
  optional assemblySoftware String = 197
  optional annot String = 198
  optional numberContig Integer = 199
  optional featPred String = 200
  optional refDb String = 201
  optional simSearchMeth String = 202
  optional taxClass String = 203
  optional associatedResource String = 204
  optional sop String = 205
 }
// Combinatorial checklist Minimum Information About a Single Amplified Genome with environmental package built environment
message BuiltEnvironmentMISAG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional geoLocName String = 5
  optional collectionDate Date = 6
  optional envBroadScale String = 7
  optional envLocalScale String = 8
  optional envMedium String = 9
  optional surfMaterial SurfMaterialEnum = 10
  repeated surfAirCont SurfAirContEnum = 11
  relAirHumidity QuantityValue = 12
  absAirHumidity QuantityValue = 13
  optional surfHumidity QuantityValue = 14
  temp QuantityValue = 15
  optional surfTemp QuantityValue = 16
  optional surfMoisturePh Double = 17
  repeated buildOccupType BuildOccupTypeEnum = 18
  optional surfMoisture QuantityValue = 19
  optional dewPoint QuantityValue = 20
  carbDioxide QuantityValue = 21
  ventilationType String = 22
  repeated organismCount OrganismCountEnum = 23
  indoorSpace IndoorSpaceEnum = 24
  optional indoorSurf IndoorSurfEnum = 25
  repeated filterType FilterTypeEnum = 26
  repeated heatCoolType HeatCoolTypeEnum = 27
  repeated substructureType SubstructureTypeEnum = 28
  buildingSetting BuildingSettingEnum = 29
  repeated lightType LightTypeEnum = 30
  repeated sampSortMeth String = 31
  spaceTypState String = 32
  typOccupDensity Double = 33
  occupSamp Integer = 34
  occupDensitySamp Double = 35
  optional address String = 36
  optional adjRoom String = 37
  optional aeroStruc String = 38
  optional amountLight QuantityValue = 39
  optional archStruc ArchStrucEnum = 40
  optional avgOccup Double = 41
  optional avgDewPoint QuantityValue = 42
  optional avgTemp QuantityValue = 43
  optional bathroomCount Integer = 44
  optional bedroomCount Integer = 45
  optional builtStrucAge QuantityValue = 46
  optional builtStrucSet String = 47
  optional builtStrucType String = 48
  optional ceilArea QuantityValue = 49
  optional ceilCond CeilCondEnum = 50
  optional ceilFinishMat CeilFinishMatEnum = 51
  optional ceilWaterMold String = 52
  optional ceilStruc String = 53
  optional ceilTexture CeilTextureEnum = 54
  optional ceilThermalMass QuantityValue = 55
  optional ceilType CeilTypeEnum = 56
  optional coolSystId Integer = 57
  optional dateLastRain Date = 58
  optional buildDocs BuildDocsEnum = 59
  optional doorSize QuantityValue = 60
  optional doorCond DoorCondEnum = 61
  optional doorDirect DoorDirectEnum = 62
  optional doorLoc DoorLocEnum = 63
  optional doorMat DoorMatEnum = 64
  optional doorMove DoorMoveEnum = 65
  optional doorWaterMold String = 66
  optional doorType DoorTypeEnum = 67
  optional doorCompType DoorCompTypeEnum = 68
  optional doorTypeMetal DoorTypeMetalEnum = 69
  optional doorTypeWood DoorTypeWoodEnum = 70
  optional drawings DrawingsEnum = 71
  optional elevator Integer = 72
  optional escalator Integer = 73
  optional expDuct QuantityValue = 74
  optional expPipe Integer = 75
  optional extDoor Integer = 76
  optional fireplaceType String = 77
  optional floorAge QuantityValue = 78
  optional floorArea QuantityValue = 79
  optional floorCond FloorCondEnum = 80
  optional floorCount Integer = 81
  optional floorFinishMat FloorFinishMatEnum = 82
  optional floorWaterMold FloorWaterMoldEnum = 83
  optional floorStruc FloorStrucEnum = 84
  optional floorThermalMass QuantityValue = 85
  optional freqClean FreqCleanEnum = 86
  optional freqCook Integer = 87
  optional furniture FurnitureEnum = 88
  optional genderRestroom GenderRestroomEnum = 89
  optional hallCount Integer = 90
  optional handidness HandidnessEnum = 91
  optional heatDelivLoc HeatDelivLocEnum = 92
  optional heatSysDelivMeth String = 93
  optional heatSystemId Integer = 94
  optional heightCarperFiber QuantityValue = 95
  optional insideLux QuantityValue = 96
  optional intWallCond IntWallCondEnum = 97
  optional lastClean Date = 98
  optional maxOccup Integer = 99
  optional mechStruc MechStrucEnum = 100
  optional numberPlants Integer = 101
  optional numberPets Integer = 102
  optional numberResident Integer = 103
  optional occupDocument OccupDocumentEnum = 104
  optional extWallOrient ExtWallOrientEnum = 105
  optional extWindowOrient ExtWindowOrientEnum = 106
  optional relHumidityOut QuantityValue = 107
  optional presAnimalInsect String = 108
  optional quadPos QuadPosEnum = 109
  optional relSampLoc RelSampLocEnum = 110
  optional roomAirExchRate QuantityValue = 111
  optional roomArchitecElem String = 112
  optional roomCondt RoomCondtEnum = 113
  optional roomCount Integer = 114
  optional roomDim String = 115
  optional roomDoorDist String = 116
  optional roomLoc RoomLocEnum = 117
  optional roomMoistDamHist Integer = 118
  optional roomNetArea String = 119
  optional roomOccup Integer = 120
  optional roomSampPos RoomSampPosEnum = 121
  optional roomType RoomTypeEnum = 122
  optional roomVol String = 123
  optional roomWindowCount Integer = 124
  optional roomConnected RoomConnectedEnum = 125
  optional roomHallway String = 126
  optional roomDoorShare String = 127
  optional roomWallShare String = 128
  optional sampWeather SampWeatherEnum = 129
  optional sampFloor SampFloorEnum = 130
  optional sampRoomId Integer = 131
  optional sampTimeOut Double = 132
  optional season String = 133
  optional seasonUse SeasonUseEnum = 134
  optional shadingDeviceCond ShadingDeviceCondEnum = 135
  optional shadingDeviceLoc String = 136
  optional shadingDeviceMat String = 137
  optional shadDevWaterMold String = 138
  optional shadingDeviceType ShadingDeviceTypeEnum = 139
  optional specificHumidity QuantityValue = 140
  optional specific SpecificEnum = 141
  optional tempOut QuantityValue = 142
  optional trainLine TrainLineEnum = 143
  optional trainStatLoc TrainStatLocEnum = 144
  optional trainStopLoc TrainStopLocEnum = 145
  optional visMedia VisMediaEnum = 146
  optional wallArea QuantityValue = 147
  optional wallConstType WallConstTypeEnum = 148
  optional wallFinishMat WallFinishMatEnum = 149
  optional wallHeight QuantityValue = 150
  optional wallLoc WallLocEnum = 151
  optional wallWaterMold String = 152
  optional wallSurfTreatment WallSurfTreatmentEnum = 153
  optional wallTexture WallTextureEnum = 154
  optional wallThermalMass QuantityValue = 155
  optional waterFeatSize QuantityValue = 156
  optional waterFeatType WaterFeatTypeEnum = 157
  optional weekday WeekdayEnum = 158
  optional windowSize String = 159
  optional windowCond WindowCondEnum = 160
  optional windowCover WindowCoverEnum = 161
  optional windowHorizPos WindowHorizPosEnum = 162
  optional windowLoc WindowLocEnum = 163
  optional windowMat WindowMatEnum = 164
  optional windowOpenFreq Integer = 165
  optional windowWaterMold String = 166
  optional windowStatus String = 167
  optional windowType WindowTypeEnum = 168
  optional windowVertPos WindowVertPosEnum = 169
  sampName String = 170
  projectName String = 171
  sampTaxonId String = 172
  optional experimentalFactor String = 173
  optional negContType NegContTypeEnum = 174
  optional posContType String = 175
  optional refBiomaterial String = 176
  optional sourceMatId String = 177
  optional relToOxygen RelToOxygenEnum = 178
  optional sampCollecDevice String = 179
  optional sampCollecMethod String = 180
  optional sampMatProcess String = 181
  optional sizeFrac String = 182
  optional sampSize QuantityValue = 183
  optional sampVolWeDnaExt QuantityValue = 184
  optional nuclAcidExt String = 185
  optional nuclAcidAmp String = 186
  optional libSize Integer = 187
  optional libReadsSeqd Integer = 188
  optional libLayout LibLayoutEnum = 189
  optional libVector String = 190
  optional libScreen String = 191
  optional mid String = 192
  optional adapters String = 193
  seqMeth String = 194
  taxIdent TaxIdentEnum = 195
  assemblyQual AssemblyQualEnum = 196
  optional assemblyName String = 197
  assemblySoftware String = 198
  optional annot String = 199
  optional numberContig Integer = 200
  optional featPred String = 201
  optional refDb String = 202
  optional simSearchMeth String = 203
  optional taxClass String = 204
  optional x16sRecover String = 205
  optional x16sRecoverSoftware String = 206
  optional trnas Integer = 207
  optional trnaExtSoftware String = 208
  complScore String = 209
  complSoftware String = 210
  optional complAppr ComplApprEnum = 211
  contamScore String = 212
  optional contamScreenInput String = 213
  optional contamScreenParam String = 214
  optional decontamSoftware DecontamSoftwareEnum = 215
  sortTech SortTechEnum = 216
  singleCellLysisAppr SingleCellLysisApprEnum = 217
  optional singleCellLysisProt String = 218
  wgaAmpAppr String = 219
  optional wgaAmpKit String = 220
  optional associatedResource String = 221
  optional sop String = 222
 }
// Combinatorial checklist Minimum Information About an Uncultivated Virus Genome with environmental package built environment
message BuiltEnvironmentMIUVIG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional geoLocName String = 5
  optional collectionDate Date = 6
  optional envBroadScale String = 7
  optional envLocalScale String = 8
  optional envMedium String = 9
  optional surfMaterial SurfMaterialEnum = 10
  repeated surfAirCont SurfAirContEnum = 11
  relAirHumidity QuantityValue = 12
  absAirHumidity QuantityValue = 13
  optional surfHumidity QuantityValue = 14
  temp QuantityValue = 15
  optional surfTemp QuantityValue = 16
  optional surfMoisturePh Double = 17
  repeated buildOccupType BuildOccupTypeEnum = 18
  optional surfMoisture QuantityValue = 19
  optional dewPoint QuantityValue = 20
  carbDioxide QuantityValue = 21
  ventilationType String = 22
  repeated organismCount OrganismCountEnum = 23
  indoorSpace IndoorSpaceEnum = 24
  optional indoorSurf IndoorSurfEnum = 25
  repeated filterType FilterTypeEnum = 26
  repeated heatCoolType HeatCoolTypeEnum = 27
  repeated substructureType SubstructureTypeEnum = 28
  buildingSetting BuildingSettingEnum = 29
  repeated lightType LightTypeEnum = 30
  repeated sampSortMeth String = 31
  spaceTypState String = 32
  typOccupDensity Double = 33
  occupSamp Integer = 34
  occupDensitySamp Double = 35
  optional address String = 36
  optional adjRoom String = 37
  optional aeroStruc String = 38
  optional amountLight QuantityValue = 39
  optional archStruc ArchStrucEnum = 40
  optional avgOccup Double = 41
  optional avgDewPoint QuantityValue = 42
  optional avgTemp QuantityValue = 43
  optional bathroomCount Integer = 44
  optional bedroomCount Integer = 45
  optional builtStrucAge QuantityValue = 46
  optional builtStrucSet String = 47
  optional builtStrucType String = 48
  optional ceilArea QuantityValue = 49
  optional ceilCond CeilCondEnum = 50
  optional ceilFinishMat CeilFinishMatEnum = 51
  optional ceilWaterMold String = 52
  optional ceilStruc String = 53
  optional ceilTexture CeilTextureEnum = 54
  optional ceilThermalMass QuantityValue = 55
  optional ceilType CeilTypeEnum = 56
  optional coolSystId Integer = 57
  optional dateLastRain Date = 58
  optional buildDocs BuildDocsEnum = 59
  optional doorSize QuantityValue = 60
  optional doorCond DoorCondEnum = 61
  optional doorDirect DoorDirectEnum = 62
  optional doorLoc DoorLocEnum = 63
  optional doorMat DoorMatEnum = 64
  optional doorMove DoorMoveEnum = 65
  optional doorWaterMold String = 66
  optional doorType DoorTypeEnum = 67
  optional doorCompType DoorCompTypeEnum = 68
  optional doorTypeMetal DoorTypeMetalEnum = 69
  optional doorTypeWood DoorTypeWoodEnum = 70
  optional drawings DrawingsEnum = 71
  optional elevator Integer = 72
  optional escalator Integer = 73
  optional expDuct QuantityValue = 74
  optional expPipe Integer = 75
  optional extDoor Integer = 76
  optional fireplaceType String = 77
  optional floorAge QuantityValue = 78
  optional floorArea QuantityValue = 79
  optional floorCond FloorCondEnum = 80
  optional floorCount Integer = 81
  optional floorFinishMat FloorFinishMatEnum = 82
  optional floorWaterMold FloorWaterMoldEnum = 83
  optional floorStruc FloorStrucEnum = 84
  optional floorThermalMass QuantityValue = 85
  optional freqClean FreqCleanEnum = 86
  optional freqCook Integer = 87
  optional furniture FurnitureEnum = 88
  optional genderRestroom GenderRestroomEnum = 89
  optional hallCount Integer = 90
  optional handidness HandidnessEnum = 91
  optional heatDelivLoc HeatDelivLocEnum = 92
  optional heatSysDelivMeth String = 93
  optional heatSystemId Integer = 94
  optional heightCarperFiber QuantityValue = 95
  optional insideLux QuantityValue = 96
  optional intWallCond IntWallCondEnum = 97
  optional lastClean Date = 98
  optional maxOccup Integer = 99
  optional mechStruc MechStrucEnum = 100
  optional numberPlants Integer = 101
  optional numberPets Integer = 102
  optional numberResident Integer = 103
  optional occupDocument OccupDocumentEnum = 104
  optional extWallOrient ExtWallOrientEnum = 105
  optional extWindowOrient ExtWindowOrientEnum = 106
  optional relHumidityOut QuantityValue = 107
  optional presAnimalInsect String = 108
  optional quadPos QuadPosEnum = 109
  optional relSampLoc RelSampLocEnum = 110
  optional roomAirExchRate QuantityValue = 111
  optional roomArchitecElem String = 112
  optional roomCondt RoomCondtEnum = 113
  optional roomCount Integer = 114
  optional roomDim String = 115
  optional roomDoorDist String = 116
  optional roomLoc RoomLocEnum = 117
  optional roomMoistDamHist Integer = 118
  optional roomNetArea String = 119
  optional roomOccup Integer = 120
  optional roomSampPos RoomSampPosEnum = 121
  optional roomType RoomTypeEnum = 122
  optional roomVol String = 123
  optional roomWindowCount Integer = 124
  optional roomConnected RoomConnectedEnum = 125
  optional roomHallway String = 126
  optional roomDoorShare String = 127
  optional roomWallShare String = 128
  optional sampWeather SampWeatherEnum = 129
  optional sampFloor SampFloorEnum = 130
  optional sampRoomId Integer = 131
  optional sampTimeOut Double = 132
  optional season String = 133
  optional seasonUse SeasonUseEnum = 134
  optional shadingDeviceCond ShadingDeviceCondEnum = 135
  optional shadingDeviceLoc String = 136
  optional shadingDeviceMat String = 137
  optional shadDevWaterMold String = 138
  optional shadingDeviceType ShadingDeviceTypeEnum = 139
  optional specificHumidity QuantityValue = 140
  optional specific SpecificEnum = 141
  optional tempOut QuantityValue = 142
  optional trainLine TrainLineEnum = 143
  optional trainStatLoc TrainStatLocEnum = 144
  optional trainStopLoc TrainStopLocEnum = 145
  optional visMedia VisMediaEnum = 146
  optional wallArea QuantityValue = 147
  optional wallConstType WallConstTypeEnum = 148
  optional wallFinishMat WallFinishMatEnum = 149
  optional wallHeight QuantityValue = 150
  optional wallLoc WallLocEnum = 151
  optional wallWaterMold String = 152
  optional wallSurfTreatment WallSurfTreatmentEnum = 153
  optional wallTexture WallTextureEnum = 154
  optional wallThermalMass QuantityValue = 155
  optional waterFeatSize QuantityValue = 156
  optional waterFeatType WaterFeatTypeEnum = 157
  optional weekday WeekdayEnum = 158
  optional windowSize String = 159
  optional windowCond WindowCondEnum = 160
  optional windowCover WindowCoverEnum = 161
  optional windowHorizPos WindowHorizPosEnum = 162
  optional windowLoc WindowLocEnum = 163
  optional windowMat WindowMatEnum = 164
  optional windowOpenFreq Integer = 165
  optional windowWaterMold String = 166
  optional windowStatus String = 167
  optional windowType WindowTypeEnum = 168
  optional windowVertPos WindowVertPosEnum = 169
  sampName String = 170
  projectName String = 171
  sampTaxonId String = 172
  optional experimentalFactor String = 173
  optional negContType NegContTypeEnum = 174
  optional posContType String = 175
  optional estimatedSize String = 176
  optional refBiomaterial String = 177
  optional sourceMatId String = 178
  optional pathogenicity String = 179
  optional bioticRelationship BioticRelationshipEnum = 180
  optional specificHost String = 181
  optional hostSpecRange Integer = 182
  optional hostDiseaseStat String = 183
  optional sampCollecDevice String = 184
  optional sampCollecMethod String = 185
  optional sampMatProcess String = 186
  optional sizeFrac String = 187
  optional sampSize QuantityValue = 188
  optional sampVolWeDnaExt QuantityValue = 189
  sourceUvig SourceUvigEnum = 190
  virusEnrichAppr VirusEnrichApprEnum = 191
  optional nuclAcidExt String = 192
  optional nuclAcidAmp String = 193
  optional libSize Integer = 194
  optional libReadsSeqd Integer = 195
  optional libLayout LibLayoutEnum = 196
  optional libVector String = 197
  optional libScreen String = 198
  optional mid String = 199
  optional adapters String = 200
  seqMeth String = 201
  optional taxIdent TaxIdentEnum = 202
  assemblyQual AssemblyQualEnum = 203
  optional assemblyName String = 204
  assemblySoftware String = 205
  optional annot String = 206
  numberContig Integer = 207
  optional featPred String = 208
  optional refDb String = 209
  optional simSearchMeth String = 210
  optional taxClass String = 211
  optional trnas Integer = 212
  optional trnaExtSoftware String = 213
  optional complScore String = 214
  optional complSoftware String = 215
  optional complAppr ComplApprEnum = 216
  optional sortTech SortTechEnum = 217
  optional singleCellLysisAppr SingleCellLysisApprEnum = 218
  optional singleCellLysisProt String = 219
  optional wgaAmpAppr String = 220
  optional wgaAmpKit String = 221
  optional binParam BinParamEnum = 222
  optional binSoftware String = 223
  optional reassemblyBin String = 224
  optional magCovSoftware MagCovSoftwareEnum = 225
  virIdentSoftware String = 226
  predGenomeType PredGenomeTypeEnum = 227
  predGenomeStruc PredGenomeStrucEnum = 228
  detecType String = 229
  optional otuClassAppr String = 230
  optional otuSeqCompAppr String = 231
  optional otuDb String = 232
  optional hostPredAppr HostPredApprEnum = 233
  optional hostPredEstAcc String = 234
  optional associatedResource String = 235
  optional sop String = 236
 }
// Core package. Do not use this directly, this is used to build other packages
message Core
 {
  optional sampName String = 1
  optional sampTaxonId String = 2
  optional projectName String = 3
  optional experimentalFactor String = 4
  optional latLon String = 5
  optional depth QuantityValue = 6
  optional alt QuantityValue = 7
  optional elev QuantityValue = 8
  optional temp QuantityValue = 9
  optional geoLocName String = 10
  optional collectionDate Date = 11
  optional negContType NegContTypeEnum = 12
  optional posContType String = 13
  optional envBroadScale String = 14
  optional envLocalScale String = 15
  optional envMedium String = 16
  optional subspecfGenLin String = 17
  optional ploidy String = 18
  optional numReplicons Integer = 19
  optional extrachromElements Integer = 20
  optional estimatedSize String = 21
  optional refBiomaterial String = 22
  optional sourceMatId String = 23
  optional pathogenicity String = 24
  optional bioticRelationship BioticRelationshipEnum = 25
  optional specificHost String = 26
  optional hostSpecRange Integer = 27
  optional hostDiseaseStat String = 28
  optional trophicLevel TrophicLevelEnum = 29
  optional propagation String = 30
  optional encodedTraits String = 31
  optional relToOxygen RelToOxygenEnum = 32
  optional isolGrowthCondt String = 33
  optional sampCollecDevice String = 34
  optional sampCollecMethod String = 35
  optional sampMatProcess String = 36
  optional sizeFrac String = 37
  optional sampSize QuantityValue = 38
  optional sampVolWeDnaExt QuantityValue = 39
  optional sourceUvig SourceUvigEnum = 40
  optional virusEnrichAppr VirusEnrichApprEnum = 41
  optional nuclAcidExt String = 42
  optional nuclAcidAmp String = 43
  optional libSize Integer = 44
  optional libReadsSeqd Integer = 45
  optional libLayout LibLayoutEnum = 46
  optional libVector String = 47
  optional libScreen String = 48
  optional targetGene String = 49
  optional targetSubfragment String = 50
  optional pcrPrimers String = 51
  optional mid String = 52
  optional adapters String = 53
  optional pcrCond String = 54
  optional seqMeth String = 55
  optional seqQualityCheck String = 56
  optional chimeraCheck String = 57
  optional taxIdent TaxIdentEnum = 58
  optional assemblyQual AssemblyQualEnum = 59
  optional assemblyName String = 60
  optional assemblySoftware String = 61
  optional annot String = 62
  optional numberContig Integer = 63
  optional featPred String = 64
  optional refDb String = 65
  optional simSearchMeth String = 66
  optional taxClass String = 67
  optional x16sRecover String = 68
  optional x16sRecoverSoftware String = 69
  optional trnas Integer = 70
  optional trnaExtSoftware String = 71
  optional complScore String = 72
  optional complSoftware String = 73
  optional complAppr ComplApprEnum = 74
  optional contamScore String = 75
  optional contamScreenInput String = 76
  optional contamScreenParam String = 77
  optional decontamSoftware DecontamSoftwareEnum = 78
  optional sortTech SortTechEnum = 79
  optional singleCellLysisAppr SingleCellLysisApprEnum = 80
  optional singleCellLysisProt String = 81
  optional wgaAmpAppr String = 82
  optional wgaAmpKit String = 83
  optional binParam BinParamEnum = 84
  optional binSoftware String = 85
  optional reassemblyBin String = 86
  optional magCovSoftware MagCovSoftwareEnum = 87
  optional virIdentSoftware String = 88
  optional predGenomeType PredGenomeTypeEnum = 89
  optional predGenomeStruc PredGenomeStrucEnum = 90
  optional detecType String = 91
  optional otuClassAppr String = 92
  optional otuSeqCompAppr String = 93
  optional otuDb String = 94
  optional hostPredAppr HostPredApprEnum = 95
  optional hostPredEstAcc String = 96
  optional associatedResource String = 97
  optional sop String = 98
 }
// food-animal and animal feed
message Food-animalAndAnimalFeed
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  optional sampCollectDevice String = 11
  repeated organismCount OrganismCountEnum = 12
  optional spikeinCount SpikeinCountEnum = 13
  optional sampStorTemp QuantityValue = 14
  optional sampStorDur String = 15
  optional poolDnaExtracts String = 16
  optional sampStorLoc String = 17
  optional sampTransportCont SampTransportContEnum = 18
  repeated perturbation String = 19
  collSiteGeoFeat String = 20
  foodOrigin String = 21
  repeated foodProd String = 22
  repeated foodProductType String = 23
  optional foodSource String = 24
  repeated iFSACCategory String = 25
  repeated intendedConsumer String = 26
  sampPurpose String = 27
  optional animalAm String = 28
  optional animalAmDur String = 29
  optional animalAmFreq QuantityValue = 30
  optional animalAmRoute String = 31
  optional animalAmUse String = 32
  optional animalBodyCond AnimalBodyCondEnum = 33
  repeated animalDiet String = 34
  repeated animalFeedEquip String = 35
  optional animalGroupSize Integer = 36
  repeated animalHousing String = 37
  optional animalSex AnimalSexEnum = 38
  optional bacterialDensity QuantityValue = 39
  optional consFoodStorDur String = 40
  optional consFoodStorTemp String = 41
  optional consPurchDate Date = 42
  optional consQtyPurchased String = 43
  optional cultIsolDate Date = 44
  optional cultResult CultResultEnum = 45
  repeated cultResultOrg String = 46
  repeated cultTarget String = 47
  optional enrichmentProtocol String = 48
  repeated foodAdditive String = 49
  repeated foodContactSurf String = 50
  optional foodContainWrap String = 51
  repeated foodCookingProc String = 52
  repeated foodDisPoint String = 53
  optional foodDisPointCity String = 54
  repeated foodIngredient String = 55
  optional foodPackCapacity QuantityValue = 56
  repeated foodPackIntegrity String = 57
  repeated foodPackMedium String = 58
  repeated foodPreservProc String = 59
  repeated foodPriorContact String = 60
  repeated foodProdSynonym String = 61
  optional foodProductQual String = 62
  optional foodQualityDate String = 63
  optional foodSourceAge QuantityValue = 64
  optional foodTraceList FoodTraceListEnum = 65
  repeated foodTravMode String = 66
  repeated foodTravVehic String = 67
  repeated foodTreatProc String = 68
  repeated hACCPTerm String = 69
  optional libraryPrepKit String = 70
  repeated lotNumber String = 71
  optional microbCultMed String = 72
  repeated partPlantAnimal String = 73
  repeated repositoryName String = 74
  optional sampCollectMethod String = 75
  repeated sampPooling String = 76
  optional sampRepBiol QuantityValue = 77
  optional sampRepTech QuantityValue = 78
  optional sampSourceMatCat String = 79
  optional sampStorDevice String = 80
  optional sampStorMedia String = 81
  optional sampTransportDur QuantityValue = 82
  optional sampTransportTemp String = 83
  optional sequencingKit String = 84
  optional sequencingLocation String = 85
  repeated serovarOrSerotype String = 86
  repeated spikeinAMR String = 87
  repeated spikeinAntibiotic String = 88
  repeated spikeinGrowthMed String = 89
  repeated spikeinMetal String = 90
  repeated spikeinOrg String = 91
  repeated spikeinSerovar String = 92
  repeated spikeinStrain String = 93
  repeated studyDesign String = 94
  optional studyIncDur QuantityValue = 95
  optional studyIncTemp QuantityValue = 96
  optional studyTimecourse QuantityValue = 97
  repeated studyTmnt String = 98
  optional timepoint Double = 99
  repeated miscParam String = 100
  sampName String = 101
  projectName String = 102
  seqMeth String = 103
  optional sampSize QuantityValue = 104
  optional experimentalFactor String = 105
  optional nuclAcidExt String = 106
  optional sampVolWeDnaExt QuantityValue = 107
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package food-animal and animal feed
message Food-animalAndAnimalFeedMIGSBacteria
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  optional sampCollectDevice String = 11
  repeated organismCount OrganismCountEnum = 12
  optional spikeinCount SpikeinCountEnum = 13
  optional sampStorTemp QuantityValue = 14
  optional sampStorDur String = 15
  optional poolDnaExtracts String = 16
  optional sampStorLoc String = 17
  repeated perturbation String = 18
  collSiteGeoFeat String = 19
  foodOrigin String = 20
  repeated foodProd String = 21
  repeated foodProductType String = 22
  optional foodSource String = 23
  repeated iFSACCategory String = 24
  repeated intendedConsumer String = 25
  sampPurpose String = 26
  optional animalAm String = 27
  optional animalAmDur String = 28
  optional animalAmFreq QuantityValue = 29
  optional animalAmRoute String = 30
  optional animalAmUse String = 31
  optional animalBodyCond AnimalBodyCondEnum = 32
  repeated animalDiet String = 33
  repeated animalFeedEquip String = 34
  optional animalGroupSize Integer = 35
  repeated animalHousing String = 36
  optional animalSex AnimalSexEnum = 37
  optional bacterialDensity QuantityValue = 38
  optional consFoodStorDur String = 39
  optional consFoodStorTemp String = 40
  optional consPurchDate Date = 41
  optional consQtyPurchased String = 42
  optional cultIsolDate Date = 43
  optional cultResult CultResultEnum = 44
  repeated cultResultOrg String = 45
  repeated cultTarget String = 46
  optional enrichmentProtocol String = 47
  repeated foodAdditive String = 48
  repeated foodContactSurf String = 49
  optional foodContainWrap String = 50
  repeated foodCookingProc String = 51
  repeated foodDisPoint String = 52
  optional foodDisPointCity String = 53
  repeated foodIngredient String = 54
  optional foodPackCapacity QuantityValue = 55
  repeated foodPackIntegrity String = 56
  repeated foodPackMedium String = 57
  repeated foodPreservProc String = 58
  repeated foodPriorContact String = 59
  repeated foodProdSynonym String = 60
  optional foodProductQual String = 61
  optional foodQualityDate String = 62
  optional foodSourceAge QuantityValue = 63
  optional foodTraceList FoodTraceListEnum = 64
  repeated foodTravMode String = 65
  repeated foodTravVehic String = 66
  repeated foodTreatProc String = 67
  repeated hACCPTerm String = 68
  optional libraryPrepKit String = 69
  repeated lotNumber String = 70
  optional microbCultMed String = 71
  repeated partPlantAnimal String = 72
  repeated repositoryName String = 73
  optional sampCollectMethod String = 74
  repeated sampPooling String = 75
  optional sampRepBiol QuantityValue = 76
  optional sampRepTech QuantityValue = 77
  optional sampSourceMatCat String = 78
  optional sampStorDevice String = 79
  optional sampStorMedia String = 80
  optional sampTransportCont SampTransportContEnum = 81
  optional sampTransportDur QuantityValue = 82
  optional sampTransportTemp String = 83
  optional sequencingKit String = 84
  optional sequencingLocation String = 85
  repeated serovarOrSerotype String = 86
  repeated spikeinAMR String = 87
  repeated spikeinAntibiotic String = 88
  repeated spikeinGrowthMed String = 89
  repeated spikeinMetal String = 90
  repeated spikeinOrg String = 91
  repeated spikeinSerovar String = 92
  repeated spikeinStrain String = 93
  repeated studyDesign String = 94
  optional studyIncDur QuantityValue = 95
  optional studyIncTemp QuantityValue = 96
  optional studyTimecourse QuantityValue = 97
  repeated studyTmnt String = 98
  optional timepoint Double = 99
  repeated miscParam String = 100
  sampName String = 101
  projectName String = 102
  seqMeth String = 103
  optional sampSize QuantityValue = 104
  optional experimentalFactor String = 105
  optional nuclAcidExt String = 106
  optional sampVolWeDnaExt QuantityValue = 107
  sampTaxonId String = 108
  optional negContType NegContTypeEnum = 109
  optional posContType String = 110
  optional subspecfGenLin String = 111
  numReplicons Integer = 112
  optional extrachromElements Integer = 113
  optional estimatedSize String = 114
  refBiomaterial String = 115
  optional sourceMatId String = 116
  optional pathogenicity String = 117
  optional bioticRelationship BioticRelationshipEnum = 118
  optional specificHost String = 119
  optional hostSpecRange Integer = 120
  optional hostDiseaseStat String = 121
  optional trophicLevel TrophicLevelEnum = 122
  optional encodedTraits String = 123
  optional relToOxygen RelToOxygenEnum = 124
  isolGrowthCondt String = 125
  optional sampCollecDevice String = 126
  optional sampCollecMethod String = 127
  optional sampMatProcess String = 128
  optional nuclAcidAmp String = 129
  optional libSize Integer = 130
  optional libReadsSeqd Integer = 131
  optional libLayout LibLayoutEnum = 132
  optional libVector String = 133
  optional libScreen String = 134
  optional adapters String = 135
  optional taxIdent TaxIdentEnum = 136
  assemblyQual AssemblyQualEnum = 137
  optional assemblyName String = 138
  assemblySoftware String = 139
  optional annot String = 140
  numberContig Integer = 141
  optional featPred String = 142
  optional refDb String = 143
  optional simSearchMeth String = 144
  optional taxClass String = 145
  optional complScore String = 146
  optional complSoftware String = 147
  optional associatedResource String = 148
  optional sop String = 149
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: eukaryote with environmental package food-animal and animal feed
message Food-animalAndAnimalFeedMIGSEukaryote
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  optional sampCollectDevice String = 11
  repeated organismCount OrganismCountEnum = 12
  optional spikeinCount SpikeinCountEnum = 13
  optional sampStorTemp QuantityValue = 14
  optional sampStorDur String = 15
  optional poolDnaExtracts String = 16
  optional sampStorLoc String = 17
  repeated perturbation String = 18
  collSiteGeoFeat String = 19
  foodOrigin String = 20
  repeated foodProd String = 21
  repeated foodProductType String = 22
  optional foodSource String = 23
  repeated iFSACCategory String = 24
  repeated intendedConsumer String = 25
  sampPurpose String = 26
  optional animalAm String = 27
  optional animalAmDur String = 28
  optional animalAmFreq QuantityValue = 29
  optional animalAmRoute String = 30
  optional animalAmUse String = 31
  optional animalBodyCond AnimalBodyCondEnum = 32
  repeated animalDiet String = 33
  repeated animalFeedEquip String = 34
  optional animalGroupSize Integer = 35
  repeated animalHousing String = 36
  optional animalSex AnimalSexEnum = 37
  optional bacterialDensity QuantityValue = 38
  optional consFoodStorDur String = 39
  optional consFoodStorTemp String = 40
  optional consPurchDate Date = 41
  optional consQtyPurchased String = 42
  optional cultIsolDate Date = 43
  optional cultResult CultResultEnum = 44
  repeated cultResultOrg String = 45
  repeated cultTarget String = 46
  optional enrichmentProtocol String = 47
  repeated foodAdditive String = 48
  repeated foodContactSurf String = 49
  optional foodContainWrap String = 50
  repeated foodCookingProc String = 51
  repeated foodDisPoint String = 52
  optional foodDisPointCity String = 53
  repeated foodIngredient String = 54
  optional foodPackCapacity QuantityValue = 55
  repeated foodPackIntegrity String = 56
  repeated foodPackMedium String = 57
  repeated foodPreservProc String = 58
  repeated foodPriorContact String = 59
  repeated foodProdSynonym String = 60
  optional foodProductQual String = 61
  optional foodQualityDate String = 62
  optional foodSourceAge QuantityValue = 63
  optional foodTraceList FoodTraceListEnum = 64
  repeated foodTravMode String = 65
  repeated foodTravVehic String = 66
  repeated foodTreatProc String = 67
  repeated hACCPTerm String = 68
  optional libraryPrepKit String = 69
  repeated lotNumber String = 70
  optional microbCultMed String = 71
  repeated partPlantAnimal String = 72
  repeated repositoryName String = 73
  optional sampCollectMethod String = 74
  repeated sampPooling String = 75
  optional sampRepBiol QuantityValue = 76
  optional sampRepTech QuantityValue = 77
  optional sampSourceMatCat String = 78
  optional sampStorDevice String = 79
  optional sampStorMedia String = 80
  optional sampTransportCont SampTransportContEnum = 81
  optional sampTransportDur QuantityValue = 82
  optional sampTransportTemp String = 83
  optional sequencingKit String = 84
  optional sequencingLocation String = 85
  repeated serovarOrSerotype String = 86
  repeated spikeinAMR String = 87
  repeated spikeinAntibiotic String = 88
  repeated spikeinGrowthMed String = 89
  repeated spikeinMetal String = 90
  repeated spikeinOrg String = 91
  repeated spikeinSerovar String = 92
  repeated spikeinStrain String = 93
  repeated studyDesign String = 94
  optional studyIncDur QuantityValue = 95
  optional studyIncTemp QuantityValue = 96
  optional studyTimecourse QuantityValue = 97
  repeated studyTmnt String = 98
  optional timepoint Double = 99
  repeated miscParam String = 100
  sampName String = 101
  projectName String = 102
  seqMeth String = 103
  optional sampSize QuantityValue = 104
  optional experimentalFactor String = 105
  optional nuclAcidExt String = 106
  optional sampVolWeDnaExt QuantityValue = 107
  sampTaxonId String = 108
  optional negContType NegContTypeEnum = 109
  optional posContType String = 110
  optional subspecfGenLin String = 111
  optional ploidy String = 112
  optional numReplicons Integer = 113
  optional extrachromElements Integer = 114
  optional estimatedSize String = 115
  optional refBiomaterial String = 116
  optional sourceMatId String = 117
  optional pathogenicity String = 118
  optional bioticRelationship BioticRelationshipEnum = 119
  optional specificHost String = 120
  optional hostSpecRange Integer = 121
  optional hostDiseaseStat String = 122
  optional trophicLevel TrophicLevelEnum = 123
  optional propagation String = 124
  isolGrowthCondt String = 125
  optional sampCollecDevice String = 126
  optional sampCollecMethod String = 127
  optional sampMatProcess String = 128
  optional nuclAcidAmp String = 129
  optional libSize Integer = 130
  optional libReadsSeqd Integer = 131
  optional libLayout LibLayoutEnum = 132
  optional libVector String = 133
  optional libScreen String = 134
  optional adapters String = 135
  optional taxIdent TaxIdentEnum = 136
  assemblyQual AssemblyQualEnum = 137
  optional assemblyName String = 138
  assemblySoftware String = 139
  optional annot String = 140
  numberContig Integer = 141
  optional featPred String = 142
  optional refDb String = 143
  optional simSearchMeth String = 144
  optional taxClass String = 145
  optional complScore String = 146
  optional complSoftware String = 147
  optional associatedResource String = 148
  optional sop String = 149
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: org with environmental package food-animal and animal feed
message Food-animalAndAnimalFeedMIGSOrg
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  optional sampCollectDevice String = 11
  repeated organismCount OrganismCountEnum = 12
  optional spikeinCount SpikeinCountEnum = 13
  optional sampStorTemp QuantityValue = 14
  optional sampStorDur String = 15
  optional poolDnaExtracts String = 16
  optional sampStorLoc String = 17
  repeated perturbation String = 18
  collSiteGeoFeat String = 19
  foodOrigin String = 20
  repeated foodProd String = 21
  repeated foodProductType String = 22
  optional foodSource String = 23
  repeated iFSACCategory String = 24
  repeated intendedConsumer String = 25
  sampPurpose String = 26
  optional animalAm String = 27
  optional animalAmDur String = 28
  optional animalAmFreq QuantityValue = 29
  optional animalAmRoute String = 30
  optional animalAmUse String = 31
  optional animalBodyCond AnimalBodyCondEnum = 32
  repeated animalDiet String = 33
  repeated animalFeedEquip String = 34
  optional animalGroupSize Integer = 35
  repeated animalHousing String = 36
  optional animalSex AnimalSexEnum = 37
  optional bacterialDensity QuantityValue = 38
  optional consFoodStorDur String = 39
  optional consFoodStorTemp String = 40
  optional consPurchDate Date = 41
  optional consQtyPurchased String = 42
  optional cultIsolDate Date = 43
  optional cultResult CultResultEnum = 44
  repeated cultResultOrg String = 45
  repeated cultTarget String = 46
  optional enrichmentProtocol String = 47
  repeated foodAdditive String = 48
  repeated foodContactSurf String = 49
  optional foodContainWrap String = 50
  repeated foodCookingProc String = 51
  repeated foodDisPoint String = 52
  optional foodDisPointCity String = 53
  repeated foodIngredient String = 54
  optional foodPackCapacity QuantityValue = 55
  repeated foodPackIntegrity String = 56
  repeated foodPackMedium String = 57
  repeated foodPreservProc String = 58
  repeated foodPriorContact String = 59
  repeated foodProdSynonym String = 60
  optional foodProductQual String = 61
  optional foodQualityDate String = 62
  optional foodSourceAge QuantityValue = 63
  optional foodTraceList FoodTraceListEnum = 64
  repeated foodTravMode String = 65
  repeated foodTravVehic String = 66
  repeated foodTreatProc String = 67
  repeated hACCPTerm String = 68
  optional libraryPrepKit String = 69
  repeated lotNumber String = 70
  optional microbCultMed String = 71
  repeated partPlantAnimal String = 72
  repeated repositoryName String = 73
  optional sampCollectMethod String = 74
  repeated sampPooling String = 75
  optional sampRepBiol QuantityValue = 76
  optional sampRepTech QuantityValue = 77
  optional sampSourceMatCat String = 78
  optional sampStorDevice String = 79
  optional sampStorMedia String = 80
  optional sampTransportCont SampTransportContEnum = 81
  optional sampTransportDur QuantityValue = 82
  optional sampTransportTemp String = 83
  optional sequencingKit String = 84
  optional sequencingLocation String = 85
  repeated serovarOrSerotype String = 86
  repeated spikeinAMR String = 87
  repeated spikeinAntibiotic String = 88
  repeated spikeinGrowthMed String = 89
  repeated spikeinMetal String = 90
  repeated spikeinOrg String = 91
  repeated spikeinSerovar String = 92
  repeated spikeinStrain String = 93
  repeated studyDesign String = 94
  optional studyIncDur QuantityValue = 95
  optional studyIncTemp QuantityValue = 96
  optional studyTimecourse QuantityValue = 97
  repeated studyTmnt String = 98
  optional timepoint Double = 99
  repeated miscParam String = 100
  sampName String = 101
  projectName String = 102
  seqMeth String = 103
  optional sampSize QuantityValue = 104
  optional experimentalFactor String = 105
  optional nuclAcidExt String = 106
  optional sampVolWeDnaExt QuantityValue = 107
  sampTaxonId String = 108
  optional negContType NegContTypeEnum = 109
  optional posContType String = 110
  optional subspecfGenLin String = 111
  optional extrachromElements Integer = 112
  optional estimatedSize String = 113
  optional refBiomaterial String = 114
  optional sourceMatId String = 115
  isolGrowthCondt String = 116
  optional sampCollecDevice String = 117
  optional sampCollecMethod String = 118
  optional sampMatProcess String = 119
  optional nuclAcidAmp String = 120
  optional libSize Integer = 121
  optional libReadsSeqd Integer = 122
  optional libLayout LibLayoutEnum = 123
  optional libVector String = 124
  optional libScreen String = 125
  optional adapters String = 126
  optional taxIdent TaxIdentEnum = 127
  optional assemblyQual AssemblyQualEnum = 128
  optional assemblyName String = 129
  assemblySoftware String = 130
  optional annot String = 131
  optional numberContig Integer = 132
  optional featPred String = 133
  optional refDb String = 134
  optional simSearchMeth String = 135
  optional taxClass String = 136
  optional complScore String = 137
  optional complSoftware String = 138
  optional associatedResource String = 139
  optional sop String = 140
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: plant with environmental package food-animal and animal feed
message Food-animalAndAnimalFeedMIGSPlant
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  optional sampCollectDevice String = 11
  repeated organismCount OrganismCountEnum = 12
  optional spikeinCount SpikeinCountEnum = 13
  optional sampStorTemp QuantityValue = 14
  optional sampStorDur String = 15
  optional poolDnaExtracts String = 16
  optional sampStorLoc String = 17
  repeated perturbation String = 18
  collSiteGeoFeat String = 19
  foodOrigin String = 20
  repeated foodProd String = 21
  repeated foodProductType String = 22
  optional foodSource String = 23
  repeated iFSACCategory String = 24
  repeated intendedConsumer String = 25
  sampPurpose String = 26
  optional animalAm String = 27
  optional animalAmDur String = 28
  optional animalAmFreq QuantityValue = 29
  optional animalAmRoute String = 30
  optional animalAmUse String = 31
  optional animalBodyCond AnimalBodyCondEnum = 32
  repeated animalDiet String = 33
  repeated animalFeedEquip String = 34
  optional animalGroupSize Integer = 35
  repeated animalHousing String = 36
  optional animalSex AnimalSexEnum = 37
  optional bacterialDensity QuantityValue = 38
  optional consFoodStorDur String = 39
  optional consFoodStorTemp String = 40
  optional consPurchDate Date = 41
  optional consQtyPurchased String = 42
  optional cultIsolDate Date = 43
  optional cultResult CultResultEnum = 44
  repeated cultResultOrg String = 45
  repeated cultTarget String = 46
  optional enrichmentProtocol String = 47
  repeated foodAdditive String = 48
  repeated foodContactSurf String = 49
  optional foodContainWrap String = 50
  repeated foodCookingProc String = 51
  repeated foodDisPoint String = 52
  optional foodDisPointCity String = 53
  repeated foodIngredient String = 54
  optional foodPackCapacity QuantityValue = 55
  repeated foodPackIntegrity String = 56
  repeated foodPackMedium String = 57
  repeated foodPreservProc String = 58
  repeated foodPriorContact String = 59
  repeated foodProdSynonym String = 60
  optional foodProductQual String = 61
  optional foodQualityDate String = 62
  optional foodSourceAge QuantityValue = 63
  optional foodTraceList FoodTraceListEnum = 64
  repeated foodTravMode String = 65
  repeated foodTravVehic String = 66
  repeated foodTreatProc String = 67
  repeated hACCPTerm String = 68
  optional libraryPrepKit String = 69
  repeated lotNumber String = 70
  optional microbCultMed String = 71
  repeated partPlantAnimal String = 72
  repeated repositoryName String = 73
  optional sampCollectMethod String = 74
  repeated sampPooling String = 75
  optional sampRepBiol QuantityValue = 76
  optional sampRepTech QuantityValue = 77
  optional sampSourceMatCat String = 78
  optional sampStorDevice String = 79
  optional sampStorMedia String = 80
  optional sampTransportCont SampTransportContEnum = 81
  optional sampTransportDur QuantityValue = 82
  optional sampTransportTemp String = 83
  optional sequencingKit String = 84
  optional sequencingLocation String = 85
  repeated serovarOrSerotype String = 86
  repeated spikeinAMR String = 87
  repeated spikeinAntibiotic String = 88
  repeated spikeinGrowthMed String = 89
  repeated spikeinMetal String = 90
  repeated spikeinOrg String = 91
  repeated spikeinSerovar String = 92
  repeated spikeinStrain String = 93
  repeated studyDesign String = 94
  optional studyIncDur QuantityValue = 95
  optional studyIncTemp QuantityValue = 96
  optional studyTimecourse QuantityValue = 97
  repeated studyTmnt String = 98
  optional timepoint Double = 99
  repeated miscParam String = 100
  sampName String = 101
  projectName String = 102
  seqMeth String = 103
  optional sampSize QuantityValue = 104
  optional experimentalFactor String = 105
  optional nuclAcidExt String = 106
  optional sampVolWeDnaExt QuantityValue = 107
  sampTaxonId String = 108
  optional negContType NegContTypeEnum = 109
  optional posContType String = 110
  optional subspecfGenLin String = 111
  optional estimatedSize String = 112
  optional refBiomaterial String = 113
  optional sourceMatId String = 114
  optional specificHost String = 115
  optional hostSpecRange Integer = 116
  propagation String = 117
  optional encodedTraits String = 118
  isolGrowthCondt String = 119
  optional sampCollecDevice String = 120
  optional sampCollecMethod String = 121
  optional sampMatProcess String = 122
  optional nuclAcidAmp String = 123
  optional libSize Integer = 124
  optional libReadsSeqd Integer = 125
  optional libLayout LibLayoutEnum = 126
  optional libVector String = 127
  optional libScreen String = 128
  optional adapters String = 129
  optional taxIdent TaxIdentEnum = 130
  optional assemblyQual AssemblyQualEnum = 131
  optional assemblyName String = 132
  assemblySoftware String = 133
  optional annot String = 134
  optional numberContig Integer = 135
  optional featPred String = 136
  optional refDb String = 137
  optional simSearchMeth String = 138
  optional taxClass String = 139
  optional complScore String = 140
  optional complSoftware String = 141
  optional associatedResource String = 142
  optional sop String = 143
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package food-animal and animal feed
message Food-animalAndAnimalFeedMIGSVirus
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  optional sampCollectDevice String = 11
  repeated organismCount OrganismCountEnum = 12
  optional spikeinCount SpikeinCountEnum = 13
  optional sampStorTemp QuantityValue = 14
  optional sampStorDur String = 15
  optional poolDnaExtracts String = 16
  optional sampStorLoc String = 17
  repeated perturbation String = 18
  collSiteGeoFeat String = 19
  foodOrigin String = 20
  repeated foodProd String = 21
  repeated foodProductType String = 22
  optional foodSource String = 23
  repeated iFSACCategory String = 24
  repeated intendedConsumer String = 25
  sampPurpose String = 26
  optional animalAm String = 27
  optional animalAmDur String = 28
  optional animalAmFreq QuantityValue = 29
  optional animalAmRoute String = 30
  optional animalAmUse String = 31
  optional animalBodyCond AnimalBodyCondEnum = 32
  repeated animalDiet String = 33
  repeated animalFeedEquip String = 34
  optional animalGroupSize Integer = 35
  repeated animalHousing String = 36
  optional animalSex AnimalSexEnum = 37
  optional bacterialDensity QuantityValue = 38
  optional consFoodStorDur String = 39
  optional consFoodStorTemp String = 40
  optional consPurchDate Date = 41
  optional consQtyPurchased String = 42
  optional cultIsolDate Date = 43
  optional cultResult CultResultEnum = 44
  repeated cultResultOrg String = 45
  repeated cultTarget String = 46
  optional enrichmentProtocol String = 47
  repeated foodAdditive String = 48
  repeated foodContactSurf String = 49
  optional foodContainWrap String = 50
  repeated foodCookingProc String = 51
  repeated foodDisPoint String = 52
  optional foodDisPointCity String = 53
  repeated foodIngredient String = 54
  optional foodPackCapacity QuantityValue = 55
  repeated foodPackIntegrity String = 56
  repeated foodPackMedium String = 57
  repeated foodPreservProc String = 58
  repeated foodPriorContact String = 59
  repeated foodProdSynonym String = 60
  optional foodProductQual String = 61
  optional foodQualityDate String = 62
  optional foodSourceAge QuantityValue = 63
  optional foodTraceList FoodTraceListEnum = 64
  repeated foodTravMode String = 65
  repeated foodTravVehic String = 66
  repeated foodTreatProc String = 67
  repeated hACCPTerm String = 68
  optional libraryPrepKit String = 69
  repeated lotNumber String = 70
  optional microbCultMed String = 71
  repeated partPlantAnimal String = 72
  repeated repositoryName String = 73
  optional sampCollectMethod String = 74
  repeated sampPooling String = 75
  optional sampRepBiol QuantityValue = 76
  optional sampRepTech QuantityValue = 77
  optional sampSourceMatCat String = 78
  optional sampStorDevice String = 79
  optional sampStorMedia String = 80
  optional sampTransportCont SampTransportContEnum = 81
  optional sampTransportDur QuantityValue = 82
  optional sampTransportTemp String = 83
  optional sequencingKit String = 84
  optional sequencingLocation String = 85
  repeated serovarOrSerotype String = 86
  repeated spikeinAMR String = 87
  repeated spikeinAntibiotic String = 88
  repeated spikeinGrowthMed String = 89
  repeated spikeinMetal String = 90
  repeated spikeinOrg String = 91
  repeated spikeinSerovar String = 92
  repeated spikeinStrain String = 93
  repeated studyDesign String = 94
  optional studyIncDur QuantityValue = 95
  optional studyIncTemp QuantityValue = 96
  optional studyTimecourse QuantityValue = 97
  repeated studyTmnt String = 98
  optional timepoint Double = 99
  repeated miscParam String = 100
  sampName String = 101
  projectName String = 102
  seqMeth String = 103
  optional sampSize QuantityValue = 104
  optional experimentalFactor String = 105
  optional nuclAcidExt String = 106
  optional sampVolWeDnaExt QuantityValue = 107
  sampTaxonId String = 108
  optional negContType NegContTypeEnum = 109
  optional posContType String = 110
  optional subspecfGenLin String = 111
  optional numReplicons Integer = 112
  optional estimatedSize String = 113
  optional refBiomaterial String = 114
  optional sourceMatId String = 115
  optional pathogenicity String = 116
  optional bioticRelationship BioticRelationshipEnum = 117
  optional specificHost String = 118
  optional hostSpecRange Integer = 119
  optional hostDiseaseStat String = 120
  propagation String = 121
  optional encodedTraits String = 122
  isolGrowthCondt String = 123
  optional sampCollecDevice String = 124
  optional sampCollecMethod String = 125
  optional sampMatProcess String = 126
  optional virusEnrichAppr VirusEnrichApprEnum = 127
  optional nuclAcidAmp String = 128
  optional libSize Integer = 129
  optional libReadsSeqd Integer = 130
  optional libLayout LibLayoutEnum = 131
  optional libVector String = 132
  optional libScreen String = 133
  optional adapters String = 134
  optional taxIdent TaxIdentEnum = 135
  optional assemblyQual AssemblyQualEnum = 136
  optional assemblyName String = 137
  assemblySoftware String = 138
  optional annot String = 139
  optional numberContig Integer = 140
  optional featPred String = 141
  optional refDb String = 142
  optional simSearchMeth String = 143
  optional taxClass String = 144
  optional complScore String = 145
  optional complSoftware String = 146
  optional associatedResource String = 147
  optional sop String = 148
 }
// Combinatorial checklist Minimum Information About a Metagenome-Assembled Genome with environmental package food-animal and animal feed
message Food-animalAndAnimalFeedMIMAG
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  optional sampCollectDevice String = 11
  repeated organismCount OrganismCountEnum = 12
  optional spikeinCount SpikeinCountEnum = 13
  optional sampStorTemp QuantityValue = 14
  optional sampStorDur String = 15
  optional poolDnaExtracts String = 16
  optional sampStorLoc String = 17
  repeated perturbation String = 18
  collSiteGeoFeat String = 19
  foodOrigin String = 20
  repeated foodProd String = 21
  repeated foodProductType String = 22
  optional foodSource String = 23
  repeated iFSACCategory String = 24
  repeated intendedConsumer String = 25
  sampPurpose String = 26
  optional animalAm String = 27
  optional animalAmDur String = 28
  optional animalAmFreq QuantityValue = 29
  optional animalAmRoute String = 30
  optional animalAmUse String = 31
  optional animalBodyCond AnimalBodyCondEnum = 32
  repeated animalDiet String = 33
  repeated animalFeedEquip String = 34
  optional animalGroupSize Integer = 35
  repeated animalHousing String = 36
  optional animalSex AnimalSexEnum = 37
  optional bacterialDensity QuantityValue = 38
  optional consFoodStorDur String = 39
  optional consFoodStorTemp String = 40
  optional consPurchDate Date = 41
  optional consQtyPurchased String = 42
  optional cultIsolDate Date = 43
  optional cultResult CultResultEnum = 44
  repeated cultResultOrg String = 45
  repeated cultTarget String = 46
  optional enrichmentProtocol String = 47
  repeated foodAdditive String = 48
  repeated foodContactSurf String = 49
  optional foodContainWrap String = 50
  repeated foodCookingProc String = 51
  repeated foodDisPoint String = 52
  optional foodDisPointCity String = 53
  repeated foodIngredient String = 54
  optional foodPackCapacity QuantityValue = 55
  repeated foodPackIntegrity String = 56
  repeated foodPackMedium String = 57
  repeated foodPreservProc String = 58
  repeated foodPriorContact String = 59
  repeated foodProdSynonym String = 60
  optional foodProductQual String = 61
  optional foodQualityDate String = 62
  optional foodSourceAge QuantityValue = 63
  optional foodTraceList FoodTraceListEnum = 64
  repeated foodTravMode String = 65
  repeated foodTravVehic String = 66
  repeated foodTreatProc String = 67
  repeated hACCPTerm String = 68
  optional libraryPrepKit String = 69
  repeated lotNumber String = 70
  optional microbCultMed String = 71
  repeated partPlantAnimal String = 72
  repeated repositoryName String = 73
  optional sampCollectMethod String = 74
  repeated sampPooling String = 75
  optional sampRepBiol QuantityValue = 76
  optional sampRepTech QuantityValue = 77
  optional sampSourceMatCat String = 78
  optional sampStorDevice String = 79
  optional sampStorMedia String = 80
  optional sampTransportCont SampTransportContEnum = 81
  optional sampTransportDur QuantityValue = 82
  optional sampTransportTemp String = 83
  optional sequencingKit String = 84
  optional sequencingLocation String = 85
  repeated serovarOrSerotype String = 86
  repeated spikeinAMR String = 87
  repeated spikeinAntibiotic String = 88
  repeated spikeinGrowthMed String = 89
  repeated spikeinMetal String = 90
  repeated spikeinOrg String = 91
  repeated spikeinSerovar String = 92
  repeated spikeinStrain String = 93
  repeated studyDesign String = 94
  optional studyIncDur QuantityValue = 95
  optional studyIncTemp QuantityValue = 96
  optional studyTimecourse QuantityValue = 97
  repeated studyTmnt String = 98
  optional timepoint Double = 99
  repeated miscParam String = 100
  sampName String = 101
  projectName String = 102
  seqMeth String = 103
  optional sampSize QuantityValue = 104
  optional experimentalFactor String = 105
  optional nuclAcidExt String = 106
  optional sampVolWeDnaExt QuantityValue = 107
  sampTaxonId String = 108
  optional negContType NegContTypeEnum = 109
  optional posContType String = 110
  optional refBiomaterial String = 111
  optional sourceMatId String = 112
  optional relToOxygen RelToOxygenEnum = 113
  optional sampCollecDevice String = 114
  optional sampCollecMethod String = 115
  optional sampMatProcess String = 116
  optional sizeFrac String = 117
  optional nuclAcidAmp String = 118
  optional libSize Integer = 119
  optional libReadsSeqd Integer = 120
  optional libLayout LibLayoutEnum = 121
  optional libVector String = 122
  optional libScreen String = 123
  optional mid String = 124
  optional adapters String = 125
  taxIdent TaxIdentEnum = 126
  assemblyQual AssemblyQualEnum = 127
  optional assemblyName String = 128
  assemblySoftware String = 129
  optional annot String = 130
  optional numberContig Integer = 131
  optional featPred String = 132
  optional refDb String = 133
  optional simSearchMeth String = 134
  optional taxClass String = 135
  optional x16sRecover String = 136
  optional x16sRecoverSoftware String = 137
  optional trnas Integer = 138
  optional trnaExtSoftware String = 139
  complScore String = 140
  complSoftware String = 141
  optional complAppr ComplApprEnum = 142
  contamScore String = 143
  optional contamScreenInput String = 144
  optional contamScreenParam String = 145
  optional decontamSoftware DecontamSoftwareEnum = 146
  binParam BinParamEnum = 147
  binSoftware String = 148
  optional reassemblyBin String = 149
  optional magCovSoftware MagCovSoftwareEnum = 150
  optional associatedResource String = 151
  optional sop String = 152
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: specimen with environmental package food-animal and animal feed
message Food-animalAndAnimalFeedMIMARKSSpecimen
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  optional sampCollectDevice String = 11
  repeated organismCount OrganismCountEnum = 12
  optional spikeinCount SpikeinCountEnum = 13
  optional sampStorTemp QuantityValue = 14
  optional sampStorDur String = 15
  optional poolDnaExtracts String = 16
  optional sampStorLoc String = 17
  repeated perturbation String = 18
  collSiteGeoFeat String = 19
  foodOrigin String = 20
  repeated foodProd String = 21
  repeated foodProductType String = 22
  optional foodSource String = 23
  repeated iFSACCategory String = 24
  repeated intendedConsumer String = 25
  sampPurpose String = 26
  optional animalAm String = 27
  optional animalAmDur String = 28
  optional animalAmFreq QuantityValue = 29
  optional animalAmRoute String = 30
  optional animalAmUse String = 31
  optional animalBodyCond AnimalBodyCondEnum = 32
  repeated animalDiet String = 33
  repeated animalFeedEquip String = 34
  optional animalGroupSize Integer = 35
  repeated animalHousing String = 36
  optional animalSex AnimalSexEnum = 37
  optional bacterialDensity QuantityValue = 38
  optional consFoodStorDur String = 39
  optional consFoodStorTemp String = 40
  optional consPurchDate Date = 41
  optional consQtyPurchased String = 42
  optional cultIsolDate Date = 43
  optional cultResult CultResultEnum = 44
  repeated cultResultOrg String = 45
  repeated cultTarget String = 46
  optional enrichmentProtocol String = 47
  repeated foodAdditive String = 48
  repeated foodContactSurf String = 49
  optional foodContainWrap String = 50
  repeated foodCookingProc String = 51
  repeated foodDisPoint String = 52
  optional foodDisPointCity String = 53
  repeated foodIngredient String = 54
  optional foodPackCapacity QuantityValue = 55
  repeated foodPackIntegrity String = 56
  repeated foodPackMedium String = 57
  repeated foodPreservProc String = 58
  repeated foodPriorContact String = 59
  repeated foodProdSynonym String = 60
  optional foodProductQual String = 61
  optional foodQualityDate String = 62
  optional foodSourceAge QuantityValue = 63
  optional foodTraceList FoodTraceListEnum = 64
  repeated foodTravMode String = 65
  repeated foodTravVehic String = 66
  repeated foodTreatProc String = 67
  repeated hACCPTerm String = 68
  optional libraryPrepKit String = 69
  repeated lotNumber String = 70
  optional microbCultMed String = 71
  repeated partPlantAnimal String = 72
  repeated repositoryName String = 73
  optional sampCollectMethod String = 74
  repeated sampPooling String = 75
  optional sampRepBiol QuantityValue = 76
  optional sampRepTech QuantityValue = 77
  optional sampSourceMatCat String = 78
  optional sampStorDevice String = 79
  optional sampStorMedia String = 80
  optional sampTransportCont SampTransportContEnum = 81
  optional sampTransportDur QuantityValue = 82
  optional sampTransportTemp String = 83
  optional sequencingKit String = 84
  optional sequencingLocation String = 85
  repeated serovarOrSerotype String = 86
  repeated spikeinAMR String = 87
  repeated spikeinAntibiotic String = 88
  repeated spikeinGrowthMed String = 89
  repeated spikeinMetal String = 90
  repeated spikeinOrg String = 91
  repeated spikeinSerovar String = 92
  repeated spikeinStrain String = 93
  repeated studyDesign String = 94
  optional studyIncDur QuantityValue = 95
  optional studyIncTemp QuantityValue = 96
  optional studyTimecourse QuantityValue = 97
  repeated studyTmnt String = 98
  optional timepoint Double = 99
  repeated miscParam String = 100
  sampName String = 101
  projectName String = 102
  seqMeth String = 103
  optional sampSize QuantityValue = 104
  optional experimentalFactor String = 105
  optional nuclAcidExt String = 106
  optional sampVolWeDnaExt QuantityValue = 107
  sampTaxonId String = 108
  optional negContType NegContTypeEnum = 109
  optional posContType String = 110
  optional sourceMatId String = 111
  optional relToOxygen RelToOxygenEnum = 112
  optional sampCollecDevice String = 113
  optional sampCollecMethod String = 114
  optional sampMatProcess String = 115
  optional sizeFrac String = 116
  optional nuclAcidAmp String = 117
  optional libSize Integer = 118
  optional libReadsSeqd Integer = 119
  optional libLayout LibLayoutEnum = 120
  optional libVector String = 121
  optional libScreen String = 122
  targetGene String = 123
  optional targetSubfragment String = 124
  optional pcrPrimers String = 125
  optional mid String = 126
  optional adapters String = 127
  optional pcrCond String = 128
  optional seqQualityCheck String = 129
  optional chimeraCheck String = 130
  optional assemblySoftware String = 131
  optional associatedResource String = 132
  optional sop String = 133
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: survey with environmental package food-animal and animal feed
message Food-animalAndAnimalFeedMIMARKSSurvey
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  optional sampCollectDevice String = 11
  repeated organismCount OrganismCountEnum = 12
  optional spikeinCount SpikeinCountEnum = 13
  optional sampStorTemp QuantityValue = 14
  optional sampStorDur String = 15
  optional poolDnaExtracts String = 16
  optional sampStorLoc String = 17
  repeated perturbation String = 18
  collSiteGeoFeat String = 19
  foodOrigin String = 20
  repeated foodProd String = 21
  repeated foodProductType String = 22
  optional foodSource String = 23
  repeated iFSACCategory String = 24
  repeated intendedConsumer String = 25
  sampPurpose String = 26
  optional animalAm String = 27
  optional animalAmDur String = 28
  optional animalAmFreq QuantityValue = 29
  optional animalAmRoute String = 30
  optional animalAmUse String = 31
  optional animalBodyCond AnimalBodyCondEnum = 32
  repeated animalDiet String = 33
  repeated animalFeedEquip String = 34
  optional animalGroupSize Integer = 35
  repeated animalHousing String = 36
  optional animalSex AnimalSexEnum = 37
  optional bacterialDensity QuantityValue = 38
  optional consFoodStorDur String = 39
  optional consFoodStorTemp String = 40
  optional consPurchDate Date = 41
  optional consQtyPurchased String = 42
  optional cultIsolDate Date = 43
  optional cultResult CultResultEnum = 44
  repeated cultResultOrg String = 45
  repeated cultTarget String = 46
  optional enrichmentProtocol String = 47
  repeated foodAdditive String = 48
  repeated foodContactSurf String = 49
  optional foodContainWrap String = 50
  repeated foodCookingProc String = 51
  repeated foodDisPoint String = 52
  optional foodDisPointCity String = 53
  repeated foodIngredient String = 54
  optional foodPackCapacity QuantityValue = 55
  repeated foodPackIntegrity String = 56
  repeated foodPackMedium String = 57
  repeated foodPreservProc String = 58
  repeated foodPriorContact String = 59
  repeated foodProdSynonym String = 60
  optional foodProductQual String = 61
  optional foodQualityDate String = 62
  optional foodSourceAge QuantityValue = 63
  optional foodTraceList FoodTraceListEnum = 64
  repeated foodTravMode String = 65
  repeated foodTravVehic String = 66
  repeated foodTreatProc String = 67
  repeated hACCPTerm String = 68
  optional libraryPrepKit String = 69
  repeated lotNumber String = 70
  optional microbCultMed String = 71
  repeated partPlantAnimal String = 72
  repeated repositoryName String = 73
  optional sampCollectMethod String = 74
  repeated sampPooling String = 75
  optional sampRepBiol QuantityValue = 76
  optional sampRepTech QuantityValue = 77
  optional sampSourceMatCat String = 78
  optional sampStorDevice String = 79
  optional sampStorMedia String = 80
  optional sampTransportCont SampTransportContEnum = 81
  optional sampTransportDur QuantityValue = 82
  optional sampTransportTemp String = 83
  optional sequencingKit String = 84
  optional sequencingLocation String = 85
  repeated serovarOrSerotype String = 86
  repeated spikeinAMR String = 87
  repeated spikeinAntibiotic String = 88
  repeated spikeinGrowthMed String = 89
  repeated spikeinMetal String = 90
  repeated spikeinOrg String = 91
  repeated spikeinSerovar String = 92
  repeated spikeinStrain String = 93
  repeated studyDesign String = 94
  optional studyIncDur QuantityValue = 95
  optional studyIncTemp QuantityValue = 96
  optional studyTimecourse QuantityValue = 97
  repeated studyTmnt String = 98
  optional timepoint Double = 99
  repeated miscParam String = 100
  sampName String = 101
  projectName String = 102
  seqMeth String = 103
  optional sampSize QuantityValue = 104
  optional experimentalFactor String = 105
  optional nuclAcidExt String = 106
  optional sampVolWeDnaExt QuantityValue = 107
  sampTaxonId String = 108
  optional negContType NegContTypeEnum = 109
  optional posContType String = 110
  optional subspecfGenLin String = 111
  optional extrachromElements Integer = 112
  optional sourceMatId String = 113
  optional bioticRelationship BioticRelationshipEnum = 114
  optional trophicLevel TrophicLevelEnum = 115
  optional relToOxygen RelToOxygenEnum = 116
  isolGrowthCondt String = 117
  optional sampCollecDevice String = 118
  optional sampCollecMethod String = 119
  optional sampMatProcess String = 120
  optional nuclAcidAmp String = 121
  targetGene String = 122
  optional targetSubfragment String = 123
  optional pcrPrimers String = 124
  optional pcrCond String = 125
  optional seqQualityCheck String = 126
  optional chimeraCheck String = 127
  optional associatedResource String = 128
  optional sop String = 129
 }
// Combinatorial checklist Metagenome or Environmental with environmental package food-animal and animal feed
message Food-animalAndAnimalFeedMIMS
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  optional sampCollectDevice String = 11
  repeated organismCount OrganismCountEnum = 12
  optional spikeinCount SpikeinCountEnum = 13
  optional sampStorTemp QuantityValue = 14
  optional sampStorDur String = 15
  optional poolDnaExtracts String = 16
  optional sampStorLoc String = 17
  repeated perturbation String = 18
  collSiteGeoFeat String = 19
  foodOrigin String = 20
  repeated foodProd String = 21
  repeated foodProductType String = 22
  optional foodSource String = 23
  repeated iFSACCategory String = 24
  repeated intendedConsumer String = 25
  sampPurpose String = 26
  optional animalAm String = 27
  optional animalAmDur String = 28
  optional animalAmFreq QuantityValue = 29
  optional animalAmRoute String = 30
  optional animalAmUse String = 31
  optional animalBodyCond AnimalBodyCondEnum = 32
  repeated animalDiet String = 33
  repeated animalFeedEquip String = 34
  optional animalGroupSize Integer = 35
  repeated animalHousing String = 36
  optional animalSex AnimalSexEnum = 37
  optional bacterialDensity QuantityValue = 38
  optional consFoodStorDur String = 39
  optional consFoodStorTemp String = 40
  optional consPurchDate Date = 41
  optional consQtyPurchased String = 42
  optional cultIsolDate Date = 43
  optional cultResult CultResultEnum = 44
  repeated cultResultOrg String = 45
  repeated cultTarget String = 46
  optional enrichmentProtocol String = 47
  repeated foodAdditive String = 48
  repeated foodContactSurf String = 49
  optional foodContainWrap String = 50
  repeated foodCookingProc String = 51
  repeated foodDisPoint String = 52
  optional foodDisPointCity String = 53
  repeated foodIngredient String = 54
  optional foodPackCapacity QuantityValue = 55
  repeated foodPackIntegrity String = 56
  repeated foodPackMedium String = 57
  repeated foodPreservProc String = 58
  repeated foodPriorContact String = 59
  repeated foodProdSynonym String = 60
  optional foodProductQual String = 61
  optional foodQualityDate String = 62
  optional foodSourceAge QuantityValue = 63
  optional foodTraceList FoodTraceListEnum = 64
  repeated foodTravMode String = 65
  repeated foodTravVehic String = 66
  repeated foodTreatProc String = 67
  repeated hACCPTerm String = 68
  optional libraryPrepKit String = 69
  repeated lotNumber String = 70
  optional microbCultMed String = 71
  repeated partPlantAnimal String = 72
  repeated repositoryName String = 73
  optional sampCollectMethod String = 74
  repeated sampPooling String = 75
  optional sampRepBiol QuantityValue = 76
  optional sampRepTech QuantityValue = 77
  optional sampSourceMatCat String = 78
  optional sampStorDevice String = 79
  optional sampStorMedia String = 80
  optional sampTransportCont SampTransportContEnum = 81
  optional sampTransportDur QuantityValue = 82
  optional sampTransportTemp String = 83
  optional sequencingKit String = 84
  optional sequencingLocation String = 85
  repeated serovarOrSerotype String = 86
  repeated spikeinAMR String = 87
  repeated spikeinAntibiotic String = 88
  repeated spikeinGrowthMed String = 89
  repeated spikeinMetal String = 90
  repeated spikeinOrg String = 91
  repeated spikeinSerovar String = 92
  repeated spikeinStrain String = 93
  repeated studyDesign String = 94
  optional studyIncDur QuantityValue = 95
  optional studyIncTemp QuantityValue = 96
  optional studyTimecourse QuantityValue = 97
  repeated studyTmnt String = 98
  optional timepoint Double = 99
  repeated miscParam String = 100
  sampName String = 101
  projectName String = 102
  seqMeth String = 103
  optional sampSize QuantityValue = 104
  optional experimentalFactor String = 105
  optional nuclAcidExt String = 106
  optional sampVolWeDnaExt QuantityValue = 107
  sampTaxonId String = 108
  optional negContType NegContTypeEnum = 109
  optional posContType String = 110
  optional refBiomaterial String = 111
  optional sourceMatId String = 112
  optional relToOxygen RelToOxygenEnum = 113
  optional sampCollecDevice String = 114
  optional sampCollecMethod String = 115
  optional sampMatProcess String = 116
  optional sizeFrac String = 117
  optional nuclAcidAmp String = 118
  optional libSize Integer = 119
  optional libReadsSeqd Integer = 120
  optional libLayout LibLayoutEnum = 121
  optional libVector String = 122
  optional libScreen String = 123
  optional mid String = 124
  optional adapters String = 125
  optional assemblyQual AssemblyQualEnum = 126
  optional assemblyName String = 127
  optional assemblySoftware String = 128
  optional annot String = 129
  optional numberContig Integer = 130
  optional featPred String = 131
  optional refDb String = 132
  optional simSearchMeth String = 133
  optional taxClass String = 134
  optional associatedResource String = 135
  optional sop String = 136
 }
// Combinatorial checklist Minimum Information About a Single Amplified Genome with environmental package food-animal and animal feed
message Food-animalAndAnimalFeedMISAG
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  optional sampCollectDevice String = 11
  repeated organismCount OrganismCountEnum = 12
  optional spikeinCount SpikeinCountEnum = 13
  optional sampStorTemp QuantityValue = 14
  optional sampStorDur String = 15
  optional poolDnaExtracts String = 16
  optional sampStorLoc String = 17
  repeated perturbation String = 18
  collSiteGeoFeat String = 19
  foodOrigin String = 20
  repeated foodProd String = 21
  repeated foodProductType String = 22
  optional foodSource String = 23
  repeated iFSACCategory String = 24
  repeated intendedConsumer String = 25
  sampPurpose String = 26
  optional animalAm String = 27
  optional animalAmDur String = 28
  optional animalAmFreq QuantityValue = 29
  optional animalAmRoute String = 30
  optional animalAmUse String = 31
  optional animalBodyCond AnimalBodyCondEnum = 32
  repeated animalDiet String = 33
  repeated animalFeedEquip String = 34
  optional animalGroupSize Integer = 35
  repeated animalHousing String = 36
  optional animalSex AnimalSexEnum = 37
  optional bacterialDensity QuantityValue = 38
  optional consFoodStorDur String = 39
  optional consFoodStorTemp String = 40
  optional consPurchDate Date = 41
  optional consQtyPurchased String = 42
  optional cultIsolDate Date = 43
  optional cultResult CultResultEnum = 44
  repeated cultResultOrg String = 45
  repeated cultTarget String = 46
  optional enrichmentProtocol String = 47
  repeated foodAdditive String = 48
  repeated foodContactSurf String = 49
  optional foodContainWrap String = 50
  repeated foodCookingProc String = 51
  repeated foodDisPoint String = 52
  optional foodDisPointCity String = 53
  repeated foodIngredient String = 54
  optional foodPackCapacity QuantityValue = 55
  repeated foodPackIntegrity String = 56
  repeated foodPackMedium String = 57
  repeated foodPreservProc String = 58
  repeated foodPriorContact String = 59
  repeated foodProdSynonym String = 60
  optional foodProductQual String = 61
  optional foodQualityDate String = 62
  optional foodSourceAge QuantityValue = 63
  optional foodTraceList FoodTraceListEnum = 64
  repeated foodTravMode String = 65
  repeated foodTravVehic String = 66
  repeated foodTreatProc String = 67
  repeated hACCPTerm String = 68
  optional libraryPrepKit String = 69
  repeated lotNumber String = 70
  optional microbCultMed String = 71
  repeated partPlantAnimal String = 72
  repeated repositoryName String = 73
  optional sampCollectMethod String = 74
  repeated sampPooling String = 75
  optional sampRepBiol QuantityValue = 76
  optional sampRepTech QuantityValue = 77
  optional sampSourceMatCat String = 78
  optional sampStorDevice String = 79
  optional sampStorMedia String = 80
  optional sampTransportCont SampTransportContEnum = 81
  optional sampTransportDur QuantityValue = 82
  optional sampTransportTemp String = 83
  optional sequencingKit String = 84
  optional sequencingLocation String = 85
  repeated serovarOrSerotype String = 86
  repeated spikeinAMR String = 87
  repeated spikeinAntibiotic String = 88
  repeated spikeinGrowthMed String = 89
  repeated spikeinMetal String = 90
  repeated spikeinOrg String = 91
  repeated spikeinSerovar String = 92
  repeated spikeinStrain String = 93
  repeated studyDesign String = 94
  optional studyIncDur QuantityValue = 95
  optional studyIncTemp QuantityValue = 96
  optional studyTimecourse QuantityValue = 97
  repeated studyTmnt String = 98
  optional timepoint Double = 99
  repeated miscParam String = 100
  sampName String = 101
  projectName String = 102
  seqMeth String = 103
  optional sampSize QuantityValue = 104
  optional experimentalFactor String = 105
  optional nuclAcidExt String = 106
  optional sampVolWeDnaExt QuantityValue = 107
  sampTaxonId String = 108
  optional negContType NegContTypeEnum = 109
  optional posContType String = 110
  optional refBiomaterial String = 111
  optional sourceMatId String = 112
  optional relToOxygen RelToOxygenEnum = 113
  optional sampCollecDevice String = 114
  optional sampCollecMethod String = 115
  optional sampMatProcess String = 116
  optional sizeFrac String = 117
  optional nuclAcidAmp String = 118
  optional libSize Integer = 119
  optional libReadsSeqd Integer = 120
  optional libLayout LibLayoutEnum = 121
  optional libVector String = 122
  optional libScreen String = 123
  optional mid String = 124
  optional adapters String = 125
  taxIdent TaxIdentEnum = 126
  assemblyQual AssemblyQualEnum = 127
  optional assemblyName String = 128
  assemblySoftware String = 129
  optional annot String = 130
  optional numberContig Integer = 131
  optional featPred String = 132
  optional refDb String = 133
  optional simSearchMeth String = 134
  optional taxClass String = 135
  optional x16sRecover String = 136
  optional x16sRecoverSoftware String = 137
  optional trnas Integer = 138
  optional trnaExtSoftware String = 139
  complScore String = 140
  complSoftware String = 141
  optional complAppr ComplApprEnum = 142
  contamScore String = 143
  optional contamScreenInput String = 144
  optional contamScreenParam String = 145
  optional decontamSoftware DecontamSoftwareEnum = 146
  sortTech SortTechEnum = 147
  singleCellLysisAppr SingleCellLysisApprEnum = 148
  optional singleCellLysisProt String = 149
  wgaAmpAppr String = 150
  optional wgaAmpKit String = 151
  optional associatedResource String = 152
  optional sop String = 153
 }
// Combinatorial checklist Minimum Information About an Uncultivated Virus Genome with environmental package food-animal and animal feed
message Food-animalAndAnimalFeedMIUVIG
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  optional sampCollectDevice String = 11
  repeated organismCount OrganismCountEnum = 12
  optional spikeinCount SpikeinCountEnum = 13
  optional sampStorTemp QuantityValue = 14
  optional sampStorDur String = 15
  optional poolDnaExtracts String = 16
  optional sampStorLoc String = 17
  repeated perturbation String = 18
  collSiteGeoFeat String = 19
  foodOrigin String = 20
  repeated foodProd String = 21
  repeated foodProductType String = 22
  optional foodSource String = 23
  repeated iFSACCategory String = 24
  repeated intendedConsumer String = 25
  sampPurpose String = 26
  optional animalAm String = 27
  optional animalAmDur String = 28
  optional animalAmFreq QuantityValue = 29
  optional animalAmRoute String = 30
  optional animalAmUse String = 31
  optional animalBodyCond AnimalBodyCondEnum = 32
  repeated animalDiet String = 33
  repeated animalFeedEquip String = 34
  optional animalGroupSize Integer = 35
  repeated animalHousing String = 36
  optional animalSex AnimalSexEnum = 37
  optional bacterialDensity QuantityValue = 38
  optional consFoodStorDur String = 39
  optional consFoodStorTemp String = 40
  optional consPurchDate Date = 41
  optional consQtyPurchased String = 42
  optional cultIsolDate Date = 43
  optional cultResult CultResultEnum = 44
  repeated cultResultOrg String = 45
  repeated cultTarget String = 46
  optional enrichmentProtocol String = 47
  repeated foodAdditive String = 48
  repeated foodContactSurf String = 49
  optional foodContainWrap String = 50
  repeated foodCookingProc String = 51
  repeated foodDisPoint String = 52
  optional foodDisPointCity String = 53
  repeated foodIngredient String = 54
  optional foodPackCapacity QuantityValue = 55
  repeated foodPackIntegrity String = 56
  repeated foodPackMedium String = 57
  repeated foodPreservProc String = 58
  repeated foodPriorContact String = 59
  repeated foodProdSynonym String = 60
  optional foodProductQual String = 61
  optional foodQualityDate String = 62
  optional foodSourceAge QuantityValue = 63
  optional foodTraceList FoodTraceListEnum = 64
  repeated foodTravMode String = 65
  repeated foodTravVehic String = 66
  repeated foodTreatProc String = 67
  repeated hACCPTerm String = 68
  optional libraryPrepKit String = 69
  repeated lotNumber String = 70
  optional microbCultMed String = 71
  repeated partPlantAnimal String = 72
  repeated repositoryName String = 73
  optional sampCollectMethod String = 74
  repeated sampPooling String = 75
  optional sampRepBiol QuantityValue = 76
  optional sampRepTech QuantityValue = 77
  optional sampSourceMatCat String = 78
  optional sampStorDevice String = 79
  optional sampStorMedia String = 80
  optional sampTransportCont SampTransportContEnum = 81
  optional sampTransportDur QuantityValue = 82
  optional sampTransportTemp String = 83
  optional sequencingKit String = 84
  optional sequencingLocation String = 85
  repeated serovarOrSerotype String = 86
  repeated spikeinAMR String = 87
  repeated spikeinAntibiotic String = 88
  repeated spikeinGrowthMed String = 89
  repeated spikeinMetal String = 90
  repeated spikeinOrg String = 91
  repeated spikeinSerovar String = 92
  repeated spikeinStrain String = 93
  repeated studyDesign String = 94
  optional studyIncDur QuantityValue = 95
  optional studyIncTemp QuantityValue = 96
  optional studyTimecourse QuantityValue = 97
  repeated studyTmnt String = 98
  optional timepoint Double = 99
  repeated miscParam String = 100
  sampName String = 101
  projectName String = 102
  seqMeth String = 103
  optional sampSize QuantityValue = 104
  optional experimentalFactor String = 105
  optional nuclAcidExt String = 106
  optional sampVolWeDnaExt QuantityValue = 107
  sampTaxonId String = 108
  optional negContType NegContTypeEnum = 109
  optional posContType String = 110
  optional estimatedSize String = 111
  optional refBiomaterial String = 112
  optional sourceMatId String = 113
  optional pathogenicity String = 114
  optional bioticRelationship BioticRelationshipEnum = 115
  optional specificHost String = 116
  optional hostSpecRange Integer = 117
  optional hostDiseaseStat String = 118
  optional sampCollecDevice String = 119
  optional sampCollecMethod String = 120
  optional sampMatProcess String = 121
  optional sizeFrac String = 122
  sourceUvig SourceUvigEnum = 123
  virusEnrichAppr VirusEnrichApprEnum = 124
  optional nuclAcidAmp String = 125
  optional libSize Integer = 126
  optional libReadsSeqd Integer = 127
  optional libLayout LibLayoutEnum = 128
  optional libVector String = 129
  optional libScreen String = 130
  optional mid String = 131
  optional adapters String = 132
  optional taxIdent TaxIdentEnum = 133
  assemblyQual AssemblyQualEnum = 134
  optional assemblyName String = 135
  assemblySoftware String = 136
  optional annot String = 137
  numberContig Integer = 138
  optional featPred String = 139
  optional refDb String = 140
  optional simSearchMeth String = 141
  optional taxClass String = 142
  optional trnas Integer = 143
  optional trnaExtSoftware String = 144
  optional complScore String = 145
  optional complSoftware String = 146
  optional complAppr ComplApprEnum = 147
  optional sortTech SortTechEnum = 148
  optional singleCellLysisAppr SingleCellLysisApprEnum = 149
  optional singleCellLysisProt String = 150
  optional wgaAmpAppr String = 151
  optional wgaAmpKit String = 152
  optional binParam BinParamEnum = 153
  optional binSoftware String = 154
  optional reassemblyBin String = 155
  optional magCovSoftware MagCovSoftwareEnum = 156
  virIdentSoftware String = 157
  predGenomeType PredGenomeTypeEnum = 158
  predGenomeStruc PredGenomeStrucEnum = 159
  detecType String = 160
  optional otuClassAppr String = 161
  optional otuSeqCompAppr String = 162
  optional otuDb String = 163
  optional hostPredAppr HostPredApprEnum = 164
  optional hostPredEstAcc String = 165
  optional associatedResource String = 166
  optional sop String = 167
 }
// food-farm environment
message Food-farmEnvironment
 {
  latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  optional sampCollectDevice String = 11
  optional humidity QuantityValue = 12
  repeated organismCount OrganismCountEnum = 13
  optional spikeinCount SpikeinCountEnum = 14
  optional sampStorTemp QuantityValue = 15
  optional solarIrradiance QuantityValue = 16
  optional ventilationRate QuantityValue = 17
  optional sampStorDur String = 18
  optional windSpeed QuantityValue = 19
  optional salinity QuantityValue = 20
  optional previousLandUse String = 21
  optional cropRotation String = 22
  optional soilTypeMeth String = 23
  optional totOrgCMeth String = 24
  optional totNitroContMeth String = 25
  optional salinityMeth String = 26
  optional hostAge QuantityValue = 27
  optional hostDryMass QuantityValue = 28
  optional hostHeight QuantityValue = 29
  optional hostLength QuantityValue = 30
  optional hostTotMass QuantityValue = 31
  optional rootMedCarbon String = 32
  optional rootMedMacronutr String = 33
  optional rootMedMicronutr String = 34
  optional seasonTemp QuantityValue = 35
  optional seasonPrecpt QuantityValue = 36
  optional totOrgCarb QuantityValue = 37
  optional totNitroContent QuantityValue = 38
  optional conduc QuantityValue = 39
  optional turbidity QuantityValue = 40
  optional sizeFracLow QuantityValue = 41
  optional sizeFracUp QuantityValue = 42
  optional ventilationType String = 43
  optional windDirection String = 44
  optional geneticMod String = 45
  optional hostPhenotype String = 46
  optional ph Double = 47
  optional ancesData String = 48
  bioticRegm String = 49
  repeated chemAdministration String = 50
  optional growthHabit GrowthHabitEnum = 51
  optional hostGenotype String = 52
  optional hostTaxid String = 53
  repeated mechanicalDamage String = 54
  repeated perturbation String = 55
  optional rootCond String = 56
  optional rootMedPh Double = 57
  repeated tillage TillageEnum = 58
  optional phMeth String = 59
  optional growthMedium String = 60
  optional season String = 61
  repeated foodProductType String = 62
  sampType String = 63
  repeated farmWaterSource FarmWaterSourceEnum = 64
  optional plantWaterMethod String = 65
  repeated airPMConcen String = 66
  repeated animalFeedEquip String = 67
  repeated animalIntrusion String = 68
  repeated animWaterMethod String = 69
  optional cropYield String = 70
  optional cultResult CultResultEnum = 71
  repeated cultResultOrg String = 72
  repeated cultTarget String = 73
  optional plantPartMaturity String = 74
  repeated adjacentEnvironment String = 75
  repeated waterSourceAdjac String = 76
  repeated farmEquipShared String = 77
  repeated farmEquipSan String = 78
  optional farmEquipSanFreq String = 79
  repeated farmEquip String = 80
  optional fertilizerAdmin String = 81
  optional fertilizerDate Date = 82
  optional animalGroupSize Integer = 83
  repeated animalDiet String = 84
  repeated foodContactSurf String = 85
  optional foodContainWrap String = 86
  repeated foodHarvestProc String = 87
  repeated foodPackMedium String = 88
  repeated foodPreservProc String = 89
  repeated foodProdChar String = 90
  repeated prodLabelClaims String = 91
  repeated foodTravMode String = 92
  repeated foodTravVehic String = 93
  optional foodSource String = 94
  repeated foodTreatProc String = 95
  repeated extrWeatherEvent ExtrWeatherEventEnum = 96
  repeated dateExtrWeath Date = 97
  repeated hostSubspecfGenlin String = 98
  repeated intendedConsumer String = 99
  optional libraryPrepKit String = 100
  repeated airFlowImpede String = 101
  repeated lotNumber String = 102
  optional seasonHumidity QuantityValue = 103
  repeated partPlantAnimal String = 104
  optional plantGrowthMed PlantGrowthMedEnum = 105
  repeated plantReprodCrop PlantReprodCropEnum = 106
  optional sampPurpose String = 107
  repeated repositoryName String = 108
  repeated sampPooling String = 109
  optional sampSourceMatCat String = 110
  optional sequencingKit String = 111
  optional sequencingLocation String = 112
  repeated serovarOrSerotype String = 113
  optional soilConductivity QuantityValue = 114
  optional soilCover String = 115
  optional soilPH Double = 116
  optional relLocation String = 117
  optional soilPorosity String = 118
  optional soilTextureClass SoilTextureClassEnum = 119
  optional soilTextureMeth String = 120
  optional soilType String = 121
  repeated spikeinOrg String = 122
  repeated spikeinSerovar String = 123
  repeated spikeinGrowthMed String = 124
  repeated spikeinStrain String = 125
  repeated spikeinAntibiotic String = 126
  repeated spikeinMetal String = 127
  optional timepoint Double = 128
  optional waterFrequency String = 129
  optional waterPH Double = 130
  repeated waterSourceShared WaterSourceSharedEnum = 131
  optional enrichmentProtocol String = 132
  optional foodQualityDate String = 133
  repeated iFSACCategory String = 134
  repeated animalHousing String = 135
  optional cultIsolDate Date = 136
  repeated foodCleanProc FoodCleanProcEnum = 137
  repeated miscParam String = 138
  sampName String = 139
  projectName String = 140
  seqMeth String = 141
  optional sampSize QuantityValue = 142
  optional nuclAcidExt String = 143
  optional sampVolWeDnaExt QuantityValue = 144
  optional hostDiseaseStat String = 145
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package food-farm environment
message Food-farmEnvironmentMIGSBacteria
 {
  latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  geoLocName String = 5
  collectionDate Date = 6
  envBroadScale String = 7
  envLocalScale String = 8
  envMedium String = 9
  optional sampCollectDevice String = 10
  optional humidity QuantityValue = 11
  repeated organismCount OrganismCountEnum = 12
  optional spikeinCount SpikeinCountEnum = 13
  optional sampStorTemp QuantityValue = 14
  optional solarIrradiance QuantityValue = 15
  optional ventilationRate QuantityValue = 16
  optional sampStorDur String = 17
  optional windSpeed QuantityValue = 18
  optional salinity QuantityValue = 19
  optional previousLandUse String = 20
  optional cropRotation String = 21
  optional soilTypeMeth String = 22
  optional totOrgCMeth String = 23
  optional totNitroContMeth String = 24
  optional salinityMeth String = 25
  optional hostAge QuantityValue = 26
  optional hostDryMass QuantityValue = 27
  optional hostHeight QuantityValue = 28
  optional hostLength QuantityValue = 29
  optional hostTotMass QuantityValue = 30
  optional rootMedCarbon String = 31
  optional rootMedMacronutr String = 32
  optional rootMedMicronutr String = 33
  optional seasonTemp QuantityValue = 34
  optional seasonPrecpt QuantityValue = 35
  optional totOrgCarb QuantityValue = 36
  optional totNitroContent QuantityValue = 37
  optional conduc QuantityValue = 38
  optional turbidity QuantityValue = 39
  optional sizeFracLow QuantityValue = 40
  optional sizeFracUp QuantityValue = 41
  optional ventilationType String = 42
  optional windDirection String = 43
  optional geneticMod String = 44
  optional hostPhenotype String = 45
  optional ph Double = 46
  optional ancesData String = 47
  bioticRegm String = 48
  repeated chemAdministration String = 49
  optional growthHabit GrowthHabitEnum = 50
  optional hostGenotype String = 51
  optional hostTaxid String = 52
  repeated mechanicalDamage String = 53
  repeated perturbation String = 54
  optional rootCond String = 55
  optional rootMedPh Double = 56
  repeated tillage TillageEnum = 57
  optional phMeth String = 58
  optional growthMedium String = 59
  optional season String = 60
  repeated foodProductType String = 61
  sampType String = 62
  repeated farmWaterSource FarmWaterSourceEnum = 63
  optional plantWaterMethod String = 64
  repeated airPMConcen String = 65
  repeated animalFeedEquip String = 66
  repeated animalIntrusion String = 67
  repeated animWaterMethod String = 68
  optional cropYield String = 69
  optional cultResult CultResultEnum = 70
  repeated cultResultOrg String = 71
  repeated cultTarget String = 72
  optional plantPartMaturity String = 73
  repeated adjacentEnvironment String = 74
  repeated waterSourceAdjac String = 75
  repeated farmEquipShared String = 76
  repeated farmEquipSan String = 77
  optional farmEquipSanFreq String = 78
  repeated farmEquip String = 79
  optional fertilizerAdmin String = 80
  optional fertilizerDate Date = 81
  optional animalGroupSize Integer = 82
  repeated animalDiet String = 83
  repeated foodContactSurf String = 84
  optional foodContainWrap String = 85
  repeated foodHarvestProc String = 86
  repeated foodPackMedium String = 87
  repeated foodPreservProc String = 88
  repeated foodProdChar String = 89
  repeated prodLabelClaims String = 90
  repeated foodTravMode String = 91
  repeated foodTravVehic String = 92
  optional foodSource String = 93
  repeated foodTreatProc String = 94
  repeated extrWeatherEvent ExtrWeatherEventEnum = 95
  repeated dateExtrWeath Date = 96
  repeated hostSubspecfGenlin String = 97
  repeated intendedConsumer String = 98
  optional libraryPrepKit String = 99
  repeated airFlowImpede String = 100
  repeated lotNumber String = 101
  optional seasonHumidity QuantityValue = 102
  repeated partPlantAnimal String = 103
  optional plantGrowthMed PlantGrowthMedEnum = 104
  repeated plantReprodCrop PlantReprodCropEnum = 105
  optional sampPurpose String = 106
  repeated repositoryName String = 107
  repeated sampPooling String = 108
  optional sampSourceMatCat String = 109
  optional sequencingKit String = 110
  optional sequencingLocation String = 111
  repeated serovarOrSerotype String = 112
  optional soilConductivity QuantityValue = 113
  optional soilCover String = 114
  optional soilPH Double = 115
  optional relLocation String = 116
  optional soilPorosity String = 117
  optional temp QuantityValue = 118
  optional soilTextureClass SoilTextureClassEnum = 119
  optional soilTextureMeth String = 120
  optional soilType String = 121
  repeated spikeinOrg String = 122
  repeated spikeinSerovar String = 123
  repeated spikeinGrowthMed String = 124
  repeated spikeinStrain String = 125
  repeated spikeinAntibiotic String = 126
  repeated spikeinMetal String = 127
  optional timepoint Double = 128
  optional waterFrequency String = 129
  optional waterPH Double = 130
  repeated waterSourceShared WaterSourceSharedEnum = 131
  optional enrichmentProtocol String = 132
  optional foodQualityDate String = 133
  repeated iFSACCategory String = 134
  repeated animalHousing String = 135
  optional cultIsolDate Date = 136
  repeated foodCleanProc FoodCleanProcEnum = 137
  repeated miscParam String = 138
  sampName String = 139
  projectName String = 140
  seqMeth String = 141
  optional sampSize QuantityValue = 142
  optional nuclAcidExt String = 143
  optional sampVolWeDnaExt QuantityValue = 144
  optional hostDiseaseStat String = 145
  sampTaxonId String = 146
  optional experimentalFactor String = 147
  optional negContType NegContTypeEnum = 148
  optional posContType String = 149
  optional subspecfGenLin String = 150
  numReplicons Integer = 151
  optional extrachromElements Integer = 152
  optional estimatedSize String = 153
  refBiomaterial String = 154
  optional sourceMatId String = 155
  optional pathogenicity String = 156
  optional bioticRelationship BioticRelationshipEnum = 157
  optional specificHost String = 158
  optional hostSpecRange Integer = 159
  optional trophicLevel TrophicLevelEnum = 160
  optional encodedTraits String = 161
  optional relToOxygen RelToOxygenEnum = 162
  isolGrowthCondt String = 163
  optional sampCollecDevice String = 164
  optional sampCollecMethod String = 165
  optional sampMatProcess String = 166
  optional nuclAcidAmp String = 167
  optional libSize Integer = 168
  optional libReadsSeqd Integer = 169
  optional libLayout LibLayoutEnum = 170
  optional libVector String = 171
  optional libScreen String = 172
  optional adapters String = 173
  optional taxIdent TaxIdentEnum = 174
  assemblyQual AssemblyQualEnum = 175
  optional assemblyName String = 176
  assemblySoftware String = 177
  optional annot String = 178
  numberContig Integer = 179
  optional featPred String = 180
  optional refDb String = 181
  optional simSearchMeth String = 182
  optional taxClass String = 183
  optional complScore String = 184
  optional complSoftware String = 185
  optional associatedResource String = 186
  optional sop String = 187
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: eukaryote with environmental package food-farm environment
message Food-farmEnvironmentMIGSEukaryote
 {
  latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  geoLocName String = 5
  collectionDate Date = 6
  envBroadScale String = 7
  envLocalScale String = 8
  envMedium String = 9
  optional sampCollectDevice String = 10
  optional humidity QuantityValue = 11
  repeated organismCount OrganismCountEnum = 12
  optional spikeinCount SpikeinCountEnum = 13
  optional sampStorTemp QuantityValue = 14
  optional solarIrradiance QuantityValue = 15
  optional ventilationRate QuantityValue = 16
  optional sampStorDur String = 17
  optional windSpeed QuantityValue = 18
  optional salinity QuantityValue = 19
  optional previousLandUse String = 20
  optional cropRotation String = 21
  optional soilTypeMeth String = 22
  optional totOrgCMeth String = 23
  optional totNitroContMeth String = 24
  optional salinityMeth String = 25
  optional hostAge QuantityValue = 26
  optional hostDryMass QuantityValue = 27
  optional hostHeight QuantityValue = 28
  optional hostLength QuantityValue = 29
  optional hostTotMass QuantityValue = 30
  optional rootMedCarbon String = 31
  optional rootMedMacronutr String = 32
  optional rootMedMicronutr String = 33
  optional seasonTemp QuantityValue = 34
  optional seasonPrecpt QuantityValue = 35
  optional totOrgCarb QuantityValue = 36
  optional totNitroContent QuantityValue = 37
  optional conduc QuantityValue = 38
  optional turbidity QuantityValue = 39
  optional sizeFracLow QuantityValue = 40
  optional sizeFracUp QuantityValue = 41
  optional ventilationType String = 42
  optional windDirection String = 43
  optional geneticMod String = 44
  optional hostPhenotype String = 45
  optional ph Double = 46
  optional ancesData String = 47
  bioticRegm String = 48
  repeated chemAdministration String = 49
  optional growthHabit GrowthHabitEnum = 50
  optional hostGenotype String = 51
  optional hostTaxid String = 52
  repeated mechanicalDamage String = 53
  repeated perturbation String = 54
  optional rootCond String = 55
  optional rootMedPh Double = 56
  repeated tillage TillageEnum = 57
  optional phMeth String = 58
  optional growthMedium String = 59
  optional season String = 60
  repeated foodProductType String = 61
  sampType String = 62
  repeated farmWaterSource FarmWaterSourceEnum = 63
  optional plantWaterMethod String = 64
  repeated airPMConcen String = 65
  repeated animalFeedEquip String = 66
  repeated animalIntrusion String = 67
  repeated animWaterMethod String = 68
  optional cropYield String = 69
  optional cultResult CultResultEnum = 70
  repeated cultResultOrg String = 71
  repeated cultTarget String = 72
  optional plantPartMaturity String = 73
  repeated adjacentEnvironment String = 74
  repeated waterSourceAdjac String = 75
  repeated farmEquipShared String = 76
  repeated farmEquipSan String = 77
  optional farmEquipSanFreq String = 78
  repeated farmEquip String = 79
  optional fertilizerAdmin String = 80
  optional fertilizerDate Date = 81
  optional animalGroupSize Integer = 82
  repeated animalDiet String = 83
  repeated foodContactSurf String = 84
  optional foodContainWrap String = 85
  repeated foodHarvestProc String = 86
  repeated foodPackMedium String = 87
  repeated foodPreservProc String = 88
  repeated foodProdChar String = 89
  repeated prodLabelClaims String = 90
  repeated foodTravMode String = 91
  repeated foodTravVehic String = 92
  optional foodSource String = 93
  repeated foodTreatProc String = 94
  repeated extrWeatherEvent ExtrWeatherEventEnum = 95
  repeated dateExtrWeath Date = 96
  repeated hostSubspecfGenlin String = 97
  repeated intendedConsumer String = 98
  optional libraryPrepKit String = 99
  repeated airFlowImpede String = 100
  repeated lotNumber String = 101
  optional seasonHumidity QuantityValue = 102
  repeated partPlantAnimal String = 103
  optional plantGrowthMed PlantGrowthMedEnum = 104
  repeated plantReprodCrop PlantReprodCropEnum = 105
  optional sampPurpose String = 106
  repeated repositoryName String = 107
  repeated sampPooling String = 108
  optional sampSourceMatCat String = 109
  optional sequencingKit String = 110
  optional sequencingLocation String = 111
  repeated serovarOrSerotype String = 112
  optional soilConductivity QuantityValue = 113
  optional soilCover String = 114
  optional soilPH Double = 115
  optional relLocation String = 116
  optional soilPorosity String = 117
  optional temp QuantityValue = 118
  optional soilTextureClass SoilTextureClassEnum = 119
  optional soilTextureMeth String = 120
  optional soilType String = 121
  repeated spikeinOrg String = 122
  repeated spikeinSerovar String = 123
  repeated spikeinGrowthMed String = 124
  repeated spikeinStrain String = 125
  repeated spikeinAntibiotic String = 126
  repeated spikeinMetal String = 127
  optional timepoint Double = 128
  optional waterFrequency String = 129
  optional waterPH Double = 130
  repeated waterSourceShared WaterSourceSharedEnum = 131
  optional enrichmentProtocol String = 132
  optional foodQualityDate String = 133
  repeated iFSACCategory String = 134
  repeated animalHousing String = 135
  optional cultIsolDate Date = 136
  repeated foodCleanProc FoodCleanProcEnum = 137
  repeated miscParam String = 138
  sampName String = 139
  projectName String = 140
  seqMeth String = 141
  optional sampSize QuantityValue = 142
  optional nuclAcidExt String = 143
  optional sampVolWeDnaExt QuantityValue = 144
  optional hostDiseaseStat String = 145
  sampTaxonId String = 146
  optional experimentalFactor String = 147
  optional negContType NegContTypeEnum = 148
  optional posContType String = 149
  optional subspecfGenLin String = 150
  optional ploidy String = 151
  optional numReplicons Integer = 152
  optional extrachromElements Integer = 153
  optional estimatedSize String = 154
  optional refBiomaterial String = 155
  optional sourceMatId String = 156
  optional pathogenicity String = 157
  optional bioticRelationship BioticRelationshipEnum = 158
  optional specificHost String = 159
  optional hostSpecRange Integer = 160
  optional trophicLevel TrophicLevelEnum = 161
  optional propagation String = 162
  isolGrowthCondt String = 163
  optional sampCollecDevice String = 164
  optional sampCollecMethod String = 165
  optional sampMatProcess String = 166
  optional nuclAcidAmp String = 167
  optional libSize Integer = 168
  optional libReadsSeqd Integer = 169
  optional libLayout LibLayoutEnum = 170
  optional libVector String = 171
  optional libScreen String = 172
  optional adapters String = 173
  optional taxIdent TaxIdentEnum = 174
  assemblyQual AssemblyQualEnum = 175
  optional assemblyName String = 176
  assemblySoftware String = 177
  optional annot String = 178
  numberContig Integer = 179
  optional featPred String = 180
  optional refDb String = 181
  optional simSearchMeth String = 182
  optional taxClass String = 183
  optional complScore String = 184
  optional complSoftware String = 185
  optional associatedResource String = 186
  optional sop String = 187
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: org with environmental package food-farm environment
message Food-farmEnvironmentMIGSOrg
 {
  latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  geoLocName String = 5
  collectionDate Date = 6
  envBroadScale String = 7
  envLocalScale String = 8
  envMedium String = 9
  optional sampCollectDevice String = 10
  optional humidity QuantityValue = 11
  repeated organismCount OrganismCountEnum = 12
  optional spikeinCount SpikeinCountEnum = 13
  optional sampStorTemp QuantityValue = 14
  optional solarIrradiance QuantityValue = 15
  optional ventilationRate QuantityValue = 16
  optional sampStorDur String = 17
  optional windSpeed QuantityValue = 18
  optional salinity QuantityValue = 19
  optional previousLandUse String = 20
  optional cropRotation String = 21
  optional soilTypeMeth String = 22
  optional totOrgCMeth String = 23
  optional totNitroContMeth String = 24
  optional salinityMeth String = 25
  optional hostAge QuantityValue = 26
  optional hostDryMass QuantityValue = 27
  optional hostHeight QuantityValue = 28
  optional hostLength QuantityValue = 29
  optional hostTotMass QuantityValue = 30
  optional rootMedCarbon String = 31
  optional rootMedMacronutr String = 32
  optional rootMedMicronutr String = 33
  optional seasonTemp QuantityValue = 34
  optional seasonPrecpt QuantityValue = 35
  optional totOrgCarb QuantityValue = 36
  optional totNitroContent QuantityValue = 37
  optional conduc QuantityValue = 38
  optional turbidity QuantityValue = 39
  optional sizeFracLow QuantityValue = 40
  optional sizeFracUp QuantityValue = 41
  optional ventilationType String = 42
  optional windDirection String = 43
  optional geneticMod String = 44
  optional hostPhenotype String = 45
  optional ph Double = 46
  optional ancesData String = 47
  bioticRegm String = 48
  repeated chemAdministration String = 49
  optional growthHabit GrowthHabitEnum = 50
  optional hostGenotype String = 51
  optional hostTaxid String = 52
  repeated mechanicalDamage String = 53
  repeated perturbation String = 54
  optional rootCond String = 55
  optional rootMedPh Double = 56
  repeated tillage TillageEnum = 57
  optional phMeth String = 58
  optional growthMedium String = 59
  optional season String = 60
  repeated foodProductType String = 61
  sampType String = 62
  repeated farmWaterSource FarmWaterSourceEnum = 63
  optional plantWaterMethod String = 64
  repeated airPMConcen String = 65
  repeated animalFeedEquip String = 66
  repeated animalIntrusion String = 67
  repeated animWaterMethod String = 68
  optional cropYield String = 69
  optional cultResult CultResultEnum = 70
  repeated cultResultOrg String = 71
  repeated cultTarget String = 72
  optional plantPartMaturity String = 73
  repeated adjacentEnvironment String = 74
  repeated waterSourceAdjac String = 75
  repeated farmEquipShared String = 76
  repeated farmEquipSan String = 77
  optional farmEquipSanFreq String = 78
  repeated farmEquip String = 79
  optional fertilizerAdmin String = 80
  optional fertilizerDate Date = 81
  optional animalGroupSize Integer = 82
  repeated animalDiet String = 83
  repeated foodContactSurf String = 84
  optional foodContainWrap String = 85
  repeated foodHarvestProc String = 86
  repeated foodPackMedium String = 87
  repeated foodPreservProc String = 88
  repeated foodProdChar String = 89
  repeated prodLabelClaims String = 90
  repeated foodTravMode String = 91
  repeated foodTravVehic String = 92
  optional foodSource String = 93
  repeated foodTreatProc String = 94
  repeated extrWeatherEvent ExtrWeatherEventEnum = 95
  repeated dateExtrWeath Date = 96
  repeated hostSubspecfGenlin String = 97
  repeated intendedConsumer String = 98
  optional libraryPrepKit String = 99
  repeated airFlowImpede String = 100
  repeated lotNumber String = 101
  optional seasonHumidity QuantityValue = 102
  repeated partPlantAnimal String = 103
  optional plantGrowthMed PlantGrowthMedEnum = 104
  repeated plantReprodCrop PlantReprodCropEnum = 105
  optional sampPurpose String = 106
  repeated repositoryName String = 107
  repeated sampPooling String = 108
  optional sampSourceMatCat String = 109
  optional sequencingKit String = 110
  optional sequencingLocation String = 111
  repeated serovarOrSerotype String = 112
  optional soilConductivity QuantityValue = 113
  optional soilCover String = 114
  optional soilPH Double = 115
  optional relLocation String = 116
  optional soilPorosity String = 117
  optional temp QuantityValue = 118
  optional soilTextureClass SoilTextureClassEnum = 119
  optional soilTextureMeth String = 120
  optional soilType String = 121
  repeated spikeinOrg String = 122
  repeated spikeinSerovar String = 123
  repeated spikeinGrowthMed String = 124
  repeated spikeinStrain String = 125
  repeated spikeinAntibiotic String = 126
  repeated spikeinMetal String = 127
  optional timepoint Double = 128
  optional waterFrequency String = 129
  optional waterPH Double = 130
  repeated waterSourceShared WaterSourceSharedEnum = 131
  optional enrichmentProtocol String = 132
  optional foodQualityDate String = 133
  repeated iFSACCategory String = 134
  repeated animalHousing String = 135
  optional cultIsolDate Date = 136
  repeated foodCleanProc FoodCleanProcEnum = 137
  repeated miscParam String = 138
  sampName String = 139
  projectName String = 140
  seqMeth String = 141
  optional sampSize QuantityValue = 142
  optional nuclAcidExt String = 143
  optional sampVolWeDnaExt QuantityValue = 144
  optional hostDiseaseStat String = 145
  sampTaxonId String = 146
  optional experimentalFactor String = 147
  optional negContType NegContTypeEnum = 148
  optional posContType String = 149
  optional subspecfGenLin String = 150
  optional extrachromElements Integer = 151
  optional estimatedSize String = 152
  optional refBiomaterial String = 153
  optional sourceMatId String = 154
  isolGrowthCondt String = 155
  optional sampCollecDevice String = 156
  optional sampCollecMethod String = 157
  optional sampMatProcess String = 158
  optional nuclAcidAmp String = 159
  optional libSize Integer = 160
  optional libReadsSeqd Integer = 161
  optional libLayout LibLayoutEnum = 162
  optional libVector String = 163
  optional libScreen String = 164
  optional adapters String = 165
  optional taxIdent TaxIdentEnum = 166
  optional assemblyQual AssemblyQualEnum = 167
  optional assemblyName String = 168
  assemblySoftware String = 169
  optional annot String = 170
  optional numberContig Integer = 171
  optional featPred String = 172
  optional refDb String = 173
  optional simSearchMeth String = 174
  optional taxClass String = 175
  optional complScore String = 176
  optional complSoftware String = 177
  optional associatedResource String = 178
  optional sop String = 179
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: plant with environmental package food-farm environment
message Food-farmEnvironmentMIGSPlant
 {
  latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  geoLocName String = 5
  collectionDate Date = 6
  envBroadScale String = 7
  envLocalScale String = 8
  envMedium String = 9
  optional sampCollectDevice String = 10
  optional humidity QuantityValue = 11
  repeated organismCount OrganismCountEnum = 12
  optional spikeinCount SpikeinCountEnum = 13
  optional sampStorTemp QuantityValue = 14
  optional solarIrradiance QuantityValue = 15
  optional ventilationRate QuantityValue = 16
  optional sampStorDur String = 17
  optional windSpeed QuantityValue = 18
  optional salinity QuantityValue = 19
  optional previousLandUse String = 20
  optional cropRotation String = 21
  optional soilTypeMeth String = 22
  optional totOrgCMeth String = 23
  optional totNitroContMeth String = 24
  optional salinityMeth String = 25
  optional hostAge QuantityValue = 26
  optional hostDryMass QuantityValue = 27
  optional hostHeight QuantityValue = 28
  optional hostLength QuantityValue = 29
  optional hostTotMass QuantityValue = 30
  optional rootMedCarbon String = 31
  optional rootMedMacronutr String = 32
  optional rootMedMicronutr String = 33
  optional seasonTemp QuantityValue = 34
  optional seasonPrecpt QuantityValue = 35
  optional totOrgCarb QuantityValue = 36
  optional totNitroContent QuantityValue = 37
  optional conduc QuantityValue = 38
  optional turbidity QuantityValue = 39
  optional sizeFracLow QuantityValue = 40
  optional sizeFracUp QuantityValue = 41
  optional ventilationType String = 42
  optional windDirection String = 43
  optional geneticMod String = 44
  optional hostPhenotype String = 45
  optional ph Double = 46
  optional ancesData String = 47
  bioticRegm String = 48
  repeated chemAdministration String = 49
  optional growthHabit GrowthHabitEnum = 50
  optional hostGenotype String = 51
  optional hostTaxid String = 52
  repeated mechanicalDamage String = 53
  repeated perturbation String = 54
  optional rootCond String = 55
  optional rootMedPh Double = 56
  repeated tillage TillageEnum = 57
  optional phMeth String = 58
  optional growthMedium String = 59
  optional season String = 60
  repeated foodProductType String = 61
  sampType String = 62
  repeated farmWaterSource FarmWaterSourceEnum = 63
  optional plantWaterMethod String = 64
  repeated airPMConcen String = 65
  repeated animalFeedEquip String = 66
  repeated animalIntrusion String = 67
  repeated animWaterMethod String = 68
  optional cropYield String = 69
  optional cultResult CultResultEnum = 70
  repeated cultResultOrg String = 71
  repeated cultTarget String = 72
  optional plantPartMaturity String = 73
  repeated adjacentEnvironment String = 74
  repeated waterSourceAdjac String = 75
  repeated farmEquipShared String = 76
  repeated farmEquipSan String = 77
  optional farmEquipSanFreq String = 78
  repeated farmEquip String = 79
  optional fertilizerAdmin String = 80
  optional fertilizerDate Date = 81
  optional animalGroupSize Integer = 82
  repeated animalDiet String = 83
  repeated foodContactSurf String = 84
  optional foodContainWrap String = 85
  repeated foodHarvestProc String = 86
  repeated foodPackMedium String = 87
  repeated foodPreservProc String = 88
  repeated foodProdChar String = 89
  repeated prodLabelClaims String = 90
  repeated foodTravMode String = 91
  repeated foodTravVehic String = 92
  optional foodSource String = 93
  repeated foodTreatProc String = 94
  repeated extrWeatherEvent ExtrWeatherEventEnum = 95
  repeated dateExtrWeath Date = 96
  repeated hostSubspecfGenlin String = 97
  repeated intendedConsumer String = 98
  optional libraryPrepKit String = 99
  repeated airFlowImpede String = 100
  repeated lotNumber String = 101
  optional seasonHumidity QuantityValue = 102
  repeated partPlantAnimal String = 103
  optional plantGrowthMed PlantGrowthMedEnum = 104
  repeated plantReprodCrop PlantReprodCropEnum = 105
  optional sampPurpose String = 106
  repeated repositoryName String = 107
  repeated sampPooling String = 108
  optional sampSourceMatCat String = 109
  optional sequencingKit String = 110
  optional sequencingLocation String = 111
  repeated serovarOrSerotype String = 112
  optional soilConductivity QuantityValue = 113
  optional soilCover String = 114
  optional soilPH Double = 115
  optional relLocation String = 116
  optional soilPorosity String = 117
  optional temp QuantityValue = 118
  optional soilTextureClass SoilTextureClassEnum = 119
  optional soilTextureMeth String = 120
  optional soilType String = 121
  repeated spikeinOrg String = 122
  repeated spikeinSerovar String = 123
  repeated spikeinGrowthMed String = 124
  repeated spikeinStrain String = 125
  repeated spikeinAntibiotic String = 126
  repeated spikeinMetal String = 127
  optional timepoint Double = 128
  optional waterFrequency String = 129
  optional waterPH Double = 130
  repeated waterSourceShared WaterSourceSharedEnum = 131
  optional enrichmentProtocol String = 132
  optional foodQualityDate String = 133
  repeated iFSACCategory String = 134
  repeated animalHousing String = 135
  optional cultIsolDate Date = 136
  repeated foodCleanProc FoodCleanProcEnum = 137
  repeated miscParam String = 138
  sampName String = 139
  projectName String = 140
  seqMeth String = 141
  optional sampSize QuantityValue = 142
  optional nuclAcidExt String = 143
  optional sampVolWeDnaExt QuantityValue = 144
  optional hostDiseaseStat String = 145
  sampTaxonId String = 146
  optional experimentalFactor String = 147
  optional negContType NegContTypeEnum = 148
  optional posContType String = 149
  optional subspecfGenLin String = 150
  optional estimatedSize String = 151
  optional refBiomaterial String = 152
  optional sourceMatId String = 153
  optional specificHost String = 154
  optional hostSpecRange Integer = 155
  propagation String = 156
  optional encodedTraits String = 157
  isolGrowthCondt String = 158
  optional sampCollecDevice String = 159
  optional sampCollecMethod String = 160
  optional sampMatProcess String = 161
  optional nuclAcidAmp String = 162
  optional libSize Integer = 163
  optional libReadsSeqd Integer = 164
  optional libLayout LibLayoutEnum = 165
  optional libVector String = 166
  optional libScreen String = 167
  optional adapters String = 168
  optional taxIdent TaxIdentEnum = 169
  optional assemblyQual AssemblyQualEnum = 170
  optional assemblyName String = 171
  assemblySoftware String = 172
  optional annot String = 173
  optional numberContig Integer = 174
  optional featPred String = 175
  optional refDb String = 176
  optional simSearchMeth String = 177
  optional taxClass String = 178
  optional complScore String = 179
  optional complSoftware String = 180
  optional associatedResource String = 181
  optional sop String = 182
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package food-farm environment
message Food-farmEnvironmentMIGSVirus
 {
  latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  geoLocName String = 5
  collectionDate Date = 6
  envBroadScale String = 7
  envLocalScale String = 8
  envMedium String = 9
  optional sampCollectDevice String = 10
  optional humidity QuantityValue = 11
  repeated organismCount OrganismCountEnum = 12
  optional spikeinCount SpikeinCountEnum = 13
  optional sampStorTemp QuantityValue = 14
  optional solarIrradiance QuantityValue = 15
  optional ventilationRate QuantityValue = 16
  optional sampStorDur String = 17
  optional windSpeed QuantityValue = 18
  optional salinity QuantityValue = 19
  optional previousLandUse String = 20
  optional cropRotation String = 21
  optional soilTypeMeth String = 22
  optional totOrgCMeth String = 23
  optional totNitroContMeth String = 24
  optional salinityMeth String = 25
  optional hostAge QuantityValue = 26
  optional hostDryMass QuantityValue = 27
  optional hostHeight QuantityValue = 28
  optional hostLength QuantityValue = 29
  optional hostTotMass QuantityValue = 30
  optional rootMedCarbon String = 31
  optional rootMedMacronutr String = 32
  optional rootMedMicronutr String = 33
  optional seasonTemp QuantityValue = 34
  optional seasonPrecpt QuantityValue = 35
  optional totOrgCarb QuantityValue = 36
  optional totNitroContent QuantityValue = 37
  optional conduc QuantityValue = 38
  optional turbidity QuantityValue = 39
  optional sizeFracLow QuantityValue = 40
  optional sizeFracUp QuantityValue = 41
  optional ventilationType String = 42
  optional windDirection String = 43
  optional geneticMod String = 44
  optional hostPhenotype String = 45
  optional ph Double = 46
  optional ancesData String = 47
  bioticRegm String = 48
  repeated chemAdministration String = 49
  optional growthHabit GrowthHabitEnum = 50
  optional hostGenotype String = 51
  optional hostTaxid String = 52
  repeated mechanicalDamage String = 53
  repeated perturbation String = 54
  optional rootCond String = 55
  optional rootMedPh Double = 56
  repeated tillage TillageEnum = 57
  optional phMeth String = 58
  optional growthMedium String = 59
  optional season String = 60
  repeated foodProductType String = 61
  sampType String = 62
  repeated farmWaterSource FarmWaterSourceEnum = 63
  optional plantWaterMethod String = 64
  repeated airPMConcen String = 65
  repeated animalFeedEquip String = 66
  repeated animalIntrusion String = 67
  repeated animWaterMethod String = 68
  optional cropYield String = 69
  optional cultResult CultResultEnum = 70
  repeated cultResultOrg String = 71
  repeated cultTarget String = 72
  optional plantPartMaturity String = 73
  repeated adjacentEnvironment String = 74
  repeated waterSourceAdjac String = 75
  repeated farmEquipShared String = 76
  repeated farmEquipSan String = 77
  optional farmEquipSanFreq String = 78
  repeated farmEquip String = 79
  optional fertilizerAdmin String = 80
  optional fertilizerDate Date = 81
  optional animalGroupSize Integer = 82
  repeated animalDiet String = 83
  repeated foodContactSurf String = 84
  optional foodContainWrap String = 85
  repeated foodHarvestProc String = 86
  repeated foodPackMedium String = 87
  repeated foodPreservProc String = 88
  repeated foodProdChar String = 89
  repeated prodLabelClaims String = 90
  repeated foodTravMode String = 91
  repeated foodTravVehic String = 92
  optional foodSource String = 93
  repeated foodTreatProc String = 94
  repeated extrWeatherEvent ExtrWeatherEventEnum = 95
  repeated dateExtrWeath Date = 96
  repeated hostSubspecfGenlin String = 97
  repeated intendedConsumer String = 98
  optional libraryPrepKit String = 99
  repeated airFlowImpede String = 100
  repeated lotNumber String = 101
  optional seasonHumidity QuantityValue = 102
  repeated partPlantAnimal String = 103
  optional plantGrowthMed PlantGrowthMedEnum = 104
  repeated plantReprodCrop PlantReprodCropEnum = 105
  optional sampPurpose String = 106
  repeated repositoryName String = 107
  repeated sampPooling String = 108
  optional sampSourceMatCat String = 109
  optional sequencingKit String = 110
  optional sequencingLocation String = 111
  repeated serovarOrSerotype String = 112
  optional soilConductivity QuantityValue = 113
  optional soilCover String = 114
  optional soilPH Double = 115
  optional relLocation String = 116
  optional soilPorosity String = 117
  optional temp QuantityValue = 118
  optional soilTextureClass SoilTextureClassEnum = 119
  optional soilTextureMeth String = 120
  optional soilType String = 121
  repeated spikeinOrg String = 122
  repeated spikeinSerovar String = 123
  repeated spikeinGrowthMed String = 124
  repeated spikeinStrain String = 125
  repeated spikeinAntibiotic String = 126
  repeated spikeinMetal String = 127
  optional timepoint Double = 128
  optional waterFrequency String = 129
  optional waterPH Double = 130
  repeated waterSourceShared WaterSourceSharedEnum = 131
  optional enrichmentProtocol String = 132
  optional foodQualityDate String = 133
  repeated iFSACCategory String = 134
  repeated animalHousing String = 135
  optional cultIsolDate Date = 136
  repeated foodCleanProc FoodCleanProcEnum = 137
  repeated miscParam String = 138
  sampName String = 139
  projectName String = 140
  seqMeth String = 141
  optional sampSize QuantityValue = 142
  optional nuclAcidExt String = 143
  optional sampVolWeDnaExt QuantityValue = 144
  optional hostDiseaseStat String = 145
  sampTaxonId String = 146
  optional experimentalFactor String = 147
  optional negContType NegContTypeEnum = 148
  optional posContType String = 149
  optional subspecfGenLin String = 150
  optional numReplicons Integer = 151
  optional estimatedSize String = 152
  optional refBiomaterial String = 153
  optional sourceMatId String = 154
  optional pathogenicity String = 155
  optional bioticRelationship BioticRelationshipEnum = 156
  optional specificHost String = 157
  optional hostSpecRange Integer = 158
  propagation String = 159
  optional encodedTraits String = 160
  isolGrowthCondt String = 161
  optional sampCollecDevice String = 162
  optional sampCollecMethod String = 163
  optional sampMatProcess String = 164
  optional virusEnrichAppr VirusEnrichApprEnum = 165
  optional nuclAcidAmp String = 166
  optional libSize Integer = 167
  optional libReadsSeqd Integer = 168
  optional libLayout LibLayoutEnum = 169
  optional libVector String = 170
  optional libScreen String = 171
  optional adapters String = 172
  optional taxIdent TaxIdentEnum = 173
  optional assemblyQual AssemblyQualEnum = 174
  optional assemblyName String = 175
  assemblySoftware String = 176
  optional annot String = 177
  optional numberContig Integer = 178
  optional featPred String = 179
  optional refDb String = 180
  optional simSearchMeth String = 181
  optional taxClass String = 182
  optional complScore String = 183
  optional complSoftware String = 184
  optional associatedResource String = 185
  optional sop String = 186
 }
// Combinatorial checklist Minimum Information About a Metagenome-Assembled Genome with environmental package food-farm environment
message Food-farmEnvironmentMIMAG
 {
  latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  geoLocName String = 5
  collectionDate Date = 6
  envBroadScale String = 7
  envLocalScale String = 8
  envMedium String = 9
  optional sampCollectDevice String = 10
  optional humidity QuantityValue = 11
  repeated organismCount OrganismCountEnum = 12
  optional spikeinCount SpikeinCountEnum = 13
  optional sampStorTemp QuantityValue = 14
  optional solarIrradiance QuantityValue = 15
  optional ventilationRate QuantityValue = 16
  optional sampStorDur String = 17
  optional windSpeed QuantityValue = 18
  optional salinity QuantityValue = 19
  optional previousLandUse String = 20
  optional cropRotation String = 21
  optional soilTypeMeth String = 22
  optional totOrgCMeth String = 23
  optional totNitroContMeth String = 24
  optional salinityMeth String = 25
  optional hostAge QuantityValue = 26
  optional hostDryMass QuantityValue = 27
  optional hostHeight QuantityValue = 28
  optional hostLength QuantityValue = 29
  optional hostTotMass QuantityValue = 30
  optional rootMedCarbon String = 31
  optional rootMedMacronutr String = 32
  optional rootMedMicronutr String = 33
  optional seasonTemp QuantityValue = 34
  optional seasonPrecpt QuantityValue = 35
  optional totOrgCarb QuantityValue = 36
  optional totNitroContent QuantityValue = 37
  optional conduc QuantityValue = 38
  optional turbidity QuantityValue = 39
  optional sizeFracLow QuantityValue = 40
  optional sizeFracUp QuantityValue = 41
  optional ventilationType String = 42
  optional windDirection String = 43
  optional geneticMod String = 44
  optional hostPhenotype String = 45
  optional ph Double = 46
  optional ancesData String = 47
  bioticRegm String = 48
  repeated chemAdministration String = 49
  optional growthHabit GrowthHabitEnum = 50
  optional hostGenotype String = 51
  optional hostTaxid String = 52
  repeated mechanicalDamage String = 53
  repeated perturbation String = 54
  optional rootCond String = 55
  optional rootMedPh Double = 56
  repeated tillage TillageEnum = 57
  optional phMeth String = 58
  optional growthMedium String = 59
  optional season String = 60
  repeated foodProductType String = 61
  sampType String = 62
  repeated farmWaterSource FarmWaterSourceEnum = 63
  optional plantWaterMethod String = 64
  repeated airPMConcen String = 65
  repeated animalFeedEquip String = 66
  repeated animalIntrusion String = 67
  repeated animWaterMethod String = 68
  optional cropYield String = 69
  optional cultResult CultResultEnum = 70
  repeated cultResultOrg String = 71
  repeated cultTarget String = 72
  optional plantPartMaturity String = 73
  repeated adjacentEnvironment String = 74
  repeated waterSourceAdjac String = 75
  repeated farmEquipShared String = 76
  repeated farmEquipSan String = 77
  optional farmEquipSanFreq String = 78
  repeated farmEquip String = 79
  optional fertilizerAdmin String = 80
  optional fertilizerDate Date = 81
  optional animalGroupSize Integer = 82
  repeated animalDiet String = 83
  repeated foodContactSurf String = 84
  optional foodContainWrap String = 85
  repeated foodHarvestProc String = 86
  repeated foodPackMedium String = 87
  repeated foodPreservProc String = 88
  repeated foodProdChar String = 89
  repeated prodLabelClaims String = 90
  repeated foodTravMode String = 91
  repeated foodTravVehic String = 92
  optional foodSource String = 93
  repeated foodTreatProc String = 94
  repeated extrWeatherEvent ExtrWeatherEventEnum = 95
  repeated dateExtrWeath Date = 96
  repeated hostSubspecfGenlin String = 97
  repeated intendedConsumer String = 98
  optional libraryPrepKit String = 99
  repeated airFlowImpede String = 100
  repeated lotNumber String = 101
  optional seasonHumidity QuantityValue = 102
  repeated partPlantAnimal String = 103
  optional plantGrowthMed PlantGrowthMedEnum = 104
  repeated plantReprodCrop PlantReprodCropEnum = 105
  optional sampPurpose String = 106
  repeated repositoryName String = 107
  repeated sampPooling String = 108
  optional sampSourceMatCat String = 109
  optional sequencingKit String = 110
  optional sequencingLocation String = 111
  repeated serovarOrSerotype String = 112
  optional soilConductivity QuantityValue = 113
  optional soilCover String = 114
  optional soilPH Double = 115
  optional relLocation String = 116
  optional soilPorosity String = 117
  optional temp QuantityValue = 118
  optional soilTextureClass SoilTextureClassEnum = 119
  optional soilTextureMeth String = 120
  optional soilType String = 121
  repeated spikeinOrg String = 122
  repeated spikeinSerovar String = 123
  repeated spikeinGrowthMed String = 124
  repeated spikeinStrain String = 125
  repeated spikeinAntibiotic String = 126
  repeated spikeinMetal String = 127
  optional timepoint Double = 128
  optional waterFrequency String = 129
  optional waterPH Double = 130
  repeated waterSourceShared WaterSourceSharedEnum = 131
  optional enrichmentProtocol String = 132
  optional foodQualityDate String = 133
  repeated iFSACCategory String = 134
  repeated animalHousing String = 135
  optional cultIsolDate Date = 136
  repeated foodCleanProc FoodCleanProcEnum = 137
  repeated miscParam String = 138
  sampName String = 139
  projectName String = 140
  seqMeth String = 141
  optional sampSize QuantityValue = 142
  optional nuclAcidExt String = 143
  optional sampVolWeDnaExt QuantityValue = 144
  optional hostDiseaseStat String = 145
  sampTaxonId String = 146
  optional experimentalFactor String = 147
  optional negContType NegContTypeEnum = 148
  optional posContType String = 149
  optional refBiomaterial String = 150
  optional sourceMatId String = 151
  optional relToOxygen RelToOxygenEnum = 152
  optional sampCollecDevice String = 153
  optional sampCollecMethod String = 154
  optional sampMatProcess String = 155
  optional sizeFrac String = 156
  optional nuclAcidAmp String = 157
  optional libSize Integer = 158
  optional libReadsSeqd Integer = 159
  optional libLayout LibLayoutEnum = 160
  optional libVector String = 161
  optional libScreen String = 162
  optional mid String = 163
  optional adapters String = 164
  taxIdent TaxIdentEnum = 165
  assemblyQual AssemblyQualEnum = 166
  optional assemblyName String = 167
  assemblySoftware String = 168
  optional annot String = 169
  optional numberContig Integer = 170
  optional featPred String = 171
  optional refDb String = 172
  optional simSearchMeth String = 173
  optional taxClass String = 174
  optional x16sRecover String = 175
  optional x16sRecoverSoftware String = 176
  optional trnas Integer = 177
  optional trnaExtSoftware String = 178
  complScore String = 179
  complSoftware String = 180
  optional complAppr ComplApprEnum = 181
  contamScore String = 182
  optional contamScreenInput String = 183
  optional contamScreenParam String = 184
  optional decontamSoftware DecontamSoftwareEnum = 185
  binParam BinParamEnum = 186
  binSoftware String = 187
  optional reassemblyBin String = 188
  optional magCovSoftware MagCovSoftwareEnum = 189
  optional associatedResource String = 190
  optional sop String = 191
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: specimen with environmental package food-farm environment
message Food-farmEnvironmentMIMARKSSpecimen
 {
  latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  geoLocName String = 5
  collectionDate Date = 6
  envBroadScale String = 7
  envLocalScale String = 8
  envMedium String = 9
  optional sampCollectDevice String = 10
  optional humidity QuantityValue = 11
  repeated organismCount OrganismCountEnum = 12
  optional spikeinCount SpikeinCountEnum = 13
  optional sampStorTemp QuantityValue = 14
  optional solarIrradiance QuantityValue = 15
  optional ventilationRate QuantityValue = 16
  optional sampStorDur String = 17
  optional windSpeed QuantityValue = 18
  optional salinity QuantityValue = 19
  optional previousLandUse String = 20
  optional cropRotation String = 21
  optional soilTypeMeth String = 22
  optional totOrgCMeth String = 23
  optional totNitroContMeth String = 24
  optional salinityMeth String = 25
  optional hostAge QuantityValue = 26
  optional hostDryMass QuantityValue = 27
  optional hostHeight QuantityValue = 28
  optional hostLength QuantityValue = 29
  optional hostTotMass QuantityValue = 30
  optional rootMedCarbon String = 31
  optional rootMedMacronutr String = 32
  optional rootMedMicronutr String = 33
  optional seasonTemp QuantityValue = 34
  optional seasonPrecpt QuantityValue = 35
  optional totOrgCarb QuantityValue = 36
  optional totNitroContent QuantityValue = 37
  optional conduc QuantityValue = 38
  optional turbidity QuantityValue = 39
  optional sizeFracLow QuantityValue = 40
  optional sizeFracUp QuantityValue = 41
  optional ventilationType String = 42
  optional windDirection String = 43
  optional geneticMod String = 44
  optional hostPhenotype String = 45
  optional ph Double = 46
  optional ancesData String = 47
  bioticRegm String = 48
  repeated chemAdministration String = 49
  optional growthHabit GrowthHabitEnum = 50
  optional hostGenotype String = 51
  optional hostTaxid String = 52
  repeated mechanicalDamage String = 53
  repeated perturbation String = 54
  optional rootCond String = 55
  optional rootMedPh Double = 56
  repeated tillage TillageEnum = 57
  optional phMeth String = 58
  optional growthMedium String = 59
  optional season String = 60
  repeated foodProductType String = 61
  sampType String = 62
  repeated farmWaterSource FarmWaterSourceEnum = 63
  optional plantWaterMethod String = 64
  repeated airPMConcen String = 65
  repeated animalFeedEquip String = 66
  repeated animalIntrusion String = 67
  repeated animWaterMethod String = 68
  optional cropYield String = 69
  optional cultResult CultResultEnum = 70
  repeated cultResultOrg String = 71
  repeated cultTarget String = 72
  optional plantPartMaturity String = 73
  repeated adjacentEnvironment String = 74
  repeated waterSourceAdjac String = 75
  repeated farmEquipShared String = 76
  repeated farmEquipSan String = 77
  optional farmEquipSanFreq String = 78
  repeated farmEquip String = 79
  optional fertilizerAdmin String = 80
  optional fertilizerDate Date = 81
  optional animalGroupSize Integer = 82
  repeated animalDiet String = 83
  repeated foodContactSurf String = 84
  optional foodContainWrap String = 85
  repeated foodHarvestProc String = 86
  repeated foodPackMedium String = 87
  repeated foodPreservProc String = 88
  repeated foodProdChar String = 89
  repeated prodLabelClaims String = 90
  repeated foodTravMode String = 91
  repeated foodTravVehic String = 92
  optional foodSource String = 93
  repeated foodTreatProc String = 94
  repeated extrWeatherEvent ExtrWeatherEventEnum = 95
  repeated dateExtrWeath Date = 96
  repeated hostSubspecfGenlin String = 97
  repeated intendedConsumer String = 98
  optional libraryPrepKit String = 99
  repeated airFlowImpede String = 100
  repeated lotNumber String = 101
  optional seasonHumidity QuantityValue = 102
  repeated partPlantAnimal String = 103
  optional plantGrowthMed PlantGrowthMedEnum = 104
  repeated plantReprodCrop PlantReprodCropEnum = 105
  optional sampPurpose String = 106
  repeated repositoryName String = 107
  repeated sampPooling String = 108
  optional sampSourceMatCat String = 109
  optional sequencingKit String = 110
  optional sequencingLocation String = 111
  repeated serovarOrSerotype String = 112
  optional soilConductivity QuantityValue = 113
  optional soilCover String = 114
  optional soilPH Double = 115
  optional relLocation String = 116
  optional soilPorosity String = 117
  optional temp QuantityValue = 118
  optional soilTextureClass SoilTextureClassEnum = 119
  optional soilTextureMeth String = 120
  optional soilType String = 121
  repeated spikeinOrg String = 122
  repeated spikeinSerovar String = 123
  repeated spikeinGrowthMed String = 124
  repeated spikeinStrain String = 125
  repeated spikeinAntibiotic String = 126
  repeated spikeinMetal String = 127
  optional timepoint Double = 128
  optional waterFrequency String = 129
  optional waterPH Double = 130
  repeated waterSourceShared WaterSourceSharedEnum = 131
  optional enrichmentProtocol String = 132
  optional foodQualityDate String = 133
  repeated iFSACCategory String = 134
  repeated animalHousing String = 135
  optional cultIsolDate Date = 136
  repeated foodCleanProc FoodCleanProcEnum = 137
  repeated miscParam String = 138
  sampName String = 139
  projectName String = 140
  seqMeth String = 141
  optional sampSize QuantityValue = 142
  optional nuclAcidExt String = 143
  optional sampVolWeDnaExt QuantityValue = 144
  optional hostDiseaseStat String = 145
  sampTaxonId String = 146
  optional experimentalFactor String = 147
  optional negContType NegContTypeEnum = 148
  optional posContType String = 149
  optional sourceMatId String = 150
  optional relToOxygen RelToOxygenEnum = 151
  optional sampCollecDevice String = 152
  optional sampCollecMethod String = 153
  optional sampMatProcess String = 154
  optional sizeFrac String = 155
  optional nuclAcidAmp String = 156
  optional libSize Integer = 157
  optional libReadsSeqd Integer = 158
  optional libLayout LibLayoutEnum = 159
  optional libVector String = 160
  optional libScreen String = 161
  targetGene String = 162
  optional targetSubfragment String = 163
  optional pcrPrimers String = 164
  optional mid String = 165
  optional adapters String = 166
  optional pcrCond String = 167
  optional seqQualityCheck String = 168
  optional chimeraCheck String = 169
  optional assemblySoftware String = 170
  optional associatedResource String = 171
  optional sop String = 172
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: survey with environmental package food-farm environment
message Food-farmEnvironmentMIMARKSSurvey
 {
  latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  geoLocName String = 5
  collectionDate Date = 6
  envBroadScale String = 7
  envLocalScale String = 8
  envMedium String = 9
  optional sampCollectDevice String = 10
  optional humidity QuantityValue = 11
  repeated organismCount OrganismCountEnum = 12
  optional spikeinCount SpikeinCountEnum = 13
  optional sampStorTemp QuantityValue = 14
  optional solarIrradiance QuantityValue = 15
  optional ventilationRate QuantityValue = 16
  optional sampStorDur String = 17
  optional windSpeed QuantityValue = 18
  optional salinity QuantityValue = 19
  optional previousLandUse String = 20
  optional cropRotation String = 21
  optional soilTypeMeth String = 22
  optional totOrgCMeth String = 23
  optional totNitroContMeth String = 24
  optional salinityMeth String = 25
  optional hostAge QuantityValue = 26
  optional hostDryMass QuantityValue = 27
  optional hostHeight QuantityValue = 28
  optional hostLength QuantityValue = 29
  optional hostTotMass QuantityValue = 30
  optional rootMedCarbon String = 31
  optional rootMedMacronutr String = 32
  optional rootMedMicronutr String = 33
  optional seasonTemp QuantityValue = 34
  optional seasonPrecpt QuantityValue = 35
  optional totOrgCarb QuantityValue = 36
  optional totNitroContent QuantityValue = 37
  optional conduc QuantityValue = 38
  optional turbidity QuantityValue = 39
  optional sizeFracLow QuantityValue = 40
  optional sizeFracUp QuantityValue = 41
  optional ventilationType String = 42
  optional windDirection String = 43
  optional geneticMod String = 44
  optional hostPhenotype String = 45
  optional ph Double = 46
  optional ancesData String = 47
  bioticRegm String = 48
  repeated chemAdministration String = 49
  optional growthHabit GrowthHabitEnum = 50
  optional hostGenotype String = 51
  optional hostTaxid String = 52
  repeated mechanicalDamage String = 53
  repeated perturbation String = 54
  optional rootCond String = 55
  optional rootMedPh Double = 56
  repeated tillage TillageEnum = 57
  optional phMeth String = 58
  optional growthMedium String = 59
  optional season String = 60
  repeated foodProductType String = 61
  sampType String = 62
  repeated farmWaterSource FarmWaterSourceEnum = 63
  optional plantWaterMethod String = 64
  repeated airPMConcen String = 65
  repeated animalFeedEquip String = 66
  repeated animalIntrusion String = 67
  repeated animWaterMethod String = 68
  optional cropYield String = 69
  optional cultResult CultResultEnum = 70
  repeated cultResultOrg String = 71
  repeated cultTarget String = 72
  optional plantPartMaturity String = 73
  repeated adjacentEnvironment String = 74
  repeated waterSourceAdjac String = 75
  repeated farmEquipShared String = 76
  repeated farmEquipSan String = 77
  optional farmEquipSanFreq String = 78
  repeated farmEquip String = 79
  optional fertilizerAdmin String = 80
  optional fertilizerDate Date = 81
  optional animalGroupSize Integer = 82
  repeated animalDiet String = 83
  repeated foodContactSurf String = 84
  optional foodContainWrap String = 85
  repeated foodHarvestProc String = 86
  repeated foodPackMedium String = 87
  repeated foodPreservProc String = 88
  repeated foodProdChar String = 89
  repeated prodLabelClaims String = 90
  repeated foodTravMode String = 91
  repeated foodTravVehic String = 92
  optional foodSource String = 93
  repeated foodTreatProc String = 94
  repeated extrWeatherEvent ExtrWeatherEventEnum = 95
  repeated dateExtrWeath Date = 96
  repeated hostSubspecfGenlin String = 97
  repeated intendedConsumer String = 98
  optional libraryPrepKit String = 99
  repeated airFlowImpede String = 100
  repeated lotNumber String = 101
  optional seasonHumidity QuantityValue = 102
  repeated partPlantAnimal String = 103
  optional plantGrowthMed PlantGrowthMedEnum = 104
  repeated plantReprodCrop PlantReprodCropEnum = 105
  optional sampPurpose String = 106
  repeated repositoryName String = 107
  repeated sampPooling String = 108
  optional sampSourceMatCat String = 109
  optional sequencingKit String = 110
  optional sequencingLocation String = 111
  repeated serovarOrSerotype String = 112
  optional soilConductivity QuantityValue = 113
  optional soilCover String = 114
  optional soilPH Double = 115
  optional relLocation String = 116
  optional soilPorosity String = 117
  optional temp QuantityValue = 118
  optional soilTextureClass SoilTextureClassEnum = 119
  optional soilTextureMeth String = 120
  optional soilType String = 121
  repeated spikeinOrg String = 122
  repeated spikeinSerovar String = 123
  repeated spikeinGrowthMed String = 124
  repeated spikeinStrain String = 125
  repeated spikeinAntibiotic String = 126
  repeated spikeinMetal String = 127
  optional timepoint Double = 128
  optional waterFrequency String = 129
  optional waterPH Double = 130
  repeated waterSourceShared WaterSourceSharedEnum = 131
  optional enrichmentProtocol String = 132
  optional foodQualityDate String = 133
  repeated iFSACCategory String = 134
  repeated animalHousing String = 135
  optional cultIsolDate Date = 136
  repeated foodCleanProc FoodCleanProcEnum = 137
  repeated miscParam String = 138
  sampName String = 139
  projectName String = 140
  seqMeth String = 141
  optional sampSize QuantityValue = 142
  optional nuclAcidExt String = 143
  optional sampVolWeDnaExt QuantityValue = 144
  optional hostDiseaseStat String = 145
  sampTaxonId String = 146
  optional experimentalFactor String = 147
  optional negContType NegContTypeEnum = 148
  optional posContType String = 149
  optional subspecfGenLin String = 150
  optional extrachromElements Integer = 151
  optional sourceMatId String = 152
  optional bioticRelationship BioticRelationshipEnum = 153
  optional trophicLevel TrophicLevelEnum = 154
  optional relToOxygen RelToOxygenEnum = 155
  isolGrowthCondt String = 156
  optional sampCollecDevice String = 157
  optional sampCollecMethod String = 158
  optional sampMatProcess String = 159
  optional nuclAcidAmp String = 160
  targetGene String = 161
  optional targetSubfragment String = 162
  optional pcrPrimers String = 163
  optional pcrCond String = 164
  optional seqQualityCheck String = 165
  optional chimeraCheck String = 166
  optional associatedResource String = 167
  optional sop String = 168
 }
// Combinatorial checklist Metagenome or Environmental with environmental package food-farm environment
message Food-farmEnvironmentMIMS
 {
  latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  geoLocName String = 5
  collectionDate Date = 6
  envBroadScale String = 7
  envLocalScale String = 8
  envMedium String = 9
  optional sampCollectDevice String = 10
  optional humidity QuantityValue = 11
  repeated organismCount OrganismCountEnum = 12
  optional spikeinCount SpikeinCountEnum = 13
  optional sampStorTemp QuantityValue = 14
  optional solarIrradiance QuantityValue = 15
  optional ventilationRate QuantityValue = 16
  optional sampStorDur String = 17
  optional windSpeed QuantityValue = 18
  optional salinity QuantityValue = 19
  optional previousLandUse String = 20
  optional cropRotation String = 21
  optional soilTypeMeth String = 22
  optional totOrgCMeth String = 23
  optional totNitroContMeth String = 24
  optional salinityMeth String = 25
  optional hostAge QuantityValue = 26
  optional hostDryMass QuantityValue = 27
  optional hostHeight QuantityValue = 28
  optional hostLength QuantityValue = 29
  optional hostTotMass QuantityValue = 30
  optional rootMedCarbon String = 31
  optional rootMedMacronutr String = 32
  optional rootMedMicronutr String = 33
  optional seasonTemp QuantityValue = 34
  optional seasonPrecpt QuantityValue = 35
  optional totOrgCarb QuantityValue = 36
  optional totNitroContent QuantityValue = 37
  optional conduc QuantityValue = 38
  optional turbidity QuantityValue = 39
  optional sizeFracLow QuantityValue = 40
  optional sizeFracUp QuantityValue = 41
  optional ventilationType String = 42
  optional windDirection String = 43
  optional geneticMod String = 44
  optional hostPhenotype String = 45
  optional ph Double = 46
  optional ancesData String = 47
  bioticRegm String = 48
  repeated chemAdministration String = 49
  optional growthHabit GrowthHabitEnum = 50
  optional hostGenotype String = 51
  optional hostTaxid String = 52
  repeated mechanicalDamage String = 53
  repeated perturbation String = 54
  optional rootCond String = 55
  optional rootMedPh Double = 56
  repeated tillage TillageEnum = 57
  optional phMeth String = 58
  optional growthMedium String = 59
  optional season String = 60
  repeated foodProductType String = 61
  sampType String = 62
  repeated farmWaterSource FarmWaterSourceEnum = 63
  optional plantWaterMethod String = 64
  repeated airPMConcen String = 65
  repeated animalFeedEquip String = 66
  repeated animalIntrusion String = 67
  repeated animWaterMethod String = 68
  optional cropYield String = 69
  optional cultResult CultResultEnum = 70
  repeated cultResultOrg String = 71
  repeated cultTarget String = 72
  optional plantPartMaturity String = 73
  repeated adjacentEnvironment String = 74
  repeated waterSourceAdjac String = 75
  repeated farmEquipShared String = 76
  repeated farmEquipSan String = 77
  optional farmEquipSanFreq String = 78
  repeated farmEquip String = 79
  optional fertilizerAdmin String = 80
  optional fertilizerDate Date = 81
  optional animalGroupSize Integer = 82
  repeated animalDiet String = 83
  repeated foodContactSurf String = 84
  optional foodContainWrap String = 85
  repeated foodHarvestProc String = 86
  repeated foodPackMedium String = 87
  repeated foodPreservProc String = 88
  repeated foodProdChar String = 89
  repeated prodLabelClaims String = 90
  repeated foodTravMode String = 91
  repeated foodTravVehic String = 92
  optional foodSource String = 93
  repeated foodTreatProc String = 94
  repeated extrWeatherEvent ExtrWeatherEventEnum = 95
  repeated dateExtrWeath Date = 96
  repeated hostSubspecfGenlin String = 97
  repeated intendedConsumer String = 98
  optional libraryPrepKit String = 99
  repeated airFlowImpede String = 100
  repeated lotNumber String = 101
  optional seasonHumidity QuantityValue = 102
  repeated partPlantAnimal String = 103
  optional plantGrowthMed PlantGrowthMedEnum = 104
  repeated plantReprodCrop PlantReprodCropEnum = 105
  optional sampPurpose String = 106
  repeated repositoryName String = 107
  repeated sampPooling String = 108
  optional sampSourceMatCat String = 109
  optional sequencingKit String = 110
  optional sequencingLocation String = 111
  repeated serovarOrSerotype String = 112
  optional soilConductivity QuantityValue = 113
  optional soilCover String = 114
  optional soilPH Double = 115
  optional relLocation String = 116
  optional soilPorosity String = 117
  optional temp QuantityValue = 118
  optional soilTextureClass SoilTextureClassEnum = 119
  optional soilTextureMeth String = 120
  optional soilType String = 121
  repeated spikeinOrg String = 122
  repeated spikeinSerovar String = 123
  repeated spikeinGrowthMed String = 124
  repeated spikeinStrain String = 125
  repeated spikeinAntibiotic String = 126
  repeated spikeinMetal String = 127
  optional timepoint Double = 128
  optional waterFrequency String = 129
  optional waterPH Double = 130
  repeated waterSourceShared WaterSourceSharedEnum = 131
  optional enrichmentProtocol String = 132
  optional foodQualityDate String = 133
  repeated iFSACCategory String = 134
  repeated animalHousing String = 135
  optional cultIsolDate Date = 136
  repeated foodCleanProc FoodCleanProcEnum = 137
  repeated miscParam String = 138
  sampName String = 139
  projectName String = 140
  seqMeth String = 141
  optional sampSize QuantityValue = 142
  optional nuclAcidExt String = 143
  optional sampVolWeDnaExt QuantityValue = 144
  optional hostDiseaseStat String = 145
  sampTaxonId String = 146
  optional experimentalFactor String = 147
  optional negContType NegContTypeEnum = 148
  optional posContType String = 149
  optional refBiomaterial String = 150
  optional sourceMatId String = 151
  optional relToOxygen RelToOxygenEnum = 152
  optional sampCollecDevice String = 153
  optional sampCollecMethod String = 154
  optional sampMatProcess String = 155
  optional sizeFrac String = 156
  optional nuclAcidAmp String = 157
  optional libSize Integer = 158
  optional libReadsSeqd Integer = 159
  optional libLayout LibLayoutEnum = 160
  optional libVector String = 161
  optional libScreen String = 162
  optional mid String = 163
  optional adapters String = 164
  optional assemblyQual AssemblyQualEnum = 165
  optional assemblyName String = 166
  optional assemblySoftware String = 167
  optional annot String = 168
  optional numberContig Integer = 169
  optional featPred String = 170
  optional refDb String = 171
  optional simSearchMeth String = 172
  optional taxClass String = 173
  optional associatedResource String = 174
  optional sop String = 175
 }
// Combinatorial checklist Minimum Information About a Single Amplified Genome with environmental package food-farm environment
message Food-farmEnvironmentMISAG
 {
  latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  geoLocName String = 5
  collectionDate Date = 6
  envBroadScale String = 7
  envLocalScale String = 8
  envMedium String = 9
  optional sampCollectDevice String = 10
  optional humidity QuantityValue = 11
  repeated organismCount OrganismCountEnum = 12
  optional spikeinCount SpikeinCountEnum = 13
  optional sampStorTemp QuantityValue = 14
  optional solarIrradiance QuantityValue = 15
  optional ventilationRate QuantityValue = 16
  optional sampStorDur String = 17
  optional windSpeed QuantityValue = 18
  optional salinity QuantityValue = 19
  optional previousLandUse String = 20
  optional cropRotation String = 21
  optional soilTypeMeth String = 22
  optional totOrgCMeth String = 23
  optional totNitroContMeth String = 24
  optional salinityMeth String = 25
  optional hostAge QuantityValue = 26
  optional hostDryMass QuantityValue = 27
  optional hostHeight QuantityValue = 28
  optional hostLength QuantityValue = 29
  optional hostTotMass QuantityValue = 30
  optional rootMedCarbon String = 31
  optional rootMedMacronutr String = 32
  optional rootMedMicronutr String = 33
  optional seasonTemp QuantityValue = 34
  optional seasonPrecpt QuantityValue = 35
  optional totOrgCarb QuantityValue = 36
  optional totNitroContent QuantityValue = 37
  optional conduc QuantityValue = 38
  optional turbidity QuantityValue = 39
  optional sizeFracLow QuantityValue = 40
  optional sizeFracUp QuantityValue = 41
  optional ventilationType String = 42
  optional windDirection String = 43
  optional geneticMod String = 44
  optional hostPhenotype String = 45
  optional ph Double = 46
  optional ancesData String = 47
  bioticRegm String = 48
  repeated chemAdministration String = 49
  optional growthHabit GrowthHabitEnum = 50
  optional hostGenotype String = 51
  optional hostTaxid String = 52
  repeated mechanicalDamage String = 53
  repeated perturbation String = 54
  optional rootCond String = 55
  optional rootMedPh Double = 56
  repeated tillage TillageEnum = 57
  optional phMeth String = 58
  optional growthMedium String = 59
  optional season String = 60
  repeated foodProductType String = 61
  sampType String = 62
  repeated farmWaterSource FarmWaterSourceEnum = 63
  optional plantWaterMethod String = 64
  repeated airPMConcen String = 65
  repeated animalFeedEquip String = 66
  repeated animalIntrusion String = 67
  repeated animWaterMethod String = 68
  optional cropYield String = 69
  optional cultResult CultResultEnum = 70
  repeated cultResultOrg String = 71
  repeated cultTarget String = 72
  optional plantPartMaturity String = 73
  repeated adjacentEnvironment String = 74
  repeated waterSourceAdjac String = 75
  repeated farmEquipShared String = 76
  repeated farmEquipSan String = 77
  optional farmEquipSanFreq String = 78
  repeated farmEquip String = 79
  optional fertilizerAdmin String = 80
  optional fertilizerDate Date = 81
  optional animalGroupSize Integer = 82
  repeated animalDiet String = 83
  repeated foodContactSurf String = 84
  optional foodContainWrap String = 85
  repeated foodHarvestProc String = 86
  repeated foodPackMedium String = 87
  repeated foodPreservProc String = 88
  repeated foodProdChar String = 89
  repeated prodLabelClaims String = 90
  repeated foodTravMode String = 91
  repeated foodTravVehic String = 92
  optional foodSource String = 93
  repeated foodTreatProc String = 94
  repeated extrWeatherEvent ExtrWeatherEventEnum = 95
  repeated dateExtrWeath Date = 96
  repeated hostSubspecfGenlin String = 97
  repeated intendedConsumer String = 98
  optional libraryPrepKit String = 99
  repeated airFlowImpede String = 100
  repeated lotNumber String = 101
  optional seasonHumidity QuantityValue = 102
  repeated partPlantAnimal String = 103
  optional plantGrowthMed PlantGrowthMedEnum = 104
  repeated plantReprodCrop PlantReprodCropEnum = 105
  optional sampPurpose String = 106
  repeated repositoryName String = 107
  repeated sampPooling String = 108
  optional sampSourceMatCat String = 109
  optional sequencingKit String = 110
  optional sequencingLocation String = 111
  repeated serovarOrSerotype String = 112
  optional soilConductivity QuantityValue = 113
  optional soilCover String = 114
  optional soilPH Double = 115
  optional relLocation String = 116
  optional soilPorosity String = 117
  optional temp QuantityValue = 118
  optional soilTextureClass SoilTextureClassEnum = 119
  optional soilTextureMeth String = 120
  optional soilType String = 121
  repeated spikeinOrg String = 122
  repeated spikeinSerovar String = 123
  repeated spikeinGrowthMed String = 124
  repeated spikeinStrain String = 125
  repeated spikeinAntibiotic String = 126
  repeated spikeinMetal String = 127
  optional timepoint Double = 128
  optional waterFrequency String = 129
  optional waterPH Double = 130
  repeated waterSourceShared WaterSourceSharedEnum = 131
  optional enrichmentProtocol String = 132
  optional foodQualityDate String = 133
  repeated iFSACCategory String = 134
  repeated animalHousing String = 135
  optional cultIsolDate Date = 136
  repeated foodCleanProc FoodCleanProcEnum = 137
  repeated miscParam String = 138
  sampName String = 139
  projectName String = 140
  seqMeth String = 141
  optional sampSize QuantityValue = 142
  optional nuclAcidExt String = 143
  optional sampVolWeDnaExt QuantityValue = 144
  optional hostDiseaseStat String = 145
  sampTaxonId String = 146
  optional experimentalFactor String = 147
  optional negContType NegContTypeEnum = 148
  optional posContType String = 149
  optional refBiomaterial String = 150
  optional sourceMatId String = 151
  optional relToOxygen RelToOxygenEnum = 152
  optional sampCollecDevice String = 153
  optional sampCollecMethod String = 154
  optional sampMatProcess String = 155
  optional sizeFrac String = 156
  optional nuclAcidAmp String = 157
  optional libSize Integer = 158
  optional libReadsSeqd Integer = 159
  optional libLayout LibLayoutEnum = 160
  optional libVector String = 161
  optional libScreen String = 162
  optional mid String = 163
  optional adapters String = 164
  taxIdent TaxIdentEnum = 165
  assemblyQual AssemblyQualEnum = 166
  optional assemblyName String = 167
  assemblySoftware String = 168
  optional annot String = 169
  optional numberContig Integer = 170
  optional featPred String = 171
  optional refDb String = 172
  optional simSearchMeth String = 173
  optional taxClass String = 174
  optional x16sRecover String = 175
  optional x16sRecoverSoftware String = 176
  optional trnas Integer = 177
  optional trnaExtSoftware String = 178
  complScore String = 179
  complSoftware String = 180
  optional complAppr ComplApprEnum = 181
  contamScore String = 182
  optional contamScreenInput String = 183
  optional contamScreenParam String = 184
  optional decontamSoftware DecontamSoftwareEnum = 185
  sortTech SortTechEnum = 186
  singleCellLysisAppr SingleCellLysisApprEnum = 187
  optional singleCellLysisProt String = 188
  wgaAmpAppr String = 189
  optional wgaAmpKit String = 190
  optional associatedResource String = 191
  optional sop String = 192
 }
// Combinatorial checklist Minimum Information About an Uncultivated Virus Genome with environmental package food-farm environment
message Food-farmEnvironmentMIUVIG
 {
  latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  geoLocName String = 5
  collectionDate Date = 6
  envBroadScale String = 7
  envLocalScale String = 8
  envMedium String = 9
  optional sampCollectDevice String = 10
  optional humidity QuantityValue = 11
  repeated organismCount OrganismCountEnum = 12
  optional spikeinCount SpikeinCountEnum = 13
  optional sampStorTemp QuantityValue = 14
  optional solarIrradiance QuantityValue = 15
  optional ventilationRate QuantityValue = 16
  optional sampStorDur String = 17
  optional windSpeed QuantityValue = 18
  optional salinity QuantityValue = 19
  optional previousLandUse String = 20
  optional cropRotation String = 21
  optional soilTypeMeth String = 22
  optional totOrgCMeth String = 23
  optional totNitroContMeth String = 24
  optional salinityMeth String = 25
  optional hostAge QuantityValue = 26
  optional hostDryMass QuantityValue = 27
  optional hostHeight QuantityValue = 28
  optional hostLength QuantityValue = 29
  optional hostTotMass QuantityValue = 30
  optional rootMedCarbon String = 31
  optional rootMedMacronutr String = 32
  optional rootMedMicronutr String = 33
  optional seasonTemp QuantityValue = 34
  optional seasonPrecpt QuantityValue = 35
  optional totOrgCarb QuantityValue = 36
  optional totNitroContent QuantityValue = 37
  optional conduc QuantityValue = 38
  optional turbidity QuantityValue = 39
  optional sizeFracLow QuantityValue = 40
  optional sizeFracUp QuantityValue = 41
  optional ventilationType String = 42
  optional windDirection String = 43
  optional geneticMod String = 44
  optional hostPhenotype String = 45
  optional ph Double = 46
  optional ancesData String = 47
  bioticRegm String = 48
  repeated chemAdministration String = 49
  optional growthHabit GrowthHabitEnum = 50
  optional hostGenotype String = 51
  optional hostTaxid String = 52
  repeated mechanicalDamage String = 53
  repeated perturbation String = 54
  optional rootCond String = 55
  optional rootMedPh Double = 56
  repeated tillage TillageEnum = 57
  optional phMeth String = 58
  optional growthMedium String = 59
  optional season String = 60
  repeated foodProductType String = 61
  sampType String = 62
  repeated farmWaterSource FarmWaterSourceEnum = 63
  optional plantWaterMethod String = 64
  repeated airPMConcen String = 65
  repeated animalFeedEquip String = 66
  repeated animalIntrusion String = 67
  repeated animWaterMethod String = 68
  optional cropYield String = 69
  optional cultResult CultResultEnum = 70
  repeated cultResultOrg String = 71
  repeated cultTarget String = 72
  optional plantPartMaturity String = 73
  repeated adjacentEnvironment String = 74
  repeated waterSourceAdjac String = 75
  repeated farmEquipShared String = 76
  repeated farmEquipSan String = 77
  optional farmEquipSanFreq String = 78
  repeated farmEquip String = 79
  optional fertilizerAdmin String = 80
  optional fertilizerDate Date = 81
  optional animalGroupSize Integer = 82
  repeated animalDiet String = 83
  repeated foodContactSurf String = 84
  optional foodContainWrap String = 85
  repeated foodHarvestProc String = 86
  repeated foodPackMedium String = 87
  repeated foodPreservProc String = 88
  repeated foodProdChar String = 89
  repeated prodLabelClaims String = 90
  repeated foodTravMode String = 91
  repeated foodTravVehic String = 92
  optional foodSource String = 93
  repeated foodTreatProc String = 94
  repeated extrWeatherEvent ExtrWeatherEventEnum = 95
  repeated dateExtrWeath Date = 96
  repeated hostSubspecfGenlin String = 97
  repeated intendedConsumer String = 98
  optional libraryPrepKit String = 99
  repeated airFlowImpede String = 100
  repeated lotNumber String = 101
  optional seasonHumidity QuantityValue = 102
  repeated partPlantAnimal String = 103
  optional plantGrowthMed PlantGrowthMedEnum = 104
  repeated plantReprodCrop PlantReprodCropEnum = 105
  optional sampPurpose String = 106
  repeated repositoryName String = 107
  repeated sampPooling String = 108
  optional sampSourceMatCat String = 109
  optional sequencingKit String = 110
  optional sequencingLocation String = 111
  repeated serovarOrSerotype String = 112
  optional soilConductivity QuantityValue = 113
  optional soilCover String = 114
  optional soilPH Double = 115
  optional relLocation String = 116
  optional soilPorosity String = 117
  optional temp QuantityValue = 118
  optional soilTextureClass SoilTextureClassEnum = 119
  optional soilTextureMeth String = 120
  optional soilType String = 121
  repeated spikeinOrg String = 122
  repeated spikeinSerovar String = 123
  repeated spikeinGrowthMed String = 124
  repeated spikeinStrain String = 125
  repeated spikeinAntibiotic String = 126
  repeated spikeinMetal String = 127
  optional timepoint Double = 128
  optional waterFrequency String = 129
  optional waterPH Double = 130
  repeated waterSourceShared WaterSourceSharedEnum = 131
  optional enrichmentProtocol String = 132
  optional foodQualityDate String = 133
  repeated iFSACCategory String = 134
  repeated animalHousing String = 135
  optional cultIsolDate Date = 136
  repeated foodCleanProc FoodCleanProcEnum = 137
  repeated miscParam String = 138
  sampName String = 139
  projectName String = 140
  seqMeth String = 141
  optional sampSize QuantityValue = 142
  optional nuclAcidExt String = 143
  optional sampVolWeDnaExt QuantityValue = 144
  optional hostDiseaseStat String = 145
  sampTaxonId String = 146
  optional experimentalFactor String = 147
  optional negContType NegContTypeEnum = 148
  optional posContType String = 149
  optional estimatedSize String = 150
  optional refBiomaterial String = 151
  optional sourceMatId String = 152
  optional pathogenicity String = 153
  optional bioticRelationship BioticRelationshipEnum = 154
  optional specificHost String = 155
  optional hostSpecRange Integer = 156
  optional sampCollecDevice String = 157
  optional sampCollecMethod String = 158
  optional sampMatProcess String = 159
  optional sizeFrac String = 160
  sourceUvig SourceUvigEnum = 161
  virusEnrichAppr VirusEnrichApprEnum = 162
  optional nuclAcidAmp String = 163
  optional libSize Integer = 164
  optional libReadsSeqd Integer = 165
  optional libLayout LibLayoutEnum = 166
  optional libVector String = 167
  optional libScreen String = 168
  optional mid String = 169
  optional adapters String = 170
  optional taxIdent TaxIdentEnum = 171
  assemblyQual AssemblyQualEnum = 172
  optional assemblyName String = 173
  assemblySoftware String = 174
  optional annot String = 175
  numberContig Integer = 176
  optional featPred String = 177
  optional refDb String = 178
  optional simSearchMeth String = 179
  optional taxClass String = 180
  optional trnas Integer = 181
  optional trnaExtSoftware String = 182
  optional complScore String = 183
  optional complSoftware String = 184
  optional complAppr ComplApprEnum = 185
  optional sortTech SortTechEnum = 186
  optional singleCellLysisAppr SingleCellLysisApprEnum = 187
  optional singleCellLysisProt String = 188
  optional wgaAmpAppr String = 189
  optional wgaAmpKit String = 190
  optional binParam BinParamEnum = 191
  optional binSoftware String = 192
  optional reassemblyBin String = 193
  optional magCovSoftware MagCovSoftwareEnum = 194
  virIdentSoftware String = 195
  predGenomeType PredGenomeTypeEnum = 196
  predGenomeStruc PredGenomeStrucEnum = 197
  detecType String = 198
  optional otuClassAppr String = 199
  optional otuSeqCompAppr String = 200
  optional otuDb String = 201
  optional hostPredAppr HostPredApprEnum = 202
  optional hostPredEstAcc String = 203
  optional associatedResource String = 204
  optional sop String = 205
 }
// food-food production facility
message Food-foodProductionFacility
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  optional sampCollectDevice String = 11
  repeated organismCount OrganismCountEnum = 12
  optional sampStorTemp QuantityValue = 13
  optional sampStorDur String = 14
  optional roomDim String = 15
  optional freqClean FreqCleanEnum = 16
  optional sampRoomId Integer = 17
  optional poolDnaExtracts String = 18
  optional sampStorLoc String = 19
  optional surfMaterial SurfMaterialEnum = 20
  optional indoorSurf IndoorSurfEnum = 21
  optional avgOccup Double = 22
  optional sampFloor SampFloorEnum = 23
  optional geneticMod String = 24
  collSiteGeoFeat String = 25
  sampSourceMatCat String = 26
  sampType String = 27
  sampStorMedia String = 28
  sampStorDevice String = 29
  repeated foodProductType String = 30
  repeated iFSACCategory String = 31
  foodProductQual String = 32
  repeated foodContactSurf String = 33
  repeated facilityType FacilityTypeEnum = 34
  repeated foodTravMode String = 35
  repeated foodTravVehic String = 36
  optional sampTransportDur QuantityValue = 37
  optional sampTransportTemp String = 38
  optional sampCollectMethod String = 39
  optional numSampCollect QuantityValue = 40
  repeated lotNumber String = 41
  optional hygienicArea String = 42
  optional envMonitoringZone String = 43
  optional areaSampSize String = 44
  repeated sampSurfMoisture SampSurfMoistureEnum = 45
  optional sampLocCondition SampLocConditionEnum = 46
  repeated biocideUsed String = 47
  repeated sterMethSampRoom String = 48
  optional enrichmentProtocol String = 49
  repeated cultTarget String = 50
  optional microbCultMed String = 51
  optional timepoint Double = 52
  optional bacterialDensity QuantityValue = 53
  optional cultIsolDate Date = 54
  optional cultResult CultResultEnum = 55
  repeated cultResultOrg String = 56
  repeated sampPooling String = 57
  optional sampPurpose String = 58
  optional sampRepTech QuantityValue = 59
  optional sampRepBiol QuantityValue = 60
  optional sampTransportCont SampTransportContEnum = 61
  repeated studyDesign String = 62
  repeated nuclAcidExtKit String = 63
  optional libraryPrepKit String = 64
  optional sequencingKit String = 65
  optional sequencingLocation String = 66
  optional studyIncTemp QuantityValue = 67
  optional studyIncDur QuantityValue = 68
  optional studyTimecourse QuantityValue = 69
  repeated studyTmnt String = 70
  optional foodSource String = 71
  repeated foodDisPoint String = 72
  optional foodDisPointCity String = 73
  optional foodOrigin String = 74
  repeated foodProdSynonym String = 75
  repeated foodAdditive String = 76
  optional foodTraceList FoodTraceListEnum = 77
  repeated partPlantAnimal String = 78
  repeated foodIngredient String = 79
  repeated specIntendedCons String = 80
  repeated hACCPTerm String = 81
  repeated dietaryClaimUse String = 82
  repeated foodAllergenLabel String = 83
  repeated foodProdChar String = 84
  repeated prodLabelClaims String = 85
  optional foodNameStatus String = 86
  repeated foodPreservProc String = 87
  repeated foodCookingProc String = 88
  repeated foodTreatProc String = 89
  optional foodContainWrap String = 90
  optional foodPackCapacity QuantityValue = 91
  repeated foodPackMedium String = 92
  repeated foodPriorContact String = 93
  repeated foodProd String = 94
  optional foodQualityDate String = 95
  repeated repositoryName String = 96
  repeated intendedConsumer String = 97
  repeated foodPackIntegrity String = 98
  repeated miscParam String = 99
  sampName String = 100
  projectName String = 101
  seqMeth String = 102
  optional sampSize QuantityValue = 103
  optional experimentalFactor String = 104
  optional nuclAcidExt String = 105
  optional sampVolWeDnaExt QuantityValue = 106
  optional subspecfGenLin String = 107
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package food-food production facility
message Food-foodProductionFacilityMIGSBacteria
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  geoLocName String = 5
  collectionDate Date = 6
  envBroadScale String = 7
  envLocalScale String = 8
  envMedium String = 9
  optional sampCollectDevice String = 10
  repeated organismCount OrganismCountEnum = 11
  optional sampStorTemp QuantityValue = 12
  optional sampStorDur String = 13
  optional temp QuantityValue = 14
  optional roomDim String = 15
  optional freqClean FreqCleanEnum = 16
  optional sampRoomId Integer = 17
  optional poolDnaExtracts String = 18
  optional sampStorLoc String = 19
  optional surfMaterial SurfMaterialEnum = 20
  optional indoorSurf IndoorSurfEnum = 21
  optional avgOccup Double = 22
  optional sampFloor SampFloorEnum = 23
  optional geneticMod String = 24
  collSiteGeoFeat String = 25
  sampSourceMatCat String = 26
  sampType String = 27
  sampStorMedia String = 28
  sampStorDevice String = 29
  repeated foodProductType String = 30
  repeated iFSACCategory String = 31
  foodProductQual String = 32
  repeated foodContactSurf String = 33
  repeated facilityType FacilityTypeEnum = 34
  repeated foodTravMode String = 35
  repeated foodTravVehic String = 36
  optional sampTransportDur QuantityValue = 37
  optional sampTransportTemp String = 38
  optional sampCollectMethod String = 39
  optional numSampCollect QuantityValue = 40
  repeated lotNumber String = 41
  optional hygienicArea String = 42
  optional envMonitoringZone String = 43
  optional areaSampSize String = 44
  repeated sampSurfMoisture SampSurfMoistureEnum = 45
  optional sampLocCondition SampLocConditionEnum = 46
  repeated biocideUsed String = 47
  repeated sterMethSampRoom String = 48
  optional enrichmentProtocol String = 49
  repeated cultTarget String = 50
  optional microbCultMed String = 51
  optional timepoint Double = 52
  optional bacterialDensity QuantityValue = 53
  optional cultIsolDate Date = 54
  optional cultResult CultResultEnum = 55
  repeated cultResultOrg String = 56
  repeated sampPooling String = 57
  optional sampPurpose String = 58
  optional sampRepTech QuantityValue = 59
  optional sampRepBiol QuantityValue = 60
  optional sampTransportCont SampTransportContEnum = 61
  repeated studyDesign String = 62
  repeated nuclAcidExtKit String = 63
  optional libraryPrepKit String = 64
  optional sequencingKit String = 65
  optional sequencingLocation String = 66
  optional studyIncTemp QuantityValue = 67
  optional studyIncDur QuantityValue = 68
  optional studyTimecourse QuantityValue = 69
  repeated studyTmnt String = 70
  optional foodSource String = 71
  repeated foodDisPoint String = 72
  optional foodDisPointCity String = 73
  optional foodOrigin String = 74
  repeated foodProdSynonym String = 75
  repeated foodAdditive String = 76
  optional foodTraceList FoodTraceListEnum = 77
  repeated partPlantAnimal String = 78
  repeated foodIngredient String = 79
  repeated specIntendedCons String = 80
  repeated hACCPTerm String = 81
  repeated dietaryClaimUse String = 82
  repeated foodAllergenLabel String = 83
  repeated foodProdChar String = 84
  repeated prodLabelClaims String = 85
  optional foodNameStatus String = 86
  repeated foodPreservProc String = 87
  repeated foodCookingProc String = 88
  repeated foodTreatProc String = 89
  optional foodContainWrap String = 90
  optional foodPackCapacity QuantityValue = 91
  repeated foodPackMedium String = 92
  repeated foodPriorContact String = 93
  repeated foodProd String = 94
  optional foodQualityDate String = 95
  repeated repositoryName String = 96
  repeated intendedConsumer String = 97
  repeated foodPackIntegrity String = 98
  repeated miscParam String = 99
  sampName String = 100
  projectName String = 101
  seqMeth String = 102
  optional sampSize QuantityValue = 103
  optional experimentalFactor String = 104
  optional nuclAcidExt String = 105
  optional sampVolWeDnaExt QuantityValue = 106
  optional subspecfGenLin String = 107
  sampTaxonId String = 108
  optional negContType NegContTypeEnum = 109
  optional posContType String = 110
  numReplicons Integer = 111
  optional extrachromElements Integer = 112
  optional estimatedSize String = 113
  refBiomaterial String = 114
  optional sourceMatId String = 115
  optional pathogenicity String = 116
  optional bioticRelationship BioticRelationshipEnum = 117
  optional specificHost String = 118
  optional hostSpecRange Integer = 119
  optional hostDiseaseStat String = 120
  optional trophicLevel TrophicLevelEnum = 121
  optional encodedTraits String = 122
  optional relToOxygen RelToOxygenEnum = 123
  isolGrowthCondt String = 124
  optional sampCollecDevice String = 125
  optional sampCollecMethod String = 126
  optional sampMatProcess String = 127
  optional nuclAcidAmp String = 128
  optional libSize Integer = 129
  optional libReadsSeqd Integer = 130
  optional libLayout LibLayoutEnum = 131
  optional libVector String = 132
  optional libScreen String = 133
  optional adapters String = 134
  optional taxIdent TaxIdentEnum = 135
  assemblyQual AssemblyQualEnum = 136
  optional assemblyName String = 137
  assemblySoftware String = 138
  optional annot String = 139
  numberContig Integer = 140
  optional featPred String = 141
  optional refDb String = 142
  optional simSearchMeth String = 143
  optional taxClass String = 144
  optional complScore String = 145
  optional complSoftware String = 146
  optional associatedResource String = 147
  optional sop String = 148
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: eukaryote with environmental package food-food production facility
message Food-foodProductionFacilityMIGSEukaryote
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  geoLocName String = 5
  collectionDate Date = 6
  envBroadScale String = 7
  envLocalScale String = 8
  envMedium String = 9
  optional sampCollectDevice String = 10
  repeated organismCount OrganismCountEnum = 11
  optional sampStorTemp QuantityValue = 12
  optional sampStorDur String = 13
  optional temp QuantityValue = 14
  optional roomDim String = 15
  optional freqClean FreqCleanEnum = 16
  optional sampRoomId Integer = 17
  optional poolDnaExtracts String = 18
  optional sampStorLoc String = 19
  optional surfMaterial SurfMaterialEnum = 20
  optional indoorSurf IndoorSurfEnum = 21
  optional avgOccup Double = 22
  optional sampFloor SampFloorEnum = 23
  optional geneticMod String = 24
  collSiteGeoFeat String = 25
  sampSourceMatCat String = 26
  sampType String = 27
  sampStorMedia String = 28
  sampStorDevice String = 29
  repeated foodProductType String = 30
  repeated iFSACCategory String = 31
  foodProductQual String = 32
  repeated foodContactSurf String = 33
  repeated facilityType FacilityTypeEnum = 34
  repeated foodTravMode String = 35
  repeated foodTravVehic String = 36
  optional sampTransportDur QuantityValue = 37
  optional sampTransportTemp String = 38
  optional sampCollectMethod String = 39
  optional numSampCollect QuantityValue = 40
  repeated lotNumber String = 41
  optional hygienicArea String = 42
  optional envMonitoringZone String = 43
  optional areaSampSize String = 44
  repeated sampSurfMoisture SampSurfMoistureEnum = 45
  optional sampLocCondition SampLocConditionEnum = 46
  repeated biocideUsed String = 47
  repeated sterMethSampRoom String = 48
  optional enrichmentProtocol String = 49
  repeated cultTarget String = 50
  optional microbCultMed String = 51
  optional timepoint Double = 52
  optional bacterialDensity QuantityValue = 53
  optional cultIsolDate Date = 54
  optional cultResult CultResultEnum = 55
  repeated cultResultOrg String = 56
  repeated sampPooling String = 57
  optional sampPurpose String = 58
  optional sampRepTech QuantityValue = 59
  optional sampRepBiol QuantityValue = 60
  optional sampTransportCont SampTransportContEnum = 61
  repeated studyDesign String = 62
  repeated nuclAcidExtKit String = 63
  optional libraryPrepKit String = 64
  optional sequencingKit String = 65
  optional sequencingLocation String = 66
  optional studyIncTemp QuantityValue = 67
  optional studyIncDur QuantityValue = 68
  optional studyTimecourse QuantityValue = 69
  repeated studyTmnt String = 70
  optional foodSource String = 71
  repeated foodDisPoint String = 72
  optional foodDisPointCity String = 73
  optional foodOrigin String = 74
  repeated foodProdSynonym String = 75
  repeated foodAdditive String = 76
  optional foodTraceList FoodTraceListEnum = 77
  repeated partPlantAnimal String = 78
  repeated foodIngredient String = 79
  repeated specIntendedCons String = 80
  repeated hACCPTerm String = 81
  repeated dietaryClaimUse String = 82
  repeated foodAllergenLabel String = 83
  repeated foodProdChar String = 84
  repeated prodLabelClaims String = 85
  optional foodNameStatus String = 86
  repeated foodPreservProc String = 87
  repeated foodCookingProc String = 88
  repeated foodTreatProc String = 89
  optional foodContainWrap String = 90
  optional foodPackCapacity QuantityValue = 91
  repeated foodPackMedium String = 92
  repeated foodPriorContact String = 93
  repeated foodProd String = 94
  optional foodQualityDate String = 95
  repeated repositoryName String = 96
  repeated intendedConsumer String = 97
  repeated foodPackIntegrity String = 98
  repeated miscParam String = 99
  sampName String = 100
  projectName String = 101
  seqMeth String = 102
  optional sampSize QuantityValue = 103
  optional experimentalFactor String = 104
  optional nuclAcidExt String = 105
  optional sampVolWeDnaExt QuantityValue = 106
  optional subspecfGenLin String = 107
  sampTaxonId String = 108
  optional negContType NegContTypeEnum = 109
  optional posContType String = 110
  optional ploidy String = 111
  optional numReplicons Integer = 112
  optional extrachromElements Integer = 113
  optional estimatedSize String = 114
  optional refBiomaterial String = 115
  optional sourceMatId String = 116
  optional pathogenicity String = 117
  optional bioticRelationship BioticRelationshipEnum = 118
  optional specificHost String = 119
  optional hostSpecRange Integer = 120
  optional hostDiseaseStat String = 121
  optional trophicLevel TrophicLevelEnum = 122
  optional propagation String = 123
  isolGrowthCondt String = 124
  optional sampCollecDevice String = 125
  optional sampCollecMethod String = 126
  optional sampMatProcess String = 127
  optional nuclAcidAmp String = 128
  optional libSize Integer = 129
  optional libReadsSeqd Integer = 130
  optional libLayout LibLayoutEnum = 131
  optional libVector String = 132
  optional libScreen String = 133
  optional adapters String = 134
  optional taxIdent TaxIdentEnum = 135
  assemblyQual AssemblyQualEnum = 136
  optional assemblyName String = 137
  assemblySoftware String = 138
  optional annot String = 139
  numberContig Integer = 140
  optional featPred String = 141
  optional refDb String = 142
  optional simSearchMeth String = 143
  optional taxClass String = 144
  optional complScore String = 145
  optional complSoftware String = 146
  optional associatedResource String = 147
  optional sop String = 148
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: org with environmental package food-food production facility
message Food-foodProductionFacilityMIGSOrg
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  geoLocName String = 5
  collectionDate Date = 6
  envBroadScale String = 7
  envLocalScale String = 8
  envMedium String = 9
  optional sampCollectDevice String = 10
  repeated organismCount OrganismCountEnum = 11
  optional sampStorTemp QuantityValue = 12
  optional sampStorDur String = 13
  optional temp QuantityValue = 14
  optional roomDim String = 15
  optional freqClean FreqCleanEnum = 16
  optional sampRoomId Integer = 17
  optional poolDnaExtracts String = 18
  optional sampStorLoc String = 19
  optional surfMaterial SurfMaterialEnum = 20
  optional indoorSurf IndoorSurfEnum = 21
  optional avgOccup Double = 22
  optional sampFloor SampFloorEnum = 23
  optional geneticMod String = 24
  collSiteGeoFeat String = 25
  sampSourceMatCat String = 26
  sampType String = 27
  sampStorMedia String = 28
  sampStorDevice String = 29
  repeated foodProductType String = 30
  repeated iFSACCategory String = 31
  foodProductQual String = 32
  repeated foodContactSurf String = 33
  repeated facilityType FacilityTypeEnum = 34
  repeated foodTravMode String = 35
  repeated foodTravVehic String = 36
  optional sampTransportDur QuantityValue = 37
  optional sampTransportTemp String = 38
  optional sampCollectMethod String = 39
  optional numSampCollect QuantityValue = 40
  repeated lotNumber String = 41
  optional hygienicArea String = 42
  optional envMonitoringZone String = 43
  optional areaSampSize String = 44
  repeated sampSurfMoisture SampSurfMoistureEnum = 45
  optional sampLocCondition SampLocConditionEnum = 46
  repeated biocideUsed String = 47
  repeated sterMethSampRoom String = 48
  optional enrichmentProtocol String = 49
  repeated cultTarget String = 50
  optional microbCultMed String = 51
  optional timepoint Double = 52
  optional bacterialDensity QuantityValue = 53
  optional cultIsolDate Date = 54
  optional cultResult CultResultEnum = 55
  repeated cultResultOrg String = 56
  repeated sampPooling String = 57
  optional sampPurpose String = 58
  optional sampRepTech QuantityValue = 59
  optional sampRepBiol QuantityValue = 60
  optional sampTransportCont SampTransportContEnum = 61
  repeated studyDesign String = 62
  repeated nuclAcidExtKit String = 63
  optional libraryPrepKit String = 64
  optional sequencingKit String = 65
  optional sequencingLocation String = 66
  optional studyIncTemp QuantityValue = 67
  optional studyIncDur QuantityValue = 68
  optional studyTimecourse QuantityValue = 69
  repeated studyTmnt String = 70
  optional foodSource String = 71
  repeated foodDisPoint String = 72
  optional foodDisPointCity String = 73
  optional foodOrigin String = 74
  repeated foodProdSynonym String = 75
  repeated foodAdditive String = 76
  optional foodTraceList FoodTraceListEnum = 77
  repeated partPlantAnimal String = 78
  repeated foodIngredient String = 79
  repeated specIntendedCons String = 80
  repeated hACCPTerm String = 81
  repeated dietaryClaimUse String = 82
  repeated foodAllergenLabel String = 83
  repeated foodProdChar String = 84
  repeated prodLabelClaims String = 85
  optional foodNameStatus String = 86
  repeated foodPreservProc String = 87
  repeated foodCookingProc String = 88
  repeated foodTreatProc String = 89
  optional foodContainWrap String = 90
  optional foodPackCapacity QuantityValue = 91
  repeated foodPackMedium String = 92
  repeated foodPriorContact String = 93
  repeated foodProd String = 94
  optional foodQualityDate String = 95
  repeated repositoryName String = 96
  repeated intendedConsumer String = 97
  repeated foodPackIntegrity String = 98
  repeated miscParam String = 99
  sampName String = 100
  projectName String = 101
  seqMeth String = 102
  optional sampSize QuantityValue = 103
  optional experimentalFactor String = 104
  optional nuclAcidExt String = 105
  optional sampVolWeDnaExt QuantityValue = 106
  optional subspecfGenLin String = 107
  sampTaxonId String = 108
  optional negContType NegContTypeEnum = 109
  optional posContType String = 110
  optional extrachromElements Integer = 111
  optional estimatedSize String = 112
  optional refBiomaterial String = 113
  optional sourceMatId String = 114
  isolGrowthCondt String = 115
  optional sampCollecDevice String = 116
  optional sampCollecMethod String = 117
  optional sampMatProcess String = 118
  optional nuclAcidAmp String = 119
  optional libSize Integer = 120
  optional libReadsSeqd Integer = 121
  optional libLayout LibLayoutEnum = 122
  optional libVector String = 123
  optional libScreen String = 124
  optional adapters String = 125
  optional taxIdent TaxIdentEnum = 126
  optional assemblyQual AssemblyQualEnum = 127
  optional assemblyName String = 128
  assemblySoftware String = 129
  optional annot String = 130
  optional numberContig Integer = 131
  optional featPred String = 132
  optional refDb String = 133
  optional simSearchMeth String = 134
  optional taxClass String = 135
  optional complScore String = 136
  optional complSoftware String = 137
  optional associatedResource String = 138
  optional sop String = 139
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: plant with environmental package food-food production facility
message Food-foodProductionFacilityMIGSPlant
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  geoLocName String = 5
  collectionDate Date = 6
  envBroadScale String = 7
  envLocalScale String = 8
  envMedium String = 9
  optional sampCollectDevice String = 10
  repeated organismCount OrganismCountEnum = 11
  optional sampStorTemp QuantityValue = 12
  optional sampStorDur String = 13
  optional temp QuantityValue = 14
  optional roomDim String = 15
  optional freqClean FreqCleanEnum = 16
  optional sampRoomId Integer = 17
  optional poolDnaExtracts String = 18
  optional sampStorLoc String = 19
  optional surfMaterial SurfMaterialEnum = 20
  optional indoorSurf IndoorSurfEnum = 21
  optional avgOccup Double = 22
  optional sampFloor SampFloorEnum = 23
  optional geneticMod String = 24
  collSiteGeoFeat String = 25
  sampSourceMatCat String = 26
  sampType String = 27
  sampStorMedia String = 28
  sampStorDevice String = 29
  repeated foodProductType String = 30
  repeated iFSACCategory String = 31
  foodProductQual String = 32
  repeated foodContactSurf String = 33
  repeated facilityType FacilityTypeEnum = 34
  repeated foodTravMode String = 35
  repeated foodTravVehic String = 36
  optional sampTransportDur QuantityValue = 37
  optional sampTransportTemp String = 38
  optional sampCollectMethod String = 39
  optional numSampCollect QuantityValue = 40
  repeated lotNumber String = 41
  optional hygienicArea String = 42
  optional envMonitoringZone String = 43
  optional areaSampSize String = 44
  repeated sampSurfMoisture SampSurfMoistureEnum = 45
  optional sampLocCondition SampLocConditionEnum = 46
  repeated biocideUsed String = 47
  repeated sterMethSampRoom String = 48
  optional enrichmentProtocol String = 49
  repeated cultTarget String = 50
  optional microbCultMed String = 51
  optional timepoint Double = 52
  optional bacterialDensity QuantityValue = 53
  optional cultIsolDate Date = 54
  optional cultResult CultResultEnum = 55
  repeated cultResultOrg String = 56
  repeated sampPooling String = 57
  optional sampPurpose String = 58
  optional sampRepTech QuantityValue = 59
  optional sampRepBiol QuantityValue = 60
  optional sampTransportCont SampTransportContEnum = 61
  repeated studyDesign String = 62
  repeated nuclAcidExtKit String = 63
  optional libraryPrepKit String = 64
  optional sequencingKit String = 65
  optional sequencingLocation String = 66
  optional studyIncTemp QuantityValue = 67
  optional studyIncDur QuantityValue = 68
  optional studyTimecourse QuantityValue = 69
  repeated studyTmnt String = 70
  optional foodSource String = 71
  repeated foodDisPoint String = 72
  optional foodDisPointCity String = 73
  optional foodOrigin String = 74
  repeated foodProdSynonym String = 75
  repeated foodAdditive String = 76
  optional foodTraceList FoodTraceListEnum = 77
  repeated partPlantAnimal String = 78
  repeated foodIngredient String = 79
  repeated specIntendedCons String = 80
  repeated hACCPTerm String = 81
  repeated dietaryClaimUse String = 82
  repeated foodAllergenLabel String = 83
  repeated foodProdChar String = 84
  repeated prodLabelClaims String = 85
  optional foodNameStatus String = 86
  repeated foodPreservProc String = 87
  repeated foodCookingProc String = 88
  repeated foodTreatProc String = 89
  optional foodContainWrap String = 90
  optional foodPackCapacity QuantityValue = 91
  repeated foodPackMedium String = 92
  repeated foodPriorContact String = 93
  repeated foodProd String = 94
  optional foodQualityDate String = 95
  repeated repositoryName String = 96
  repeated intendedConsumer String = 97
  repeated foodPackIntegrity String = 98
  repeated miscParam String = 99
  sampName String = 100
  projectName String = 101
  seqMeth String = 102
  optional sampSize QuantityValue = 103
  optional experimentalFactor String = 104
  optional nuclAcidExt String = 105
  optional sampVolWeDnaExt QuantityValue = 106
  optional subspecfGenLin String = 107
  sampTaxonId String = 108
  optional negContType NegContTypeEnum = 109
  optional posContType String = 110
  optional estimatedSize String = 111
  optional refBiomaterial String = 112
  optional sourceMatId String = 113
  optional specificHost String = 114
  optional hostSpecRange Integer = 115
  propagation String = 116
  optional encodedTraits String = 117
  isolGrowthCondt String = 118
  optional sampCollecDevice String = 119
  optional sampCollecMethod String = 120
  optional sampMatProcess String = 121
  optional nuclAcidAmp String = 122
  optional libSize Integer = 123
  optional libReadsSeqd Integer = 124
  optional libLayout LibLayoutEnum = 125
  optional libVector String = 126
  optional libScreen String = 127
  optional adapters String = 128
  optional taxIdent TaxIdentEnum = 129
  optional assemblyQual AssemblyQualEnum = 130
  optional assemblyName String = 131
  assemblySoftware String = 132
  optional annot String = 133
  optional numberContig Integer = 134
  optional featPred String = 135
  optional refDb String = 136
  optional simSearchMeth String = 137
  optional taxClass String = 138
  optional complScore String = 139
  optional complSoftware String = 140
  optional associatedResource String = 141
  optional sop String = 142
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package food-food production facility
message Food-foodProductionFacilityMIGSVirus
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  geoLocName String = 5
  collectionDate Date = 6
  envBroadScale String = 7
  envLocalScale String = 8
  envMedium String = 9
  optional sampCollectDevice String = 10
  repeated organismCount OrganismCountEnum = 11
  optional sampStorTemp QuantityValue = 12
  optional sampStorDur String = 13
  optional temp QuantityValue = 14
  optional roomDim String = 15
  optional freqClean FreqCleanEnum = 16
  optional sampRoomId Integer = 17
  optional poolDnaExtracts String = 18
  optional sampStorLoc String = 19
  optional surfMaterial SurfMaterialEnum = 20
  optional indoorSurf IndoorSurfEnum = 21
  optional avgOccup Double = 22
  optional sampFloor SampFloorEnum = 23
  optional geneticMod String = 24
  collSiteGeoFeat String = 25
  sampSourceMatCat String = 26
  sampType String = 27
  sampStorMedia String = 28
  sampStorDevice String = 29
  repeated foodProductType String = 30
  repeated iFSACCategory String = 31
  foodProductQual String = 32
  repeated foodContactSurf String = 33
  repeated facilityType FacilityTypeEnum = 34
  repeated foodTravMode String = 35
  repeated foodTravVehic String = 36
  optional sampTransportDur QuantityValue = 37
  optional sampTransportTemp String = 38
  optional sampCollectMethod String = 39
  optional numSampCollect QuantityValue = 40
  repeated lotNumber String = 41
  optional hygienicArea String = 42
  optional envMonitoringZone String = 43
  optional areaSampSize String = 44
  repeated sampSurfMoisture SampSurfMoistureEnum = 45
  optional sampLocCondition SampLocConditionEnum = 46
  repeated biocideUsed String = 47
  repeated sterMethSampRoom String = 48
  optional enrichmentProtocol String = 49
  repeated cultTarget String = 50
  optional microbCultMed String = 51
  optional timepoint Double = 52
  optional bacterialDensity QuantityValue = 53
  optional cultIsolDate Date = 54
  optional cultResult CultResultEnum = 55
  repeated cultResultOrg String = 56
  repeated sampPooling String = 57
  optional sampPurpose String = 58
  optional sampRepTech QuantityValue = 59
  optional sampRepBiol QuantityValue = 60
  optional sampTransportCont SampTransportContEnum = 61
  repeated studyDesign String = 62
  repeated nuclAcidExtKit String = 63
  optional libraryPrepKit String = 64
  optional sequencingKit String = 65
  optional sequencingLocation String = 66
  optional studyIncTemp QuantityValue = 67
  optional studyIncDur QuantityValue = 68
  optional studyTimecourse QuantityValue = 69
  repeated studyTmnt String = 70
  optional foodSource String = 71
  repeated foodDisPoint String = 72
  optional foodDisPointCity String = 73
  optional foodOrigin String = 74
  repeated foodProdSynonym String = 75
  repeated foodAdditive String = 76
  optional foodTraceList FoodTraceListEnum = 77
  repeated partPlantAnimal String = 78
  repeated foodIngredient String = 79
  repeated specIntendedCons String = 80
  repeated hACCPTerm String = 81
  repeated dietaryClaimUse String = 82
  repeated foodAllergenLabel String = 83
  repeated foodProdChar String = 84
  repeated prodLabelClaims String = 85
  optional foodNameStatus String = 86
  repeated foodPreservProc String = 87
  repeated foodCookingProc String = 88
  repeated foodTreatProc String = 89
  optional foodContainWrap String = 90
  optional foodPackCapacity QuantityValue = 91
  repeated foodPackMedium String = 92
  repeated foodPriorContact String = 93
  repeated foodProd String = 94
  optional foodQualityDate String = 95
  repeated repositoryName String = 96
  repeated intendedConsumer String = 97
  repeated foodPackIntegrity String = 98
  repeated miscParam String = 99
  sampName String = 100
  projectName String = 101
  seqMeth String = 102
  optional sampSize QuantityValue = 103
  optional experimentalFactor String = 104
  optional nuclAcidExt String = 105
  optional sampVolWeDnaExt QuantityValue = 106
  optional subspecfGenLin String = 107
  sampTaxonId String = 108
  optional negContType NegContTypeEnum = 109
  optional posContType String = 110
  optional numReplicons Integer = 111
  optional estimatedSize String = 112
  optional refBiomaterial String = 113
  optional sourceMatId String = 114
  optional pathogenicity String = 115
  optional bioticRelationship BioticRelationshipEnum = 116
  optional specificHost String = 117
  optional hostSpecRange Integer = 118
  optional hostDiseaseStat String = 119
  propagation String = 120
  optional encodedTraits String = 121
  isolGrowthCondt String = 122
  optional sampCollecDevice String = 123
  optional sampCollecMethod String = 124
  optional sampMatProcess String = 125
  optional virusEnrichAppr VirusEnrichApprEnum = 126
  optional nuclAcidAmp String = 127
  optional libSize Integer = 128
  optional libReadsSeqd Integer = 129
  optional libLayout LibLayoutEnum = 130
  optional libVector String = 131
  optional libScreen String = 132
  optional adapters String = 133
  optional taxIdent TaxIdentEnum = 134
  optional assemblyQual AssemblyQualEnum = 135
  optional assemblyName String = 136
  assemblySoftware String = 137
  optional annot String = 138
  optional numberContig Integer = 139
  optional featPred String = 140
  optional refDb String = 141
  optional simSearchMeth String = 142
  optional taxClass String = 143
  optional complScore String = 144
  optional complSoftware String = 145
  optional associatedResource String = 146
  optional sop String = 147
 }
// Combinatorial checklist Minimum Information About a Metagenome-Assembled Genome with environmental package food-food production facility
message Food-foodProductionFacilityMIMAG
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  geoLocName String = 5
  collectionDate Date = 6
  envBroadScale String = 7
  envLocalScale String = 8
  envMedium String = 9
  optional sampCollectDevice String = 10
  repeated organismCount OrganismCountEnum = 11
  optional sampStorTemp QuantityValue = 12
  optional sampStorDur String = 13
  optional temp QuantityValue = 14
  optional roomDim String = 15
  optional freqClean FreqCleanEnum = 16
  optional sampRoomId Integer = 17
  optional poolDnaExtracts String = 18
  optional sampStorLoc String = 19
  optional surfMaterial SurfMaterialEnum = 20
  optional indoorSurf IndoorSurfEnum = 21
  optional avgOccup Double = 22
  optional sampFloor SampFloorEnum = 23
  optional geneticMod String = 24
  collSiteGeoFeat String = 25
  sampSourceMatCat String = 26
  sampType String = 27
  sampStorMedia String = 28
  sampStorDevice String = 29
  repeated foodProductType String = 30
  repeated iFSACCategory String = 31
  foodProductQual String = 32
  repeated foodContactSurf String = 33
  repeated facilityType FacilityTypeEnum = 34
  repeated foodTravMode String = 35
  repeated foodTravVehic String = 36
  optional sampTransportDur QuantityValue = 37
  optional sampTransportTemp String = 38
  optional sampCollectMethod String = 39
  optional numSampCollect QuantityValue = 40
  repeated lotNumber String = 41
  optional hygienicArea String = 42
  optional envMonitoringZone String = 43
  optional areaSampSize String = 44
  repeated sampSurfMoisture SampSurfMoistureEnum = 45
  optional sampLocCondition SampLocConditionEnum = 46
  repeated biocideUsed String = 47
  repeated sterMethSampRoom String = 48
  optional enrichmentProtocol String = 49
  repeated cultTarget String = 50
  optional microbCultMed String = 51
  optional timepoint Double = 52
  optional bacterialDensity QuantityValue = 53
  optional cultIsolDate Date = 54
  optional cultResult CultResultEnum = 55
  repeated cultResultOrg String = 56
  repeated sampPooling String = 57
  optional sampPurpose String = 58
  optional sampRepTech QuantityValue = 59
  optional sampRepBiol QuantityValue = 60
  optional sampTransportCont SampTransportContEnum = 61
  repeated studyDesign String = 62
  repeated nuclAcidExtKit String = 63
  optional libraryPrepKit String = 64
  optional sequencingKit String = 65
  optional sequencingLocation String = 66
  optional studyIncTemp QuantityValue = 67
  optional studyIncDur QuantityValue = 68
  optional studyTimecourse QuantityValue = 69
  repeated studyTmnt String = 70
  optional foodSource String = 71
  repeated foodDisPoint String = 72
  optional foodDisPointCity String = 73
  optional foodOrigin String = 74
  repeated foodProdSynonym String = 75
  repeated foodAdditive String = 76
  optional foodTraceList FoodTraceListEnum = 77
  repeated partPlantAnimal String = 78
  repeated foodIngredient String = 79
  repeated specIntendedCons String = 80
  repeated hACCPTerm String = 81
  repeated dietaryClaimUse String = 82
  repeated foodAllergenLabel String = 83
  repeated foodProdChar String = 84
  repeated prodLabelClaims String = 85
  optional foodNameStatus String = 86
  repeated foodPreservProc String = 87
  repeated foodCookingProc String = 88
  repeated foodTreatProc String = 89
  optional foodContainWrap String = 90
  optional foodPackCapacity QuantityValue = 91
  repeated foodPackMedium String = 92
  repeated foodPriorContact String = 93
  repeated foodProd String = 94
  optional foodQualityDate String = 95
  repeated repositoryName String = 96
  repeated intendedConsumer String = 97
  repeated foodPackIntegrity String = 98
  repeated miscParam String = 99
  sampName String = 100
  projectName String = 101
  seqMeth String = 102
  optional sampSize QuantityValue = 103
  optional experimentalFactor String = 104
  optional nuclAcidExt String = 105
  optional sampVolWeDnaExt QuantityValue = 106
  optional subspecfGenLin String = 107
  sampTaxonId String = 108
  optional negContType NegContTypeEnum = 109
  optional posContType String = 110
  optional refBiomaterial String = 111
  optional sourceMatId String = 112
  optional relToOxygen RelToOxygenEnum = 113
  optional sampCollecDevice String = 114
  optional sampCollecMethod String = 115
  optional sampMatProcess String = 116
  optional sizeFrac String = 117
  optional nuclAcidAmp String = 118
  optional libSize Integer = 119
  optional libReadsSeqd Integer = 120
  optional libLayout LibLayoutEnum = 121
  optional libVector String = 122
  optional libScreen String = 123
  optional mid String = 124
  optional adapters String = 125
  taxIdent TaxIdentEnum = 126
  assemblyQual AssemblyQualEnum = 127
  optional assemblyName String = 128
  assemblySoftware String = 129
  optional annot String = 130
  optional numberContig Integer = 131
  optional featPred String = 132
  optional refDb String = 133
  optional simSearchMeth String = 134
  optional taxClass String = 135
  optional x16sRecover String = 136
  optional x16sRecoverSoftware String = 137
  optional trnas Integer = 138
  optional trnaExtSoftware String = 139
  complScore String = 140
  complSoftware String = 141
  optional complAppr ComplApprEnum = 142
  contamScore String = 143
  optional contamScreenInput String = 144
  optional contamScreenParam String = 145
  optional decontamSoftware DecontamSoftwareEnum = 146
  binParam BinParamEnum = 147
  binSoftware String = 148
  optional reassemblyBin String = 149
  optional magCovSoftware MagCovSoftwareEnum = 150
  optional associatedResource String = 151
  optional sop String = 152
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: specimen with environmental package food-food production facility
message Food-foodProductionFacilityMIMARKSSpecimen
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  geoLocName String = 5
  collectionDate Date = 6
  envBroadScale String = 7
  envLocalScale String = 8
  envMedium String = 9
  optional sampCollectDevice String = 10
  repeated organismCount OrganismCountEnum = 11
  optional sampStorTemp QuantityValue = 12
  optional sampStorDur String = 13
  optional temp QuantityValue = 14
  optional roomDim String = 15
  optional freqClean FreqCleanEnum = 16
  optional sampRoomId Integer = 17
  optional poolDnaExtracts String = 18
  optional sampStorLoc String = 19
  optional surfMaterial SurfMaterialEnum = 20
  optional indoorSurf IndoorSurfEnum = 21
  optional avgOccup Double = 22
  optional sampFloor SampFloorEnum = 23
  optional geneticMod String = 24
  collSiteGeoFeat String = 25
  sampSourceMatCat String = 26
  sampType String = 27
  sampStorMedia String = 28
  sampStorDevice String = 29
  repeated foodProductType String = 30
  repeated iFSACCategory String = 31
  foodProductQual String = 32
  repeated foodContactSurf String = 33
  repeated facilityType FacilityTypeEnum = 34
  repeated foodTravMode String = 35
  repeated foodTravVehic String = 36
  optional sampTransportDur QuantityValue = 37
  optional sampTransportTemp String = 38
  optional sampCollectMethod String = 39
  optional numSampCollect QuantityValue = 40
  repeated lotNumber String = 41
  optional hygienicArea String = 42
  optional envMonitoringZone String = 43
  optional areaSampSize String = 44
  repeated sampSurfMoisture SampSurfMoistureEnum = 45
  optional sampLocCondition SampLocConditionEnum = 46
  repeated biocideUsed String = 47
  repeated sterMethSampRoom String = 48
  optional enrichmentProtocol String = 49
  repeated cultTarget String = 50
  optional microbCultMed String = 51
  optional timepoint Double = 52
  optional bacterialDensity QuantityValue = 53
  optional cultIsolDate Date = 54
  optional cultResult CultResultEnum = 55
  repeated cultResultOrg String = 56
  repeated sampPooling String = 57
  optional sampPurpose String = 58
  optional sampRepTech QuantityValue = 59
  optional sampRepBiol QuantityValue = 60
  optional sampTransportCont SampTransportContEnum = 61
  repeated studyDesign String = 62
  repeated nuclAcidExtKit String = 63
  optional libraryPrepKit String = 64
  optional sequencingKit String = 65
  optional sequencingLocation String = 66
  optional studyIncTemp QuantityValue = 67
  optional studyIncDur QuantityValue = 68
  optional studyTimecourse QuantityValue = 69
  repeated studyTmnt String = 70
  optional foodSource String = 71
  repeated foodDisPoint String = 72
  optional foodDisPointCity String = 73
  optional foodOrigin String = 74
  repeated foodProdSynonym String = 75
  repeated foodAdditive String = 76
  optional foodTraceList FoodTraceListEnum = 77
  repeated partPlantAnimal String = 78
  repeated foodIngredient String = 79
  repeated specIntendedCons String = 80
  repeated hACCPTerm String = 81
  repeated dietaryClaimUse String = 82
  repeated foodAllergenLabel String = 83
  repeated foodProdChar String = 84
  repeated prodLabelClaims String = 85
  optional foodNameStatus String = 86
  repeated foodPreservProc String = 87
  repeated foodCookingProc String = 88
  repeated foodTreatProc String = 89
  optional foodContainWrap String = 90
  optional foodPackCapacity QuantityValue = 91
  repeated foodPackMedium String = 92
  repeated foodPriorContact String = 93
  repeated foodProd String = 94
  optional foodQualityDate String = 95
  repeated repositoryName String = 96
  repeated intendedConsumer String = 97
  repeated foodPackIntegrity String = 98
  repeated miscParam String = 99
  sampName String = 100
  projectName String = 101
  seqMeth String = 102
  optional sampSize QuantityValue = 103
  optional experimentalFactor String = 104
  optional nuclAcidExt String = 105
  optional sampVolWeDnaExt QuantityValue = 106
  optional subspecfGenLin String = 107
  sampTaxonId String = 108
  optional negContType NegContTypeEnum = 109
  optional posContType String = 110
  optional sourceMatId String = 111
  optional relToOxygen RelToOxygenEnum = 112
  optional sampCollecDevice String = 113
  optional sampCollecMethod String = 114
  optional sampMatProcess String = 115
  optional sizeFrac String = 116
  optional nuclAcidAmp String = 117
  optional libSize Integer = 118
  optional libReadsSeqd Integer = 119
  optional libLayout LibLayoutEnum = 120
  optional libVector String = 121
  optional libScreen String = 122
  targetGene String = 123
  optional targetSubfragment String = 124
  optional pcrPrimers String = 125
  optional mid String = 126
  optional adapters String = 127
  optional pcrCond String = 128
  optional seqQualityCheck String = 129
  optional chimeraCheck String = 130
  optional assemblySoftware String = 131
  optional associatedResource String = 132
  optional sop String = 133
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: survey with environmental package food-food production facility
message Food-foodProductionFacilityMIMARKSSurvey
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  geoLocName String = 5
  collectionDate Date = 6
  envBroadScale String = 7
  envLocalScale String = 8
  envMedium String = 9
  optional sampCollectDevice String = 10
  repeated organismCount OrganismCountEnum = 11
  optional sampStorTemp QuantityValue = 12
  optional sampStorDur String = 13
  optional temp QuantityValue = 14
  optional roomDim String = 15
  optional freqClean FreqCleanEnum = 16
  optional sampRoomId Integer = 17
  optional poolDnaExtracts String = 18
  optional sampStorLoc String = 19
  optional surfMaterial SurfMaterialEnum = 20
  optional indoorSurf IndoorSurfEnum = 21
  optional avgOccup Double = 22
  optional sampFloor SampFloorEnum = 23
  optional geneticMod String = 24
  collSiteGeoFeat String = 25
  sampSourceMatCat String = 26
  sampType String = 27
  sampStorMedia String = 28
  sampStorDevice String = 29
  repeated foodProductType String = 30
  repeated iFSACCategory String = 31
  foodProductQual String = 32
  repeated foodContactSurf String = 33
  repeated facilityType FacilityTypeEnum = 34
  repeated foodTravMode String = 35
  repeated foodTravVehic String = 36
  optional sampTransportDur QuantityValue = 37
  optional sampTransportTemp String = 38
  optional sampCollectMethod String = 39
  optional numSampCollect QuantityValue = 40
  repeated lotNumber String = 41
  optional hygienicArea String = 42
  optional envMonitoringZone String = 43
  optional areaSampSize String = 44
  repeated sampSurfMoisture SampSurfMoistureEnum = 45
  optional sampLocCondition SampLocConditionEnum = 46
  repeated biocideUsed String = 47
  repeated sterMethSampRoom String = 48
  optional enrichmentProtocol String = 49
  repeated cultTarget String = 50
  optional microbCultMed String = 51
  optional timepoint Double = 52
  optional bacterialDensity QuantityValue = 53
  optional cultIsolDate Date = 54
  optional cultResult CultResultEnum = 55
  repeated cultResultOrg String = 56
  repeated sampPooling String = 57
  optional sampPurpose String = 58
  optional sampRepTech QuantityValue = 59
  optional sampRepBiol QuantityValue = 60
  optional sampTransportCont SampTransportContEnum = 61
  repeated studyDesign String = 62
  repeated nuclAcidExtKit String = 63
  optional libraryPrepKit String = 64
  optional sequencingKit String = 65
  optional sequencingLocation String = 66
  optional studyIncTemp QuantityValue = 67
  optional studyIncDur QuantityValue = 68
  optional studyTimecourse QuantityValue = 69
  repeated studyTmnt String = 70
  optional foodSource String = 71
  repeated foodDisPoint String = 72
  optional foodDisPointCity String = 73
  optional foodOrigin String = 74
  repeated foodProdSynonym String = 75
  repeated foodAdditive String = 76
  optional foodTraceList FoodTraceListEnum = 77
  repeated partPlantAnimal String = 78
  repeated foodIngredient String = 79
  repeated specIntendedCons String = 80
  repeated hACCPTerm String = 81
  repeated dietaryClaimUse String = 82
  repeated foodAllergenLabel String = 83
  repeated foodProdChar String = 84
  repeated prodLabelClaims String = 85
  optional foodNameStatus String = 86
  repeated foodPreservProc String = 87
  repeated foodCookingProc String = 88
  repeated foodTreatProc String = 89
  optional foodContainWrap String = 90
  optional foodPackCapacity QuantityValue = 91
  repeated foodPackMedium String = 92
  repeated foodPriorContact String = 93
  repeated foodProd String = 94
  optional foodQualityDate String = 95
  repeated repositoryName String = 96
  repeated intendedConsumer String = 97
  repeated foodPackIntegrity String = 98
  repeated miscParam String = 99
  sampName String = 100
  projectName String = 101
  seqMeth String = 102
  optional sampSize QuantityValue = 103
  optional experimentalFactor String = 104
  optional nuclAcidExt String = 105
  optional sampVolWeDnaExt QuantityValue = 106
  optional subspecfGenLin String = 107
  sampTaxonId String = 108
  optional negContType NegContTypeEnum = 109
  optional posContType String = 110
  optional extrachromElements Integer = 111
  optional sourceMatId String = 112
  optional bioticRelationship BioticRelationshipEnum = 113
  optional trophicLevel TrophicLevelEnum = 114
  optional relToOxygen RelToOxygenEnum = 115
  isolGrowthCondt String = 116
  optional sampCollecDevice String = 117
  optional sampCollecMethod String = 118
  optional sampMatProcess String = 119
  optional nuclAcidAmp String = 120
  targetGene String = 121
  optional targetSubfragment String = 122
  optional pcrPrimers String = 123
  optional pcrCond String = 124
  optional seqQualityCheck String = 125
  optional chimeraCheck String = 126
  optional associatedResource String = 127
  optional sop String = 128
 }
// Combinatorial checklist Metagenome or Environmental with environmental package food-food production facility
message Food-foodProductionFacilityMIMS
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  geoLocName String = 5
  collectionDate Date = 6
  envBroadScale String = 7
  envLocalScale String = 8
  envMedium String = 9
  optional sampCollectDevice String = 10
  repeated organismCount OrganismCountEnum = 11
  optional sampStorTemp QuantityValue = 12
  optional sampStorDur String = 13
  optional temp QuantityValue = 14
  optional roomDim String = 15
  optional freqClean FreqCleanEnum = 16
  optional sampRoomId Integer = 17
  optional poolDnaExtracts String = 18
  optional sampStorLoc String = 19
  optional surfMaterial SurfMaterialEnum = 20
  optional indoorSurf IndoorSurfEnum = 21
  optional avgOccup Double = 22
  optional sampFloor SampFloorEnum = 23
  optional geneticMod String = 24
  collSiteGeoFeat String = 25
  sampSourceMatCat String = 26
  sampType String = 27
  sampStorMedia String = 28
  sampStorDevice String = 29
  repeated foodProductType String = 30
  repeated iFSACCategory String = 31
  foodProductQual String = 32
  repeated foodContactSurf String = 33
  repeated facilityType FacilityTypeEnum = 34
  repeated foodTravMode String = 35
  repeated foodTravVehic String = 36
  optional sampTransportDur QuantityValue = 37
  optional sampTransportTemp String = 38
  optional sampCollectMethod String = 39
  optional numSampCollect QuantityValue = 40
  repeated lotNumber String = 41
  optional hygienicArea String = 42
  optional envMonitoringZone String = 43
  optional areaSampSize String = 44
  repeated sampSurfMoisture SampSurfMoistureEnum = 45
  optional sampLocCondition SampLocConditionEnum = 46
  repeated biocideUsed String = 47
  repeated sterMethSampRoom String = 48
  optional enrichmentProtocol String = 49
  repeated cultTarget String = 50
  optional microbCultMed String = 51
  optional timepoint Double = 52
  optional bacterialDensity QuantityValue = 53
  optional cultIsolDate Date = 54
  optional cultResult CultResultEnum = 55
  repeated cultResultOrg String = 56
  repeated sampPooling String = 57
  optional sampPurpose String = 58
  optional sampRepTech QuantityValue = 59
  optional sampRepBiol QuantityValue = 60
  optional sampTransportCont SampTransportContEnum = 61
  repeated studyDesign String = 62
  repeated nuclAcidExtKit String = 63
  optional libraryPrepKit String = 64
  optional sequencingKit String = 65
  optional sequencingLocation String = 66
  optional studyIncTemp QuantityValue = 67
  optional studyIncDur QuantityValue = 68
  optional studyTimecourse QuantityValue = 69
  repeated studyTmnt String = 70
  optional foodSource String = 71
  repeated foodDisPoint String = 72
  optional foodDisPointCity String = 73
  optional foodOrigin String = 74
  repeated foodProdSynonym String = 75
  repeated foodAdditive String = 76
  optional foodTraceList FoodTraceListEnum = 77
  repeated partPlantAnimal String = 78
  repeated foodIngredient String = 79
  repeated specIntendedCons String = 80
  repeated hACCPTerm String = 81
  repeated dietaryClaimUse String = 82
  repeated foodAllergenLabel String = 83
  repeated foodProdChar String = 84
  repeated prodLabelClaims String = 85
  optional foodNameStatus String = 86
  repeated foodPreservProc String = 87
  repeated foodCookingProc String = 88
  repeated foodTreatProc String = 89
  optional foodContainWrap String = 90
  optional foodPackCapacity QuantityValue = 91
  repeated foodPackMedium String = 92
  repeated foodPriorContact String = 93
  repeated foodProd String = 94
  optional foodQualityDate String = 95
  repeated repositoryName String = 96
  repeated intendedConsumer String = 97
  repeated foodPackIntegrity String = 98
  repeated miscParam String = 99
  sampName String = 100
  projectName String = 101
  seqMeth String = 102
  optional sampSize QuantityValue = 103
  optional experimentalFactor String = 104
  optional nuclAcidExt String = 105
  optional sampVolWeDnaExt QuantityValue = 106
  optional subspecfGenLin String = 107
  sampTaxonId String = 108
  optional negContType NegContTypeEnum = 109
  optional posContType String = 110
  optional refBiomaterial String = 111
  optional sourceMatId String = 112
  optional relToOxygen RelToOxygenEnum = 113
  optional sampCollecDevice String = 114
  optional sampCollecMethod String = 115
  optional sampMatProcess String = 116
  optional sizeFrac String = 117
  optional nuclAcidAmp String = 118
  optional libSize Integer = 119
  optional libReadsSeqd Integer = 120
  optional libLayout LibLayoutEnum = 121
  optional libVector String = 122
  optional libScreen String = 123
  optional mid String = 124
  optional adapters String = 125
  optional assemblyQual AssemblyQualEnum = 126
  optional assemblyName String = 127
  optional assemblySoftware String = 128
  optional annot String = 129
  optional numberContig Integer = 130
  optional featPred String = 131
  optional refDb String = 132
  optional simSearchMeth String = 133
  optional taxClass String = 134
  optional associatedResource String = 135
  optional sop String = 136
 }
// Combinatorial checklist Minimum Information About a Single Amplified Genome with environmental package food-food production facility
message Food-foodProductionFacilityMISAG
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  geoLocName String = 5
  collectionDate Date = 6
  envBroadScale String = 7
  envLocalScale String = 8
  envMedium String = 9
  optional sampCollectDevice String = 10
  repeated organismCount OrganismCountEnum = 11
  optional sampStorTemp QuantityValue = 12
  optional sampStorDur String = 13
  optional temp QuantityValue = 14
  optional roomDim String = 15
  optional freqClean FreqCleanEnum = 16
  optional sampRoomId Integer = 17
  optional poolDnaExtracts String = 18
  optional sampStorLoc String = 19
  optional surfMaterial SurfMaterialEnum = 20
  optional indoorSurf IndoorSurfEnum = 21
  optional avgOccup Double = 22
  optional sampFloor SampFloorEnum = 23
  optional geneticMod String = 24
  collSiteGeoFeat String = 25
  sampSourceMatCat String = 26
  sampType String = 27
  sampStorMedia String = 28
  sampStorDevice String = 29
  repeated foodProductType String = 30
  repeated iFSACCategory String = 31
  foodProductQual String = 32
  repeated foodContactSurf String = 33
  repeated facilityType FacilityTypeEnum = 34
  repeated foodTravMode String = 35
  repeated foodTravVehic String = 36
  optional sampTransportDur QuantityValue = 37
  optional sampTransportTemp String = 38
  optional sampCollectMethod String = 39
  optional numSampCollect QuantityValue = 40
  repeated lotNumber String = 41
  optional hygienicArea String = 42
  optional envMonitoringZone String = 43
  optional areaSampSize String = 44
  repeated sampSurfMoisture SampSurfMoistureEnum = 45
  optional sampLocCondition SampLocConditionEnum = 46
  repeated biocideUsed String = 47
  repeated sterMethSampRoom String = 48
  optional enrichmentProtocol String = 49
  repeated cultTarget String = 50
  optional microbCultMed String = 51
  optional timepoint Double = 52
  optional bacterialDensity QuantityValue = 53
  optional cultIsolDate Date = 54
  optional cultResult CultResultEnum = 55
  repeated cultResultOrg String = 56
  repeated sampPooling String = 57
  optional sampPurpose String = 58
  optional sampRepTech QuantityValue = 59
  optional sampRepBiol QuantityValue = 60
  optional sampTransportCont SampTransportContEnum = 61
  repeated studyDesign String = 62
  repeated nuclAcidExtKit String = 63
  optional libraryPrepKit String = 64
  optional sequencingKit String = 65
  optional sequencingLocation String = 66
  optional studyIncTemp QuantityValue = 67
  optional studyIncDur QuantityValue = 68
  optional studyTimecourse QuantityValue = 69
  repeated studyTmnt String = 70
  optional foodSource String = 71
  repeated foodDisPoint String = 72
  optional foodDisPointCity String = 73
  optional foodOrigin String = 74
  repeated foodProdSynonym String = 75
  repeated foodAdditive String = 76
  optional foodTraceList FoodTraceListEnum = 77
  repeated partPlantAnimal String = 78
  repeated foodIngredient String = 79
  repeated specIntendedCons String = 80
  repeated hACCPTerm String = 81
  repeated dietaryClaimUse String = 82
  repeated foodAllergenLabel String = 83
  repeated foodProdChar String = 84
  repeated prodLabelClaims String = 85
  optional foodNameStatus String = 86
  repeated foodPreservProc String = 87
  repeated foodCookingProc String = 88
  repeated foodTreatProc String = 89
  optional foodContainWrap String = 90
  optional foodPackCapacity QuantityValue = 91
  repeated foodPackMedium String = 92
  repeated foodPriorContact String = 93
  repeated foodProd String = 94
  optional foodQualityDate String = 95
  repeated repositoryName String = 96
  repeated intendedConsumer String = 97
  repeated foodPackIntegrity String = 98
  repeated miscParam String = 99
  sampName String = 100
  projectName String = 101
  seqMeth String = 102
  optional sampSize QuantityValue = 103
  optional experimentalFactor String = 104
  optional nuclAcidExt String = 105
  optional sampVolWeDnaExt QuantityValue = 106
  optional subspecfGenLin String = 107
  sampTaxonId String = 108
  optional negContType NegContTypeEnum = 109
  optional posContType String = 110
  optional refBiomaterial String = 111
  optional sourceMatId String = 112
  optional relToOxygen RelToOxygenEnum = 113
  optional sampCollecDevice String = 114
  optional sampCollecMethod String = 115
  optional sampMatProcess String = 116
  optional sizeFrac String = 117
  optional nuclAcidAmp String = 118
  optional libSize Integer = 119
  optional libReadsSeqd Integer = 120
  optional libLayout LibLayoutEnum = 121
  optional libVector String = 122
  optional libScreen String = 123
  optional mid String = 124
  optional adapters String = 125
  taxIdent TaxIdentEnum = 126
  assemblyQual AssemblyQualEnum = 127
  optional assemblyName String = 128
  assemblySoftware String = 129
  optional annot String = 130
  optional numberContig Integer = 131
  optional featPred String = 132
  optional refDb String = 133
  optional simSearchMeth String = 134
  optional taxClass String = 135
  optional x16sRecover String = 136
  optional x16sRecoverSoftware String = 137
  optional trnas Integer = 138
  optional trnaExtSoftware String = 139
  complScore String = 140
  complSoftware String = 141
  optional complAppr ComplApprEnum = 142
  contamScore String = 143
  optional contamScreenInput String = 144
  optional contamScreenParam String = 145
  optional decontamSoftware DecontamSoftwareEnum = 146
  sortTech SortTechEnum = 147
  singleCellLysisAppr SingleCellLysisApprEnum = 148
  optional singleCellLysisProt String = 149
  wgaAmpAppr String = 150
  optional wgaAmpKit String = 151
  optional associatedResource String = 152
  optional sop String = 153
 }
// Combinatorial checklist Minimum Information About an Uncultivated Virus Genome with environmental package food-food production facility
message Food-foodProductionFacilityMIUVIG
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  geoLocName String = 5
  collectionDate Date = 6
  envBroadScale String = 7
  envLocalScale String = 8
  envMedium String = 9
  optional sampCollectDevice String = 10
  repeated organismCount OrganismCountEnum = 11
  optional sampStorTemp QuantityValue = 12
  optional sampStorDur String = 13
  optional temp QuantityValue = 14
  optional roomDim String = 15
  optional freqClean FreqCleanEnum = 16
  optional sampRoomId Integer = 17
  optional poolDnaExtracts String = 18
  optional sampStorLoc String = 19
  optional surfMaterial SurfMaterialEnum = 20
  optional indoorSurf IndoorSurfEnum = 21
  optional avgOccup Double = 22
  optional sampFloor SampFloorEnum = 23
  optional geneticMod String = 24
  collSiteGeoFeat String = 25
  sampSourceMatCat String = 26
  sampType String = 27
  sampStorMedia String = 28
  sampStorDevice String = 29
  repeated foodProductType String = 30
  repeated iFSACCategory String = 31
  foodProductQual String = 32
  repeated foodContactSurf String = 33
  repeated facilityType FacilityTypeEnum = 34
  repeated foodTravMode String = 35
  repeated foodTravVehic String = 36
  optional sampTransportDur QuantityValue = 37
  optional sampTransportTemp String = 38
  optional sampCollectMethod String = 39
  optional numSampCollect QuantityValue = 40
  repeated lotNumber String = 41
  optional hygienicArea String = 42
  optional envMonitoringZone String = 43
  optional areaSampSize String = 44
  repeated sampSurfMoisture SampSurfMoistureEnum = 45
  optional sampLocCondition SampLocConditionEnum = 46
  repeated biocideUsed String = 47
  repeated sterMethSampRoom String = 48
  optional enrichmentProtocol String = 49
  repeated cultTarget String = 50
  optional microbCultMed String = 51
  optional timepoint Double = 52
  optional bacterialDensity QuantityValue = 53
  optional cultIsolDate Date = 54
  optional cultResult CultResultEnum = 55
  repeated cultResultOrg String = 56
  repeated sampPooling String = 57
  optional sampPurpose String = 58
  optional sampRepTech QuantityValue = 59
  optional sampRepBiol QuantityValue = 60
  optional sampTransportCont SampTransportContEnum = 61
  repeated studyDesign String = 62
  repeated nuclAcidExtKit String = 63
  optional libraryPrepKit String = 64
  optional sequencingKit String = 65
  optional sequencingLocation String = 66
  optional studyIncTemp QuantityValue = 67
  optional studyIncDur QuantityValue = 68
  optional studyTimecourse QuantityValue = 69
  repeated studyTmnt String = 70
  optional foodSource String = 71
  repeated foodDisPoint String = 72
  optional foodDisPointCity String = 73
  optional foodOrigin String = 74
  repeated foodProdSynonym String = 75
  repeated foodAdditive String = 76
  optional foodTraceList FoodTraceListEnum = 77
  repeated partPlantAnimal String = 78
  repeated foodIngredient String = 79
  repeated specIntendedCons String = 80
  repeated hACCPTerm String = 81
  repeated dietaryClaimUse String = 82
  repeated foodAllergenLabel String = 83
  repeated foodProdChar String = 84
  repeated prodLabelClaims String = 85
  optional foodNameStatus String = 86
  repeated foodPreservProc String = 87
  repeated foodCookingProc String = 88
  repeated foodTreatProc String = 89
  optional foodContainWrap String = 90
  optional foodPackCapacity QuantityValue = 91
  repeated foodPackMedium String = 92
  repeated foodPriorContact String = 93
  repeated foodProd String = 94
  optional foodQualityDate String = 95
  repeated repositoryName String = 96
  repeated intendedConsumer String = 97
  repeated foodPackIntegrity String = 98
  repeated miscParam String = 99
  sampName String = 100
  projectName String = 101
  seqMeth String = 102
  optional sampSize QuantityValue = 103
  optional experimentalFactor String = 104
  optional nuclAcidExt String = 105
  optional sampVolWeDnaExt QuantityValue = 106
  optional subspecfGenLin String = 107
  sampTaxonId String = 108
  optional negContType NegContTypeEnum = 109
  optional posContType String = 110
  optional estimatedSize String = 111
  optional refBiomaterial String = 112
  optional sourceMatId String = 113
  optional pathogenicity String = 114
  optional bioticRelationship BioticRelationshipEnum = 115
  optional specificHost String = 116
  optional hostSpecRange Integer = 117
  optional hostDiseaseStat String = 118
  optional sampCollecDevice String = 119
  optional sampCollecMethod String = 120
  optional sampMatProcess String = 121
  optional sizeFrac String = 122
  sourceUvig SourceUvigEnum = 123
  virusEnrichAppr VirusEnrichApprEnum = 124
  optional nuclAcidAmp String = 125
  optional libSize Integer = 126
  optional libReadsSeqd Integer = 127
  optional libLayout LibLayoutEnum = 128
  optional libVector String = 129
  optional libScreen String = 130
  optional mid String = 131
  optional adapters String = 132
  optional taxIdent TaxIdentEnum = 133
  assemblyQual AssemblyQualEnum = 134
  optional assemblyName String = 135
  assemblySoftware String = 136
  optional annot String = 137
  numberContig Integer = 138
  optional featPred String = 139
  optional refDb String = 140
  optional simSearchMeth String = 141
  optional taxClass String = 142
  optional trnas Integer = 143
  optional trnaExtSoftware String = 144
  optional complScore String = 145
  optional complSoftware String = 146
  optional complAppr ComplApprEnum = 147
  optional sortTech SortTechEnum = 148
  optional singleCellLysisAppr SingleCellLysisApprEnum = 149
  optional singleCellLysisProt String = 150
  optional wgaAmpAppr String = 151
  optional wgaAmpKit String = 152
  optional binParam BinParamEnum = 153
  optional binSoftware String = 154
  optional reassemblyBin String = 155
  optional magCovSoftware MagCovSoftwareEnum = 156
  virIdentSoftware String = 157
  predGenomeType PredGenomeTypeEnum = 158
  predGenomeStruc PredGenomeStrucEnum = 159
  detecType String = 160
  optional otuClassAppr String = 161
  optional otuSeqCompAppr String = 162
  optional otuDb String = 163
  optional hostPredAppr HostPredApprEnum = 164
  optional hostPredEstAcc String = 165
  optional associatedResource String = 166
  optional sop String = 167
 }
// food-human foods
message Food-humanFoods
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  optional sampCollectDevice String = 11
  repeated organismCount OrganismCountEnum = 12
  optional spikeinCount SpikeinCountEnum = 13
  optional sampStorTemp QuantityValue = 14
  optional sampStorDur String = 15
  optional poolDnaExtracts String = 16
  optional sampStorLoc String = 17
  optional geneticMod String = 18
  repeated perturbation String = 19
  collSiteGeoFeat String = 20
  repeated foodProductType String = 21
  repeated iFSACCategory String = 22
  repeated fermChemAdd QuantityValue = 23
  repeated fermChemAddPerc String = 24
  optional fermHeadspaceOxy String = 25
  optional fermMedium String = 26
  optional fermPH Double = 27
  optional fermRelHumidity QuantityValue = 28
  optional fermTemp QuantityValue = 29
  optional fermTime String = 30
  optional fermVessel String = 31
  optional bacterialDensity QuantityValue = 32
  optional consFoodStorDur String = 33
  optional consFoodStorTemp String = 34
  optional consPurchDate Date = 35
  optional consQtyPurchased String = 36
  optional cultIsolDate Date = 37
  optional cultResult CultResultEnum = 38
  repeated cultResultOrg String = 39
  repeated cultTarget String = 40
  repeated dietaryClaimUse String = 41
  optional enrichmentProtocol String = 42
  repeated foodAdditive String = 43
  repeated foodAllergenLabel String = 44
  repeated foodContactSurf String = 45
  optional foodContainWrap String = 46
  repeated foodCookingProc String = 47
  repeated foodDisPoint String = 48
  repeated foodIngredient String = 49
  optional foodNameStatus String = 50
  optional foodOrigin String = 51
  optional foodPackCapacity QuantityValue = 52
  repeated foodPackIntegrity String = 53
  repeated foodPackMedium String = 54
  repeated foodPreservProc String = 55
  repeated foodPriorContact String = 56
  repeated foodProd String = 57
  repeated foodProdSynonym String = 58
  optional foodProductQual String = 59
  optional foodQualityDate String = 60
  optional foodSource String = 61
  optional foodTraceList FoodTraceListEnum = 62
  repeated foodTravMode String = 63
  repeated foodTravVehic String = 64
  repeated foodTreatProc String = 65
  repeated hACCPTerm String = 66
  repeated intendedConsumer String = 67
  optional libraryPrepKit String = 68
  repeated lotNumber String = 69
  optional microbCultMed String = 70
  optional microbStart String = 71
  optional microbStartCount MicrobStartCountEnum = 72
  optional microbStartInoc QuantityValue = 73
  optional microbStartPrep String = 74
  optional microbStartSource String = 75
  optional microbStartTaxID String = 76
  repeated nuclAcidExtKit String = 77
  optional numSampCollect QuantityValue = 78
  repeated partPlantAnimal String = 79
  repeated repositoryName String = 80
  optional sampleCollecMethod String = 81
  repeated sampPooling String = 82
  optional sampRepBiol QuantityValue = 83
  optional sampRepTech QuantityValue = 84
  optional sampSourceMatCat String = 85
  optional sampStorDevice String = 86
  optional sampStorMedia String = 87
  optional sampTransportCont SampTransportContEnum = 88
  optional sampTransportDur QuantityValue = 89
  optional sampTransportTemp String = 90
  optional sampPurpose String = 91
  optional sequencingKit String = 92
  optional sequencingLocation String = 93
  repeated serovarOrSerotype String = 94
  repeated spikeinAMR String = 95
  repeated spikeinAntibiotic String = 96
  repeated spikeinGrowthMed String = 97
  repeated spikeinMetal String = 98
  repeated spikeinOrg String = 99
  repeated spikeinSerovar String = 100
  repeated spikeinStrain String = 101
  repeated studyDesign String = 102
  optional studyIncDur QuantityValue = 103
  optional studyIncTemp QuantityValue = 104
  optional studyTimecourse QuantityValue = 105
  repeated studyTmnt String = 106
  optional timepoint Double = 107
  repeated miscParam String = 108
  sampName String = 109
  projectName String = 110
  seqMeth String = 111
  optional sampSize QuantityValue = 112
  optional experimentalFactor String = 113
  optional nuclAcidExt String = 114
  optional sampVolWeDnaExt QuantityValue = 115
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package food-human foods
message Food-humanFoodsMIGSBacteria
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  optional sampCollectDevice String = 11
  repeated organismCount OrganismCountEnum = 12
  optional spikeinCount SpikeinCountEnum = 13
  optional sampStorTemp QuantityValue = 14
  optional sampStorDur String = 15
  optional poolDnaExtracts String = 16
  optional sampStorLoc String = 17
  optional geneticMod String = 18
  repeated perturbation String = 19
  collSiteGeoFeat String = 20
  repeated foodProductType String = 21
  repeated iFSACCategory String = 22
  repeated fermChemAdd QuantityValue = 23
  repeated fermChemAddPerc String = 24
  optional fermHeadspaceOxy String = 25
  optional fermMedium String = 26
  optional fermPH Double = 27
  optional fermRelHumidity QuantityValue = 28
  optional fermTemp QuantityValue = 29
  optional fermTime String = 30
  optional fermVessel String = 31
  optional bacterialDensity QuantityValue = 32
  optional consFoodStorDur String = 33
  optional consFoodStorTemp String = 34
  optional consPurchDate Date = 35
  optional consQtyPurchased String = 36
  optional cultIsolDate Date = 37
  optional cultResult CultResultEnum = 38
  repeated cultResultOrg String = 39
  repeated cultTarget String = 40
  repeated dietaryClaimUse String = 41
  optional enrichmentProtocol String = 42
  repeated foodAdditive String = 43
  repeated foodAllergenLabel String = 44
  repeated foodContactSurf String = 45
  optional foodContainWrap String = 46
  repeated foodCookingProc String = 47
  repeated foodDisPoint String = 48
  repeated foodIngredient String = 49
  optional foodNameStatus String = 50
  optional foodOrigin String = 51
  optional foodPackCapacity QuantityValue = 52
  repeated foodPackIntegrity String = 53
  repeated foodPackMedium String = 54
  repeated foodPreservProc String = 55
  repeated foodPriorContact String = 56
  repeated foodProd String = 57
  repeated foodProdSynonym String = 58
  optional foodProductQual String = 59
  optional foodQualityDate String = 60
  optional foodSource String = 61
  optional foodTraceList FoodTraceListEnum = 62
  repeated foodTravMode String = 63
  repeated foodTravVehic String = 64
  repeated foodTreatProc String = 65
  repeated hACCPTerm String = 66
  repeated intendedConsumer String = 67
  optional libraryPrepKit String = 68
  repeated lotNumber String = 69
  optional microbCultMed String = 70
  optional microbStart String = 71
  optional microbStartCount MicrobStartCountEnum = 72
  optional microbStartInoc QuantityValue = 73
  optional microbStartPrep String = 74
  optional microbStartSource String = 75
  optional microbStartTaxID String = 76
  repeated nuclAcidExtKit String = 77
  optional numSampCollect QuantityValue = 78
  repeated partPlantAnimal String = 79
  repeated repositoryName String = 80
  optional sampleCollecMethod String = 81
  repeated sampPooling String = 82
  optional sampRepBiol QuantityValue = 83
  optional sampRepTech QuantityValue = 84
  optional sampSourceMatCat String = 85
  optional sampStorDevice String = 86
  optional sampStorMedia String = 87
  optional sampTransportCont SampTransportContEnum = 88
  optional sampTransportDur QuantityValue = 89
  optional sampTransportTemp String = 90
  optional sampPurpose String = 91
  optional sequencingKit String = 92
  optional sequencingLocation String = 93
  repeated serovarOrSerotype String = 94
  repeated spikeinAMR String = 95
  repeated spikeinAntibiotic String = 96
  repeated spikeinGrowthMed String = 97
  repeated spikeinMetal String = 98
  repeated spikeinOrg String = 99
  repeated spikeinSerovar String = 100
  repeated spikeinStrain String = 101
  repeated studyDesign String = 102
  optional studyIncDur QuantityValue = 103
  optional studyIncTemp QuantityValue = 104
  optional studyTimecourse QuantityValue = 105
  repeated studyTmnt String = 106
  optional timepoint Double = 107
  repeated miscParam String = 108
  sampName String = 109
  projectName String = 110
  seqMeth String = 111
  optional sampSize QuantityValue = 112
  optional experimentalFactor String = 113
  optional nuclAcidExt String = 114
  optional sampVolWeDnaExt QuantityValue = 115
  sampTaxonId String = 116
  optional negContType NegContTypeEnum = 117
  optional posContType String = 118
  optional subspecfGenLin String = 119
  numReplicons Integer = 120
  optional extrachromElements Integer = 121
  optional estimatedSize String = 122
  refBiomaterial String = 123
  optional sourceMatId String = 124
  optional pathogenicity String = 125
  optional bioticRelationship BioticRelationshipEnum = 126
  optional specificHost String = 127
  optional hostSpecRange Integer = 128
  optional hostDiseaseStat String = 129
  optional trophicLevel TrophicLevelEnum = 130
  optional encodedTraits String = 131
  optional relToOxygen RelToOxygenEnum = 132
  isolGrowthCondt String = 133
  optional sampCollecDevice String = 134
  optional sampCollecMethod String = 135
  optional sampMatProcess String = 136
  optional nuclAcidAmp String = 137
  optional libSize Integer = 138
  optional libReadsSeqd Integer = 139
  optional libLayout LibLayoutEnum = 140
  optional libVector String = 141
  optional libScreen String = 142
  optional adapters String = 143
  optional taxIdent TaxIdentEnum = 144
  assemblyQual AssemblyQualEnum = 145
  optional assemblyName String = 146
  assemblySoftware String = 147
  optional annot String = 148
  numberContig Integer = 149
  optional featPred String = 150
  optional refDb String = 151
  optional simSearchMeth String = 152
  optional taxClass String = 153
  optional complScore String = 154
  optional complSoftware String = 155
  optional associatedResource String = 156
  optional sop String = 157
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: eukaryote with environmental package food-human foods
message Food-humanFoodsMIGSEukaryote
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  optional sampCollectDevice String = 11
  repeated organismCount OrganismCountEnum = 12
  optional spikeinCount SpikeinCountEnum = 13
  optional sampStorTemp QuantityValue = 14
  optional sampStorDur String = 15
  optional poolDnaExtracts String = 16
  optional sampStorLoc String = 17
  optional geneticMod String = 18
  repeated perturbation String = 19
  collSiteGeoFeat String = 20
  repeated foodProductType String = 21
  repeated iFSACCategory String = 22
  repeated fermChemAdd QuantityValue = 23
  repeated fermChemAddPerc String = 24
  optional fermHeadspaceOxy String = 25
  optional fermMedium String = 26
  optional fermPH Double = 27
  optional fermRelHumidity QuantityValue = 28
  optional fermTemp QuantityValue = 29
  optional fermTime String = 30
  optional fermVessel String = 31
  optional bacterialDensity QuantityValue = 32
  optional consFoodStorDur String = 33
  optional consFoodStorTemp String = 34
  optional consPurchDate Date = 35
  optional consQtyPurchased String = 36
  optional cultIsolDate Date = 37
  optional cultResult CultResultEnum = 38
  repeated cultResultOrg String = 39
  repeated cultTarget String = 40
  repeated dietaryClaimUse String = 41
  optional enrichmentProtocol String = 42
  repeated foodAdditive String = 43
  repeated foodAllergenLabel String = 44
  repeated foodContactSurf String = 45
  optional foodContainWrap String = 46
  repeated foodCookingProc String = 47
  repeated foodDisPoint String = 48
  repeated foodIngredient String = 49
  optional foodNameStatus String = 50
  optional foodOrigin String = 51
  optional foodPackCapacity QuantityValue = 52
  repeated foodPackIntegrity String = 53
  repeated foodPackMedium String = 54
  repeated foodPreservProc String = 55
  repeated foodPriorContact String = 56
  repeated foodProd String = 57
  repeated foodProdSynonym String = 58
  optional foodProductQual String = 59
  optional foodQualityDate String = 60
  optional foodSource String = 61
  optional foodTraceList FoodTraceListEnum = 62
  repeated foodTravMode String = 63
  repeated foodTravVehic String = 64
  repeated foodTreatProc String = 65
  repeated hACCPTerm String = 66
  repeated intendedConsumer String = 67
  optional libraryPrepKit String = 68
  repeated lotNumber String = 69
  optional microbCultMed String = 70
  optional microbStart String = 71
  optional microbStartCount MicrobStartCountEnum = 72
  optional microbStartInoc QuantityValue = 73
  optional microbStartPrep String = 74
  optional microbStartSource String = 75
  optional microbStartTaxID String = 76
  repeated nuclAcidExtKit String = 77
  optional numSampCollect QuantityValue = 78
  repeated partPlantAnimal String = 79
  repeated repositoryName String = 80
  optional sampleCollecMethod String = 81
  repeated sampPooling String = 82
  optional sampRepBiol QuantityValue = 83
  optional sampRepTech QuantityValue = 84
  optional sampSourceMatCat String = 85
  optional sampStorDevice String = 86
  optional sampStorMedia String = 87
  optional sampTransportCont SampTransportContEnum = 88
  optional sampTransportDur QuantityValue = 89
  optional sampTransportTemp String = 90
  optional sampPurpose String = 91
  optional sequencingKit String = 92
  optional sequencingLocation String = 93
  repeated serovarOrSerotype String = 94
  repeated spikeinAMR String = 95
  repeated spikeinAntibiotic String = 96
  repeated spikeinGrowthMed String = 97
  repeated spikeinMetal String = 98
  repeated spikeinOrg String = 99
  repeated spikeinSerovar String = 100
  repeated spikeinStrain String = 101
  repeated studyDesign String = 102
  optional studyIncDur QuantityValue = 103
  optional studyIncTemp QuantityValue = 104
  optional studyTimecourse QuantityValue = 105
  repeated studyTmnt String = 106
  optional timepoint Double = 107
  repeated miscParam String = 108
  sampName String = 109
  projectName String = 110
  seqMeth String = 111
  optional sampSize QuantityValue = 112
  optional experimentalFactor String = 113
  optional nuclAcidExt String = 114
  optional sampVolWeDnaExt QuantityValue = 115
  sampTaxonId String = 116
  optional negContType NegContTypeEnum = 117
  optional posContType String = 118
  optional subspecfGenLin String = 119
  optional ploidy String = 120
  optional numReplicons Integer = 121
  optional extrachromElements Integer = 122
  optional estimatedSize String = 123
  optional refBiomaterial String = 124
  optional sourceMatId String = 125
  optional pathogenicity String = 126
  optional bioticRelationship BioticRelationshipEnum = 127
  optional specificHost String = 128
  optional hostSpecRange Integer = 129
  optional hostDiseaseStat String = 130
  optional trophicLevel TrophicLevelEnum = 131
  optional propagation String = 132
  isolGrowthCondt String = 133
  optional sampCollecDevice String = 134
  optional sampCollecMethod String = 135
  optional sampMatProcess String = 136
  optional nuclAcidAmp String = 137
  optional libSize Integer = 138
  optional libReadsSeqd Integer = 139
  optional libLayout LibLayoutEnum = 140
  optional libVector String = 141
  optional libScreen String = 142
  optional adapters String = 143
  optional taxIdent TaxIdentEnum = 144
  assemblyQual AssemblyQualEnum = 145
  optional assemblyName String = 146
  assemblySoftware String = 147
  optional annot String = 148
  numberContig Integer = 149
  optional featPred String = 150
  optional refDb String = 151
  optional simSearchMeth String = 152
  optional taxClass String = 153
  optional complScore String = 154
  optional complSoftware String = 155
  optional associatedResource String = 156
  optional sop String = 157
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: org with environmental package food-human foods
message Food-humanFoodsMIGSOrg
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  optional sampCollectDevice String = 11
  repeated organismCount OrganismCountEnum = 12
  optional spikeinCount SpikeinCountEnum = 13
  optional sampStorTemp QuantityValue = 14
  optional sampStorDur String = 15
  optional poolDnaExtracts String = 16
  optional sampStorLoc String = 17
  optional geneticMod String = 18
  repeated perturbation String = 19
  collSiteGeoFeat String = 20
  repeated foodProductType String = 21
  repeated iFSACCategory String = 22
  repeated fermChemAdd QuantityValue = 23
  repeated fermChemAddPerc String = 24
  optional fermHeadspaceOxy String = 25
  optional fermMedium String = 26
  optional fermPH Double = 27
  optional fermRelHumidity QuantityValue = 28
  optional fermTemp QuantityValue = 29
  optional fermTime String = 30
  optional fermVessel String = 31
  optional bacterialDensity QuantityValue = 32
  optional consFoodStorDur String = 33
  optional consFoodStorTemp String = 34
  optional consPurchDate Date = 35
  optional consQtyPurchased String = 36
  optional cultIsolDate Date = 37
  optional cultResult CultResultEnum = 38
  repeated cultResultOrg String = 39
  repeated cultTarget String = 40
  repeated dietaryClaimUse String = 41
  optional enrichmentProtocol String = 42
  repeated foodAdditive String = 43
  repeated foodAllergenLabel String = 44
  repeated foodContactSurf String = 45
  optional foodContainWrap String = 46
  repeated foodCookingProc String = 47
  repeated foodDisPoint String = 48
  repeated foodIngredient String = 49
  optional foodNameStatus String = 50
  optional foodOrigin String = 51
  optional foodPackCapacity QuantityValue = 52
  repeated foodPackIntegrity String = 53
  repeated foodPackMedium String = 54
  repeated foodPreservProc String = 55
  repeated foodPriorContact String = 56
  repeated foodProd String = 57
  repeated foodProdSynonym String = 58
  optional foodProductQual String = 59
  optional foodQualityDate String = 60
  optional foodSource String = 61
  optional foodTraceList FoodTraceListEnum = 62
  repeated foodTravMode String = 63
  repeated foodTravVehic String = 64
  repeated foodTreatProc String = 65
  repeated hACCPTerm String = 66
  repeated intendedConsumer String = 67
  optional libraryPrepKit String = 68
  repeated lotNumber String = 69
  optional microbCultMed String = 70
  optional microbStart String = 71
  optional microbStartCount MicrobStartCountEnum = 72
  optional microbStartInoc QuantityValue = 73
  optional microbStartPrep String = 74
  optional microbStartSource String = 75
  optional microbStartTaxID String = 76
  repeated nuclAcidExtKit String = 77
  optional numSampCollect QuantityValue = 78
  repeated partPlantAnimal String = 79
  repeated repositoryName String = 80
  optional sampleCollecMethod String = 81
  repeated sampPooling String = 82
  optional sampRepBiol QuantityValue = 83
  optional sampRepTech QuantityValue = 84
  optional sampSourceMatCat String = 85
  optional sampStorDevice String = 86
  optional sampStorMedia String = 87
  optional sampTransportCont SampTransportContEnum = 88
  optional sampTransportDur QuantityValue = 89
  optional sampTransportTemp String = 90
  optional sampPurpose String = 91
  optional sequencingKit String = 92
  optional sequencingLocation String = 93
  repeated serovarOrSerotype String = 94
  repeated spikeinAMR String = 95
  repeated spikeinAntibiotic String = 96
  repeated spikeinGrowthMed String = 97
  repeated spikeinMetal String = 98
  repeated spikeinOrg String = 99
  repeated spikeinSerovar String = 100
  repeated spikeinStrain String = 101
  repeated studyDesign String = 102
  optional studyIncDur QuantityValue = 103
  optional studyIncTemp QuantityValue = 104
  optional studyTimecourse QuantityValue = 105
  repeated studyTmnt String = 106
  optional timepoint Double = 107
  repeated miscParam String = 108
  sampName String = 109
  projectName String = 110
  seqMeth String = 111
  optional sampSize QuantityValue = 112
  optional experimentalFactor String = 113
  optional nuclAcidExt String = 114
  optional sampVolWeDnaExt QuantityValue = 115
  sampTaxonId String = 116
  optional negContType NegContTypeEnum = 117
  optional posContType String = 118
  optional subspecfGenLin String = 119
  optional extrachromElements Integer = 120
  optional estimatedSize String = 121
  optional refBiomaterial String = 122
  optional sourceMatId String = 123
  isolGrowthCondt String = 124
  optional sampCollecDevice String = 125
  optional sampCollecMethod String = 126
  optional sampMatProcess String = 127
  optional nuclAcidAmp String = 128
  optional libSize Integer = 129
  optional libReadsSeqd Integer = 130
  optional libLayout LibLayoutEnum = 131
  optional libVector String = 132
  optional libScreen String = 133
  optional adapters String = 134
  optional taxIdent TaxIdentEnum = 135
  optional assemblyQual AssemblyQualEnum = 136
  optional assemblyName String = 137
  assemblySoftware String = 138
  optional annot String = 139
  optional numberContig Integer = 140
  optional featPred String = 141
  optional refDb String = 142
  optional simSearchMeth String = 143
  optional taxClass String = 144
  optional complScore String = 145
  optional complSoftware String = 146
  optional associatedResource String = 147
  optional sop String = 148
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: plant with environmental package food-human foods
message Food-humanFoodsMIGSPlant
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  optional sampCollectDevice String = 11
  repeated organismCount OrganismCountEnum = 12
  optional spikeinCount SpikeinCountEnum = 13
  optional sampStorTemp QuantityValue = 14
  optional sampStorDur String = 15
  optional poolDnaExtracts String = 16
  optional sampStorLoc String = 17
  optional geneticMod String = 18
  repeated perturbation String = 19
  collSiteGeoFeat String = 20
  repeated foodProductType String = 21
  repeated iFSACCategory String = 22
  repeated fermChemAdd QuantityValue = 23
  repeated fermChemAddPerc String = 24
  optional fermHeadspaceOxy String = 25
  optional fermMedium String = 26
  optional fermPH Double = 27
  optional fermRelHumidity QuantityValue = 28
  optional fermTemp QuantityValue = 29
  optional fermTime String = 30
  optional fermVessel String = 31
  optional bacterialDensity QuantityValue = 32
  optional consFoodStorDur String = 33
  optional consFoodStorTemp String = 34
  optional consPurchDate Date = 35
  optional consQtyPurchased String = 36
  optional cultIsolDate Date = 37
  optional cultResult CultResultEnum = 38
  repeated cultResultOrg String = 39
  repeated cultTarget String = 40
  repeated dietaryClaimUse String = 41
  optional enrichmentProtocol String = 42
  repeated foodAdditive String = 43
  repeated foodAllergenLabel String = 44
  repeated foodContactSurf String = 45
  optional foodContainWrap String = 46
  repeated foodCookingProc String = 47
  repeated foodDisPoint String = 48
  repeated foodIngredient String = 49
  optional foodNameStatus String = 50
  optional foodOrigin String = 51
  optional foodPackCapacity QuantityValue = 52
  repeated foodPackIntegrity String = 53
  repeated foodPackMedium String = 54
  repeated foodPreservProc String = 55
  repeated foodPriorContact String = 56
  repeated foodProd String = 57
  repeated foodProdSynonym String = 58
  optional foodProductQual String = 59
  optional foodQualityDate String = 60
  optional foodSource String = 61
  optional foodTraceList FoodTraceListEnum = 62
  repeated foodTravMode String = 63
  repeated foodTravVehic String = 64
  repeated foodTreatProc String = 65
  repeated hACCPTerm String = 66
  repeated intendedConsumer String = 67
  optional libraryPrepKit String = 68
  repeated lotNumber String = 69
  optional microbCultMed String = 70
  optional microbStart String = 71
  optional microbStartCount MicrobStartCountEnum = 72
  optional microbStartInoc QuantityValue = 73
  optional microbStartPrep String = 74
  optional microbStartSource String = 75
  optional microbStartTaxID String = 76
  repeated nuclAcidExtKit String = 77
  optional numSampCollect QuantityValue = 78
  repeated partPlantAnimal String = 79
  repeated repositoryName String = 80
  optional sampleCollecMethod String = 81
  repeated sampPooling String = 82
  optional sampRepBiol QuantityValue = 83
  optional sampRepTech QuantityValue = 84
  optional sampSourceMatCat String = 85
  optional sampStorDevice String = 86
  optional sampStorMedia String = 87
  optional sampTransportCont SampTransportContEnum = 88
  optional sampTransportDur QuantityValue = 89
  optional sampTransportTemp String = 90
  optional sampPurpose String = 91
  optional sequencingKit String = 92
  optional sequencingLocation String = 93
  repeated serovarOrSerotype String = 94
  repeated spikeinAMR String = 95
  repeated spikeinAntibiotic String = 96
  repeated spikeinGrowthMed String = 97
  repeated spikeinMetal String = 98
  repeated spikeinOrg String = 99
  repeated spikeinSerovar String = 100
  repeated spikeinStrain String = 101
  repeated studyDesign String = 102
  optional studyIncDur QuantityValue = 103
  optional studyIncTemp QuantityValue = 104
  optional studyTimecourse QuantityValue = 105
  repeated studyTmnt String = 106
  optional timepoint Double = 107
  repeated miscParam String = 108
  sampName String = 109
  projectName String = 110
  seqMeth String = 111
  optional sampSize QuantityValue = 112
  optional experimentalFactor String = 113
  optional nuclAcidExt String = 114
  optional sampVolWeDnaExt QuantityValue = 115
  sampTaxonId String = 116
  optional negContType NegContTypeEnum = 117
  optional posContType String = 118
  optional subspecfGenLin String = 119
  optional estimatedSize String = 120
  optional refBiomaterial String = 121
  optional sourceMatId String = 122
  optional specificHost String = 123
  optional hostSpecRange Integer = 124
  propagation String = 125
  optional encodedTraits String = 126
  isolGrowthCondt String = 127
  optional sampCollecDevice String = 128
  optional sampCollecMethod String = 129
  optional sampMatProcess String = 130
  optional nuclAcidAmp String = 131
  optional libSize Integer = 132
  optional libReadsSeqd Integer = 133
  optional libLayout LibLayoutEnum = 134
  optional libVector String = 135
  optional libScreen String = 136
  optional adapters String = 137
  optional taxIdent TaxIdentEnum = 138
  optional assemblyQual AssemblyQualEnum = 139
  optional assemblyName String = 140
  assemblySoftware String = 141
  optional annot String = 142
  optional numberContig Integer = 143
  optional featPred String = 144
  optional refDb String = 145
  optional simSearchMeth String = 146
  optional taxClass String = 147
  optional complScore String = 148
  optional complSoftware String = 149
  optional associatedResource String = 150
  optional sop String = 151
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package food-human foods
message Food-humanFoodsMIGSVirus
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  optional sampCollectDevice String = 11
  repeated organismCount OrganismCountEnum = 12
  optional spikeinCount SpikeinCountEnum = 13
  optional sampStorTemp QuantityValue = 14
  optional sampStorDur String = 15
  optional poolDnaExtracts String = 16
  optional sampStorLoc String = 17
  optional geneticMod String = 18
  repeated perturbation String = 19
  collSiteGeoFeat String = 20
  repeated foodProductType String = 21
  repeated iFSACCategory String = 22
  repeated fermChemAdd QuantityValue = 23
  repeated fermChemAddPerc String = 24
  optional fermHeadspaceOxy String = 25
  optional fermMedium String = 26
  optional fermPH Double = 27
  optional fermRelHumidity QuantityValue = 28
  optional fermTemp QuantityValue = 29
  optional fermTime String = 30
  optional fermVessel String = 31
  optional bacterialDensity QuantityValue = 32
  optional consFoodStorDur String = 33
  optional consFoodStorTemp String = 34
  optional consPurchDate Date = 35
  optional consQtyPurchased String = 36
  optional cultIsolDate Date = 37
  optional cultResult CultResultEnum = 38
  repeated cultResultOrg String = 39
  repeated cultTarget String = 40
  repeated dietaryClaimUse String = 41
  optional enrichmentProtocol String = 42
  repeated foodAdditive String = 43
  repeated foodAllergenLabel String = 44
  repeated foodContactSurf String = 45
  optional foodContainWrap String = 46
  repeated foodCookingProc String = 47
  repeated foodDisPoint String = 48
  repeated foodIngredient String = 49
  optional foodNameStatus String = 50
  optional foodOrigin String = 51
  optional foodPackCapacity QuantityValue = 52
  repeated foodPackIntegrity String = 53
  repeated foodPackMedium String = 54
  repeated foodPreservProc String = 55
  repeated foodPriorContact String = 56
  repeated foodProd String = 57
  repeated foodProdSynonym String = 58
  optional foodProductQual String = 59
  optional foodQualityDate String = 60
  optional foodSource String = 61
  optional foodTraceList FoodTraceListEnum = 62
  repeated foodTravMode String = 63
  repeated foodTravVehic String = 64
  repeated foodTreatProc String = 65
  repeated hACCPTerm String = 66
  repeated intendedConsumer String = 67
  optional libraryPrepKit String = 68
  repeated lotNumber String = 69
  optional microbCultMed String = 70
  optional microbStart String = 71
  optional microbStartCount MicrobStartCountEnum = 72
  optional microbStartInoc QuantityValue = 73
  optional microbStartPrep String = 74
  optional microbStartSource String = 75
  optional microbStartTaxID String = 76
  repeated nuclAcidExtKit String = 77
  optional numSampCollect QuantityValue = 78
  repeated partPlantAnimal String = 79
  repeated repositoryName String = 80
  optional sampleCollecMethod String = 81
  repeated sampPooling String = 82
  optional sampRepBiol QuantityValue = 83
  optional sampRepTech QuantityValue = 84
  optional sampSourceMatCat String = 85
  optional sampStorDevice String = 86
  optional sampStorMedia String = 87
  optional sampTransportCont SampTransportContEnum = 88
  optional sampTransportDur QuantityValue = 89
  optional sampTransportTemp String = 90
  optional sampPurpose String = 91
  optional sequencingKit String = 92
  optional sequencingLocation String = 93
  repeated serovarOrSerotype String = 94
  repeated spikeinAMR String = 95
  repeated spikeinAntibiotic String = 96
  repeated spikeinGrowthMed String = 97
  repeated spikeinMetal String = 98
  repeated spikeinOrg String = 99
  repeated spikeinSerovar String = 100
  repeated spikeinStrain String = 101
  repeated studyDesign String = 102
  optional studyIncDur QuantityValue = 103
  optional studyIncTemp QuantityValue = 104
  optional studyTimecourse QuantityValue = 105
  repeated studyTmnt String = 106
  optional timepoint Double = 107
  repeated miscParam String = 108
  sampName String = 109
  projectName String = 110
  seqMeth String = 111
  optional sampSize QuantityValue = 112
  optional experimentalFactor String = 113
  optional nuclAcidExt String = 114
  optional sampVolWeDnaExt QuantityValue = 115
  sampTaxonId String = 116
  optional negContType NegContTypeEnum = 117
  optional posContType String = 118
  optional subspecfGenLin String = 119
  optional numReplicons Integer = 120
  optional estimatedSize String = 121
  optional refBiomaterial String = 122
  optional sourceMatId String = 123
  optional pathogenicity String = 124
  optional bioticRelationship BioticRelationshipEnum = 125
  optional specificHost String = 126
  optional hostSpecRange Integer = 127
  optional hostDiseaseStat String = 128
  propagation String = 129
  optional encodedTraits String = 130
  isolGrowthCondt String = 131
  optional sampCollecDevice String = 132
  optional sampCollecMethod String = 133
  optional sampMatProcess String = 134
  optional virusEnrichAppr VirusEnrichApprEnum = 135
  optional nuclAcidAmp String = 136
  optional libSize Integer = 137
  optional libReadsSeqd Integer = 138
  optional libLayout LibLayoutEnum = 139
  optional libVector String = 140
  optional libScreen String = 141
  optional adapters String = 142
  optional taxIdent TaxIdentEnum = 143
  optional assemblyQual AssemblyQualEnum = 144
  optional assemblyName String = 145
  assemblySoftware String = 146
  optional annot String = 147
  optional numberContig Integer = 148
  optional featPred String = 149
  optional refDb String = 150
  optional simSearchMeth String = 151
  optional taxClass String = 152
  optional complScore String = 153
  optional complSoftware String = 154
  optional associatedResource String = 155
  optional sop String = 156
 }
// Combinatorial checklist Minimum Information About a Metagenome-Assembled Genome with environmental package food-human foods
message Food-humanFoodsMIMAG
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  optional sampCollectDevice String = 11
  repeated organismCount OrganismCountEnum = 12
  optional spikeinCount SpikeinCountEnum = 13
  optional sampStorTemp QuantityValue = 14
  optional sampStorDur String = 15
  optional poolDnaExtracts String = 16
  optional sampStorLoc String = 17
  optional geneticMod String = 18
  repeated perturbation String = 19
  collSiteGeoFeat String = 20
  repeated foodProductType String = 21
  repeated iFSACCategory String = 22
  repeated fermChemAdd QuantityValue = 23
  repeated fermChemAddPerc String = 24
  optional fermHeadspaceOxy String = 25
  optional fermMedium String = 26
  optional fermPH Double = 27
  optional fermRelHumidity QuantityValue = 28
  optional fermTemp QuantityValue = 29
  optional fermTime String = 30
  optional fermVessel String = 31
  optional bacterialDensity QuantityValue = 32
  optional consFoodStorDur String = 33
  optional consFoodStorTemp String = 34
  optional consPurchDate Date = 35
  optional consQtyPurchased String = 36
  optional cultIsolDate Date = 37
  optional cultResult CultResultEnum = 38
  repeated cultResultOrg String = 39
  repeated cultTarget String = 40
  repeated dietaryClaimUse String = 41
  optional enrichmentProtocol String = 42
  repeated foodAdditive String = 43
  repeated foodAllergenLabel String = 44
  repeated foodContactSurf String = 45
  optional foodContainWrap String = 46
  repeated foodCookingProc String = 47
  repeated foodDisPoint String = 48
  repeated foodIngredient String = 49
  optional foodNameStatus String = 50
  optional foodOrigin String = 51
  optional foodPackCapacity QuantityValue = 52
  repeated foodPackIntegrity String = 53
  repeated foodPackMedium String = 54
  repeated foodPreservProc String = 55
  repeated foodPriorContact String = 56
  repeated foodProd String = 57
  repeated foodProdSynonym String = 58
  optional foodProductQual String = 59
  optional foodQualityDate String = 60
  optional foodSource String = 61
  optional foodTraceList FoodTraceListEnum = 62
  repeated foodTravMode String = 63
  repeated foodTravVehic String = 64
  repeated foodTreatProc String = 65
  repeated hACCPTerm String = 66
  repeated intendedConsumer String = 67
  optional libraryPrepKit String = 68
  repeated lotNumber String = 69
  optional microbCultMed String = 70
  optional microbStart String = 71
  optional microbStartCount MicrobStartCountEnum = 72
  optional microbStartInoc QuantityValue = 73
  optional microbStartPrep String = 74
  optional microbStartSource String = 75
  optional microbStartTaxID String = 76
  repeated nuclAcidExtKit String = 77
  optional numSampCollect QuantityValue = 78
  repeated partPlantAnimal String = 79
  repeated repositoryName String = 80
  optional sampleCollecMethod String = 81
  repeated sampPooling String = 82
  optional sampRepBiol QuantityValue = 83
  optional sampRepTech QuantityValue = 84
  optional sampSourceMatCat String = 85
  optional sampStorDevice String = 86
  optional sampStorMedia String = 87
  optional sampTransportCont SampTransportContEnum = 88
  optional sampTransportDur QuantityValue = 89
  optional sampTransportTemp String = 90
  optional sampPurpose String = 91
  optional sequencingKit String = 92
  optional sequencingLocation String = 93
  repeated serovarOrSerotype String = 94
  repeated spikeinAMR String = 95
  repeated spikeinAntibiotic String = 96
  repeated spikeinGrowthMed String = 97
  repeated spikeinMetal String = 98
  repeated spikeinOrg String = 99
  repeated spikeinSerovar String = 100
  repeated spikeinStrain String = 101
  repeated studyDesign String = 102
  optional studyIncDur QuantityValue = 103
  optional studyIncTemp QuantityValue = 104
  optional studyTimecourse QuantityValue = 105
  repeated studyTmnt String = 106
  optional timepoint Double = 107
  repeated miscParam String = 108
  sampName String = 109
  projectName String = 110
  seqMeth String = 111
  optional sampSize QuantityValue = 112
  optional experimentalFactor String = 113
  optional nuclAcidExt String = 114
  optional sampVolWeDnaExt QuantityValue = 115
  sampTaxonId String = 116
  optional negContType NegContTypeEnum = 117
  optional posContType String = 118
  optional refBiomaterial String = 119
  optional sourceMatId String = 120
  optional relToOxygen RelToOxygenEnum = 121
  optional sampCollecDevice String = 122
  optional sampCollecMethod String = 123
  optional sampMatProcess String = 124
  optional sizeFrac String = 125
  optional nuclAcidAmp String = 126
  optional libSize Integer = 127
  optional libReadsSeqd Integer = 128
  optional libLayout LibLayoutEnum = 129
  optional libVector String = 130
  optional libScreen String = 131
  optional mid String = 132
  optional adapters String = 133
  taxIdent TaxIdentEnum = 134
  assemblyQual AssemblyQualEnum = 135
  optional assemblyName String = 136
  assemblySoftware String = 137
  optional annot String = 138
  optional numberContig Integer = 139
  optional featPred String = 140
  optional refDb String = 141
  optional simSearchMeth String = 142
  optional taxClass String = 143
  optional x16sRecover String = 144
  optional x16sRecoverSoftware String = 145
  optional trnas Integer = 146
  optional trnaExtSoftware String = 147
  complScore String = 148
  complSoftware String = 149
  optional complAppr ComplApprEnum = 150
  contamScore String = 151
  optional contamScreenInput String = 152
  optional contamScreenParam String = 153
  optional decontamSoftware DecontamSoftwareEnum = 154
  binParam BinParamEnum = 155
  binSoftware String = 156
  optional reassemblyBin String = 157
  optional magCovSoftware MagCovSoftwareEnum = 158
  optional associatedResource String = 159
  optional sop String = 160
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: specimen with environmental package food-human foods
message Food-humanFoodsMIMARKSSpecimen
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  optional sampCollectDevice String = 11
  repeated organismCount OrganismCountEnum = 12
  optional spikeinCount SpikeinCountEnum = 13
  optional sampStorTemp QuantityValue = 14
  optional sampStorDur String = 15
  optional poolDnaExtracts String = 16
  optional sampStorLoc String = 17
  optional geneticMod String = 18
  repeated perturbation String = 19
  collSiteGeoFeat String = 20
  repeated foodProductType String = 21
  repeated iFSACCategory String = 22
  repeated fermChemAdd QuantityValue = 23
  repeated fermChemAddPerc String = 24
  optional fermHeadspaceOxy String = 25
  optional fermMedium String = 26
  optional fermPH Double = 27
  optional fermRelHumidity QuantityValue = 28
  optional fermTemp QuantityValue = 29
  optional fermTime String = 30
  optional fermVessel String = 31
  optional bacterialDensity QuantityValue = 32
  optional consFoodStorDur String = 33
  optional consFoodStorTemp String = 34
  optional consPurchDate Date = 35
  optional consQtyPurchased String = 36
  optional cultIsolDate Date = 37
  optional cultResult CultResultEnum = 38
  repeated cultResultOrg String = 39
  repeated cultTarget String = 40
  repeated dietaryClaimUse String = 41
  optional enrichmentProtocol String = 42
  repeated foodAdditive String = 43
  repeated foodAllergenLabel String = 44
  repeated foodContactSurf String = 45
  optional foodContainWrap String = 46
  repeated foodCookingProc String = 47
  repeated foodDisPoint String = 48
  repeated foodIngredient String = 49
  optional foodNameStatus String = 50
  optional foodOrigin String = 51
  optional foodPackCapacity QuantityValue = 52
  repeated foodPackIntegrity String = 53
  repeated foodPackMedium String = 54
  repeated foodPreservProc String = 55
  repeated foodPriorContact String = 56
  repeated foodProd String = 57
  repeated foodProdSynonym String = 58
  optional foodProductQual String = 59
  optional foodQualityDate String = 60
  optional foodSource String = 61
  optional foodTraceList FoodTraceListEnum = 62
  repeated foodTravMode String = 63
  repeated foodTravVehic String = 64
  repeated foodTreatProc String = 65
  repeated hACCPTerm String = 66
  repeated intendedConsumer String = 67
  optional libraryPrepKit String = 68
  repeated lotNumber String = 69
  optional microbCultMed String = 70
  optional microbStart String = 71
  optional microbStartCount MicrobStartCountEnum = 72
  optional microbStartInoc QuantityValue = 73
  optional microbStartPrep String = 74
  optional microbStartSource String = 75
  optional microbStartTaxID String = 76
  repeated nuclAcidExtKit String = 77
  optional numSampCollect QuantityValue = 78
  repeated partPlantAnimal String = 79
  repeated repositoryName String = 80
  optional sampleCollecMethod String = 81
  repeated sampPooling String = 82
  optional sampRepBiol QuantityValue = 83
  optional sampRepTech QuantityValue = 84
  optional sampSourceMatCat String = 85
  optional sampStorDevice String = 86
  optional sampStorMedia String = 87
  optional sampTransportCont SampTransportContEnum = 88
  optional sampTransportDur QuantityValue = 89
  optional sampTransportTemp String = 90
  optional sampPurpose String = 91
  optional sequencingKit String = 92
  optional sequencingLocation String = 93
  repeated serovarOrSerotype String = 94
  repeated spikeinAMR String = 95
  repeated spikeinAntibiotic String = 96
  repeated spikeinGrowthMed String = 97
  repeated spikeinMetal String = 98
  repeated spikeinOrg String = 99
  repeated spikeinSerovar String = 100
  repeated spikeinStrain String = 101
  repeated studyDesign String = 102
  optional studyIncDur QuantityValue = 103
  optional studyIncTemp QuantityValue = 104
  optional studyTimecourse QuantityValue = 105
  repeated studyTmnt String = 106
  optional timepoint Double = 107
  repeated miscParam String = 108
  sampName String = 109
  projectName String = 110
  seqMeth String = 111
  optional sampSize QuantityValue = 112
  optional experimentalFactor String = 113
  optional nuclAcidExt String = 114
  optional sampVolWeDnaExt QuantityValue = 115
  sampTaxonId String = 116
  optional negContType NegContTypeEnum = 117
  optional posContType String = 118
  optional sourceMatId String = 119
  optional relToOxygen RelToOxygenEnum = 120
  optional sampCollecDevice String = 121
  optional sampCollecMethod String = 122
  optional sampMatProcess String = 123
  optional sizeFrac String = 124
  optional nuclAcidAmp String = 125
  optional libSize Integer = 126
  optional libReadsSeqd Integer = 127
  optional libLayout LibLayoutEnum = 128
  optional libVector String = 129
  optional libScreen String = 130
  targetGene String = 131
  optional targetSubfragment String = 132
  optional pcrPrimers String = 133
  optional mid String = 134
  optional adapters String = 135
  optional pcrCond String = 136
  optional seqQualityCheck String = 137
  optional chimeraCheck String = 138
  optional assemblySoftware String = 139
  optional associatedResource String = 140
  optional sop String = 141
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: survey with environmental package food-human foods
message Food-humanFoodsMIMARKSSurvey
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  optional sampCollectDevice String = 11
  repeated organismCount OrganismCountEnum = 12
  optional spikeinCount SpikeinCountEnum = 13
  optional sampStorTemp QuantityValue = 14
  optional sampStorDur String = 15
  optional poolDnaExtracts String = 16
  optional sampStorLoc String = 17
  optional geneticMod String = 18
  repeated perturbation String = 19
  collSiteGeoFeat String = 20
  repeated foodProductType String = 21
  repeated iFSACCategory String = 22
  repeated fermChemAdd QuantityValue = 23
  repeated fermChemAddPerc String = 24
  optional fermHeadspaceOxy String = 25
  optional fermMedium String = 26
  optional fermPH Double = 27
  optional fermRelHumidity QuantityValue = 28
  optional fermTemp QuantityValue = 29
  optional fermTime String = 30
  optional fermVessel String = 31
  optional bacterialDensity QuantityValue = 32
  optional consFoodStorDur String = 33
  optional consFoodStorTemp String = 34
  optional consPurchDate Date = 35
  optional consQtyPurchased String = 36
  optional cultIsolDate Date = 37
  optional cultResult CultResultEnum = 38
  repeated cultResultOrg String = 39
  repeated cultTarget String = 40
  repeated dietaryClaimUse String = 41
  optional enrichmentProtocol String = 42
  repeated foodAdditive String = 43
  repeated foodAllergenLabel String = 44
  repeated foodContactSurf String = 45
  optional foodContainWrap String = 46
  repeated foodCookingProc String = 47
  repeated foodDisPoint String = 48
  repeated foodIngredient String = 49
  optional foodNameStatus String = 50
  optional foodOrigin String = 51
  optional foodPackCapacity QuantityValue = 52
  repeated foodPackIntegrity String = 53
  repeated foodPackMedium String = 54
  repeated foodPreservProc String = 55
  repeated foodPriorContact String = 56
  repeated foodProd String = 57
  repeated foodProdSynonym String = 58
  optional foodProductQual String = 59
  optional foodQualityDate String = 60
  optional foodSource String = 61
  optional foodTraceList FoodTraceListEnum = 62
  repeated foodTravMode String = 63
  repeated foodTravVehic String = 64
  repeated foodTreatProc String = 65
  repeated hACCPTerm String = 66
  repeated intendedConsumer String = 67
  optional libraryPrepKit String = 68
  repeated lotNumber String = 69
  optional microbCultMed String = 70
  optional microbStart String = 71
  optional microbStartCount MicrobStartCountEnum = 72
  optional microbStartInoc QuantityValue = 73
  optional microbStartPrep String = 74
  optional microbStartSource String = 75
  optional microbStartTaxID String = 76
  repeated nuclAcidExtKit String = 77
  optional numSampCollect QuantityValue = 78
  repeated partPlantAnimal String = 79
  repeated repositoryName String = 80
  optional sampleCollecMethod String = 81
  repeated sampPooling String = 82
  optional sampRepBiol QuantityValue = 83
  optional sampRepTech QuantityValue = 84
  optional sampSourceMatCat String = 85
  optional sampStorDevice String = 86
  optional sampStorMedia String = 87
  optional sampTransportCont SampTransportContEnum = 88
  optional sampTransportDur QuantityValue = 89
  optional sampTransportTemp String = 90
  optional sampPurpose String = 91
  optional sequencingKit String = 92
  optional sequencingLocation String = 93
  repeated serovarOrSerotype String = 94
  repeated spikeinAMR String = 95
  repeated spikeinAntibiotic String = 96
  repeated spikeinGrowthMed String = 97
  repeated spikeinMetal String = 98
  repeated spikeinOrg String = 99
  repeated spikeinSerovar String = 100
  repeated spikeinStrain String = 101
  repeated studyDesign String = 102
  optional studyIncDur QuantityValue = 103
  optional studyIncTemp QuantityValue = 104
  optional studyTimecourse QuantityValue = 105
  repeated studyTmnt String = 106
  optional timepoint Double = 107
  repeated miscParam String = 108
  sampName String = 109
  projectName String = 110
  seqMeth String = 111
  optional sampSize QuantityValue = 112
  optional experimentalFactor String = 113
  optional nuclAcidExt String = 114
  optional sampVolWeDnaExt QuantityValue = 115
  sampTaxonId String = 116
  optional negContType NegContTypeEnum = 117
  optional posContType String = 118
  optional subspecfGenLin String = 119
  optional extrachromElements Integer = 120
  optional sourceMatId String = 121
  optional bioticRelationship BioticRelationshipEnum = 122
  optional trophicLevel TrophicLevelEnum = 123
  optional relToOxygen RelToOxygenEnum = 124
  isolGrowthCondt String = 125
  optional sampCollecDevice String = 126
  optional sampCollecMethod String = 127
  optional sampMatProcess String = 128
  optional nuclAcidAmp String = 129
  targetGene String = 130
  optional targetSubfragment String = 131
  optional pcrPrimers String = 132
  optional pcrCond String = 133
  optional seqQualityCheck String = 134
  optional chimeraCheck String = 135
  optional associatedResource String = 136
  optional sop String = 137
 }
// Combinatorial checklist Metagenome or Environmental with environmental package food-human foods
message Food-humanFoodsMIMS
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  optional sampCollectDevice String = 11
  repeated organismCount OrganismCountEnum = 12
  optional spikeinCount SpikeinCountEnum = 13
  optional sampStorTemp QuantityValue = 14
  optional sampStorDur String = 15
  optional poolDnaExtracts String = 16
  optional sampStorLoc String = 17
  optional geneticMod String = 18
  repeated perturbation String = 19
  collSiteGeoFeat String = 20
  repeated foodProductType String = 21
  repeated iFSACCategory String = 22
  repeated fermChemAdd QuantityValue = 23
  repeated fermChemAddPerc String = 24
  optional fermHeadspaceOxy String = 25
  optional fermMedium String = 26
  optional fermPH Double = 27
  optional fermRelHumidity QuantityValue = 28
  optional fermTemp QuantityValue = 29
  optional fermTime String = 30
  optional fermVessel String = 31
  optional bacterialDensity QuantityValue = 32
  optional consFoodStorDur String = 33
  optional consFoodStorTemp String = 34
  optional consPurchDate Date = 35
  optional consQtyPurchased String = 36
  optional cultIsolDate Date = 37
  optional cultResult CultResultEnum = 38
  repeated cultResultOrg String = 39
  repeated cultTarget String = 40
  repeated dietaryClaimUse String = 41
  optional enrichmentProtocol String = 42
  repeated foodAdditive String = 43
  repeated foodAllergenLabel String = 44
  repeated foodContactSurf String = 45
  optional foodContainWrap String = 46
  repeated foodCookingProc String = 47
  repeated foodDisPoint String = 48
  repeated foodIngredient String = 49
  optional foodNameStatus String = 50
  optional foodOrigin String = 51
  optional foodPackCapacity QuantityValue = 52
  repeated foodPackIntegrity String = 53
  repeated foodPackMedium String = 54
  repeated foodPreservProc String = 55
  repeated foodPriorContact String = 56
  repeated foodProd String = 57
  repeated foodProdSynonym String = 58
  optional foodProductQual String = 59
  optional foodQualityDate String = 60
  optional foodSource String = 61
  optional foodTraceList FoodTraceListEnum = 62
  repeated foodTravMode String = 63
  repeated foodTravVehic String = 64
  repeated foodTreatProc String = 65
  repeated hACCPTerm String = 66
  repeated intendedConsumer String = 67
  optional libraryPrepKit String = 68
  repeated lotNumber String = 69
  optional microbCultMed String = 70
  optional microbStart String = 71
  optional microbStartCount MicrobStartCountEnum = 72
  optional microbStartInoc QuantityValue = 73
  optional microbStartPrep String = 74
  optional microbStartSource String = 75
  optional microbStartTaxID String = 76
  repeated nuclAcidExtKit String = 77
  optional numSampCollect QuantityValue = 78
  repeated partPlantAnimal String = 79
  repeated repositoryName String = 80
  optional sampleCollecMethod String = 81
  repeated sampPooling String = 82
  optional sampRepBiol QuantityValue = 83
  optional sampRepTech QuantityValue = 84
  optional sampSourceMatCat String = 85
  optional sampStorDevice String = 86
  optional sampStorMedia String = 87
  optional sampTransportCont SampTransportContEnum = 88
  optional sampTransportDur QuantityValue = 89
  optional sampTransportTemp String = 90
  optional sampPurpose String = 91
  optional sequencingKit String = 92
  optional sequencingLocation String = 93
  repeated serovarOrSerotype String = 94
  repeated spikeinAMR String = 95
  repeated spikeinAntibiotic String = 96
  repeated spikeinGrowthMed String = 97
  repeated spikeinMetal String = 98
  repeated spikeinOrg String = 99
  repeated spikeinSerovar String = 100
  repeated spikeinStrain String = 101
  repeated studyDesign String = 102
  optional studyIncDur QuantityValue = 103
  optional studyIncTemp QuantityValue = 104
  optional studyTimecourse QuantityValue = 105
  repeated studyTmnt String = 106
  optional timepoint Double = 107
  repeated miscParam String = 108
  sampName String = 109
  projectName String = 110
  seqMeth String = 111
  optional sampSize QuantityValue = 112
  optional experimentalFactor String = 113
  optional nuclAcidExt String = 114
  optional sampVolWeDnaExt QuantityValue = 115
  sampTaxonId String = 116
  optional negContType NegContTypeEnum = 117
  optional posContType String = 118
  optional refBiomaterial String = 119
  optional sourceMatId String = 120
  optional relToOxygen RelToOxygenEnum = 121
  optional sampCollecDevice String = 122
  optional sampCollecMethod String = 123
  optional sampMatProcess String = 124
  optional sizeFrac String = 125
  optional nuclAcidAmp String = 126
  optional libSize Integer = 127
  optional libReadsSeqd Integer = 128
  optional libLayout LibLayoutEnum = 129
  optional libVector String = 130
  optional libScreen String = 131
  optional mid String = 132
  optional adapters String = 133
  optional assemblyQual AssemblyQualEnum = 134
  optional assemblyName String = 135
  optional assemblySoftware String = 136
  optional annot String = 137
  optional numberContig Integer = 138
  optional featPred String = 139
  optional refDb String = 140
  optional simSearchMeth String = 141
  optional taxClass String = 142
  optional associatedResource String = 143
  optional sop String = 144
 }
// Combinatorial checklist Minimum Information About a Single Amplified Genome with environmental package food-human foods
message Food-humanFoodsMISAG
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  optional sampCollectDevice String = 11
  repeated organismCount OrganismCountEnum = 12
  optional spikeinCount SpikeinCountEnum = 13
  optional sampStorTemp QuantityValue = 14
  optional sampStorDur String = 15
  optional poolDnaExtracts String = 16
  optional sampStorLoc String = 17
  optional geneticMod String = 18
  repeated perturbation String = 19
  collSiteGeoFeat String = 20
  repeated foodProductType String = 21
  repeated iFSACCategory String = 22
  repeated fermChemAdd QuantityValue = 23
  repeated fermChemAddPerc String = 24
  optional fermHeadspaceOxy String = 25
  optional fermMedium String = 26
  optional fermPH Double = 27
  optional fermRelHumidity QuantityValue = 28
  optional fermTemp QuantityValue = 29
  optional fermTime String = 30
  optional fermVessel String = 31
  optional bacterialDensity QuantityValue = 32
  optional consFoodStorDur String = 33
  optional consFoodStorTemp String = 34
  optional consPurchDate Date = 35
  optional consQtyPurchased String = 36
  optional cultIsolDate Date = 37
  optional cultResult CultResultEnum = 38
  repeated cultResultOrg String = 39
  repeated cultTarget String = 40
  repeated dietaryClaimUse String = 41
  optional enrichmentProtocol String = 42
  repeated foodAdditive String = 43
  repeated foodAllergenLabel String = 44
  repeated foodContactSurf String = 45
  optional foodContainWrap String = 46
  repeated foodCookingProc String = 47
  repeated foodDisPoint String = 48
  repeated foodIngredient String = 49
  optional foodNameStatus String = 50
  optional foodOrigin String = 51
  optional foodPackCapacity QuantityValue = 52
  repeated foodPackIntegrity String = 53
  repeated foodPackMedium String = 54
  repeated foodPreservProc String = 55
  repeated foodPriorContact String = 56
  repeated foodProd String = 57
  repeated foodProdSynonym String = 58
  optional foodProductQual String = 59
  optional foodQualityDate String = 60
  optional foodSource String = 61
  optional foodTraceList FoodTraceListEnum = 62
  repeated foodTravMode String = 63
  repeated foodTravVehic String = 64
  repeated foodTreatProc String = 65
  repeated hACCPTerm String = 66
  repeated intendedConsumer String = 67
  optional libraryPrepKit String = 68
  repeated lotNumber String = 69
  optional microbCultMed String = 70
  optional microbStart String = 71
  optional microbStartCount MicrobStartCountEnum = 72
  optional microbStartInoc QuantityValue = 73
  optional microbStartPrep String = 74
  optional microbStartSource String = 75
  optional microbStartTaxID String = 76
  repeated nuclAcidExtKit String = 77
  optional numSampCollect QuantityValue = 78
  repeated partPlantAnimal String = 79
  repeated repositoryName String = 80
  optional sampleCollecMethod String = 81
  repeated sampPooling String = 82
  optional sampRepBiol QuantityValue = 83
  optional sampRepTech QuantityValue = 84
  optional sampSourceMatCat String = 85
  optional sampStorDevice String = 86
  optional sampStorMedia String = 87
  optional sampTransportCont SampTransportContEnum = 88
  optional sampTransportDur QuantityValue = 89
  optional sampTransportTemp String = 90
  optional sampPurpose String = 91
  optional sequencingKit String = 92
  optional sequencingLocation String = 93
  repeated serovarOrSerotype String = 94
  repeated spikeinAMR String = 95
  repeated spikeinAntibiotic String = 96
  repeated spikeinGrowthMed String = 97
  repeated spikeinMetal String = 98
  repeated spikeinOrg String = 99
  repeated spikeinSerovar String = 100
  repeated spikeinStrain String = 101
  repeated studyDesign String = 102
  optional studyIncDur QuantityValue = 103
  optional studyIncTemp QuantityValue = 104
  optional studyTimecourse QuantityValue = 105
  repeated studyTmnt String = 106
  optional timepoint Double = 107
  repeated miscParam String = 108
  sampName String = 109
  projectName String = 110
  seqMeth String = 111
  optional sampSize QuantityValue = 112
  optional experimentalFactor String = 113
  optional nuclAcidExt String = 114
  optional sampVolWeDnaExt QuantityValue = 115
  sampTaxonId String = 116
  optional negContType NegContTypeEnum = 117
  optional posContType String = 118
  optional refBiomaterial String = 119
  optional sourceMatId String = 120
  optional relToOxygen RelToOxygenEnum = 121
  optional sampCollecDevice String = 122
  optional sampCollecMethod String = 123
  optional sampMatProcess String = 124
  optional sizeFrac String = 125
  optional nuclAcidAmp String = 126
  optional libSize Integer = 127
  optional libReadsSeqd Integer = 128
  optional libLayout LibLayoutEnum = 129
  optional libVector String = 130
  optional libScreen String = 131
  optional mid String = 132
  optional adapters String = 133
  taxIdent TaxIdentEnum = 134
  assemblyQual AssemblyQualEnum = 135
  optional assemblyName String = 136
  assemblySoftware String = 137
  optional annot String = 138
  optional numberContig Integer = 139
  optional featPred String = 140
  optional refDb String = 141
  optional simSearchMeth String = 142
  optional taxClass String = 143
  optional x16sRecover String = 144
  optional x16sRecoverSoftware String = 145
  optional trnas Integer = 146
  optional trnaExtSoftware String = 147
  complScore String = 148
  complSoftware String = 149
  optional complAppr ComplApprEnum = 150
  contamScore String = 151
  optional contamScreenInput String = 152
  optional contamScreenParam String = 153
  optional decontamSoftware DecontamSoftwareEnum = 154
  sortTech SortTechEnum = 155
  singleCellLysisAppr SingleCellLysisApprEnum = 156
  optional singleCellLysisProt String = 157
  wgaAmpAppr String = 158
  optional wgaAmpKit String = 159
  optional associatedResource String = 160
  optional sop String = 161
 }
// Combinatorial checklist Minimum Information About an Uncultivated Virus Genome with environmental package food-human foods
message Food-humanFoodsMIUVIG
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  optional sampCollectDevice String = 11
  repeated organismCount OrganismCountEnum = 12
  optional spikeinCount SpikeinCountEnum = 13
  optional sampStorTemp QuantityValue = 14
  optional sampStorDur String = 15
  optional poolDnaExtracts String = 16
  optional sampStorLoc String = 17
  optional geneticMod String = 18
  repeated perturbation String = 19
  collSiteGeoFeat String = 20
  repeated foodProductType String = 21
  repeated iFSACCategory String = 22
  repeated fermChemAdd QuantityValue = 23
  repeated fermChemAddPerc String = 24
  optional fermHeadspaceOxy String = 25
  optional fermMedium String = 26
  optional fermPH Double = 27
  optional fermRelHumidity QuantityValue = 28
  optional fermTemp QuantityValue = 29
  optional fermTime String = 30
  optional fermVessel String = 31
  optional bacterialDensity QuantityValue = 32
  optional consFoodStorDur String = 33
  optional consFoodStorTemp String = 34
  optional consPurchDate Date = 35
  optional consQtyPurchased String = 36
  optional cultIsolDate Date = 37
  optional cultResult CultResultEnum = 38
  repeated cultResultOrg String = 39
  repeated cultTarget String = 40
  repeated dietaryClaimUse String = 41
  optional enrichmentProtocol String = 42
  repeated foodAdditive String = 43
  repeated foodAllergenLabel String = 44
  repeated foodContactSurf String = 45
  optional foodContainWrap String = 46
  repeated foodCookingProc String = 47
  repeated foodDisPoint String = 48
  repeated foodIngredient String = 49
  optional foodNameStatus String = 50
  optional foodOrigin String = 51
  optional foodPackCapacity QuantityValue = 52
  repeated foodPackIntegrity String = 53
  repeated foodPackMedium String = 54
  repeated foodPreservProc String = 55
  repeated foodPriorContact String = 56
  repeated foodProd String = 57
  repeated foodProdSynonym String = 58
  optional foodProductQual String = 59
  optional foodQualityDate String = 60
  optional foodSource String = 61
  optional foodTraceList FoodTraceListEnum = 62
  repeated foodTravMode String = 63
  repeated foodTravVehic String = 64
  repeated foodTreatProc String = 65
  repeated hACCPTerm String = 66
  repeated intendedConsumer String = 67
  optional libraryPrepKit String = 68
  repeated lotNumber String = 69
  optional microbCultMed String = 70
  optional microbStart String = 71
  optional microbStartCount MicrobStartCountEnum = 72
  optional microbStartInoc QuantityValue = 73
  optional microbStartPrep String = 74
  optional microbStartSource String = 75
  optional microbStartTaxID String = 76
  repeated nuclAcidExtKit String = 77
  optional numSampCollect QuantityValue = 78
  repeated partPlantAnimal String = 79
  repeated repositoryName String = 80
  optional sampleCollecMethod String = 81
  repeated sampPooling String = 82
  optional sampRepBiol QuantityValue = 83
  optional sampRepTech QuantityValue = 84
  optional sampSourceMatCat String = 85
  optional sampStorDevice String = 86
  optional sampStorMedia String = 87
  optional sampTransportCont SampTransportContEnum = 88
  optional sampTransportDur QuantityValue = 89
  optional sampTransportTemp String = 90
  optional sampPurpose String = 91
  optional sequencingKit String = 92
  optional sequencingLocation String = 93
  repeated serovarOrSerotype String = 94
  repeated spikeinAMR String = 95
  repeated spikeinAntibiotic String = 96
  repeated spikeinGrowthMed String = 97
  repeated spikeinMetal String = 98
  repeated spikeinOrg String = 99
  repeated spikeinSerovar String = 100
  repeated spikeinStrain String = 101
  repeated studyDesign String = 102
  optional studyIncDur QuantityValue = 103
  optional studyIncTemp QuantityValue = 104
  optional studyTimecourse QuantityValue = 105
  repeated studyTmnt String = 106
  optional timepoint Double = 107
  repeated miscParam String = 108
  sampName String = 109
  projectName String = 110
  seqMeth String = 111
  optional sampSize QuantityValue = 112
  optional experimentalFactor String = 113
  optional nuclAcidExt String = 114
  optional sampVolWeDnaExt QuantityValue = 115
  sampTaxonId String = 116
  optional negContType NegContTypeEnum = 117
  optional posContType String = 118
  optional estimatedSize String = 119
  optional refBiomaterial String = 120
  optional sourceMatId String = 121
  optional pathogenicity String = 122
  optional bioticRelationship BioticRelationshipEnum = 123
  optional specificHost String = 124
  optional hostSpecRange Integer = 125
  optional hostDiseaseStat String = 126
  optional sampCollecDevice String = 127
  optional sampCollecMethod String = 128
  optional sampMatProcess String = 129
  optional sizeFrac String = 130
  sourceUvig SourceUvigEnum = 131
  virusEnrichAppr VirusEnrichApprEnum = 132
  optional nuclAcidAmp String = 133
  optional libSize Integer = 134
  optional libReadsSeqd Integer = 135
  optional libLayout LibLayoutEnum = 136
  optional libVector String = 137
  optional libScreen String = 138
  optional mid String = 139
  optional adapters String = 140
  optional taxIdent TaxIdentEnum = 141
  assemblyQual AssemblyQualEnum = 142
  optional assemblyName String = 143
  assemblySoftware String = 144
  optional annot String = 145
  numberContig Integer = 146
  optional featPred String = 147
  optional refDb String = 148
  optional simSearchMeth String = 149
  optional taxClass String = 150
  optional trnas Integer = 151
  optional trnaExtSoftware String = 152
  optional complScore String = 153
  optional complSoftware String = 154
  optional complAppr ComplApprEnum = 155
  optional sortTech SortTechEnum = 156
  optional singleCellLysisAppr SingleCellLysisApprEnum = 157
  optional singleCellLysisProt String = 158
  optional wgaAmpAppr String = 159
  optional wgaAmpKit String = 160
  optional binParam BinParamEnum = 161
  optional binSoftware String = 162
  optional reassemblyBin String = 163
  optional magCovSoftware MagCovSoftwareEnum = 164
  virIdentSoftware String = 165
  predGenomeType PredGenomeTypeEnum = 166
  predGenomeStruc PredGenomeStrucEnum = 167
  detecType String = 168
  optional otuClassAppr String = 169
  optional otuSeqCompAppr String = 170
  optional otuDb String = 171
  optional hostPredAppr HostPredApprEnum = 172
  optional hostPredEstAcc String = 173
  optional associatedResource String = 174
  optional sop String = 175
 }
// host-associated
message Host-associated
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional ancesData String = 11
  optional biolStat BiolStatEnum = 12
  optional geneticMod String = 13
  optional hostCommonName String = 14
  optional sampCaptStatus SampCaptStatusEnum = 15
  optional sampDisStage SampDisStageEnum = 16
  optional hostTaxid String = 17
  optional hostSubjectId String = 18
  optional hostAge QuantityValue = 19
  optional hostLifeStage String = 20
  optional hostSex HostSexEnum = 21
  repeated chemAdministration String = 22
  optional hostBodyHabitat String = 23
  optional hostBodySite String = 24
  optional hostBodyProduct String = 25
  optional hostTotMass QuantityValue = 26
  optional hostHeight QuantityValue = 27
  optional hostLength QuantityValue = 28
  repeated hostDiet String = 29
  repeated hostLastMeal String = 30
  optional hostGrowthCond String = 31
  optional hostSubstrate String = 32
  repeated hostFamilyRelation String = 33
  repeated hostSubspecfGenlin String = 34
  optional hostGenotype String = 35
  optional hostPhenotype String = 36
  optional hostBodyTemp QuantityValue = 37
  optional hostDryMass QuantityValue = 38
  optional bloodPressDiast QuantityValue = 39
  optional bloodPressSyst QuantityValue = 40
  optional hostColor String = 41
  optional hostShape String = 42
  optional gravidity String = 43
  repeated perturbation String = 44
  optional salinity QuantityValue = 45
  optional oxyStatSamp OxyStatSampEnum = 46
  repeated organismCount OrganismCountEnum = 47
  optional sampStoreTemp QuantityValue = 48
  optional sampStoreDur String = 49
  optional sampStoreLoc String = 50
  repeated hostSymbiont String = 51
  repeated miscParam String = 52
  sampName String = 53
  projectName String = 54
  optional hostDiseaseStat String = 55
  optional sampVolWeDnaExt QuantityValue = 56
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package host-associated
message Host-associatedMIGSBacteria
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional ancesData String = 11
  optional biolStat BiolStatEnum = 12
  optional geneticMod String = 13
  optional hostCommonName String = 14
  optional sampCaptStatus SampCaptStatusEnum = 15
  optional sampDisStage SampDisStageEnum = 16
  optional hostTaxid String = 17
  optional hostSubjectId String = 18
  optional hostAge QuantityValue = 19
  optional hostLifeStage String = 20
  optional hostSex HostSexEnum = 21
  repeated chemAdministration String = 22
  optional hostBodyHabitat String = 23
  optional hostBodySite String = 24
  optional hostBodyProduct String = 25
  optional hostTotMass QuantityValue = 26
  optional hostHeight QuantityValue = 27
  optional hostLength QuantityValue = 28
  repeated hostDiet String = 29
  repeated hostLastMeal String = 30
  optional hostGrowthCond String = 31
  optional hostSubstrate String = 32
  repeated hostFamilyRelation String = 33
  repeated hostSubspecfGenlin String = 34
  optional hostGenotype String = 35
  optional hostPhenotype String = 36
  optional hostBodyTemp QuantityValue = 37
  optional hostDryMass QuantityValue = 38
  optional bloodPressDiast QuantityValue = 39
  optional bloodPressSyst QuantityValue = 40
  optional hostColor String = 41
  optional hostShape String = 42
  optional gravidity String = 43
  repeated perturbation String = 44
  optional salinity QuantityValue = 45
  optional oxyStatSamp OxyStatSampEnum = 46
  repeated organismCount OrganismCountEnum = 47
  optional sampStoreTemp QuantityValue = 48
  optional sampStoreDur String = 49
  optional sampStoreLoc String = 50
  repeated hostSymbiont String = 51
  repeated miscParam String = 52
  sampName String = 53
  projectName String = 54
  optional hostDiseaseStat String = 55
  optional sampVolWeDnaExt QuantityValue = 56
  sampTaxonId String = 57
  optional experimentalFactor String = 58
  optional negContType NegContTypeEnum = 59
  optional posContType String = 60
  optional subspecfGenLin String = 61
  numReplicons Integer = 62
  optional extrachromElements Integer = 63
  optional estimatedSize String = 64
  refBiomaterial String = 65
  optional sourceMatId String = 66
  optional pathogenicity String = 67
  optional bioticRelationship BioticRelationshipEnum = 68
  optional specificHost String = 69
  optional hostSpecRange Integer = 70
  optional trophicLevel TrophicLevelEnum = 71
  optional encodedTraits String = 72
  optional relToOxygen RelToOxygenEnum = 73
  isolGrowthCondt String = 74
  optional sampCollecDevice String = 75
  optional sampCollecMethod String = 76
  optional sampMatProcess String = 77
  optional sampSize QuantityValue = 78
  optional nuclAcidExt String = 79
  optional nuclAcidAmp String = 80
  optional libSize Integer = 81
  optional libReadsSeqd Integer = 82
  optional libLayout LibLayoutEnum = 83
  optional libVector String = 84
  optional libScreen String = 85
  optional adapters String = 86
  seqMeth String = 87
  optional taxIdent TaxIdentEnum = 88
  assemblyQual AssemblyQualEnum = 89
  optional assemblyName String = 90
  assemblySoftware String = 91
  optional annot String = 92
  numberContig Integer = 93
  optional featPred String = 94
  optional refDb String = 95
  optional simSearchMeth String = 96
  optional taxClass String = 97
  optional complScore String = 98
  optional complSoftware String = 99
  optional associatedResource String = 100
  optional sop String = 101
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: eukaryote with environmental package host-associated
message Host-associatedMIGSEukaryote
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional ancesData String = 11
  optional biolStat BiolStatEnum = 12
  optional geneticMod String = 13
  optional hostCommonName String = 14
  optional sampCaptStatus SampCaptStatusEnum = 15
  optional sampDisStage SampDisStageEnum = 16
  optional hostTaxid String = 17
  optional hostSubjectId String = 18
  optional hostAge QuantityValue = 19
  optional hostLifeStage String = 20
  optional hostSex HostSexEnum = 21
  repeated chemAdministration String = 22
  optional hostBodyHabitat String = 23
  optional hostBodySite String = 24
  optional hostBodyProduct String = 25
  optional hostTotMass QuantityValue = 26
  optional hostHeight QuantityValue = 27
  optional hostLength QuantityValue = 28
  repeated hostDiet String = 29
  repeated hostLastMeal String = 30
  optional hostGrowthCond String = 31
  optional hostSubstrate String = 32
  repeated hostFamilyRelation String = 33
  repeated hostSubspecfGenlin String = 34
  optional hostGenotype String = 35
  optional hostPhenotype String = 36
  optional hostBodyTemp QuantityValue = 37
  optional hostDryMass QuantityValue = 38
  optional bloodPressDiast QuantityValue = 39
  optional bloodPressSyst QuantityValue = 40
  optional hostColor String = 41
  optional hostShape String = 42
  optional gravidity String = 43
  repeated perturbation String = 44
  optional salinity QuantityValue = 45
  optional oxyStatSamp OxyStatSampEnum = 46
  repeated organismCount OrganismCountEnum = 47
  optional sampStoreTemp QuantityValue = 48
  optional sampStoreDur String = 49
  optional sampStoreLoc String = 50
  repeated hostSymbiont String = 51
  repeated miscParam String = 52
  sampName String = 53
  projectName String = 54
  optional hostDiseaseStat String = 55
  optional sampVolWeDnaExt QuantityValue = 56
  sampTaxonId String = 57
  optional experimentalFactor String = 58
  optional negContType NegContTypeEnum = 59
  optional posContType String = 60
  optional subspecfGenLin String = 61
  optional ploidy String = 62
  optional numReplicons Integer = 63
  optional extrachromElements Integer = 64
  optional estimatedSize String = 65
  optional refBiomaterial String = 66
  optional sourceMatId String = 67
  optional pathogenicity String = 68
  optional bioticRelationship BioticRelationshipEnum = 69
  optional specificHost String = 70
  optional hostSpecRange Integer = 71
  optional trophicLevel TrophicLevelEnum = 72
  optional propagation String = 73
  isolGrowthCondt String = 74
  optional sampCollecDevice String = 75
  optional sampCollecMethod String = 76
  optional sampMatProcess String = 77
  optional sampSize QuantityValue = 78
  optional nuclAcidExt String = 79
  optional nuclAcidAmp String = 80
  optional libSize Integer = 81
  optional libReadsSeqd Integer = 82
  optional libLayout LibLayoutEnum = 83
  optional libVector String = 84
  optional libScreen String = 85
  optional adapters String = 86
  seqMeth String = 87
  optional taxIdent TaxIdentEnum = 88
  assemblyQual AssemblyQualEnum = 89
  optional assemblyName String = 90
  assemblySoftware String = 91
  optional annot String = 92
  numberContig Integer = 93
  optional featPred String = 94
  optional refDb String = 95
  optional simSearchMeth String = 96
  optional taxClass String = 97
  optional complScore String = 98
  optional complSoftware String = 99
  optional associatedResource String = 100
  optional sop String = 101
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: org with environmental package host-associated
message Host-associatedMIGSOrg
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional ancesData String = 11
  optional biolStat BiolStatEnum = 12
  optional geneticMod String = 13
  optional hostCommonName String = 14
  optional sampCaptStatus SampCaptStatusEnum = 15
  optional sampDisStage SampDisStageEnum = 16
  optional hostTaxid String = 17
  optional hostSubjectId String = 18
  optional hostAge QuantityValue = 19
  optional hostLifeStage String = 20
  optional hostSex HostSexEnum = 21
  repeated chemAdministration String = 22
  optional hostBodyHabitat String = 23
  optional hostBodySite String = 24
  optional hostBodyProduct String = 25
  optional hostTotMass QuantityValue = 26
  optional hostHeight QuantityValue = 27
  optional hostLength QuantityValue = 28
  repeated hostDiet String = 29
  repeated hostLastMeal String = 30
  optional hostGrowthCond String = 31
  optional hostSubstrate String = 32
  repeated hostFamilyRelation String = 33
  repeated hostSubspecfGenlin String = 34
  optional hostGenotype String = 35
  optional hostPhenotype String = 36
  optional hostBodyTemp QuantityValue = 37
  optional hostDryMass QuantityValue = 38
  optional bloodPressDiast QuantityValue = 39
  optional bloodPressSyst QuantityValue = 40
  optional hostColor String = 41
  optional hostShape String = 42
  optional gravidity String = 43
  repeated perturbation String = 44
  optional salinity QuantityValue = 45
  optional oxyStatSamp OxyStatSampEnum = 46
  repeated organismCount OrganismCountEnum = 47
  optional sampStoreTemp QuantityValue = 48
  optional sampStoreDur String = 49
  optional sampStoreLoc String = 50
  repeated hostSymbiont String = 51
  repeated miscParam String = 52
  sampName String = 53
  projectName String = 54
  optional hostDiseaseStat String = 55
  optional sampVolWeDnaExt QuantityValue = 56
  sampTaxonId String = 57
  optional experimentalFactor String = 58
  optional negContType NegContTypeEnum = 59
  optional posContType String = 60
  optional subspecfGenLin String = 61
  optional extrachromElements Integer = 62
  optional estimatedSize String = 63
  optional refBiomaterial String = 64
  optional sourceMatId String = 65
  isolGrowthCondt String = 66
  optional sampCollecDevice String = 67
  optional sampCollecMethod String = 68
  optional sampMatProcess String = 69
  optional sampSize QuantityValue = 70
  optional nuclAcidExt String = 71
  optional nuclAcidAmp String = 72
  optional libSize Integer = 73
  optional libReadsSeqd Integer = 74
  optional libLayout LibLayoutEnum = 75
  optional libVector String = 76
  optional libScreen String = 77
  optional adapters String = 78
  seqMeth String = 79
  optional taxIdent TaxIdentEnum = 80
  optional assemblyQual AssemblyQualEnum = 81
  optional assemblyName String = 82
  assemblySoftware String = 83
  optional annot String = 84
  optional numberContig Integer = 85
  optional featPred String = 86
  optional refDb String = 87
  optional simSearchMeth String = 88
  optional taxClass String = 89
  optional complScore String = 90
  optional complSoftware String = 91
  optional associatedResource String = 92
  optional sop String = 93
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: plant with environmental package host-associated
message Host-associatedMIGSPlant
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional ancesData String = 11
  optional biolStat BiolStatEnum = 12
  optional geneticMod String = 13
  optional hostCommonName String = 14
  optional sampCaptStatus SampCaptStatusEnum = 15
  optional sampDisStage SampDisStageEnum = 16
  optional hostTaxid String = 17
  optional hostSubjectId String = 18
  optional hostAge QuantityValue = 19
  optional hostLifeStage String = 20
  optional hostSex HostSexEnum = 21
  repeated chemAdministration String = 22
  optional hostBodyHabitat String = 23
  optional hostBodySite String = 24
  optional hostBodyProduct String = 25
  optional hostTotMass QuantityValue = 26
  optional hostHeight QuantityValue = 27
  optional hostLength QuantityValue = 28
  repeated hostDiet String = 29
  repeated hostLastMeal String = 30
  optional hostGrowthCond String = 31
  optional hostSubstrate String = 32
  repeated hostFamilyRelation String = 33
  repeated hostSubspecfGenlin String = 34
  optional hostGenotype String = 35
  optional hostPhenotype String = 36
  optional hostBodyTemp QuantityValue = 37
  optional hostDryMass QuantityValue = 38
  optional bloodPressDiast QuantityValue = 39
  optional bloodPressSyst QuantityValue = 40
  optional hostColor String = 41
  optional hostShape String = 42
  optional gravidity String = 43
  repeated perturbation String = 44
  optional salinity QuantityValue = 45
  optional oxyStatSamp OxyStatSampEnum = 46
  repeated organismCount OrganismCountEnum = 47
  optional sampStoreTemp QuantityValue = 48
  optional sampStoreDur String = 49
  optional sampStoreLoc String = 50
  repeated hostSymbiont String = 51
  repeated miscParam String = 52
  sampName String = 53
  projectName String = 54
  optional hostDiseaseStat String = 55
  optional sampVolWeDnaExt QuantityValue = 56
  sampTaxonId String = 57
  optional experimentalFactor String = 58
  optional negContType NegContTypeEnum = 59
  optional posContType String = 60
  optional subspecfGenLin String = 61
  optional estimatedSize String = 62
  optional refBiomaterial String = 63
  optional sourceMatId String = 64
  optional specificHost String = 65
  optional hostSpecRange Integer = 66
  propagation String = 67
  optional encodedTraits String = 68
  isolGrowthCondt String = 69
  optional sampCollecDevice String = 70
  optional sampCollecMethod String = 71
  optional sampMatProcess String = 72
  optional sampSize QuantityValue = 73
  optional nuclAcidExt String = 74
  optional nuclAcidAmp String = 75
  optional libSize Integer = 76
  optional libReadsSeqd Integer = 77
  optional libLayout LibLayoutEnum = 78
  optional libVector String = 79
  optional libScreen String = 80
  optional adapters String = 81
  seqMeth String = 82
  optional taxIdent TaxIdentEnum = 83
  optional assemblyQual AssemblyQualEnum = 84
  optional assemblyName String = 85
  assemblySoftware String = 86
  optional annot String = 87
  optional numberContig Integer = 88
  optional featPred String = 89
  optional refDb String = 90
  optional simSearchMeth String = 91
  optional taxClass String = 92
  optional complScore String = 93
  optional complSoftware String = 94
  optional associatedResource String = 95
  optional sop String = 96
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package host-associated
message Host-associatedMIGSVirus
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional ancesData String = 11
  optional biolStat BiolStatEnum = 12
  optional geneticMod String = 13
  optional hostCommonName String = 14
  optional sampCaptStatus SampCaptStatusEnum = 15
  optional sampDisStage SampDisStageEnum = 16
  optional hostTaxid String = 17
  optional hostSubjectId String = 18
  optional hostAge QuantityValue = 19
  optional hostLifeStage String = 20
  optional hostSex HostSexEnum = 21
  repeated chemAdministration String = 22
  optional hostBodyHabitat String = 23
  optional hostBodySite String = 24
  optional hostBodyProduct String = 25
  optional hostTotMass QuantityValue = 26
  optional hostHeight QuantityValue = 27
  optional hostLength QuantityValue = 28
  repeated hostDiet String = 29
  repeated hostLastMeal String = 30
  optional hostGrowthCond String = 31
  optional hostSubstrate String = 32
  repeated hostFamilyRelation String = 33
  repeated hostSubspecfGenlin String = 34
  optional hostGenotype String = 35
  optional hostPhenotype String = 36
  optional hostBodyTemp QuantityValue = 37
  optional hostDryMass QuantityValue = 38
  optional bloodPressDiast QuantityValue = 39
  optional bloodPressSyst QuantityValue = 40
  optional hostColor String = 41
  optional hostShape String = 42
  optional gravidity String = 43
  repeated perturbation String = 44
  optional salinity QuantityValue = 45
  optional oxyStatSamp OxyStatSampEnum = 46
  repeated organismCount OrganismCountEnum = 47
  optional sampStoreTemp QuantityValue = 48
  optional sampStoreDur String = 49
  optional sampStoreLoc String = 50
  repeated hostSymbiont String = 51
  repeated miscParam String = 52
  sampName String = 53
  projectName String = 54
  optional hostDiseaseStat String = 55
  optional sampVolWeDnaExt QuantityValue = 56
  sampTaxonId String = 57
  optional experimentalFactor String = 58
  optional negContType NegContTypeEnum = 59
  optional posContType String = 60
  optional subspecfGenLin String = 61
  optional numReplicons Integer = 62
  optional estimatedSize String = 63
  optional refBiomaterial String = 64
  optional sourceMatId String = 65
  optional pathogenicity String = 66
  optional bioticRelationship BioticRelationshipEnum = 67
  optional specificHost String = 68
  optional hostSpecRange Integer = 69
  propagation String = 70
  optional encodedTraits String = 71
  isolGrowthCondt String = 72
  optional sampCollecDevice String = 73
  optional sampCollecMethod String = 74
  optional sampMatProcess String = 75
  optional sampSize QuantityValue = 76
  optional virusEnrichAppr VirusEnrichApprEnum = 77
  optional nuclAcidExt String = 78
  optional nuclAcidAmp String = 79
  optional libSize Integer = 80
  optional libReadsSeqd Integer = 81
  optional libLayout LibLayoutEnum = 82
  optional libVector String = 83
  optional libScreen String = 84
  optional adapters String = 85
  seqMeth String = 86
  optional taxIdent TaxIdentEnum = 87
  optional assemblyQual AssemblyQualEnum = 88
  optional assemblyName String = 89
  assemblySoftware String = 90
  optional annot String = 91
  optional numberContig Integer = 92
  optional featPred String = 93
  optional refDb String = 94
  optional simSearchMeth String = 95
  optional taxClass String = 96
  optional complScore String = 97
  optional complSoftware String = 98
  optional associatedResource String = 99
  optional sop String = 100
 }
// Combinatorial checklist Minimum Information About a Metagenome-Assembled Genome with environmental package host-associated
message Host-associatedMIMAG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional ancesData String = 11
  optional biolStat BiolStatEnum = 12
  optional geneticMod String = 13
  optional hostCommonName String = 14
  optional sampCaptStatus SampCaptStatusEnum = 15
  optional sampDisStage SampDisStageEnum = 16
  optional hostTaxid String = 17
  optional hostSubjectId String = 18
  optional hostAge QuantityValue = 19
  optional hostLifeStage String = 20
  optional hostSex HostSexEnum = 21
  repeated chemAdministration String = 22
  optional hostBodyHabitat String = 23
  optional hostBodySite String = 24
  optional hostBodyProduct String = 25
  optional hostTotMass QuantityValue = 26
  optional hostHeight QuantityValue = 27
  optional hostLength QuantityValue = 28
  repeated hostDiet String = 29
  repeated hostLastMeal String = 30
  optional hostGrowthCond String = 31
  optional hostSubstrate String = 32
  repeated hostFamilyRelation String = 33
  repeated hostSubspecfGenlin String = 34
  optional hostGenotype String = 35
  optional hostPhenotype String = 36
  optional hostBodyTemp QuantityValue = 37
  optional hostDryMass QuantityValue = 38
  optional bloodPressDiast QuantityValue = 39
  optional bloodPressSyst QuantityValue = 40
  optional hostColor String = 41
  optional hostShape String = 42
  optional gravidity String = 43
  repeated perturbation String = 44
  optional salinity QuantityValue = 45
  optional oxyStatSamp OxyStatSampEnum = 46
  repeated organismCount OrganismCountEnum = 47
  optional sampStoreTemp QuantityValue = 48
  optional sampStoreDur String = 49
  optional sampStoreLoc String = 50
  repeated hostSymbiont String = 51
  repeated miscParam String = 52
  sampName String = 53
  projectName String = 54
  optional hostDiseaseStat String = 55
  optional sampVolWeDnaExt QuantityValue = 56
  sampTaxonId String = 57
  optional experimentalFactor String = 58
  optional negContType NegContTypeEnum = 59
  optional posContType String = 60
  optional refBiomaterial String = 61
  optional sourceMatId String = 62
  optional relToOxygen RelToOxygenEnum = 63
  optional sampCollecDevice String = 64
  optional sampCollecMethod String = 65
  optional sampMatProcess String = 66
  optional sizeFrac String = 67
  optional sampSize QuantityValue = 68
  optional nuclAcidExt String = 69
  optional nuclAcidAmp String = 70
  optional libSize Integer = 71
  optional libReadsSeqd Integer = 72
  optional libLayout LibLayoutEnum = 73
  optional libVector String = 74
  optional libScreen String = 75
  optional mid String = 76
  optional adapters String = 77
  seqMeth String = 78
  taxIdent TaxIdentEnum = 79
  assemblyQual AssemblyQualEnum = 80
  optional assemblyName String = 81
  assemblySoftware String = 82
  optional annot String = 83
  optional numberContig Integer = 84
  optional featPred String = 85
  optional refDb String = 86
  optional simSearchMeth String = 87
  optional taxClass String = 88
  optional x16sRecover String = 89
  optional x16sRecoverSoftware String = 90
  optional trnas Integer = 91
  optional trnaExtSoftware String = 92
  complScore String = 93
  complSoftware String = 94
  optional complAppr ComplApprEnum = 95
  contamScore String = 96
  optional contamScreenInput String = 97
  optional contamScreenParam String = 98
  optional decontamSoftware DecontamSoftwareEnum = 99
  binParam BinParamEnum = 100
  binSoftware String = 101
  optional reassemblyBin String = 102
  optional magCovSoftware MagCovSoftwareEnum = 103
  optional associatedResource String = 104
  optional sop String = 105
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: specimen with environmental package host-associated
message Host-associatedMIMARKSSpecimen
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional ancesData String = 11
  optional biolStat BiolStatEnum = 12
  optional geneticMod String = 13
  optional hostCommonName String = 14
  optional sampCaptStatus SampCaptStatusEnum = 15
  optional sampDisStage SampDisStageEnum = 16
  optional hostTaxid String = 17
  optional hostSubjectId String = 18
  optional hostAge QuantityValue = 19
  optional hostLifeStage String = 20
  optional hostSex HostSexEnum = 21
  repeated chemAdministration String = 22
  optional hostBodyHabitat String = 23
  optional hostBodySite String = 24
  optional hostBodyProduct String = 25
  optional hostTotMass QuantityValue = 26
  optional hostHeight QuantityValue = 27
  optional hostLength QuantityValue = 28
  repeated hostDiet String = 29
  repeated hostLastMeal String = 30
  optional hostGrowthCond String = 31
  optional hostSubstrate String = 32
  repeated hostFamilyRelation String = 33
  repeated hostSubspecfGenlin String = 34
  optional hostGenotype String = 35
  optional hostPhenotype String = 36
  optional hostBodyTemp QuantityValue = 37
  optional hostDryMass QuantityValue = 38
  optional bloodPressDiast QuantityValue = 39
  optional bloodPressSyst QuantityValue = 40
  optional hostColor String = 41
  optional hostShape String = 42
  optional gravidity String = 43
  repeated perturbation String = 44
  optional salinity QuantityValue = 45
  optional oxyStatSamp OxyStatSampEnum = 46
  repeated organismCount OrganismCountEnum = 47
  optional sampStoreTemp QuantityValue = 48
  optional sampStoreDur String = 49
  optional sampStoreLoc String = 50
  repeated hostSymbiont String = 51
  repeated miscParam String = 52
  sampName String = 53
  projectName String = 54
  optional hostDiseaseStat String = 55
  optional sampVolWeDnaExt QuantityValue = 56
  sampTaxonId String = 57
  optional experimentalFactor String = 58
  optional negContType NegContTypeEnum = 59
  optional posContType String = 60
  optional sourceMatId String = 61
  optional relToOxygen RelToOxygenEnum = 62
  optional sampCollecDevice String = 63
  optional sampCollecMethod String = 64
  optional sampMatProcess String = 65
  optional sizeFrac String = 66
  optional sampSize QuantityValue = 67
  optional nuclAcidExt String = 68
  optional nuclAcidAmp String = 69
  optional libSize Integer = 70
  optional libReadsSeqd Integer = 71
  optional libLayout LibLayoutEnum = 72
  optional libVector String = 73
  optional libScreen String = 74
  targetGene String = 75
  optional targetSubfragment String = 76
  optional pcrPrimers String = 77
  optional mid String = 78
  optional adapters String = 79
  optional pcrCond String = 80
  seqMeth String = 81
  optional seqQualityCheck String = 82
  optional chimeraCheck String = 83
  optional assemblySoftware String = 84
  optional associatedResource String = 85
  optional sop String = 86
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: survey with environmental package host-associated
message Host-associatedMIMARKSSurvey
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional ancesData String = 11
  optional biolStat BiolStatEnum = 12
  optional geneticMod String = 13
  optional hostCommonName String = 14
  optional sampCaptStatus SampCaptStatusEnum = 15
  optional sampDisStage SampDisStageEnum = 16
  optional hostTaxid String = 17
  optional hostSubjectId String = 18
  optional hostAge QuantityValue = 19
  optional hostLifeStage String = 20
  optional hostSex HostSexEnum = 21
  repeated chemAdministration String = 22
  optional hostBodyHabitat String = 23
  optional hostBodySite String = 24
  optional hostBodyProduct String = 25
  optional hostTotMass QuantityValue = 26
  optional hostHeight QuantityValue = 27
  optional hostLength QuantityValue = 28
  repeated hostDiet String = 29
  repeated hostLastMeal String = 30
  optional hostGrowthCond String = 31
  optional hostSubstrate String = 32
  repeated hostFamilyRelation String = 33
  repeated hostSubspecfGenlin String = 34
  optional hostGenotype String = 35
  optional hostPhenotype String = 36
  optional hostBodyTemp QuantityValue = 37
  optional hostDryMass QuantityValue = 38
  optional bloodPressDiast QuantityValue = 39
  optional bloodPressSyst QuantityValue = 40
  optional hostColor String = 41
  optional hostShape String = 42
  optional gravidity String = 43
  repeated perturbation String = 44
  optional salinity QuantityValue = 45
  optional oxyStatSamp OxyStatSampEnum = 46
  repeated organismCount OrganismCountEnum = 47
  optional sampStoreTemp QuantityValue = 48
  optional sampStoreDur String = 49
  optional sampStoreLoc String = 50
  repeated hostSymbiont String = 51
  repeated miscParam String = 52
  sampName String = 53
  projectName String = 54
  optional hostDiseaseStat String = 55
  optional sampVolWeDnaExt QuantityValue = 56
  sampTaxonId String = 57
  optional experimentalFactor String = 58
  optional negContType NegContTypeEnum = 59
  optional posContType String = 60
  optional subspecfGenLin String = 61
  optional extrachromElements Integer = 62
  optional sourceMatId String = 63
  optional bioticRelationship BioticRelationshipEnum = 64
  optional trophicLevel TrophicLevelEnum = 65
  optional relToOxygen RelToOxygenEnum = 66
  isolGrowthCondt String = 67
  optional sampCollecDevice String = 68
  optional sampCollecMethod String = 69
  optional sampMatProcess String = 70
  optional sampSize QuantityValue = 71
  optional nuclAcidExt String = 72
  optional nuclAcidAmp String = 73
  targetGene String = 74
  optional targetSubfragment String = 75
  optional pcrPrimers String = 76
  optional pcrCond String = 77
  seqMeth String = 78
  optional seqQualityCheck String = 79
  optional chimeraCheck String = 80
  optional associatedResource String = 81
  optional sop String = 82
 }
// Combinatorial checklist Metagenome or Environmental with environmental package host-associated
message Host-associatedMIMS
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional ancesData String = 11
  optional biolStat BiolStatEnum = 12
  optional geneticMod String = 13
  optional hostCommonName String = 14
  optional sampCaptStatus SampCaptStatusEnum = 15
  optional sampDisStage SampDisStageEnum = 16
  optional hostTaxid String = 17
  optional hostSubjectId String = 18
  optional hostAge QuantityValue = 19
  optional hostLifeStage String = 20
  optional hostSex HostSexEnum = 21
  repeated chemAdministration String = 22
  optional hostBodyHabitat String = 23
  optional hostBodySite String = 24
  optional hostBodyProduct String = 25
  optional hostTotMass QuantityValue = 26
  optional hostHeight QuantityValue = 27
  optional hostLength QuantityValue = 28
  repeated hostDiet String = 29
  repeated hostLastMeal String = 30
  optional hostGrowthCond String = 31
  optional hostSubstrate String = 32
  repeated hostFamilyRelation String = 33
  repeated hostSubspecfGenlin String = 34
  optional hostGenotype String = 35
  optional hostPhenotype String = 36
  optional hostBodyTemp QuantityValue = 37
  optional hostDryMass QuantityValue = 38
  optional bloodPressDiast QuantityValue = 39
  optional bloodPressSyst QuantityValue = 40
  optional hostColor String = 41
  optional hostShape String = 42
  optional gravidity String = 43
  repeated perturbation String = 44
  optional salinity QuantityValue = 45
  optional oxyStatSamp OxyStatSampEnum = 46
  repeated organismCount OrganismCountEnum = 47
  optional sampStoreTemp QuantityValue = 48
  optional sampStoreDur String = 49
  optional sampStoreLoc String = 50
  repeated hostSymbiont String = 51
  repeated miscParam String = 52
  sampName String = 53
  projectName String = 54
  optional hostDiseaseStat String = 55
  optional sampVolWeDnaExt QuantityValue = 56
  sampTaxonId String = 57
  optional experimentalFactor String = 58
  optional negContType NegContTypeEnum = 59
  optional posContType String = 60
  optional refBiomaterial String = 61
  optional sourceMatId String = 62
  optional relToOxygen RelToOxygenEnum = 63
  optional sampCollecDevice String = 64
  optional sampCollecMethod String = 65
  optional sampMatProcess String = 66
  optional sizeFrac String = 67
  optional sampSize QuantityValue = 68
  optional nuclAcidExt String = 69
  optional nuclAcidAmp String = 70
  optional libSize Integer = 71
  optional libReadsSeqd Integer = 72
  optional libLayout LibLayoutEnum = 73
  optional libVector String = 74
  optional libScreen String = 75
  optional mid String = 76
  optional adapters String = 77
  seqMeth String = 78
  optional assemblyQual AssemblyQualEnum = 79
  optional assemblyName String = 80
  optional assemblySoftware String = 81
  optional annot String = 82
  optional numberContig Integer = 83
  optional featPred String = 84
  optional refDb String = 85
  optional simSearchMeth String = 86
  optional taxClass String = 87
  optional associatedResource String = 88
  optional sop String = 89
 }
// Combinatorial checklist Minimum Information About a Single Amplified Genome with environmental package host-associated
message Host-associatedMISAG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional ancesData String = 11
  optional biolStat BiolStatEnum = 12
  optional geneticMod String = 13
  optional hostCommonName String = 14
  optional sampCaptStatus SampCaptStatusEnum = 15
  optional sampDisStage SampDisStageEnum = 16
  optional hostTaxid String = 17
  optional hostSubjectId String = 18
  optional hostAge QuantityValue = 19
  optional hostLifeStage String = 20
  optional hostSex HostSexEnum = 21
  repeated chemAdministration String = 22
  optional hostBodyHabitat String = 23
  optional hostBodySite String = 24
  optional hostBodyProduct String = 25
  optional hostTotMass QuantityValue = 26
  optional hostHeight QuantityValue = 27
  optional hostLength QuantityValue = 28
  repeated hostDiet String = 29
  repeated hostLastMeal String = 30
  optional hostGrowthCond String = 31
  optional hostSubstrate String = 32
  repeated hostFamilyRelation String = 33
  repeated hostSubspecfGenlin String = 34
  optional hostGenotype String = 35
  optional hostPhenotype String = 36
  optional hostBodyTemp QuantityValue = 37
  optional hostDryMass QuantityValue = 38
  optional bloodPressDiast QuantityValue = 39
  optional bloodPressSyst QuantityValue = 40
  optional hostColor String = 41
  optional hostShape String = 42
  optional gravidity String = 43
  repeated perturbation String = 44
  optional salinity QuantityValue = 45
  optional oxyStatSamp OxyStatSampEnum = 46
  repeated organismCount OrganismCountEnum = 47
  optional sampStoreTemp QuantityValue = 48
  optional sampStoreDur String = 49
  optional sampStoreLoc String = 50
  repeated hostSymbiont String = 51
  repeated miscParam String = 52
  sampName String = 53
  projectName String = 54
  optional hostDiseaseStat String = 55
  optional sampVolWeDnaExt QuantityValue = 56
  sampTaxonId String = 57
  optional experimentalFactor String = 58
  optional negContType NegContTypeEnum = 59
  optional posContType String = 60
  optional refBiomaterial String = 61
  optional sourceMatId String = 62
  optional relToOxygen RelToOxygenEnum = 63
  optional sampCollecDevice String = 64
  optional sampCollecMethod String = 65
  optional sampMatProcess String = 66
  optional sizeFrac String = 67
  optional sampSize QuantityValue = 68
  optional nuclAcidExt String = 69
  optional nuclAcidAmp String = 70
  optional libSize Integer = 71
  optional libReadsSeqd Integer = 72
  optional libLayout LibLayoutEnum = 73
  optional libVector String = 74
  optional libScreen String = 75
  optional mid String = 76
  optional adapters String = 77
  seqMeth String = 78
  taxIdent TaxIdentEnum = 79
  assemblyQual AssemblyQualEnum = 80
  optional assemblyName String = 81
  assemblySoftware String = 82
  optional annot String = 83
  optional numberContig Integer = 84
  optional featPred String = 85
  optional refDb String = 86
  optional simSearchMeth String = 87
  optional taxClass String = 88
  optional x16sRecover String = 89
  optional x16sRecoverSoftware String = 90
  optional trnas Integer = 91
  optional trnaExtSoftware String = 92
  complScore String = 93
  complSoftware String = 94
  optional complAppr ComplApprEnum = 95
  contamScore String = 96
  optional contamScreenInput String = 97
  optional contamScreenParam String = 98
  optional decontamSoftware DecontamSoftwareEnum = 99
  sortTech SortTechEnum = 100
  singleCellLysisAppr SingleCellLysisApprEnum = 101
  optional singleCellLysisProt String = 102
  wgaAmpAppr String = 103
  optional wgaAmpKit String = 104
  optional associatedResource String = 105
  optional sop String = 106
 }
// Combinatorial checklist Minimum Information About an Uncultivated Virus Genome with environmental package host-associated
message Host-associatedMIUVIG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional ancesData String = 11
  optional biolStat BiolStatEnum = 12
  optional geneticMod String = 13
  optional hostCommonName String = 14
  optional sampCaptStatus SampCaptStatusEnum = 15
  optional sampDisStage SampDisStageEnum = 16
  optional hostTaxid String = 17
  optional hostSubjectId String = 18
  optional hostAge QuantityValue = 19
  optional hostLifeStage String = 20
  optional hostSex HostSexEnum = 21
  repeated chemAdministration String = 22
  optional hostBodyHabitat String = 23
  optional hostBodySite String = 24
  optional hostBodyProduct String = 25
  optional hostTotMass QuantityValue = 26
  optional hostHeight QuantityValue = 27
  optional hostLength QuantityValue = 28
  repeated hostDiet String = 29
  repeated hostLastMeal String = 30
  optional hostGrowthCond String = 31
  optional hostSubstrate String = 32
  repeated hostFamilyRelation String = 33
  repeated hostSubspecfGenlin String = 34
  optional hostGenotype String = 35
  optional hostPhenotype String = 36
  optional hostBodyTemp QuantityValue = 37
  optional hostDryMass QuantityValue = 38
  optional bloodPressDiast QuantityValue = 39
  optional bloodPressSyst QuantityValue = 40
  optional hostColor String = 41
  optional hostShape String = 42
  optional gravidity String = 43
  repeated perturbation String = 44
  optional salinity QuantityValue = 45
  optional oxyStatSamp OxyStatSampEnum = 46
  repeated organismCount OrganismCountEnum = 47
  optional sampStoreTemp QuantityValue = 48
  optional sampStoreDur String = 49
  optional sampStoreLoc String = 50
  repeated hostSymbiont String = 51
  repeated miscParam String = 52
  sampName String = 53
  projectName String = 54
  optional hostDiseaseStat String = 55
  optional sampVolWeDnaExt QuantityValue = 56
  sampTaxonId String = 57
  optional experimentalFactor String = 58
  optional negContType NegContTypeEnum = 59
  optional posContType String = 60
  optional estimatedSize String = 61
  optional refBiomaterial String = 62
  optional sourceMatId String = 63
  optional pathogenicity String = 64
  optional bioticRelationship BioticRelationshipEnum = 65
  optional specificHost String = 66
  optional hostSpecRange Integer = 67
  optional sampCollecDevice String = 68
  optional sampCollecMethod String = 69
  optional sampMatProcess String = 70
  optional sizeFrac String = 71
  optional sampSize QuantityValue = 72
  sourceUvig SourceUvigEnum = 73
  virusEnrichAppr VirusEnrichApprEnum = 74
  optional nuclAcidExt String = 75
  optional nuclAcidAmp String = 76
  optional libSize Integer = 77
  optional libReadsSeqd Integer = 78
  optional libLayout LibLayoutEnum = 79
  optional libVector String = 80
  optional libScreen String = 81
  optional mid String = 82
  optional adapters String = 83
  seqMeth String = 84
  optional taxIdent TaxIdentEnum = 85
  assemblyQual AssemblyQualEnum = 86
  optional assemblyName String = 87
  assemblySoftware String = 88
  optional annot String = 89
  numberContig Integer = 90
  optional featPred String = 91
  optional refDb String = 92
  optional simSearchMeth String = 93
  optional taxClass String = 94
  optional trnas Integer = 95
  optional trnaExtSoftware String = 96
  optional complScore String = 97
  optional complSoftware String = 98
  optional complAppr ComplApprEnum = 99
  optional sortTech SortTechEnum = 100
  optional singleCellLysisAppr SingleCellLysisApprEnum = 101
  optional singleCellLysisProt String = 102
  optional wgaAmpAppr String = 103
  optional wgaAmpKit String = 104
  optional binParam BinParamEnum = 105
  optional binSoftware String = 106
  optional reassemblyBin String = 107
  optional magCovSoftware MagCovSoftwareEnum = 108
  virIdentSoftware String = 109
  predGenomeType PredGenomeTypeEnum = 110
  predGenomeStruc PredGenomeStrucEnum = 111
  detecType String = 112
  optional otuClassAppr String = 113
  optional otuSeqCompAppr String = 114
  optional otuDb String = 115
  optional hostPredAppr HostPredApprEnum = 116
  optional hostPredEstAcc String = 117
  optional associatedResource String = 118
  optional sop String = 119
 }
// human-associated
message Human-associated
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional hostSubjectId String = 11
  optional hostAge QuantityValue = 12
  optional hostSex HostSexEnum = 13
  repeated ihmcMedicationCode Integer = 14
  repeated chemAdministration String = 15
  optional hostBodySite String = 16
  optional hostBodyProduct String = 17
  optional hostTotMass QuantityValue = 18
  optional hostHeight QuantityValue = 19
  repeated hostDiet String = 20
  repeated hostLastMeal String = 21
  repeated hostFamilyRelation String = 22
  optional hostGenotype String = 23
  optional hostPhenotype String = 24
  optional hostBodyTemp QuantityValue = 25
  optional smoker String = 26
  optional hostHivStat String = 27
  repeated drugUsage DrugUsageEnum = 28
  optional hostBodyMassIndex QuantityValue = 29
  optional dietLastSixMonth String = 30
  optional weightLoss3Month String = 31
  repeated ethnicity String = 32
  optional hostOccupation Integer = 33
  repeated petFarmAnimal String = 34
  repeated travelOutSixMonth String = 35
  optional twinSibling String = 36
  optional medicHistPerform String = 37
  optional studyCompltStat StudyCompltStatEnum = 38
  repeated pulmonaryDisord String = 39
  repeated noseThroatDisord String = 40
  repeated bloodBloodDisord String = 41
  optional hostPulse QuantityValue = 42
  optional gestationState String = 43
  optional maternalHealthStat String = 44
  optional foetalHealthStat String = 45
  optional amnioticFluidColor String = 46
  repeated kidneyDisord String = 47
  repeated urogenitTractDisor String = 48
  optional urineCollectMeth String = 49
  repeated perturbation String = 50
  optional salinity QuantityValue = 51
  optional oxyStatSamp OxyStatSampEnum = 52
  repeated organismCount OrganismCountEnum = 53
  optional sampStoreTemp QuantityValue = 54
  optional sampStoreDur String = 55
  repeated hostSymbiont String = 56
  optional sampStoreLoc String = 57
  repeated miscParam String = 58
  sampName String = 59
  projectName String = 60
  optional hostDiseaseStat String = 61
  optional sampVolWeDnaExt QuantityValue = 62
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package human-associated
message Human-associatedMIGSBacteria
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional hostSubjectId String = 11
  optional hostAge QuantityValue = 12
  optional hostSex HostSexEnum = 13
  repeated ihmcMedicationCode Integer = 14
  repeated chemAdministration String = 15
  optional hostBodySite String = 16
  optional hostBodyProduct String = 17
  optional hostTotMass QuantityValue = 18
  optional hostHeight QuantityValue = 19
  repeated hostDiet String = 20
  repeated hostLastMeal String = 21
  repeated hostFamilyRelation String = 22
  optional hostGenotype String = 23
  optional hostPhenotype String = 24
  optional hostBodyTemp QuantityValue = 25
  optional smoker String = 26
  optional hostHivStat String = 27
  repeated drugUsage DrugUsageEnum = 28
  optional hostBodyMassIndex QuantityValue = 29
  optional dietLastSixMonth String = 30
  optional weightLoss3Month String = 31
  repeated ethnicity String = 32
  optional hostOccupation Integer = 33
  repeated petFarmAnimal String = 34
  repeated travelOutSixMonth String = 35
  optional twinSibling String = 36
  optional medicHistPerform String = 37
  optional studyCompltStat StudyCompltStatEnum = 38
  repeated pulmonaryDisord String = 39
  repeated noseThroatDisord String = 40
  repeated bloodBloodDisord String = 41
  optional hostPulse QuantityValue = 42
  optional gestationState String = 43
  optional maternalHealthStat String = 44
  optional foetalHealthStat String = 45
  optional amnioticFluidColor String = 46
  repeated kidneyDisord String = 47
  repeated urogenitTractDisor String = 48
  optional urineCollectMeth String = 49
  repeated perturbation String = 50
  optional salinity QuantityValue = 51
  optional oxyStatSamp OxyStatSampEnum = 52
  repeated organismCount OrganismCountEnum = 53
  optional sampStoreTemp QuantityValue = 54
  optional sampStoreDur String = 55
  repeated hostSymbiont String = 56
  optional sampStoreLoc String = 57
  repeated miscParam String = 58
  sampName String = 59
  projectName String = 60
  optional hostDiseaseStat String = 61
  optional sampVolWeDnaExt QuantityValue = 62
  sampTaxonId String = 63
  optional experimentalFactor String = 64
  optional negContType NegContTypeEnum = 65
  optional posContType String = 66
  optional subspecfGenLin String = 67
  numReplicons Integer = 68
  optional extrachromElements Integer = 69
  optional estimatedSize String = 70
  refBiomaterial String = 71
  optional sourceMatId String = 72
  optional pathogenicity String = 73
  optional bioticRelationship BioticRelationshipEnum = 74
  optional specificHost String = 75
  optional hostSpecRange Integer = 76
  optional trophicLevel TrophicLevelEnum = 77
  optional encodedTraits String = 78
  optional relToOxygen RelToOxygenEnum = 79
  isolGrowthCondt String = 80
  optional sampCollecDevice String = 81
  optional sampCollecMethod String = 82
  optional sampMatProcess String = 83
  optional sampSize QuantityValue = 84
  optional nuclAcidExt String = 85
  optional nuclAcidAmp String = 86
  optional libSize Integer = 87
  optional libReadsSeqd Integer = 88
  optional libLayout LibLayoutEnum = 89
  optional libVector String = 90
  optional libScreen String = 91
  optional adapters String = 92
  seqMeth String = 93
  optional taxIdent TaxIdentEnum = 94
  assemblyQual AssemblyQualEnum = 95
  optional assemblyName String = 96
  assemblySoftware String = 97
  optional annot String = 98
  numberContig Integer = 99
  optional featPred String = 100
  optional refDb String = 101
  optional simSearchMeth String = 102
  optional taxClass String = 103
  optional complScore String = 104
  optional complSoftware String = 105
  optional associatedResource String = 106
  optional sop String = 107
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: eukaryote with environmental package human-associated
message Human-associatedMIGSEukaryote
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional hostSubjectId String = 11
  optional hostAge QuantityValue = 12
  optional hostSex HostSexEnum = 13
  repeated ihmcMedicationCode Integer = 14
  repeated chemAdministration String = 15
  optional hostBodySite String = 16
  optional hostBodyProduct String = 17
  optional hostTotMass QuantityValue = 18
  optional hostHeight QuantityValue = 19
  repeated hostDiet String = 20
  repeated hostLastMeal String = 21
  repeated hostFamilyRelation String = 22
  optional hostGenotype String = 23
  optional hostPhenotype String = 24
  optional hostBodyTemp QuantityValue = 25
  optional smoker String = 26
  optional hostHivStat String = 27
  repeated drugUsage DrugUsageEnum = 28
  optional hostBodyMassIndex QuantityValue = 29
  optional dietLastSixMonth String = 30
  optional weightLoss3Month String = 31
  repeated ethnicity String = 32
  optional hostOccupation Integer = 33
  repeated petFarmAnimal String = 34
  repeated travelOutSixMonth String = 35
  optional twinSibling String = 36
  optional medicHistPerform String = 37
  optional studyCompltStat StudyCompltStatEnum = 38
  repeated pulmonaryDisord String = 39
  repeated noseThroatDisord String = 40
  repeated bloodBloodDisord String = 41
  optional hostPulse QuantityValue = 42
  optional gestationState String = 43
  optional maternalHealthStat String = 44
  optional foetalHealthStat String = 45
  optional amnioticFluidColor String = 46
  repeated kidneyDisord String = 47
  repeated urogenitTractDisor String = 48
  optional urineCollectMeth String = 49
  repeated perturbation String = 50
  optional salinity QuantityValue = 51
  optional oxyStatSamp OxyStatSampEnum = 52
  repeated organismCount OrganismCountEnum = 53
  optional sampStoreTemp QuantityValue = 54
  optional sampStoreDur String = 55
  repeated hostSymbiont String = 56
  optional sampStoreLoc String = 57
  repeated miscParam String = 58
  sampName String = 59
  projectName String = 60
  optional hostDiseaseStat String = 61
  optional sampVolWeDnaExt QuantityValue = 62
  sampTaxonId String = 63
  optional experimentalFactor String = 64
  optional negContType NegContTypeEnum = 65
  optional posContType String = 66
  optional subspecfGenLin String = 67
  optional ploidy String = 68
  optional numReplicons Integer = 69
  optional extrachromElements Integer = 70
  optional estimatedSize String = 71
  optional refBiomaterial String = 72
  optional sourceMatId String = 73
  optional pathogenicity String = 74
  optional bioticRelationship BioticRelationshipEnum = 75
  optional specificHost String = 76
  optional hostSpecRange Integer = 77
  optional trophicLevel TrophicLevelEnum = 78
  optional propagation String = 79
  isolGrowthCondt String = 80
  optional sampCollecDevice String = 81
  optional sampCollecMethod String = 82
  optional sampMatProcess String = 83
  optional sampSize QuantityValue = 84
  optional nuclAcidExt String = 85
  optional nuclAcidAmp String = 86
  optional libSize Integer = 87
  optional libReadsSeqd Integer = 88
  optional libLayout LibLayoutEnum = 89
  optional libVector String = 90
  optional libScreen String = 91
  optional adapters String = 92
  seqMeth String = 93
  optional taxIdent TaxIdentEnum = 94
  assemblyQual AssemblyQualEnum = 95
  optional assemblyName String = 96
  assemblySoftware String = 97
  optional annot String = 98
  numberContig Integer = 99
  optional featPred String = 100
  optional refDb String = 101
  optional simSearchMeth String = 102
  optional taxClass String = 103
  optional complScore String = 104
  optional complSoftware String = 105
  optional associatedResource String = 106
  optional sop String = 107
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: org with environmental package human-associated
message Human-associatedMIGSOrg
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional hostSubjectId String = 11
  optional hostAge QuantityValue = 12
  optional hostSex HostSexEnum = 13
  repeated ihmcMedicationCode Integer = 14
  repeated chemAdministration String = 15
  optional hostBodySite String = 16
  optional hostBodyProduct String = 17
  optional hostTotMass QuantityValue = 18
  optional hostHeight QuantityValue = 19
  repeated hostDiet String = 20
  repeated hostLastMeal String = 21
  repeated hostFamilyRelation String = 22
  optional hostGenotype String = 23
  optional hostPhenotype String = 24
  optional hostBodyTemp QuantityValue = 25
  optional smoker String = 26
  optional hostHivStat String = 27
  repeated drugUsage DrugUsageEnum = 28
  optional hostBodyMassIndex QuantityValue = 29
  optional dietLastSixMonth String = 30
  optional weightLoss3Month String = 31
  repeated ethnicity String = 32
  optional hostOccupation Integer = 33
  repeated petFarmAnimal String = 34
  repeated travelOutSixMonth String = 35
  optional twinSibling String = 36
  optional medicHistPerform String = 37
  optional studyCompltStat StudyCompltStatEnum = 38
  repeated pulmonaryDisord String = 39
  repeated noseThroatDisord String = 40
  repeated bloodBloodDisord String = 41
  optional hostPulse QuantityValue = 42
  optional gestationState String = 43
  optional maternalHealthStat String = 44
  optional foetalHealthStat String = 45
  optional amnioticFluidColor String = 46
  repeated kidneyDisord String = 47
  repeated urogenitTractDisor String = 48
  optional urineCollectMeth String = 49
  repeated perturbation String = 50
  optional salinity QuantityValue = 51
  optional oxyStatSamp OxyStatSampEnum = 52
  repeated organismCount OrganismCountEnum = 53
  optional sampStoreTemp QuantityValue = 54
  optional sampStoreDur String = 55
  repeated hostSymbiont String = 56
  optional sampStoreLoc String = 57
  repeated miscParam String = 58
  sampName String = 59
  projectName String = 60
  optional hostDiseaseStat String = 61
  optional sampVolWeDnaExt QuantityValue = 62
  sampTaxonId String = 63
  optional experimentalFactor String = 64
  optional negContType NegContTypeEnum = 65
  optional posContType String = 66
  optional subspecfGenLin String = 67
  optional extrachromElements Integer = 68
  optional estimatedSize String = 69
  optional refBiomaterial String = 70
  optional sourceMatId String = 71
  isolGrowthCondt String = 72
  optional sampCollecDevice String = 73
  optional sampCollecMethod String = 74
  optional sampMatProcess String = 75
  optional sampSize QuantityValue = 76
  optional nuclAcidExt String = 77
  optional nuclAcidAmp String = 78
  optional libSize Integer = 79
  optional libReadsSeqd Integer = 80
  optional libLayout LibLayoutEnum = 81
  optional libVector String = 82
  optional libScreen String = 83
  optional adapters String = 84
  seqMeth String = 85
  optional taxIdent TaxIdentEnum = 86
  optional assemblyQual AssemblyQualEnum = 87
  optional assemblyName String = 88
  assemblySoftware String = 89
  optional annot String = 90
  optional numberContig Integer = 91
  optional featPred String = 92
  optional refDb String = 93
  optional simSearchMeth String = 94
  optional taxClass String = 95
  optional complScore String = 96
  optional complSoftware String = 97
  optional associatedResource String = 98
  optional sop String = 99
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: plant with environmental package human-associated
message Human-associatedMIGSPlant
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional hostSubjectId String = 11
  optional hostAge QuantityValue = 12
  optional hostSex HostSexEnum = 13
  repeated ihmcMedicationCode Integer = 14
  repeated chemAdministration String = 15
  optional hostBodySite String = 16
  optional hostBodyProduct String = 17
  optional hostTotMass QuantityValue = 18
  optional hostHeight QuantityValue = 19
  repeated hostDiet String = 20
  repeated hostLastMeal String = 21
  repeated hostFamilyRelation String = 22
  optional hostGenotype String = 23
  optional hostPhenotype String = 24
  optional hostBodyTemp QuantityValue = 25
  optional smoker String = 26
  optional hostHivStat String = 27
  repeated drugUsage DrugUsageEnum = 28
  optional hostBodyMassIndex QuantityValue = 29
  optional dietLastSixMonth String = 30
  optional weightLoss3Month String = 31
  repeated ethnicity String = 32
  optional hostOccupation Integer = 33
  repeated petFarmAnimal String = 34
  repeated travelOutSixMonth String = 35
  optional twinSibling String = 36
  optional medicHistPerform String = 37
  optional studyCompltStat StudyCompltStatEnum = 38
  repeated pulmonaryDisord String = 39
  repeated noseThroatDisord String = 40
  repeated bloodBloodDisord String = 41
  optional hostPulse QuantityValue = 42
  optional gestationState String = 43
  optional maternalHealthStat String = 44
  optional foetalHealthStat String = 45
  optional amnioticFluidColor String = 46
  repeated kidneyDisord String = 47
  repeated urogenitTractDisor String = 48
  optional urineCollectMeth String = 49
  repeated perturbation String = 50
  optional salinity QuantityValue = 51
  optional oxyStatSamp OxyStatSampEnum = 52
  repeated organismCount OrganismCountEnum = 53
  optional sampStoreTemp QuantityValue = 54
  optional sampStoreDur String = 55
  repeated hostSymbiont String = 56
  optional sampStoreLoc String = 57
  repeated miscParam String = 58
  sampName String = 59
  projectName String = 60
  optional hostDiseaseStat String = 61
  optional sampVolWeDnaExt QuantityValue = 62
  sampTaxonId String = 63
  optional experimentalFactor String = 64
  optional negContType NegContTypeEnum = 65
  optional posContType String = 66
  optional subspecfGenLin String = 67
  optional estimatedSize String = 68
  optional refBiomaterial String = 69
  optional sourceMatId String = 70
  optional specificHost String = 71
  optional hostSpecRange Integer = 72
  propagation String = 73
  optional encodedTraits String = 74
  isolGrowthCondt String = 75
  optional sampCollecDevice String = 76
  optional sampCollecMethod String = 77
  optional sampMatProcess String = 78
  optional sampSize QuantityValue = 79
  optional nuclAcidExt String = 80
  optional nuclAcidAmp String = 81
  optional libSize Integer = 82
  optional libReadsSeqd Integer = 83
  optional libLayout LibLayoutEnum = 84
  optional libVector String = 85
  optional libScreen String = 86
  optional adapters String = 87
  seqMeth String = 88
  optional taxIdent TaxIdentEnum = 89
  optional assemblyQual AssemblyQualEnum = 90
  optional assemblyName String = 91
  assemblySoftware String = 92
  optional annot String = 93
  optional numberContig Integer = 94
  optional featPred String = 95
  optional refDb String = 96
  optional simSearchMeth String = 97
  optional taxClass String = 98
  optional complScore String = 99
  optional complSoftware String = 100
  optional associatedResource String = 101
  optional sop String = 102
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package human-associated
message Human-associatedMIGSVirus
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional hostSubjectId String = 11
  optional hostAge QuantityValue = 12
  optional hostSex HostSexEnum = 13
  repeated ihmcMedicationCode Integer = 14
  repeated chemAdministration String = 15
  optional hostBodySite String = 16
  optional hostBodyProduct String = 17
  optional hostTotMass QuantityValue = 18
  optional hostHeight QuantityValue = 19
  repeated hostDiet String = 20
  repeated hostLastMeal String = 21
  repeated hostFamilyRelation String = 22
  optional hostGenotype String = 23
  optional hostPhenotype String = 24
  optional hostBodyTemp QuantityValue = 25
  optional smoker String = 26
  optional hostHivStat String = 27
  repeated drugUsage DrugUsageEnum = 28
  optional hostBodyMassIndex QuantityValue = 29
  optional dietLastSixMonth String = 30
  optional weightLoss3Month String = 31
  repeated ethnicity String = 32
  optional hostOccupation Integer = 33
  repeated petFarmAnimal String = 34
  repeated travelOutSixMonth String = 35
  optional twinSibling String = 36
  optional medicHistPerform String = 37
  optional studyCompltStat StudyCompltStatEnum = 38
  repeated pulmonaryDisord String = 39
  repeated noseThroatDisord String = 40
  repeated bloodBloodDisord String = 41
  optional hostPulse QuantityValue = 42
  optional gestationState String = 43
  optional maternalHealthStat String = 44
  optional foetalHealthStat String = 45
  optional amnioticFluidColor String = 46
  repeated kidneyDisord String = 47
  repeated urogenitTractDisor String = 48
  optional urineCollectMeth String = 49
  repeated perturbation String = 50
  optional salinity QuantityValue = 51
  optional oxyStatSamp OxyStatSampEnum = 52
  repeated organismCount OrganismCountEnum = 53
  optional sampStoreTemp QuantityValue = 54
  optional sampStoreDur String = 55
  repeated hostSymbiont String = 56
  optional sampStoreLoc String = 57
  repeated miscParam String = 58
  sampName String = 59
  projectName String = 60
  optional hostDiseaseStat String = 61
  optional sampVolWeDnaExt QuantityValue = 62
  sampTaxonId String = 63
  optional experimentalFactor String = 64
  optional negContType NegContTypeEnum = 65
  optional posContType String = 66
  optional subspecfGenLin String = 67
  optional numReplicons Integer = 68
  optional estimatedSize String = 69
  optional refBiomaterial String = 70
  optional sourceMatId String = 71
  optional pathogenicity String = 72
  optional bioticRelationship BioticRelationshipEnum = 73
  optional specificHost String = 74
  optional hostSpecRange Integer = 75
  propagation String = 76
  optional encodedTraits String = 77
  isolGrowthCondt String = 78
  optional sampCollecDevice String = 79
  optional sampCollecMethod String = 80
  optional sampMatProcess String = 81
  optional sampSize QuantityValue = 82
  optional virusEnrichAppr VirusEnrichApprEnum = 83
  optional nuclAcidExt String = 84
  optional nuclAcidAmp String = 85
  optional libSize Integer = 86
  optional libReadsSeqd Integer = 87
  optional libLayout LibLayoutEnum = 88
  optional libVector String = 89
  optional libScreen String = 90
  optional adapters String = 91
  seqMeth String = 92
  optional taxIdent TaxIdentEnum = 93
  optional assemblyQual AssemblyQualEnum = 94
  optional assemblyName String = 95
  assemblySoftware String = 96
  optional annot String = 97
  optional numberContig Integer = 98
  optional featPred String = 99
  optional refDb String = 100
  optional simSearchMeth String = 101
  optional taxClass String = 102
  optional complScore String = 103
  optional complSoftware String = 104
  optional associatedResource String = 105
  optional sop String = 106
 }
// Combinatorial checklist Minimum Information About a Metagenome-Assembled Genome with environmental package human-associated
message Human-associatedMIMAG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional hostSubjectId String = 11
  optional hostAge QuantityValue = 12
  optional hostSex HostSexEnum = 13
  repeated ihmcMedicationCode Integer = 14
  repeated chemAdministration String = 15
  optional hostBodySite String = 16
  optional hostBodyProduct String = 17
  optional hostTotMass QuantityValue = 18
  optional hostHeight QuantityValue = 19
  repeated hostDiet String = 20
  repeated hostLastMeal String = 21
  repeated hostFamilyRelation String = 22
  optional hostGenotype String = 23
  optional hostPhenotype String = 24
  optional hostBodyTemp QuantityValue = 25
  optional smoker String = 26
  optional hostHivStat String = 27
  repeated drugUsage DrugUsageEnum = 28
  optional hostBodyMassIndex QuantityValue = 29
  optional dietLastSixMonth String = 30
  optional weightLoss3Month String = 31
  repeated ethnicity String = 32
  optional hostOccupation Integer = 33
  repeated petFarmAnimal String = 34
  repeated travelOutSixMonth String = 35
  optional twinSibling String = 36
  optional medicHistPerform String = 37
  optional studyCompltStat StudyCompltStatEnum = 38
  repeated pulmonaryDisord String = 39
  repeated noseThroatDisord String = 40
  repeated bloodBloodDisord String = 41
  optional hostPulse QuantityValue = 42
  optional gestationState String = 43
  optional maternalHealthStat String = 44
  optional foetalHealthStat String = 45
  optional amnioticFluidColor String = 46
  repeated kidneyDisord String = 47
  repeated urogenitTractDisor String = 48
  optional urineCollectMeth String = 49
  repeated perturbation String = 50
  optional salinity QuantityValue = 51
  optional oxyStatSamp OxyStatSampEnum = 52
  repeated organismCount OrganismCountEnum = 53
  optional sampStoreTemp QuantityValue = 54
  optional sampStoreDur String = 55
  repeated hostSymbiont String = 56
  optional sampStoreLoc String = 57
  repeated miscParam String = 58
  sampName String = 59
  projectName String = 60
  optional hostDiseaseStat String = 61
  optional sampVolWeDnaExt QuantityValue = 62
  sampTaxonId String = 63
  optional experimentalFactor String = 64
  optional negContType NegContTypeEnum = 65
  optional posContType String = 66
  optional refBiomaterial String = 67
  optional sourceMatId String = 68
  optional relToOxygen RelToOxygenEnum = 69
  optional sampCollecDevice String = 70
  optional sampCollecMethod String = 71
  optional sampMatProcess String = 72
  optional sizeFrac String = 73
  optional sampSize QuantityValue = 74
  optional nuclAcidExt String = 75
  optional nuclAcidAmp String = 76
  optional libSize Integer = 77
  optional libReadsSeqd Integer = 78
  optional libLayout LibLayoutEnum = 79
  optional libVector String = 80
  optional libScreen String = 81
  optional mid String = 82
  optional adapters String = 83
  seqMeth String = 84
  taxIdent TaxIdentEnum = 85
  assemblyQual AssemblyQualEnum = 86
  optional assemblyName String = 87
  assemblySoftware String = 88
  optional annot String = 89
  optional numberContig Integer = 90
  optional featPred String = 91
  optional refDb String = 92
  optional simSearchMeth String = 93
  optional taxClass String = 94
  optional x16sRecover String = 95
  optional x16sRecoverSoftware String = 96
  optional trnas Integer = 97
  optional trnaExtSoftware String = 98
  complScore String = 99
  complSoftware String = 100
  optional complAppr ComplApprEnum = 101
  contamScore String = 102
  optional contamScreenInput String = 103
  optional contamScreenParam String = 104
  optional decontamSoftware DecontamSoftwareEnum = 105
  binParam BinParamEnum = 106
  binSoftware String = 107
  optional reassemblyBin String = 108
  optional magCovSoftware MagCovSoftwareEnum = 109
  optional associatedResource String = 110
  optional sop String = 111
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: specimen with environmental package human-associated
message Human-associatedMIMARKSSpecimen
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional hostSubjectId String = 11
  optional hostAge QuantityValue = 12
  optional hostSex HostSexEnum = 13
  repeated ihmcMedicationCode Integer = 14
  repeated chemAdministration String = 15
  optional hostBodySite String = 16
  optional hostBodyProduct String = 17
  optional hostTotMass QuantityValue = 18
  optional hostHeight QuantityValue = 19
  repeated hostDiet String = 20
  repeated hostLastMeal String = 21
  repeated hostFamilyRelation String = 22
  optional hostGenotype String = 23
  optional hostPhenotype String = 24
  optional hostBodyTemp QuantityValue = 25
  optional smoker String = 26
  optional hostHivStat String = 27
  repeated drugUsage DrugUsageEnum = 28
  optional hostBodyMassIndex QuantityValue = 29
  optional dietLastSixMonth String = 30
  optional weightLoss3Month String = 31
  repeated ethnicity String = 32
  optional hostOccupation Integer = 33
  repeated petFarmAnimal String = 34
  repeated travelOutSixMonth String = 35
  optional twinSibling String = 36
  optional medicHistPerform String = 37
  optional studyCompltStat StudyCompltStatEnum = 38
  repeated pulmonaryDisord String = 39
  repeated noseThroatDisord String = 40
  repeated bloodBloodDisord String = 41
  optional hostPulse QuantityValue = 42
  optional gestationState String = 43
  optional maternalHealthStat String = 44
  optional foetalHealthStat String = 45
  optional amnioticFluidColor String = 46
  repeated kidneyDisord String = 47
  repeated urogenitTractDisor String = 48
  optional urineCollectMeth String = 49
  repeated perturbation String = 50
  optional salinity QuantityValue = 51
  optional oxyStatSamp OxyStatSampEnum = 52
  repeated organismCount OrganismCountEnum = 53
  optional sampStoreTemp QuantityValue = 54
  optional sampStoreDur String = 55
  repeated hostSymbiont String = 56
  optional sampStoreLoc String = 57
  repeated miscParam String = 58
  sampName String = 59
  projectName String = 60
  optional hostDiseaseStat String = 61
  optional sampVolWeDnaExt QuantityValue = 62
  sampTaxonId String = 63
  optional experimentalFactor String = 64
  optional negContType NegContTypeEnum = 65
  optional posContType String = 66
  optional sourceMatId String = 67
  optional relToOxygen RelToOxygenEnum = 68
  optional sampCollecDevice String = 69
  optional sampCollecMethod String = 70
  optional sampMatProcess String = 71
  optional sizeFrac String = 72
  optional sampSize QuantityValue = 73
  optional nuclAcidExt String = 74
  optional nuclAcidAmp String = 75
  optional libSize Integer = 76
  optional libReadsSeqd Integer = 77
  optional libLayout LibLayoutEnum = 78
  optional libVector String = 79
  optional libScreen String = 80
  targetGene String = 81
  optional targetSubfragment String = 82
  optional pcrPrimers String = 83
  optional mid String = 84
  optional adapters String = 85
  optional pcrCond String = 86
  seqMeth String = 87
  optional seqQualityCheck String = 88
  optional chimeraCheck String = 89
  optional assemblySoftware String = 90
  optional associatedResource String = 91
  optional sop String = 92
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: survey with environmental package human-associated
message Human-associatedMIMARKSSurvey
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional hostSubjectId String = 11
  optional hostAge QuantityValue = 12
  optional hostSex HostSexEnum = 13
  repeated ihmcMedicationCode Integer = 14
  repeated chemAdministration String = 15
  optional hostBodySite String = 16
  optional hostBodyProduct String = 17
  optional hostTotMass QuantityValue = 18
  optional hostHeight QuantityValue = 19
  repeated hostDiet String = 20
  repeated hostLastMeal String = 21
  repeated hostFamilyRelation String = 22
  optional hostGenotype String = 23
  optional hostPhenotype String = 24
  optional hostBodyTemp QuantityValue = 25
  optional smoker String = 26
  optional hostHivStat String = 27
  repeated drugUsage DrugUsageEnum = 28
  optional hostBodyMassIndex QuantityValue = 29
  optional dietLastSixMonth String = 30
  optional weightLoss3Month String = 31
  repeated ethnicity String = 32
  optional hostOccupation Integer = 33
  repeated petFarmAnimal String = 34
  repeated travelOutSixMonth String = 35
  optional twinSibling String = 36
  optional medicHistPerform String = 37
  optional studyCompltStat StudyCompltStatEnum = 38
  repeated pulmonaryDisord String = 39
  repeated noseThroatDisord String = 40
  repeated bloodBloodDisord String = 41
  optional hostPulse QuantityValue = 42
  optional gestationState String = 43
  optional maternalHealthStat String = 44
  optional foetalHealthStat String = 45
  optional amnioticFluidColor String = 46
  repeated kidneyDisord String = 47
  repeated urogenitTractDisor String = 48
  optional urineCollectMeth String = 49
  repeated perturbation String = 50
  optional salinity QuantityValue = 51
  optional oxyStatSamp OxyStatSampEnum = 52
  repeated organismCount OrganismCountEnum = 53
  optional sampStoreTemp QuantityValue = 54
  optional sampStoreDur String = 55
  repeated hostSymbiont String = 56
  optional sampStoreLoc String = 57
  repeated miscParam String = 58
  sampName String = 59
  projectName String = 60
  optional hostDiseaseStat String = 61
  optional sampVolWeDnaExt QuantityValue = 62
  sampTaxonId String = 63
  optional experimentalFactor String = 64
  optional negContType NegContTypeEnum = 65
  optional posContType String = 66
  optional subspecfGenLin String = 67
  optional extrachromElements Integer = 68
  optional sourceMatId String = 69
  optional bioticRelationship BioticRelationshipEnum = 70
  optional trophicLevel TrophicLevelEnum = 71
  optional relToOxygen RelToOxygenEnum = 72
  isolGrowthCondt String = 73
  optional sampCollecDevice String = 74
  optional sampCollecMethod String = 75
  optional sampMatProcess String = 76
  optional sampSize QuantityValue = 77
  optional nuclAcidExt String = 78
  optional nuclAcidAmp String = 79
  targetGene String = 80
  optional targetSubfragment String = 81
  optional pcrPrimers String = 82
  optional pcrCond String = 83
  seqMeth String = 84
  optional seqQualityCheck String = 85
  optional chimeraCheck String = 86
  optional associatedResource String = 87
  optional sop String = 88
 }
// Combinatorial checklist Metagenome or Environmental with environmental package human-associated
message Human-associatedMIMS
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional hostSubjectId String = 11
  optional hostAge QuantityValue = 12
  optional hostSex HostSexEnum = 13
  repeated ihmcMedicationCode Integer = 14
  repeated chemAdministration String = 15
  optional hostBodySite String = 16
  optional hostBodyProduct String = 17
  optional hostTotMass QuantityValue = 18
  optional hostHeight QuantityValue = 19
  repeated hostDiet String = 20
  repeated hostLastMeal String = 21
  repeated hostFamilyRelation String = 22
  optional hostGenotype String = 23
  optional hostPhenotype String = 24
  optional hostBodyTemp QuantityValue = 25
  optional smoker String = 26
  optional hostHivStat String = 27
  repeated drugUsage DrugUsageEnum = 28
  optional hostBodyMassIndex QuantityValue = 29
  optional dietLastSixMonth String = 30
  optional weightLoss3Month String = 31
  repeated ethnicity String = 32
  optional hostOccupation Integer = 33
  repeated petFarmAnimal String = 34
  repeated travelOutSixMonth String = 35
  optional twinSibling String = 36
  optional medicHistPerform String = 37
  optional studyCompltStat StudyCompltStatEnum = 38
  repeated pulmonaryDisord String = 39
  repeated noseThroatDisord String = 40
  repeated bloodBloodDisord String = 41
  optional hostPulse QuantityValue = 42
  optional gestationState String = 43
  optional maternalHealthStat String = 44
  optional foetalHealthStat String = 45
  optional amnioticFluidColor String = 46
  repeated kidneyDisord String = 47
  repeated urogenitTractDisor String = 48
  optional urineCollectMeth String = 49
  repeated perturbation String = 50
  optional salinity QuantityValue = 51
  optional oxyStatSamp OxyStatSampEnum = 52
  repeated organismCount OrganismCountEnum = 53
  optional sampStoreTemp QuantityValue = 54
  optional sampStoreDur String = 55
  repeated hostSymbiont String = 56
  optional sampStoreLoc String = 57
  repeated miscParam String = 58
  sampName String = 59
  projectName String = 60
  optional hostDiseaseStat String = 61
  optional sampVolWeDnaExt QuantityValue = 62
  sampTaxonId String = 63
  optional experimentalFactor String = 64
  optional negContType NegContTypeEnum = 65
  optional posContType String = 66
  optional refBiomaterial String = 67
  optional sourceMatId String = 68
  optional relToOxygen RelToOxygenEnum = 69
  optional sampCollecDevice String = 70
  optional sampCollecMethod String = 71
  optional sampMatProcess String = 72
  optional sizeFrac String = 73
  optional sampSize QuantityValue = 74
  optional nuclAcidExt String = 75
  optional nuclAcidAmp String = 76
  optional libSize Integer = 77
  optional libReadsSeqd Integer = 78
  optional libLayout LibLayoutEnum = 79
  optional libVector String = 80
  optional libScreen String = 81
  optional mid String = 82
  optional adapters String = 83
  seqMeth String = 84
  optional assemblyQual AssemblyQualEnum = 85
  optional assemblyName String = 86
  optional assemblySoftware String = 87
  optional annot String = 88
  optional numberContig Integer = 89
  optional featPred String = 90
  optional refDb String = 91
  optional simSearchMeth String = 92
  optional taxClass String = 93
  optional associatedResource String = 94
  optional sop String = 95
 }
// Combinatorial checklist Minimum Information About a Single Amplified Genome with environmental package human-associated
message Human-associatedMISAG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional hostSubjectId String = 11
  optional hostAge QuantityValue = 12
  optional hostSex HostSexEnum = 13
  repeated ihmcMedicationCode Integer = 14
  repeated chemAdministration String = 15
  optional hostBodySite String = 16
  optional hostBodyProduct String = 17
  optional hostTotMass QuantityValue = 18
  optional hostHeight QuantityValue = 19
  repeated hostDiet String = 20
  repeated hostLastMeal String = 21
  repeated hostFamilyRelation String = 22
  optional hostGenotype String = 23
  optional hostPhenotype String = 24
  optional hostBodyTemp QuantityValue = 25
  optional smoker String = 26
  optional hostHivStat String = 27
  repeated drugUsage DrugUsageEnum = 28
  optional hostBodyMassIndex QuantityValue = 29
  optional dietLastSixMonth String = 30
  optional weightLoss3Month String = 31
  repeated ethnicity String = 32
  optional hostOccupation Integer = 33
  repeated petFarmAnimal String = 34
  repeated travelOutSixMonth String = 35
  optional twinSibling String = 36
  optional medicHistPerform String = 37
  optional studyCompltStat StudyCompltStatEnum = 38
  repeated pulmonaryDisord String = 39
  repeated noseThroatDisord String = 40
  repeated bloodBloodDisord String = 41
  optional hostPulse QuantityValue = 42
  optional gestationState String = 43
  optional maternalHealthStat String = 44
  optional foetalHealthStat String = 45
  optional amnioticFluidColor String = 46
  repeated kidneyDisord String = 47
  repeated urogenitTractDisor String = 48
  optional urineCollectMeth String = 49
  repeated perturbation String = 50
  optional salinity QuantityValue = 51
  optional oxyStatSamp OxyStatSampEnum = 52
  repeated organismCount OrganismCountEnum = 53
  optional sampStoreTemp QuantityValue = 54
  optional sampStoreDur String = 55
  repeated hostSymbiont String = 56
  optional sampStoreLoc String = 57
  repeated miscParam String = 58
  sampName String = 59
  projectName String = 60
  optional hostDiseaseStat String = 61
  optional sampVolWeDnaExt QuantityValue = 62
  sampTaxonId String = 63
  optional experimentalFactor String = 64
  optional negContType NegContTypeEnum = 65
  optional posContType String = 66
  optional refBiomaterial String = 67
  optional sourceMatId String = 68
  optional relToOxygen RelToOxygenEnum = 69
  optional sampCollecDevice String = 70
  optional sampCollecMethod String = 71
  optional sampMatProcess String = 72
  optional sizeFrac String = 73
  optional sampSize QuantityValue = 74
  optional nuclAcidExt String = 75
  optional nuclAcidAmp String = 76
  optional libSize Integer = 77
  optional libReadsSeqd Integer = 78
  optional libLayout LibLayoutEnum = 79
  optional libVector String = 80
  optional libScreen String = 81
  optional mid String = 82
  optional adapters String = 83
  seqMeth String = 84
  taxIdent TaxIdentEnum = 85
  assemblyQual AssemblyQualEnum = 86
  optional assemblyName String = 87
  assemblySoftware String = 88
  optional annot String = 89
  optional numberContig Integer = 90
  optional featPred String = 91
  optional refDb String = 92
  optional simSearchMeth String = 93
  optional taxClass String = 94
  optional x16sRecover String = 95
  optional x16sRecoverSoftware String = 96
  optional trnas Integer = 97
  optional trnaExtSoftware String = 98
  complScore String = 99
  complSoftware String = 100
  optional complAppr ComplApprEnum = 101
  contamScore String = 102
  optional contamScreenInput String = 103
  optional contamScreenParam String = 104
  optional decontamSoftware DecontamSoftwareEnum = 105
  sortTech SortTechEnum = 106
  singleCellLysisAppr SingleCellLysisApprEnum = 107
  optional singleCellLysisProt String = 108
  wgaAmpAppr String = 109
  optional wgaAmpKit String = 110
  optional associatedResource String = 111
  optional sop String = 112
 }
// Combinatorial checklist Minimum Information About an Uncultivated Virus Genome with environmental package human-associated
message Human-associatedMIUVIG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional hostSubjectId String = 11
  optional hostAge QuantityValue = 12
  optional hostSex HostSexEnum = 13
  repeated ihmcMedicationCode Integer = 14
  repeated chemAdministration String = 15
  optional hostBodySite String = 16
  optional hostBodyProduct String = 17
  optional hostTotMass QuantityValue = 18
  optional hostHeight QuantityValue = 19
  repeated hostDiet String = 20
  repeated hostLastMeal String = 21
  repeated hostFamilyRelation String = 22
  optional hostGenotype String = 23
  optional hostPhenotype String = 24
  optional hostBodyTemp QuantityValue = 25
  optional smoker String = 26
  optional hostHivStat String = 27
  repeated drugUsage DrugUsageEnum = 28
  optional hostBodyMassIndex QuantityValue = 29
  optional dietLastSixMonth String = 30
  optional weightLoss3Month String = 31
  repeated ethnicity String = 32
  optional hostOccupation Integer = 33
  repeated petFarmAnimal String = 34
  repeated travelOutSixMonth String = 35
  optional twinSibling String = 36
  optional medicHistPerform String = 37
  optional studyCompltStat StudyCompltStatEnum = 38
  repeated pulmonaryDisord String = 39
  repeated noseThroatDisord String = 40
  repeated bloodBloodDisord String = 41
  optional hostPulse QuantityValue = 42
  optional gestationState String = 43
  optional maternalHealthStat String = 44
  optional foetalHealthStat String = 45
  optional amnioticFluidColor String = 46
  repeated kidneyDisord String = 47
  repeated urogenitTractDisor String = 48
  optional urineCollectMeth String = 49
  repeated perturbation String = 50
  optional salinity QuantityValue = 51
  optional oxyStatSamp OxyStatSampEnum = 52
  repeated organismCount OrganismCountEnum = 53
  optional sampStoreTemp QuantityValue = 54
  optional sampStoreDur String = 55
  repeated hostSymbiont String = 56
  optional sampStoreLoc String = 57
  repeated miscParam String = 58
  sampName String = 59
  projectName String = 60
  optional hostDiseaseStat String = 61
  optional sampVolWeDnaExt QuantityValue = 62
  sampTaxonId String = 63
  optional experimentalFactor String = 64
  optional negContType NegContTypeEnum = 65
  optional posContType String = 66
  optional estimatedSize String = 67
  optional refBiomaterial String = 68
  optional sourceMatId String = 69
  optional pathogenicity String = 70
  optional bioticRelationship BioticRelationshipEnum = 71
  optional specificHost String = 72
  optional hostSpecRange Integer = 73
  optional sampCollecDevice String = 74
  optional sampCollecMethod String = 75
  optional sampMatProcess String = 76
  optional sizeFrac String = 77
  optional sampSize QuantityValue = 78
  sourceUvig SourceUvigEnum = 79
  virusEnrichAppr VirusEnrichApprEnum = 80
  optional nuclAcidExt String = 81
  optional nuclAcidAmp String = 82
  optional libSize Integer = 83
  optional libReadsSeqd Integer = 84
  optional libLayout LibLayoutEnum = 85
  optional libVector String = 86
  optional libScreen String = 87
  optional mid String = 88
  optional adapters String = 89
  seqMeth String = 90
  optional taxIdent TaxIdentEnum = 91
  assemblyQual AssemblyQualEnum = 92
  optional assemblyName String = 93
  assemblySoftware String = 94
  optional annot String = 95
  numberContig Integer = 96
  optional featPred String = 97
  optional refDb String = 98
  optional simSearchMeth String = 99
  optional taxClass String = 100
  optional trnas Integer = 101
  optional trnaExtSoftware String = 102
  optional complScore String = 103
  optional complSoftware String = 104
  optional complAppr ComplApprEnum = 105
  optional sortTech SortTechEnum = 106
  optional singleCellLysisAppr SingleCellLysisApprEnum = 107
  optional singleCellLysisProt String = 108
  optional wgaAmpAppr String = 109
  optional wgaAmpKit String = 110
  optional binParam BinParamEnum = 111
  optional binSoftware String = 112
  optional reassemblyBin String = 113
  optional magCovSoftware MagCovSoftwareEnum = 114
  virIdentSoftware String = 115
  predGenomeType PredGenomeTypeEnum = 116
  predGenomeStruc PredGenomeStrucEnum = 117
  detecType String = 118
  optional otuClassAppr String = 119
  optional otuSeqCompAppr String = 120
  optional otuDb String = 121
  optional hostPredAppr HostPredApprEnum = 122
  optional hostPredEstAcc String = 123
  optional associatedResource String = 124
  optional sop String = 125
 }
// human-gut
message Human-gut
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated gastrointestDisord String = 11
  repeated liverDisord String = 12
  repeated specialDiet SpecialDietEnum = 13
  optional hostSubjectId String = 14
  optional hostAge QuantityValue = 15
  optional hostSex HostSexEnum = 16
  repeated ihmcMedicationCode Integer = 17
  repeated chemAdministration String = 18
  optional hostBodySite String = 19
  optional hostBodyProduct String = 20
  optional hostTotMass QuantityValue = 21
  optional hostHeight QuantityValue = 22
  repeated hostDiet String = 23
  repeated hostLastMeal String = 24
  repeated hostFamilyRelation String = 25
  optional hostGenotype String = 26
  optional hostPhenotype String = 27
  optional hostBodyTemp QuantityValue = 28
  optional hostBodyMassIndex QuantityValue = 29
  repeated ethnicity String = 30
  optional hostOccupation Integer = 31
  optional medicHistPerform String = 32
  optional hostPulse QuantityValue = 33
  repeated perturbation String = 34
  optional salinity QuantityValue = 35
  optional oxyStatSamp OxyStatSampEnum = 36
  repeated organismCount OrganismCountEnum = 37
  optional sampStoreTemp QuantityValue = 38
  optional sampStoreDur String = 39
  repeated hostSymbiont String = 40
  optional sampStoreLoc String = 41
  repeated miscParam String = 42
  sampName String = 43
  projectName String = 44
  optional hostDiseaseStat String = 45
  optional sampVolWeDnaExt QuantityValue = 46
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package human-gut
message Human-gutMIGSBacteria
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated gastrointestDisord String = 11
  repeated liverDisord String = 12
  repeated specialDiet SpecialDietEnum = 13
  optional hostSubjectId String = 14
  optional hostAge QuantityValue = 15
  optional hostSex HostSexEnum = 16
  repeated ihmcMedicationCode Integer = 17
  repeated chemAdministration String = 18
  optional hostBodySite String = 19
  optional hostBodyProduct String = 20
  optional hostTotMass QuantityValue = 21
  optional hostHeight QuantityValue = 22
  repeated hostDiet String = 23
  repeated hostLastMeal String = 24
  repeated hostFamilyRelation String = 25
  optional hostGenotype String = 26
  optional hostPhenotype String = 27
  optional hostBodyTemp QuantityValue = 28
  optional hostBodyMassIndex QuantityValue = 29
  repeated ethnicity String = 30
  optional hostOccupation Integer = 31
  optional medicHistPerform String = 32
  optional hostPulse QuantityValue = 33
  repeated perturbation String = 34
  optional salinity QuantityValue = 35
  optional oxyStatSamp OxyStatSampEnum = 36
  repeated organismCount OrganismCountEnum = 37
  optional sampStoreTemp QuantityValue = 38
  optional sampStoreDur String = 39
  repeated hostSymbiont String = 40
  optional sampStoreLoc String = 41
  repeated miscParam String = 42
  sampName String = 43
  projectName String = 44
  optional hostDiseaseStat String = 45
  optional sampVolWeDnaExt QuantityValue = 46
  sampTaxonId String = 47
  optional experimentalFactor String = 48
  optional negContType NegContTypeEnum = 49
  optional posContType String = 50
  optional subspecfGenLin String = 51
  numReplicons Integer = 52
  optional extrachromElements Integer = 53
  optional estimatedSize String = 54
  refBiomaterial String = 55
  optional sourceMatId String = 56
  optional pathogenicity String = 57
  optional bioticRelationship BioticRelationshipEnum = 58
  optional specificHost String = 59
  optional hostSpecRange Integer = 60
  optional trophicLevel TrophicLevelEnum = 61
  optional encodedTraits String = 62
  optional relToOxygen RelToOxygenEnum = 63
  isolGrowthCondt String = 64
  optional sampCollecDevice String = 65
  optional sampCollecMethod String = 66
  optional sampMatProcess String = 67
  optional sampSize QuantityValue = 68
  optional nuclAcidExt String = 69
  optional nuclAcidAmp String = 70
  optional libSize Integer = 71
  optional libReadsSeqd Integer = 72
  optional libLayout LibLayoutEnum = 73
  optional libVector String = 74
  optional libScreen String = 75
  optional adapters String = 76
  seqMeth String = 77
  optional taxIdent TaxIdentEnum = 78
  assemblyQual AssemblyQualEnum = 79
  optional assemblyName String = 80
  assemblySoftware String = 81
  optional annot String = 82
  numberContig Integer = 83
  optional featPred String = 84
  optional refDb String = 85
  optional simSearchMeth String = 86
  optional taxClass String = 87
  optional complScore String = 88
  optional complSoftware String = 89
  optional associatedResource String = 90
  optional sop String = 91
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: eukaryote with environmental package human-gut
message Human-gutMIGSEukaryote
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated gastrointestDisord String = 11
  repeated liverDisord String = 12
  repeated specialDiet SpecialDietEnum = 13
  optional hostSubjectId String = 14
  optional hostAge QuantityValue = 15
  optional hostSex HostSexEnum = 16
  repeated ihmcMedicationCode Integer = 17
  repeated chemAdministration String = 18
  optional hostBodySite String = 19
  optional hostBodyProduct String = 20
  optional hostTotMass QuantityValue = 21
  optional hostHeight QuantityValue = 22
  repeated hostDiet String = 23
  repeated hostLastMeal String = 24
  repeated hostFamilyRelation String = 25
  optional hostGenotype String = 26
  optional hostPhenotype String = 27
  optional hostBodyTemp QuantityValue = 28
  optional hostBodyMassIndex QuantityValue = 29
  repeated ethnicity String = 30
  optional hostOccupation Integer = 31
  optional medicHistPerform String = 32
  optional hostPulse QuantityValue = 33
  repeated perturbation String = 34
  optional salinity QuantityValue = 35
  optional oxyStatSamp OxyStatSampEnum = 36
  repeated organismCount OrganismCountEnum = 37
  optional sampStoreTemp QuantityValue = 38
  optional sampStoreDur String = 39
  repeated hostSymbiont String = 40
  optional sampStoreLoc String = 41
  repeated miscParam String = 42
  sampName String = 43
  projectName String = 44
  optional hostDiseaseStat String = 45
  optional sampVolWeDnaExt QuantityValue = 46
  sampTaxonId String = 47
  optional experimentalFactor String = 48
  optional negContType NegContTypeEnum = 49
  optional posContType String = 50
  optional subspecfGenLin String = 51
  optional ploidy String = 52
  optional numReplicons Integer = 53
  optional extrachromElements Integer = 54
  optional estimatedSize String = 55
  optional refBiomaterial String = 56
  optional sourceMatId String = 57
  optional pathogenicity String = 58
  optional bioticRelationship BioticRelationshipEnum = 59
  optional specificHost String = 60
  optional hostSpecRange Integer = 61
  optional trophicLevel TrophicLevelEnum = 62
  optional propagation String = 63
  isolGrowthCondt String = 64
  optional sampCollecDevice String = 65
  optional sampCollecMethod String = 66
  optional sampMatProcess String = 67
  optional sampSize QuantityValue = 68
  optional nuclAcidExt String = 69
  optional nuclAcidAmp String = 70
  optional libSize Integer = 71
  optional libReadsSeqd Integer = 72
  optional libLayout LibLayoutEnum = 73
  optional libVector String = 74
  optional libScreen String = 75
  optional adapters String = 76
  seqMeth String = 77
  optional taxIdent TaxIdentEnum = 78
  assemblyQual AssemblyQualEnum = 79
  optional assemblyName String = 80
  assemblySoftware String = 81
  optional annot String = 82
  numberContig Integer = 83
  optional featPred String = 84
  optional refDb String = 85
  optional simSearchMeth String = 86
  optional taxClass String = 87
  optional complScore String = 88
  optional complSoftware String = 89
  optional associatedResource String = 90
  optional sop String = 91
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: org with environmental package human-gut
message Human-gutMIGSOrg
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated gastrointestDisord String = 11
  repeated liverDisord String = 12
  repeated specialDiet SpecialDietEnum = 13
  optional hostSubjectId String = 14
  optional hostAge QuantityValue = 15
  optional hostSex HostSexEnum = 16
  repeated ihmcMedicationCode Integer = 17
  repeated chemAdministration String = 18
  optional hostBodySite String = 19
  optional hostBodyProduct String = 20
  optional hostTotMass QuantityValue = 21
  optional hostHeight QuantityValue = 22
  repeated hostDiet String = 23
  repeated hostLastMeal String = 24
  repeated hostFamilyRelation String = 25
  optional hostGenotype String = 26
  optional hostPhenotype String = 27
  optional hostBodyTemp QuantityValue = 28
  optional hostBodyMassIndex QuantityValue = 29
  repeated ethnicity String = 30
  optional hostOccupation Integer = 31
  optional medicHistPerform String = 32
  optional hostPulse QuantityValue = 33
  repeated perturbation String = 34
  optional salinity QuantityValue = 35
  optional oxyStatSamp OxyStatSampEnum = 36
  repeated organismCount OrganismCountEnum = 37
  optional sampStoreTemp QuantityValue = 38
  optional sampStoreDur String = 39
  repeated hostSymbiont String = 40
  optional sampStoreLoc String = 41
  repeated miscParam String = 42
  sampName String = 43
  projectName String = 44
  optional hostDiseaseStat String = 45
  optional sampVolWeDnaExt QuantityValue = 46
  sampTaxonId String = 47
  optional experimentalFactor String = 48
  optional negContType NegContTypeEnum = 49
  optional posContType String = 50
  optional subspecfGenLin String = 51
  optional extrachromElements Integer = 52
  optional estimatedSize String = 53
  optional refBiomaterial String = 54
  optional sourceMatId String = 55
  isolGrowthCondt String = 56
  optional sampCollecDevice String = 57
  optional sampCollecMethod String = 58
  optional sampMatProcess String = 59
  optional sampSize QuantityValue = 60
  optional nuclAcidExt String = 61
  optional nuclAcidAmp String = 62
  optional libSize Integer = 63
  optional libReadsSeqd Integer = 64
  optional libLayout LibLayoutEnum = 65
  optional libVector String = 66
  optional libScreen String = 67
  optional adapters String = 68
  seqMeth String = 69
  optional taxIdent TaxIdentEnum = 70
  optional assemblyQual AssemblyQualEnum = 71
  optional assemblyName String = 72
  assemblySoftware String = 73
  optional annot String = 74
  optional numberContig Integer = 75
  optional featPred String = 76
  optional refDb String = 77
  optional simSearchMeth String = 78
  optional taxClass String = 79
  optional complScore String = 80
  optional complSoftware String = 81
  optional associatedResource String = 82
  optional sop String = 83
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: plant with environmental package human-gut
message Human-gutMIGSPlant
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated gastrointestDisord String = 11
  repeated liverDisord String = 12
  repeated specialDiet SpecialDietEnum = 13
  optional hostSubjectId String = 14
  optional hostAge QuantityValue = 15
  optional hostSex HostSexEnum = 16
  repeated ihmcMedicationCode Integer = 17
  repeated chemAdministration String = 18
  optional hostBodySite String = 19
  optional hostBodyProduct String = 20
  optional hostTotMass QuantityValue = 21
  optional hostHeight QuantityValue = 22
  repeated hostDiet String = 23
  repeated hostLastMeal String = 24
  repeated hostFamilyRelation String = 25
  optional hostGenotype String = 26
  optional hostPhenotype String = 27
  optional hostBodyTemp QuantityValue = 28
  optional hostBodyMassIndex QuantityValue = 29
  repeated ethnicity String = 30
  optional hostOccupation Integer = 31
  optional medicHistPerform String = 32
  optional hostPulse QuantityValue = 33
  repeated perturbation String = 34
  optional salinity QuantityValue = 35
  optional oxyStatSamp OxyStatSampEnum = 36
  repeated organismCount OrganismCountEnum = 37
  optional sampStoreTemp QuantityValue = 38
  optional sampStoreDur String = 39
  repeated hostSymbiont String = 40
  optional sampStoreLoc String = 41
  repeated miscParam String = 42
  sampName String = 43
  projectName String = 44
  optional hostDiseaseStat String = 45
  optional sampVolWeDnaExt QuantityValue = 46
  sampTaxonId String = 47
  optional experimentalFactor String = 48
  optional negContType NegContTypeEnum = 49
  optional posContType String = 50
  optional subspecfGenLin String = 51
  optional estimatedSize String = 52
  optional refBiomaterial String = 53
  optional sourceMatId String = 54
  optional specificHost String = 55
  optional hostSpecRange Integer = 56
  propagation String = 57
  optional encodedTraits String = 58
  isolGrowthCondt String = 59
  optional sampCollecDevice String = 60
  optional sampCollecMethod String = 61
  optional sampMatProcess String = 62
  optional sampSize QuantityValue = 63
  optional nuclAcidExt String = 64
  optional nuclAcidAmp String = 65
  optional libSize Integer = 66
  optional libReadsSeqd Integer = 67
  optional libLayout LibLayoutEnum = 68
  optional libVector String = 69
  optional libScreen String = 70
  optional adapters String = 71
  seqMeth String = 72
  optional taxIdent TaxIdentEnum = 73
  optional assemblyQual AssemblyQualEnum = 74
  optional assemblyName String = 75
  assemblySoftware String = 76
  optional annot String = 77
  optional numberContig Integer = 78
  optional featPred String = 79
  optional refDb String = 80
  optional simSearchMeth String = 81
  optional taxClass String = 82
  optional complScore String = 83
  optional complSoftware String = 84
  optional associatedResource String = 85
  optional sop String = 86
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package human-gut
message Human-gutMIGSVirus
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated gastrointestDisord String = 11
  repeated liverDisord String = 12
  repeated specialDiet SpecialDietEnum = 13
  optional hostSubjectId String = 14
  optional hostAge QuantityValue = 15
  optional hostSex HostSexEnum = 16
  repeated ihmcMedicationCode Integer = 17
  repeated chemAdministration String = 18
  optional hostBodySite String = 19
  optional hostBodyProduct String = 20
  optional hostTotMass QuantityValue = 21
  optional hostHeight QuantityValue = 22
  repeated hostDiet String = 23
  repeated hostLastMeal String = 24
  repeated hostFamilyRelation String = 25
  optional hostGenotype String = 26
  optional hostPhenotype String = 27
  optional hostBodyTemp QuantityValue = 28
  optional hostBodyMassIndex QuantityValue = 29
  repeated ethnicity String = 30
  optional hostOccupation Integer = 31
  optional medicHistPerform String = 32
  optional hostPulse QuantityValue = 33
  repeated perturbation String = 34
  optional salinity QuantityValue = 35
  optional oxyStatSamp OxyStatSampEnum = 36
  repeated organismCount OrganismCountEnum = 37
  optional sampStoreTemp QuantityValue = 38
  optional sampStoreDur String = 39
  repeated hostSymbiont String = 40
  optional sampStoreLoc String = 41
  repeated miscParam String = 42
  sampName String = 43
  projectName String = 44
  optional hostDiseaseStat String = 45
  optional sampVolWeDnaExt QuantityValue = 46
  sampTaxonId String = 47
  optional experimentalFactor String = 48
  optional negContType NegContTypeEnum = 49
  optional posContType String = 50
  optional subspecfGenLin String = 51
  optional numReplicons Integer = 52
  optional estimatedSize String = 53
  optional refBiomaterial String = 54
  optional sourceMatId String = 55
  optional pathogenicity String = 56
  optional bioticRelationship BioticRelationshipEnum = 57
  optional specificHost String = 58
  optional hostSpecRange Integer = 59
  propagation String = 60
  optional encodedTraits String = 61
  isolGrowthCondt String = 62
  optional sampCollecDevice String = 63
  optional sampCollecMethod String = 64
  optional sampMatProcess String = 65
  optional sampSize QuantityValue = 66
  optional virusEnrichAppr VirusEnrichApprEnum = 67
  optional nuclAcidExt String = 68
  optional nuclAcidAmp String = 69
  optional libSize Integer = 70
  optional libReadsSeqd Integer = 71
  optional libLayout LibLayoutEnum = 72
  optional libVector String = 73
  optional libScreen String = 74
  optional adapters String = 75
  seqMeth String = 76
  optional taxIdent TaxIdentEnum = 77
  optional assemblyQual AssemblyQualEnum = 78
  optional assemblyName String = 79
  assemblySoftware String = 80
  optional annot String = 81
  optional numberContig Integer = 82
  optional featPred String = 83
  optional refDb String = 84
  optional simSearchMeth String = 85
  optional taxClass String = 86
  optional complScore String = 87
  optional complSoftware String = 88
  optional associatedResource String = 89
  optional sop String = 90
 }
// Combinatorial checklist Minimum Information About a Metagenome-Assembled Genome with environmental package human-gut
message Human-gutMIMAG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated gastrointestDisord String = 11
  repeated liverDisord String = 12
  repeated specialDiet SpecialDietEnum = 13
  optional hostSubjectId String = 14
  optional hostAge QuantityValue = 15
  optional hostSex HostSexEnum = 16
  repeated ihmcMedicationCode Integer = 17
  repeated chemAdministration String = 18
  optional hostBodySite String = 19
  optional hostBodyProduct String = 20
  optional hostTotMass QuantityValue = 21
  optional hostHeight QuantityValue = 22
  repeated hostDiet String = 23
  repeated hostLastMeal String = 24
  repeated hostFamilyRelation String = 25
  optional hostGenotype String = 26
  optional hostPhenotype String = 27
  optional hostBodyTemp QuantityValue = 28
  optional hostBodyMassIndex QuantityValue = 29
  repeated ethnicity String = 30
  optional hostOccupation Integer = 31
  optional medicHistPerform String = 32
  optional hostPulse QuantityValue = 33
  repeated perturbation String = 34
  optional salinity QuantityValue = 35
  optional oxyStatSamp OxyStatSampEnum = 36
  repeated organismCount OrganismCountEnum = 37
  optional sampStoreTemp QuantityValue = 38
  optional sampStoreDur String = 39
  repeated hostSymbiont String = 40
  optional sampStoreLoc String = 41
  repeated miscParam String = 42
  sampName String = 43
  projectName String = 44
  optional hostDiseaseStat String = 45
  optional sampVolWeDnaExt QuantityValue = 46
  sampTaxonId String = 47
  optional experimentalFactor String = 48
  optional negContType NegContTypeEnum = 49
  optional posContType String = 50
  optional refBiomaterial String = 51
  optional sourceMatId String = 52
  optional relToOxygen RelToOxygenEnum = 53
  optional sampCollecDevice String = 54
  optional sampCollecMethod String = 55
  optional sampMatProcess String = 56
  optional sizeFrac String = 57
  optional sampSize QuantityValue = 58
  optional nuclAcidExt String = 59
  optional nuclAcidAmp String = 60
  optional libSize Integer = 61
  optional libReadsSeqd Integer = 62
  optional libLayout LibLayoutEnum = 63
  optional libVector String = 64
  optional libScreen String = 65
  optional mid String = 66
  optional adapters String = 67
  seqMeth String = 68
  taxIdent TaxIdentEnum = 69
  assemblyQual AssemblyQualEnum = 70
  optional assemblyName String = 71
  assemblySoftware String = 72
  optional annot String = 73
  optional numberContig Integer = 74
  optional featPred String = 75
  optional refDb String = 76
  optional simSearchMeth String = 77
  optional taxClass String = 78
  optional x16sRecover String = 79
  optional x16sRecoverSoftware String = 80
  optional trnas Integer = 81
  optional trnaExtSoftware String = 82
  complScore String = 83
  complSoftware String = 84
  optional complAppr ComplApprEnum = 85
  contamScore String = 86
  optional contamScreenInput String = 87
  optional contamScreenParam String = 88
  optional decontamSoftware DecontamSoftwareEnum = 89
  binParam BinParamEnum = 90
  binSoftware String = 91
  optional reassemblyBin String = 92
  optional magCovSoftware MagCovSoftwareEnum = 93
  optional associatedResource String = 94
  optional sop String = 95
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: specimen with environmental package human-gut
message Human-gutMIMARKSSpecimen
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated gastrointestDisord String = 11
  repeated liverDisord String = 12
  repeated specialDiet SpecialDietEnum = 13
  optional hostSubjectId String = 14
  optional hostAge QuantityValue = 15
  optional hostSex HostSexEnum = 16
  repeated ihmcMedicationCode Integer = 17
  repeated chemAdministration String = 18
  optional hostBodySite String = 19
  optional hostBodyProduct String = 20
  optional hostTotMass QuantityValue = 21
  optional hostHeight QuantityValue = 22
  repeated hostDiet String = 23
  repeated hostLastMeal String = 24
  repeated hostFamilyRelation String = 25
  optional hostGenotype String = 26
  optional hostPhenotype String = 27
  optional hostBodyTemp QuantityValue = 28
  optional hostBodyMassIndex QuantityValue = 29
  repeated ethnicity String = 30
  optional hostOccupation Integer = 31
  optional medicHistPerform String = 32
  optional hostPulse QuantityValue = 33
  repeated perturbation String = 34
  optional salinity QuantityValue = 35
  optional oxyStatSamp OxyStatSampEnum = 36
  repeated organismCount OrganismCountEnum = 37
  optional sampStoreTemp QuantityValue = 38
  optional sampStoreDur String = 39
  repeated hostSymbiont String = 40
  optional sampStoreLoc String = 41
  repeated miscParam String = 42
  sampName String = 43
  projectName String = 44
  optional hostDiseaseStat String = 45
  optional sampVolWeDnaExt QuantityValue = 46
  sampTaxonId String = 47
  optional experimentalFactor String = 48
  optional negContType NegContTypeEnum = 49
  optional posContType String = 50
  optional sourceMatId String = 51
  optional relToOxygen RelToOxygenEnum = 52
  optional sampCollecDevice String = 53
  optional sampCollecMethod String = 54
  optional sampMatProcess String = 55
  optional sizeFrac String = 56
  optional sampSize QuantityValue = 57
  optional nuclAcidExt String = 58
  optional nuclAcidAmp String = 59
  optional libSize Integer = 60
  optional libReadsSeqd Integer = 61
  optional libLayout LibLayoutEnum = 62
  optional libVector String = 63
  optional libScreen String = 64
  targetGene String = 65
  optional targetSubfragment String = 66
  optional pcrPrimers String = 67
  optional mid String = 68
  optional adapters String = 69
  optional pcrCond String = 70
  seqMeth String = 71
  optional seqQualityCheck String = 72
  optional chimeraCheck String = 73
  optional assemblySoftware String = 74
  optional associatedResource String = 75
  optional sop String = 76
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: survey with environmental package human-gut
message Human-gutMIMARKSSurvey
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated gastrointestDisord String = 11
  repeated liverDisord String = 12
  repeated specialDiet SpecialDietEnum = 13
  optional hostSubjectId String = 14
  optional hostAge QuantityValue = 15
  optional hostSex HostSexEnum = 16
  repeated ihmcMedicationCode Integer = 17
  repeated chemAdministration String = 18
  optional hostBodySite String = 19
  optional hostBodyProduct String = 20
  optional hostTotMass QuantityValue = 21
  optional hostHeight QuantityValue = 22
  repeated hostDiet String = 23
  repeated hostLastMeal String = 24
  repeated hostFamilyRelation String = 25
  optional hostGenotype String = 26
  optional hostPhenotype String = 27
  optional hostBodyTemp QuantityValue = 28
  optional hostBodyMassIndex QuantityValue = 29
  repeated ethnicity String = 30
  optional hostOccupation Integer = 31
  optional medicHistPerform String = 32
  optional hostPulse QuantityValue = 33
  repeated perturbation String = 34
  optional salinity QuantityValue = 35
  optional oxyStatSamp OxyStatSampEnum = 36
  repeated organismCount OrganismCountEnum = 37
  optional sampStoreTemp QuantityValue = 38
  optional sampStoreDur String = 39
  repeated hostSymbiont String = 40
  optional sampStoreLoc String = 41
  repeated miscParam String = 42
  sampName String = 43
  projectName String = 44
  optional hostDiseaseStat String = 45
  optional sampVolWeDnaExt QuantityValue = 46
  sampTaxonId String = 47
  optional experimentalFactor String = 48
  optional negContType NegContTypeEnum = 49
  optional posContType String = 50
  optional subspecfGenLin String = 51
  optional extrachromElements Integer = 52
  optional sourceMatId String = 53
  optional bioticRelationship BioticRelationshipEnum = 54
  optional trophicLevel TrophicLevelEnum = 55
  optional relToOxygen RelToOxygenEnum = 56
  isolGrowthCondt String = 57
  optional sampCollecDevice String = 58
  optional sampCollecMethod String = 59
  optional sampMatProcess String = 60
  optional sampSize QuantityValue = 61
  optional nuclAcidExt String = 62
  optional nuclAcidAmp String = 63
  targetGene String = 64
  optional targetSubfragment String = 65
  optional pcrPrimers String = 66
  optional pcrCond String = 67
  seqMeth String = 68
  optional seqQualityCheck String = 69
  optional chimeraCheck String = 70
  optional associatedResource String = 71
  optional sop String = 72
 }
// Combinatorial checklist Metagenome or Environmental with environmental package human-gut
message Human-gutMIMS
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated gastrointestDisord String = 11
  repeated liverDisord String = 12
  repeated specialDiet SpecialDietEnum = 13
  optional hostSubjectId String = 14
  optional hostAge QuantityValue = 15
  optional hostSex HostSexEnum = 16
  repeated ihmcMedicationCode Integer = 17
  repeated chemAdministration String = 18
  optional hostBodySite String = 19
  optional hostBodyProduct String = 20
  optional hostTotMass QuantityValue = 21
  optional hostHeight QuantityValue = 22
  repeated hostDiet String = 23
  repeated hostLastMeal String = 24
  repeated hostFamilyRelation String = 25
  optional hostGenotype String = 26
  optional hostPhenotype String = 27
  optional hostBodyTemp QuantityValue = 28
  optional hostBodyMassIndex QuantityValue = 29
  repeated ethnicity String = 30
  optional hostOccupation Integer = 31
  optional medicHistPerform String = 32
  optional hostPulse QuantityValue = 33
  repeated perturbation String = 34
  optional salinity QuantityValue = 35
  optional oxyStatSamp OxyStatSampEnum = 36
  repeated organismCount OrganismCountEnum = 37
  optional sampStoreTemp QuantityValue = 38
  optional sampStoreDur String = 39
  repeated hostSymbiont String = 40
  optional sampStoreLoc String = 41
  repeated miscParam String = 42
  sampName String = 43
  projectName String = 44
  optional hostDiseaseStat String = 45
  optional sampVolWeDnaExt QuantityValue = 46
  sampTaxonId String = 47
  optional experimentalFactor String = 48
  optional negContType NegContTypeEnum = 49
  optional posContType String = 50
  optional refBiomaterial String = 51
  optional sourceMatId String = 52
  optional relToOxygen RelToOxygenEnum = 53
  optional sampCollecDevice String = 54
  optional sampCollecMethod String = 55
  optional sampMatProcess String = 56
  optional sizeFrac String = 57
  optional sampSize QuantityValue = 58
  optional nuclAcidExt String = 59
  optional nuclAcidAmp String = 60
  optional libSize Integer = 61
  optional libReadsSeqd Integer = 62
  optional libLayout LibLayoutEnum = 63
  optional libVector String = 64
  optional libScreen String = 65
  optional mid String = 66
  optional adapters String = 67
  seqMeth String = 68
  optional assemblyQual AssemblyQualEnum = 69
  optional assemblyName String = 70
  optional assemblySoftware String = 71
  optional annot String = 72
  optional numberContig Integer = 73
  optional featPred String = 74
  optional refDb String = 75
  optional simSearchMeth String = 76
  optional taxClass String = 77
  optional associatedResource String = 78
  optional sop String = 79
 }
// Combinatorial checklist Minimum Information About a Single Amplified Genome with environmental package human-gut
message Human-gutMISAG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated gastrointestDisord String = 11
  repeated liverDisord String = 12
  repeated specialDiet SpecialDietEnum = 13
  optional hostSubjectId String = 14
  optional hostAge QuantityValue = 15
  optional hostSex HostSexEnum = 16
  repeated ihmcMedicationCode Integer = 17
  repeated chemAdministration String = 18
  optional hostBodySite String = 19
  optional hostBodyProduct String = 20
  optional hostTotMass QuantityValue = 21
  optional hostHeight QuantityValue = 22
  repeated hostDiet String = 23
  repeated hostLastMeal String = 24
  repeated hostFamilyRelation String = 25
  optional hostGenotype String = 26
  optional hostPhenotype String = 27
  optional hostBodyTemp QuantityValue = 28
  optional hostBodyMassIndex QuantityValue = 29
  repeated ethnicity String = 30
  optional hostOccupation Integer = 31
  optional medicHistPerform String = 32
  optional hostPulse QuantityValue = 33
  repeated perturbation String = 34
  optional salinity QuantityValue = 35
  optional oxyStatSamp OxyStatSampEnum = 36
  repeated organismCount OrganismCountEnum = 37
  optional sampStoreTemp QuantityValue = 38
  optional sampStoreDur String = 39
  repeated hostSymbiont String = 40
  optional sampStoreLoc String = 41
  repeated miscParam String = 42
  sampName String = 43
  projectName String = 44
  optional hostDiseaseStat String = 45
  optional sampVolWeDnaExt QuantityValue = 46
  sampTaxonId String = 47
  optional experimentalFactor String = 48
  optional negContType NegContTypeEnum = 49
  optional posContType String = 50
  optional refBiomaterial String = 51
  optional sourceMatId String = 52
  optional relToOxygen RelToOxygenEnum = 53
  optional sampCollecDevice String = 54
  optional sampCollecMethod String = 55
  optional sampMatProcess String = 56
  optional sizeFrac String = 57
  optional sampSize QuantityValue = 58
  optional nuclAcidExt String = 59
  optional nuclAcidAmp String = 60
  optional libSize Integer = 61
  optional libReadsSeqd Integer = 62
  optional libLayout LibLayoutEnum = 63
  optional libVector String = 64
  optional libScreen String = 65
  optional mid String = 66
  optional adapters String = 67
  seqMeth String = 68
  taxIdent TaxIdentEnum = 69
  assemblyQual AssemblyQualEnum = 70
  optional assemblyName String = 71
  assemblySoftware String = 72
  optional annot String = 73
  optional numberContig Integer = 74
  optional featPred String = 75
  optional refDb String = 76
  optional simSearchMeth String = 77
  optional taxClass String = 78
  optional x16sRecover String = 79
  optional x16sRecoverSoftware String = 80
  optional trnas Integer = 81
  optional trnaExtSoftware String = 82
  complScore String = 83
  complSoftware String = 84
  optional complAppr ComplApprEnum = 85
  contamScore String = 86
  optional contamScreenInput String = 87
  optional contamScreenParam String = 88
  optional decontamSoftware DecontamSoftwareEnum = 89
  sortTech SortTechEnum = 90
  singleCellLysisAppr SingleCellLysisApprEnum = 91
  optional singleCellLysisProt String = 92
  wgaAmpAppr String = 93
  optional wgaAmpKit String = 94
  optional associatedResource String = 95
  optional sop String = 96
 }
// Combinatorial checklist Minimum Information About an Uncultivated Virus Genome with environmental package human-gut
message Human-gutMIUVIG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated gastrointestDisord String = 11
  repeated liverDisord String = 12
  repeated specialDiet SpecialDietEnum = 13
  optional hostSubjectId String = 14
  optional hostAge QuantityValue = 15
  optional hostSex HostSexEnum = 16
  repeated ihmcMedicationCode Integer = 17
  repeated chemAdministration String = 18
  optional hostBodySite String = 19
  optional hostBodyProduct String = 20
  optional hostTotMass QuantityValue = 21
  optional hostHeight QuantityValue = 22
  repeated hostDiet String = 23
  repeated hostLastMeal String = 24
  repeated hostFamilyRelation String = 25
  optional hostGenotype String = 26
  optional hostPhenotype String = 27
  optional hostBodyTemp QuantityValue = 28
  optional hostBodyMassIndex QuantityValue = 29
  repeated ethnicity String = 30
  optional hostOccupation Integer = 31
  optional medicHistPerform String = 32
  optional hostPulse QuantityValue = 33
  repeated perturbation String = 34
  optional salinity QuantityValue = 35
  optional oxyStatSamp OxyStatSampEnum = 36
  repeated organismCount OrganismCountEnum = 37
  optional sampStoreTemp QuantityValue = 38
  optional sampStoreDur String = 39
  repeated hostSymbiont String = 40
  optional sampStoreLoc String = 41
  repeated miscParam String = 42
  sampName String = 43
  projectName String = 44
  optional hostDiseaseStat String = 45
  optional sampVolWeDnaExt QuantityValue = 46
  sampTaxonId String = 47
  optional experimentalFactor String = 48
  optional negContType NegContTypeEnum = 49
  optional posContType String = 50
  optional estimatedSize String = 51
  optional refBiomaterial String = 52
  optional sourceMatId String = 53
  optional pathogenicity String = 54
  optional bioticRelationship BioticRelationshipEnum = 55
  optional specificHost String = 56
  optional hostSpecRange Integer = 57
  optional sampCollecDevice String = 58
  optional sampCollecMethod String = 59
  optional sampMatProcess String = 60
  optional sizeFrac String = 61
  optional sampSize QuantityValue = 62
  sourceUvig SourceUvigEnum = 63
  virusEnrichAppr VirusEnrichApprEnum = 64
  optional nuclAcidExt String = 65
  optional nuclAcidAmp String = 66
  optional libSize Integer = 67
  optional libReadsSeqd Integer = 68
  optional libLayout LibLayoutEnum = 69
  optional libVector String = 70
  optional libScreen String = 71
  optional mid String = 72
  optional adapters String = 73
  seqMeth String = 74
  optional taxIdent TaxIdentEnum = 75
  assemblyQual AssemblyQualEnum = 76
  optional assemblyName String = 77
  assemblySoftware String = 78
  optional annot String = 79
  numberContig Integer = 80
  optional featPred String = 81
  optional refDb String = 82
  optional simSearchMeth String = 83
  optional taxClass String = 84
  optional trnas Integer = 85
  optional trnaExtSoftware String = 86
  optional complScore String = 87
  optional complSoftware String = 88
  optional complAppr ComplApprEnum = 89
  optional sortTech SortTechEnum = 90
  optional singleCellLysisAppr SingleCellLysisApprEnum = 91
  optional singleCellLysisProt String = 92
  optional wgaAmpAppr String = 93
  optional wgaAmpKit String = 94
  optional binParam BinParamEnum = 95
  optional binSoftware String = 96
  optional reassemblyBin String = 97
  optional magCovSoftware MagCovSoftwareEnum = 98
  virIdentSoftware String = 99
  predGenomeType PredGenomeTypeEnum = 100
  predGenomeStruc PredGenomeStrucEnum = 101
  detecType String = 102
  optional otuClassAppr String = 103
  optional otuSeqCompAppr String = 104
  optional otuDb String = 105
  optional hostPredAppr HostPredApprEnum = 106
  optional hostPredEstAcc String = 107
  optional associatedResource String = 108
  optional sop String = 109
 }
// human-oral
message Human-oral
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated noseThroatDisord String = 11
  optional timeLastToothbrush String = 12
  optional hostSubjectId String = 13
  optional hostAge QuantityValue = 14
  optional hostSex HostSexEnum = 15
  repeated ihmcMedicationCode Integer = 16
  repeated chemAdministration String = 17
  optional hostBodySite String = 18
  optional hostBodyProduct String = 19
  optional hostTotMass QuantityValue = 20
  optional hostHeight QuantityValue = 21
  repeated hostDiet String = 22
  repeated hostLastMeal String = 23
  repeated hostFamilyRelation String = 24
  optional hostGenotype String = 25
  optional hostPhenotype String = 26
  optional hostBodyTemp QuantityValue = 27
  optional hostBodyMassIndex QuantityValue = 28
  repeated ethnicity String = 29
  optional hostOccupation Integer = 30
  optional medicHistPerform String = 31
  optional hostPulse QuantityValue = 32
  repeated perturbation String = 33
  optional salinity QuantityValue = 34
  optional oxyStatSamp OxyStatSampEnum = 35
  repeated organismCount OrganismCountEnum = 36
  optional sampStoreTemp QuantityValue = 37
  optional sampStoreDur String = 38
  repeated hostSymbiont String = 39
  optional sampStoreLoc String = 40
  repeated miscParam String = 41
  sampName String = 42
  projectName String = 43
  optional hostDiseaseStat String = 44
  optional sampVolWeDnaExt QuantityValue = 45
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package human-oral
message Human-oralMIGSBacteria
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated noseThroatDisord String = 11
  optional timeLastToothbrush String = 12
  optional hostSubjectId String = 13
  optional hostAge QuantityValue = 14
  optional hostSex HostSexEnum = 15
  repeated ihmcMedicationCode Integer = 16
  repeated chemAdministration String = 17
  optional hostBodySite String = 18
  optional hostBodyProduct String = 19
  optional hostTotMass QuantityValue = 20
  optional hostHeight QuantityValue = 21
  repeated hostDiet String = 22
  repeated hostLastMeal String = 23
  repeated hostFamilyRelation String = 24
  optional hostGenotype String = 25
  optional hostPhenotype String = 26
  optional hostBodyTemp QuantityValue = 27
  optional hostBodyMassIndex QuantityValue = 28
  repeated ethnicity String = 29
  optional hostOccupation Integer = 30
  optional medicHistPerform String = 31
  optional hostPulse QuantityValue = 32
  repeated perturbation String = 33
  optional salinity QuantityValue = 34
  optional oxyStatSamp OxyStatSampEnum = 35
  repeated organismCount OrganismCountEnum = 36
  optional sampStoreTemp QuantityValue = 37
  optional sampStoreDur String = 38
  repeated hostSymbiont String = 39
  optional sampStoreLoc String = 40
  repeated miscParam String = 41
  sampName String = 42
  projectName String = 43
  optional hostDiseaseStat String = 44
  optional sampVolWeDnaExt QuantityValue = 45
  sampTaxonId String = 46
  optional experimentalFactor String = 47
  optional negContType NegContTypeEnum = 48
  optional posContType String = 49
  optional subspecfGenLin String = 50
  numReplicons Integer = 51
  optional extrachromElements Integer = 52
  optional estimatedSize String = 53
  refBiomaterial String = 54
  optional sourceMatId String = 55
  optional pathogenicity String = 56
  optional bioticRelationship BioticRelationshipEnum = 57
  optional specificHost String = 58
  optional hostSpecRange Integer = 59
  optional trophicLevel TrophicLevelEnum = 60
  optional encodedTraits String = 61
  optional relToOxygen RelToOxygenEnum = 62
  isolGrowthCondt String = 63
  optional sampCollecDevice String = 64
  optional sampCollecMethod String = 65
  optional sampMatProcess String = 66
  optional sampSize QuantityValue = 67
  optional nuclAcidExt String = 68
  optional nuclAcidAmp String = 69
  optional libSize Integer = 70
  optional libReadsSeqd Integer = 71
  optional libLayout LibLayoutEnum = 72
  optional libVector String = 73
  optional libScreen String = 74
  optional adapters String = 75
  seqMeth String = 76
  optional taxIdent TaxIdentEnum = 77
  assemblyQual AssemblyQualEnum = 78
  optional assemblyName String = 79
  assemblySoftware String = 80
  optional annot String = 81
  numberContig Integer = 82
  optional featPred String = 83
  optional refDb String = 84
  optional simSearchMeth String = 85
  optional taxClass String = 86
  optional complScore String = 87
  optional complSoftware String = 88
  optional associatedResource String = 89
  optional sop String = 90
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: eukaryote with environmental package human-oral
message Human-oralMIGSEukaryote
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated noseThroatDisord String = 11
  optional timeLastToothbrush String = 12
  optional hostSubjectId String = 13
  optional hostAge QuantityValue = 14
  optional hostSex HostSexEnum = 15
  repeated ihmcMedicationCode Integer = 16
  repeated chemAdministration String = 17
  optional hostBodySite String = 18
  optional hostBodyProduct String = 19
  optional hostTotMass QuantityValue = 20
  optional hostHeight QuantityValue = 21
  repeated hostDiet String = 22
  repeated hostLastMeal String = 23
  repeated hostFamilyRelation String = 24
  optional hostGenotype String = 25
  optional hostPhenotype String = 26
  optional hostBodyTemp QuantityValue = 27
  optional hostBodyMassIndex QuantityValue = 28
  repeated ethnicity String = 29
  optional hostOccupation Integer = 30
  optional medicHistPerform String = 31
  optional hostPulse QuantityValue = 32
  repeated perturbation String = 33
  optional salinity QuantityValue = 34
  optional oxyStatSamp OxyStatSampEnum = 35
  repeated organismCount OrganismCountEnum = 36
  optional sampStoreTemp QuantityValue = 37
  optional sampStoreDur String = 38
  repeated hostSymbiont String = 39
  optional sampStoreLoc String = 40
  repeated miscParam String = 41
  sampName String = 42
  projectName String = 43
  optional hostDiseaseStat String = 44
  optional sampVolWeDnaExt QuantityValue = 45
  sampTaxonId String = 46
  optional experimentalFactor String = 47
  optional negContType NegContTypeEnum = 48
  optional posContType String = 49
  optional subspecfGenLin String = 50
  optional ploidy String = 51
  optional numReplicons Integer = 52
  optional extrachromElements Integer = 53
  optional estimatedSize String = 54
  optional refBiomaterial String = 55
  optional sourceMatId String = 56
  optional pathogenicity String = 57
  optional bioticRelationship BioticRelationshipEnum = 58
  optional specificHost String = 59
  optional hostSpecRange Integer = 60
  optional trophicLevel TrophicLevelEnum = 61
  optional propagation String = 62
  isolGrowthCondt String = 63
  optional sampCollecDevice String = 64
  optional sampCollecMethod String = 65
  optional sampMatProcess String = 66
  optional sampSize QuantityValue = 67
  optional nuclAcidExt String = 68
  optional nuclAcidAmp String = 69
  optional libSize Integer = 70
  optional libReadsSeqd Integer = 71
  optional libLayout LibLayoutEnum = 72
  optional libVector String = 73
  optional libScreen String = 74
  optional adapters String = 75
  seqMeth String = 76
  optional taxIdent TaxIdentEnum = 77
  assemblyQual AssemblyQualEnum = 78
  optional assemblyName String = 79
  assemblySoftware String = 80
  optional annot String = 81
  numberContig Integer = 82
  optional featPred String = 83
  optional refDb String = 84
  optional simSearchMeth String = 85
  optional taxClass String = 86
  optional complScore String = 87
  optional complSoftware String = 88
  optional associatedResource String = 89
  optional sop String = 90
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: org with environmental package human-oral
message Human-oralMIGSOrg
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated noseThroatDisord String = 11
  optional timeLastToothbrush String = 12
  optional hostSubjectId String = 13
  optional hostAge QuantityValue = 14
  optional hostSex HostSexEnum = 15
  repeated ihmcMedicationCode Integer = 16
  repeated chemAdministration String = 17
  optional hostBodySite String = 18
  optional hostBodyProduct String = 19
  optional hostTotMass QuantityValue = 20
  optional hostHeight QuantityValue = 21
  repeated hostDiet String = 22
  repeated hostLastMeal String = 23
  repeated hostFamilyRelation String = 24
  optional hostGenotype String = 25
  optional hostPhenotype String = 26
  optional hostBodyTemp QuantityValue = 27
  optional hostBodyMassIndex QuantityValue = 28
  repeated ethnicity String = 29
  optional hostOccupation Integer = 30
  optional medicHistPerform String = 31
  optional hostPulse QuantityValue = 32
  repeated perturbation String = 33
  optional salinity QuantityValue = 34
  optional oxyStatSamp OxyStatSampEnum = 35
  repeated organismCount OrganismCountEnum = 36
  optional sampStoreTemp QuantityValue = 37
  optional sampStoreDur String = 38
  repeated hostSymbiont String = 39
  optional sampStoreLoc String = 40
  repeated miscParam String = 41
  sampName String = 42
  projectName String = 43
  optional hostDiseaseStat String = 44
  optional sampVolWeDnaExt QuantityValue = 45
  sampTaxonId String = 46
  optional experimentalFactor String = 47
  optional negContType NegContTypeEnum = 48
  optional posContType String = 49
  optional subspecfGenLin String = 50
  optional extrachromElements Integer = 51
  optional estimatedSize String = 52
  optional refBiomaterial String = 53
  optional sourceMatId String = 54
  isolGrowthCondt String = 55
  optional sampCollecDevice String = 56
  optional sampCollecMethod String = 57
  optional sampMatProcess String = 58
  optional sampSize QuantityValue = 59
  optional nuclAcidExt String = 60
  optional nuclAcidAmp String = 61
  optional libSize Integer = 62
  optional libReadsSeqd Integer = 63
  optional libLayout LibLayoutEnum = 64
  optional libVector String = 65
  optional libScreen String = 66
  optional adapters String = 67
  seqMeth String = 68
  optional taxIdent TaxIdentEnum = 69
  optional assemblyQual AssemblyQualEnum = 70
  optional assemblyName String = 71
  assemblySoftware String = 72
  optional annot String = 73
  optional numberContig Integer = 74
  optional featPred String = 75
  optional refDb String = 76
  optional simSearchMeth String = 77
  optional taxClass String = 78
  optional complScore String = 79
  optional complSoftware String = 80
  optional associatedResource String = 81
  optional sop String = 82
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: plant with environmental package human-oral
message Human-oralMIGSPlant
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated noseThroatDisord String = 11
  optional timeLastToothbrush String = 12
  optional hostSubjectId String = 13
  optional hostAge QuantityValue = 14
  optional hostSex HostSexEnum = 15
  repeated ihmcMedicationCode Integer = 16
  repeated chemAdministration String = 17
  optional hostBodySite String = 18
  optional hostBodyProduct String = 19
  optional hostTotMass QuantityValue = 20
  optional hostHeight QuantityValue = 21
  repeated hostDiet String = 22
  repeated hostLastMeal String = 23
  repeated hostFamilyRelation String = 24
  optional hostGenotype String = 25
  optional hostPhenotype String = 26
  optional hostBodyTemp QuantityValue = 27
  optional hostBodyMassIndex QuantityValue = 28
  repeated ethnicity String = 29
  optional hostOccupation Integer = 30
  optional medicHistPerform String = 31
  optional hostPulse QuantityValue = 32
  repeated perturbation String = 33
  optional salinity QuantityValue = 34
  optional oxyStatSamp OxyStatSampEnum = 35
  repeated organismCount OrganismCountEnum = 36
  optional sampStoreTemp QuantityValue = 37
  optional sampStoreDur String = 38
  repeated hostSymbiont String = 39
  optional sampStoreLoc String = 40
  repeated miscParam String = 41
  sampName String = 42
  projectName String = 43
  optional hostDiseaseStat String = 44
  optional sampVolWeDnaExt QuantityValue = 45
  sampTaxonId String = 46
  optional experimentalFactor String = 47
  optional negContType NegContTypeEnum = 48
  optional posContType String = 49
  optional subspecfGenLin String = 50
  optional estimatedSize String = 51
  optional refBiomaterial String = 52
  optional sourceMatId String = 53
  optional specificHost String = 54
  optional hostSpecRange Integer = 55
  propagation String = 56
  optional encodedTraits String = 57
  isolGrowthCondt String = 58
  optional sampCollecDevice String = 59
  optional sampCollecMethod String = 60
  optional sampMatProcess String = 61
  optional sampSize QuantityValue = 62
  optional nuclAcidExt String = 63
  optional nuclAcidAmp String = 64
  optional libSize Integer = 65
  optional libReadsSeqd Integer = 66
  optional libLayout LibLayoutEnum = 67
  optional libVector String = 68
  optional libScreen String = 69
  optional adapters String = 70
  seqMeth String = 71
  optional taxIdent TaxIdentEnum = 72
  optional assemblyQual AssemblyQualEnum = 73
  optional assemblyName String = 74
  assemblySoftware String = 75
  optional annot String = 76
  optional numberContig Integer = 77
  optional featPred String = 78
  optional refDb String = 79
  optional simSearchMeth String = 80
  optional taxClass String = 81
  optional complScore String = 82
  optional complSoftware String = 83
  optional associatedResource String = 84
  optional sop String = 85
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package human-oral
message Human-oralMIGSVirus
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated noseThroatDisord String = 11
  optional timeLastToothbrush String = 12
  optional hostSubjectId String = 13
  optional hostAge QuantityValue = 14
  optional hostSex HostSexEnum = 15
  repeated ihmcMedicationCode Integer = 16
  repeated chemAdministration String = 17
  optional hostBodySite String = 18
  optional hostBodyProduct String = 19
  optional hostTotMass QuantityValue = 20
  optional hostHeight QuantityValue = 21
  repeated hostDiet String = 22
  repeated hostLastMeal String = 23
  repeated hostFamilyRelation String = 24
  optional hostGenotype String = 25
  optional hostPhenotype String = 26
  optional hostBodyTemp QuantityValue = 27
  optional hostBodyMassIndex QuantityValue = 28
  repeated ethnicity String = 29
  optional hostOccupation Integer = 30
  optional medicHistPerform String = 31
  optional hostPulse QuantityValue = 32
  repeated perturbation String = 33
  optional salinity QuantityValue = 34
  optional oxyStatSamp OxyStatSampEnum = 35
  repeated organismCount OrganismCountEnum = 36
  optional sampStoreTemp QuantityValue = 37
  optional sampStoreDur String = 38
  repeated hostSymbiont String = 39
  optional sampStoreLoc String = 40
  repeated miscParam String = 41
  sampName String = 42
  projectName String = 43
  optional hostDiseaseStat String = 44
  optional sampVolWeDnaExt QuantityValue = 45
  sampTaxonId String = 46
  optional experimentalFactor String = 47
  optional negContType NegContTypeEnum = 48
  optional posContType String = 49
  optional subspecfGenLin String = 50
  optional numReplicons Integer = 51
  optional estimatedSize String = 52
  optional refBiomaterial String = 53
  optional sourceMatId String = 54
  optional pathogenicity String = 55
  optional bioticRelationship BioticRelationshipEnum = 56
  optional specificHost String = 57
  optional hostSpecRange Integer = 58
  propagation String = 59
  optional encodedTraits String = 60
  isolGrowthCondt String = 61
  optional sampCollecDevice String = 62
  optional sampCollecMethod String = 63
  optional sampMatProcess String = 64
  optional sampSize QuantityValue = 65
  optional virusEnrichAppr VirusEnrichApprEnum = 66
  optional nuclAcidExt String = 67
  optional nuclAcidAmp String = 68
  optional libSize Integer = 69
  optional libReadsSeqd Integer = 70
  optional libLayout LibLayoutEnum = 71
  optional libVector String = 72
  optional libScreen String = 73
  optional adapters String = 74
  seqMeth String = 75
  optional taxIdent TaxIdentEnum = 76
  optional assemblyQual AssemblyQualEnum = 77
  optional assemblyName String = 78
  assemblySoftware String = 79
  optional annot String = 80
  optional numberContig Integer = 81
  optional featPred String = 82
  optional refDb String = 83
  optional simSearchMeth String = 84
  optional taxClass String = 85
  optional complScore String = 86
  optional complSoftware String = 87
  optional associatedResource String = 88
  optional sop String = 89
 }
// Combinatorial checklist Minimum Information About a Metagenome-Assembled Genome with environmental package human-oral
message Human-oralMIMAG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated noseThroatDisord String = 11
  optional timeLastToothbrush String = 12
  optional hostSubjectId String = 13
  optional hostAge QuantityValue = 14
  optional hostSex HostSexEnum = 15
  repeated ihmcMedicationCode Integer = 16
  repeated chemAdministration String = 17
  optional hostBodySite String = 18
  optional hostBodyProduct String = 19
  optional hostTotMass QuantityValue = 20
  optional hostHeight QuantityValue = 21
  repeated hostDiet String = 22
  repeated hostLastMeal String = 23
  repeated hostFamilyRelation String = 24
  optional hostGenotype String = 25
  optional hostPhenotype String = 26
  optional hostBodyTemp QuantityValue = 27
  optional hostBodyMassIndex QuantityValue = 28
  repeated ethnicity String = 29
  optional hostOccupation Integer = 30
  optional medicHistPerform String = 31
  optional hostPulse QuantityValue = 32
  repeated perturbation String = 33
  optional salinity QuantityValue = 34
  optional oxyStatSamp OxyStatSampEnum = 35
  repeated organismCount OrganismCountEnum = 36
  optional sampStoreTemp QuantityValue = 37
  optional sampStoreDur String = 38
  repeated hostSymbiont String = 39
  optional sampStoreLoc String = 40
  repeated miscParam String = 41
  sampName String = 42
  projectName String = 43
  optional hostDiseaseStat String = 44
  optional sampVolWeDnaExt QuantityValue = 45
  sampTaxonId String = 46
  optional experimentalFactor String = 47
  optional negContType NegContTypeEnum = 48
  optional posContType String = 49
  optional refBiomaterial String = 50
  optional sourceMatId String = 51
  optional relToOxygen RelToOxygenEnum = 52
  optional sampCollecDevice String = 53
  optional sampCollecMethod String = 54
  optional sampMatProcess String = 55
  optional sizeFrac String = 56
  optional sampSize QuantityValue = 57
  optional nuclAcidExt String = 58
  optional nuclAcidAmp String = 59
  optional libSize Integer = 60
  optional libReadsSeqd Integer = 61
  optional libLayout LibLayoutEnum = 62
  optional libVector String = 63
  optional libScreen String = 64
  optional mid String = 65
  optional adapters String = 66
  seqMeth String = 67
  taxIdent TaxIdentEnum = 68
  assemblyQual AssemblyQualEnum = 69
  optional assemblyName String = 70
  assemblySoftware String = 71
  optional annot String = 72
  optional numberContig Integer = 73
  optional featPred String = 74
  optional refDb String = 75
  optional simSearchMeth String = 76
  optional taxClass String = 77
  optional x16sRecover String = 78
  optional x16sRecoverSoftware String = 79
  optional trnas Integer = 80
  optional trnaExtSoftware String = 81
  complScore String = 82
  complSoftware String = 83
  optional complAppr ComplApprEnum = 84
  contamScore String = 85
  optional contamScreenInput String = 86
  optional contamScreenParam String = 87
  optional decontamSoftware DecontamSoftwareEnum = 88
  binParam BinParamEnum = 89
  binSoftware String = 90
  optional reassemblyBin String = 91
  optional magCovSoftware MagCovSoftwareEnum = 92
  optional associatedResource String = 93
  optional sop String = 94
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: specimen with environmental package human-oral
message Human-oralMIMARKSSpecimen
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated noseThroatDisord String = 11
  optional timeLastToothbrush String = 12
  optional hostSubjectId String = 13
  optional hostAge QuantityValue = 14
  optional hostSex HostSexEnum = 15
  repeated ihmcMedicationCode Integer = 16
  repeated chemAdministration String = 17
  optional hostBodySite String = 18
  optional hostBodyProduct String = 19
  optional hostTotMass QuantityValue = 20
  optional hostHeight QuantityValue = 21
  repeated hostDiet String = 22
  repeated hostLastMeal String = 23
  repeated hostFamilyRelation String = 24
  optional hostGenotype String = 25
  optional hostPhenotype String = 26
  optional hostBodyTemp QuantityValue = 27
  optional hostBodyMassIndex QuantityValue = 28
  repeated ethnicity String = 29
  optional hostOccupation Integer = 30
  optional medicHistPerform String = 31
  optional hostPulse QuantityValue = 32
  repeated perturbation String = 33
  optional salinity QuantityValue = 34
  optional oxyStatSamp OxyStatSampEnum = 35
  repeated organismCount OrganismCountEnum = 36
  optional sampStoreTemp QuantityValue = 37
  optional sampStoreDur String = 38
  repeated hostSymbiont String = 39
  optional sampStoreLoc String = 40
  repeated miscParam String = 41
  sampName String = 42
  projectName String = 43
  optional hostDiseaseStat String = 44
  optional sampVolWeDnaExt QuantityValue = 45
  sampTaxonId String = 46
  optional experimentalFactor String = 47
  optional negContType NegContTypeEnum = 48
  optional posContType String = 49
  optional sourceMatId String = 50
  optional relToOxygen RelToOxygenEnum = 51
  optional sampCollecDevice String = 52
  optional sampCollecMethod String = 53
  optional sampMatProcess String = 54
  optional sizeFrac String = 55
  optional sampSize QuantityValue = 56
  optional nuclAcidExt String = 57
  optional nuclAcidAmp String = 58
  optional libSize Integer = 59
  optional libReadsSeqd Integer = 60
  optional libLayout LibLayoutEnum = 61
  optional libVector String = 62
  optional libScreen String = 63
  targetGene String = 64
  optional targetSubfragment String = 65
  optional pcrPrimers String = 66
  optional mid String = 67
  optional adapters String = 68
  optional pcrCond String = 69
  seqMeth String = 70
  optional seqQualityCheck String = 71
  optional chimeraCheck String = 72
  optional assemblySoftware String = 73
  optional associatedResource String = 74
  optional sop String = 75
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: survey with environmental package human-oral
message Human-oralMIMARKSSurvey
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated noseThroatDisord String = 11
  optional timeLastToothbrush String = 12
  optional hostSubjectId String = 13
  optional hostAge QuantityValue = 14
  optional hostSex HostSexEnum = 15
  repeated ihmcMedicationCode Integer = 16
  repeated chemAdministration String = 17
  optional hostBodySite String = 18
  optional hostBodyProduct String = 19
  optional hostTotMass QuantityValue = 20
  optional hostHeight QuantityValue = 21
  repeated hostDiet String = 22
  repeated hostLastMeal String = 23
  repeated hostFamilyRelation String = 24
  optional hostGenotype String = 25
  optional hostPhenotype String = 26
  optional hostBodyTemp QuantityValue = 27
  optional hostBodyMassIndex QuantityValue = 28
  repeated ethnicity String = 29
  optional hostOccupation Integer = 30
  optional medicHistPerform String = 31
  optional hostPulse QuantityValue = 32
  repeated perturbation String = 33
  optional salinity QuantityValue = 34
  optional oxyStatSamp OxyStatSampEnum = 35
  repeated organismCount OrganismCountEnum = 36
  optional sampStoreTemp QuantityValue = 37
  optional sampStoreDur String = 38
  repeated hostSymbiont String = 39
  optional sampStoreLoc String = 40
  repeated miscParam String = 41
  sampName String = 42
  projectName String = 43
  optional hostDiseaseStat String = 44
  optional sampVolWeDnaExt QuantityValue = 45
  sampTaxonId String = 46
  optional experimentalFactor String = 47
  optional negContType NegContTypeEnum = 48
  optional posContType String = 49
  optional subspecfGenLin String = 50
  optional extrachromElements Integer = 51
  optional sourceMatId String = 52
  optional bioticRelationship BioticRelationshipEnum = 53
  optional trophicLevel TrophicLevelEnum = 54
  optional relToOxygen RelToOxygenEnum = 55
  isolGrowthCondt String = 56
  optional sampCollecDevice String = 57
  optional sampCollecMethod String = 58
  optional sampMatProcess String = 59
  optional sampSize QuantityValue = 60
  optional nuclAcidExt String = 61
  optional nuclAcidAmp String = 62
  targetGene String = 63
  optional targetSubfragment String = 64
  optional pcrPrimers String = 65
  optional pcrCond String = 66
  seqMeth String = 67
  optional seqQualityCheck String = 68
  optional chimeraCheck String = 69
  optional associatedResource String = 70
  optional sop String = 71
 }
// Combinatorial checklist Metagenome or Environmental with environmental package human-oral
message Human-oralMIMS
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated noseThroatDisord String = 11
  optional timeLastToothbrush String = 12
  optional hostSubjectId String = 13
  optional hostAge QuantityValue = 14
  optional hostSex HostSexEnum = 15
  repeated ihmcMedicationCode Integer = 16
  repeated chemAdministration String = 17
  optional hostBodySite String = 18
  optional hostBodyProduct String = 19
  optional hostTotMass QuantityValue = 20
  optional hostHeight QuantityValue = 21
  repeated hostDiet String = 22
  repeated hostLastMeal String = 23
  repeated hostFamilyRelation String = 24
  optional hostGenotype String = 25
  optional hostPhenotype String = 26
  optional hostBodyTemp QuantityValue = 27
  optional hostBodyMassIndex QuantityValue = 28
  repeated ethnicity String = 29
  optional hostOccupation Integer = 30
  optional medicHistPerform String = 31
  optional hostPulse QuantityValue = 32
  repeated perturbation String = 33
  optional salinity QuantityValue = 34
  optional oxyStatSamp OxyStatSampEnum = 35
  repeated organismCount OrganismCountEnum = 36
  optional sampStoreTemp QuantityValue = 37
  optional sampStoreDur String = 38
  repeated hostSymbiont String = 39
  optional sampStoreLoc String = 40
  repeated miscParam String = 41
  sampName String = 42
  projectName String = 43
  optional hostDiseaseStat String = 44
  optional sampVolWeDnaExt QuantityValue = 45
  sampTaxonId String = 46
  optional experimentalFactor String = 47
  optional negContType NegContTypeEnum = 48
  optional posContType String = 49
  optional refBiomaterial String = 50
  optional sourceMatId String = 51
  optional relToOxygen RelToOxygenEnum = 52
  optional sampCollecDevice String = 53
  optional sampCollecMethod String = 54
  optional sampMatProcess String = 55
  optional sizeFrac String = 56
  optional sampSize QuantityValue = 57
  optional nuclAcidExt String = 58
  optional nuclAcidAmp String = 59
  optional libSize Integer = 60
  optional libReadsSeqd Integer = 61
  optional libLayout LibLayoutEnum = 62
  optional libVector String = 63
  optional libScreen String = 64
  optional mid String = 65
  optional adapters String = 66
  seqMeth String = 67
  optional assemblyQual AssemblyQualEnum = 68
  optional assemblyName String = 69
  optional assemblySoftware String = 70
  optional annot String = 71
  optional numberContig Integer = 72
  optional featPred String = 73
  optional refDb String = 74
  optional simSearchMeth String = 75
  optional taxClass String = 76
  optional associatedResource String = 77
  optional sop String = 78
 }
// Combinatorial checklist Minimum Information About a Single Amplified Genome with environmental package human-oral
message Human-oralMISAG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated noseThroatDisord String = 11
  optional timeLastToothbrush String = 12
  optional hostSubjectId String = 13
  optional hostAge QuantityValue = 14
  optional hostSex HostSexEnum = 15
  repeated ihmcMedicationCode Integer = 16
  repeated chemAdministration String = 17
  optional hostBodySite String = 18
  optional hostBodyProduct String = 19
  optional hostTotMass QuantityValue = 20
  optional hostHeight QuantityValue = 21
  repeated hostDiet String = 22
  repeated hostLastMeal String = 23
  repeated hostFamilyRelation String = 24
  optional hostGenotype String = 25
  optional hostPhenotype String = 26
  optional hostBodyTemp QuantityValue = 27
  optional hostBodyMassIndex QuantityValue = 28
  repeated ethnicity String = 29
  optional hostOccupation Integer = 30
  optional medicHistPerform String = 31
  optional hostPulse QuantityValue = 32
  repeated perturbation String = 33
  optional salinity QuantityValue = 34
  optional oxyStatSamp OxyStatSampEnum = 35
  repeated organismCount OrganismCountEnum = 36
  optional sampStoreTemp QuantityValue = 37
  optional sampStoreDur String = 38
  repeated hostSymbiont String = 39
  optional sampStoreLoc String = 40
  repeated miscParam String = 41
  sampName String = 42
  projectName String = 43
  optional hostDiseaseStat String = 44
  optional sampVolWeDnaExt QuantityValue = 45
  sampTaxonId String = 46
  optional experimentalFactor String = 47
  optional negContType NegContTypeEnum = 48
  optional posContType String = 49
  optional refBiomaterial String = 50
  optional sourceMatId String = 51
  optional relToOxygen RelToOxygenEnum = 52
  optional sampCollecDevice String = 53
  optional sampCollecMethod String = 54
  optional sampMatProcess String = 55
  optional sizeFrac String = 56
  optional sampSize QuantityValue = 57
  optional nuclAcidExt String = 58
  optional nuclAcidAmp String = 59
  optional libSize Integer = 60
  optional libReadsSeqd Integer = 61
  optional libLayout LibLayoutEnum = 62
  optional libVector String = 63
  optional libScreen String = 64
  optional mid String = 65
  optional adapters String = 66
  seqMeth String = 67
  taxIdent TaxIdentEnum = 68
  assemblyQual AssemblyQualEnum = 69
  optional assemblyName String = 70
  assemblySoftware String = 71
  optional annot String = 72
  optional numberContig Integer = 73
  optional featPred String = 74
  optional refDb String = 75
  optional simSearchMeth String = 76
  optional taxClass String = 77
  optional x16sRecover String = 78
  optional x16sRecoverSoftware String = 79
  optional trnas Integer = 80
  optional trnaExtSoftware String = 81
  complScore String = 82
  complSoftware String = 83
  optional complAppr ComplApprEnum = 84
  contamScore String = 85
  optional contamScreenInput String = 86
  optional contamScreenParam String = 87
  optional decontamSoftware DecontamSoftwareEnum = 88
  sortTech SortTechEnum = 89
  singleCellLysisAppr SingleCellLysisApprEnum = 90
  optional singleCellLysisProt String = 91
  wgaAmpAppr String = 92
  optional wgaAmpKit String = 93
  optional associatedResource String = 94
  optional sop String = 95
 }
// Combinatorial checklist Minimum Information About an Uncultivated Virus Genome with environmental package human-oral
message Human-oralMIUVIG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated noseThroatDisord String = 11
  optional timeLastToothbrush String = 12
  optional hostSubjectId String = 13
  optional hostAge QuantityValue = 14
  optional hostSex HostSexEnum = 15
  repeated ihmcMedicationCode Integer = 16
  repeated chemAdministration String = 17
  optional hostBodySite String = 18
  optional hostBodyProduct String = 19
  optional hostTotMass QuantityValue = 20
  optional hostHeight QuantityValue = 21
  repeated hostDiet String = 22
  repeated hostLastMeal String = 23
  repeated hostFamilyRelation String = 24
  optional hostGenotype String = 25
  optional hostPhenotype String = 26
  optional hostBodyTemp QuantityValue = 27
  optional hostBodyMassIndex QuantityValue = 28
  repeated ethnicity String = 29
  optional hostOccupation Integer = 30
  optional medicHistPerform String = 31
  optional hostPulse QuantityValue = 32
  repeated perturbation String = 33
  optional salinity QuantityValue = 34
  optional oxyStatSamp OxyStatSampEnum = 35
  repeated organismCount OrganismCountEnum = 36
  optional sampStoreTemp QuantityValue = 37
  optional sampStoreDur String = 38
  repeated hostSymbiont String = 39
  optional sampStoreLoc String = 40
  repeated miscParam String = 41
  sampName String = 42
  projectName String = 43
  optional hostDiseaseStat String = 44
  optional sampVolWeDnaExt QuantityValue = 45
  sampTaxonId String = 46
  optional experimentalFactor String = 47
  optional negContType NegContTypeEnum = 48
  optional posContType String = 49
  optional estimatedSize String = 50
  optional refBiomaterial String = 51
  optional sourceMatId String = 52
  optional pathogenicity String = 53
  optional bioticRelationship BioticRelationshipEnum = 54
  optional specificHost String = 55
  optional hostSpecRange Integer = 56
  optional sampCollecDevice String = 57
  optional sampCollecMethod String = 58
  optional sampMatProcess String = 59
  optional sizeFrac String = 60
  optional sampSize QuantityValue = 61
  sourceUvig SourceUvigEnum = 62
  virusEnrichAppr VirusEnrichApprEnum = 63
  optional nuclAcidExt String = 64
  optional nuclAcidAmp String = 65
  optional libSize Integer = 66
  optional libReadsSeqd Integer = 67
  optional libLayout LibLayoutEnum = 68
  optional libVector String = 69
  optional libScreen String = 70
  optional mid String = 71
  optional adapters String = 72
  seqMeth String = 73
  optional taxIdent TaxIdentEnum = 74
  assemblyQual AssemblyQualEnum = 75
  optional assemblyName String = 76
  assemblySoftware String = 77
  optional annot String = 78
  numberContig Integer = 79
  optional featPred String = 80
  optional refDb String = 81
  optional simSearchMeth String = 82
  optional taxClass String = 83
  optional trnas Integer = 84
  optional trnaExtSoftware String = 85
  optional complScore String = 86
  optional complSoftware String = 87
  optional complAppr ComplApprEnum = 88
  optional sortTech SortTechEnum = 89
  optional singleCellLysisAppr SingleCellLysisApprEnum = 90
  optional singleCellLysisProt String = 91
  optional wgaAmpAppr String = 92
  optional wgaAmpKit String = 93
  optional binParam BinParamEnum = 94
  optional binSoftware String = 95
  optional reassemblyBin String = 96
  optional magCovSoftware MagCovSoftwareEnum = 97
  virIdentSoftware String = 98
  predGenomeType PredGenomeTypeEnum = 99
  predGenomeStruc PredGenomeStrucEnum = 100
  detecType String = 101
  optional otuClassAppr String = 102
  optional otuSeqCompAppr String = 103
  optional otuDb String = 104
  optional hostPredAppr HostPredApprEnum = 105
  optional hostPredEstAcc String = 106
  optional associatedResource String = 107
  optional sop String = 108
 }
// human-skin
message Human-skin
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated dermatologyDisord String = 11
  optional timeSinceLastWash String = 12
  optional dominantHand DominantHandEnum = 13
  optional hostSubjectId String = 14
  optional hostAge QuantityValue = 15
  optional hostSex HostSexEnum = 16
  repeated ihmcMedicationCode Integer = 17
  repeated chemAdministration String = 18
  optional hostBodySite String = 19
  optional hostBodyProduct String = 20
  optional hostTotMass QuantityValue = 21
  optional hostHeight QuantityValue = 22
  repeated hostDiet String = 23
  repeated hostLastMeal String = 24
  repeated hostFamilyRelation String = 25
  optional hostGenotype String = 26
  optional hostPhenotype String = 27
  optional hostBodyTemp QuantityValue = 28
  optional hostBodyMassIndex QuantityValue = 29
  repeated ethnicity String = 30
  optional hostOccupation Integer = 31
  optional medicHistPerform String = 32
  optional hostPulse QuantityValue = 33
  repeated perturbation String = 34
  optional salinity QuantityValue = 35
  optional oxyStatSamp OxyStatSampEnum = 36
  repeated organismCount OrganismCountEnum = 37
  optional sampStoreTemp QuantityValue = 38
  optional sampStoreDur String = 39
  optional sampStoreLoc String = 40
  repeated hostSymbiont String = 41
  repeated miscParam String = 42
  sampName String = 43
  projectName String = 44
  optional hostDiseaseStat String = 45
  optional sampVolWeDnaExt QuantityValue = 46
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package human-skin
message Human-skinMIGSBacteria
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated dermatologyDisord String = 11
  optional timeSinceLastWash String = 12
  optional dominantHand DominantHandEnum = 13
  optional hostSubjectId String = 14
  optional hostAge QuantityValue = 15
  optional hostSex HostSexEnum = 16
  repeated ihmcMedicationCode Integer = 17
  repeated chemAdministration String = 18
  optional hostBodySite String = 19
  optional hostBodyProduct String = 20
  optional hostTotMass QuantityValue = 21
  optional hostHeight QuantityValue = 22
  repeated hostDiet String = 23
  repeated hostLastMeal String = 24
  repeated hostFamilyRelation String = 25
  optional hostGenotype String = 26
  optional hostPhenotype String = 27
  optional hostBodyTemp QuantityValue = 28
  optional hostBodyMassIndex QuantityValue = 29
  repeated ethnicity String = 30
  optional hostOccupation Integer = 31
  optional medicHistPerform String = 32
  optional hostPulse QuantityValue = 33
  repeated perturbation String = 34
  optional salinity QuantityValue = 35
  optional oxyStatSamp OxyStatSampEnum = 36
  repeated organismCount OrganismCountEnum = 37
  optional sampStoreTemp QuantityValue = 38
  optional sampStoreDur String = 39
  optional sampStoreLoc String = 40
  repeated hostSymbiont String = 41
  repeated miscParam String = 42
  sampName String = 43
  projectName String = 44
  optional hostDiseaseStat String = 45
  optional sampVolWeDnaExt QuantityValue = 46
  sampTaxonId String = 47
  optional experimentalFactor String = 48
  optional negContType NegContTypeEnum = 49
  optional posContType String = 50
  optional subspecfGenLin String = 51
  numReplicons Integer = 52
  optional extrachromElements Integer = 53
  optional estimatedSize String = 54
  refBiomaterial String = 55
  optional sourceMatId String = 56
  optional pathogenicity String = 57
  optional bioticRelationship BioticRelationshipEnum = 58
  optional specificHost String = 59
  optional hostSpecRange Integer = 60
  optional trophicLevel TrophicLevelEnum = 61
  optional encodedTraits String = 62
  optional relToOxygen RelToOxygenEnum = 63
  isolGrowthCondt String = 64
  optional sampCollecDevice String = 65
  optional sampCollecMethod String = 66
  optional sampMatProcess String = 67
  optional sampSize QuantityValue = 68
  optional nuclAcidExt String = 69
  optional nuclAcidAmp String = 70
  optional libSize Integer = 71
  optional libReadsSeqd Integer = 72
  optional libLayout LibLayoutEnum = 73
  optional libVector String = 74
  optional libScreen String = 75
  optional adapters String = 76
  seqMeth String = 77
  optional taxIdent TaxIdentEnum = 78
  assemblyQual AssemblyQualEnum = 79
  optional assemblyName String = 80
  assemblySoftware String = 81
  optional annot String = 82
  numberContig Integer = 83
  optional featPred String = 84
  optional refDb String = 85
  optional simSearchMeth String = 86
  optional taxClass String = 87
  optional complScore String = 88
  optional complSoftware String = 89
  optional associatedResource String = 90
  optional sop String = 91
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: eukaryote with environmental package human-skin
message Human-skinMIGSEukaryote
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated dermatologyDisord String = 11
  optional timeSinceLastWash String = 12
  optional dominantHand DominantHandEnum = 13
  optional hostSubjectId String = 14
  optional hostAge QuantityValue = 15
  optional hostSex HostSexEnum = 16
  repeated ihmcMedicationCode Integer = 17
  repeated chemAdministration String = 18
  optional hostBodySite String = 19
  optional hostBodyProduct String = 20
  optional hostTotMass QuantityValue = 21
  optional hostHeight QuantityValue = 22
  repeated hostDiet String = 23
  repeated hostLastMeal String = 24
  repeated hostFamilyRelation String = 25
  optional hostGenotype String = 26
  optional hostPhenotype String = 27
  optional hostBodyTemp QuantityValue = 28
  optional hostBodyMassIndex QuantityValue = 29
  repeated ethnicity String = 30
  optional hostOccupation Integer = 31
  optional medicHistPerform String = 32
  optional hostPulse QuantityValue = 33
  repeated perturbation String = 34
  optional salinity QuantityValue = 35
  optional oxyStatSamp OxyStatSampEnum = 36
  repeated organismCount OrganismCountEnum = 37
  optional sampStoreTemp QuantityValue = 38
  optional sampStoreDur String = 39
  optional sampStoreLoc String = 40
  repeated hostSymbiont String = 41
  repeated miscParam String = 42
  sampName String = 43
  projectName String = 44
  optional hostDiseaseStat String = 45
  optional sampVolWeDnaExt QuantityValue = 46
  sampTaxonId String = 47
  optional experimentalFactor String = 48
  optional negContType NegContTypeEnum = 49
  optional posContType String = 50
  optional subspecfGenLin String = 51
  optional ploidy String = 52
  optional numReplicons Integer = 53
  optional extrachromElements Integer = 54
  optional estimatedSize String = 55
  optional refBiomaterial String = 56
  optional sourceMatId String = 57
  optional pathogenicity String = 58
  optional bioticRelationship BioticRelationshipEnum = 59
  optional specificHost String = 60
  optional hostSpecRange Integer = 61
  optional trophicLevel TrophicLevelEnum = 62
  optional propagation String = 63
  isolGrowthCondt String = 64
  optional sampCollecDevice String = 65
  optional sampCollecMethod String = 66
  optional sampMatProcess String = 67
  optional sampSize QuantityValue = 68
  optional nuclAcidExt String = 69
  optional nuclAcidAmp String = 70
  optional libSize Integer = 71
  optional libReadsSeqd Integer = 72
  optional libLayout LibLayoutEnum = 73
  optional libVector String = 74
  optional libScreen String = 75
  optional adapters String = 76
  seqMeth String = 77
  optional taxIdent TaxIdentEnum = 78
  assemblyQual AssemblyQualEnum = 79
  optional assemblyName String = 80
  assemblySoftware String = 81
  optional annot String = 82
  numberContig Integer = 83
  optional featPred String = 84
  optional refDb String = 85
  optional simSearchMeth String = 86
  optional taxClass String = 87
  optional complScore String = 88
  optional complSoftware String = 89
  optional associatedResource String = 90
  optional sop String = 91
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: org with environmental package human-skin
message Human-skinMIGSOrg
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated dermatologyDisord String = 11
  optional timeSinceLastWash String = 12
  optional dominantHand DominantHandEnum = 13
  optional hostSubjectId String = 14
  optional hostAge QuantityValue = 15
  optional hostSex HostSexEnum = 16
  repeated ihmcMedicationCode Integer = 17
  repeated chemAdministration String = 18
  optional hostBodySite String = 19
  optional hostBodyProduct String = 20
  optional hostTotMass QuantityValue = 21
  optional hostHeight QuantityValue = 22
  repeated hostDiet String = 23
  repeated hostLastMeal String = 24
  repeated hostFamilyRelation String = 25
  optional hostGenotype String = 26
  optional hostPhenotype String = 27
  optional hostBodyTemp QuantityValue = 28
  optional hostBodyMassIndex QuantityValue = 29
  repeated ethnicity String = 30
  optional hostOccupation Integer = 31
  optional medicHistPerform String = 32
  optional hostPulse QuantityValue = 33
  repeated perturbation String = 34
  optional salinity QuantityValue = 35
  optional oxyStatSamp OxyStatSampEnum = 36
  repeated organismCount OrganismCountEnum = 37
  optional sampStoreTemp QuantityValue = 38
  optional sampStoreDur String = 39
  optional sampStoreLoc String = 40
  repeated hostSymbiont String = 41
  repeated miscParam String = 42
  sampName String = 43
  projectName String = 44
  optional hostDiseaseStat String = 45
  optional sampVolWeDnaExt QuantityValue = 46
  sampTaxonId String = 47
  optional experimentalFactor String = 48
  optional negContType NegContTypeEnum = 49
  optional posContType String = 50
  optional subspecfGenLin String = 51
  optional extrachromElements Integer = 52
  optional estimatedSize String = 53
  optional refBiomaterial String = 54
  optional sourceMatId String = 55
  isolGrowthCondt String = 56
  optional sampCollecDevice String = 57
  optional sampCollecMethod String = 58
  optional sampMatProcess String = 59
  optional sampSize QuantityValue = 60
  optional nuclAcidExt String = 61
  optional nuclAcidAmp String = 62
  optional libSize Integer = 63
  optional libReadsSeqd Integer = 64
  optional libLayout LibLayoutEnum = 65
  optional libVector String = 66
  optional libScreen String = 67
  optional adapters String = 68
  seqMeth String = 69
  optional taxIdent TaxIdentEnum = 70
  optional assemblyQual AssemblyQualEnum = 71
  optional assemblyName String = 72
  assemblySoftware String = 73
  optional annot String = 74
  optional numberContig Integer = 75
  optional featPred String = 76
  optional refDb String = 77
  optional simSearchMeth String = 78
  optional taxClass String = 79
  optional complScore String = 80
  optional complSoftware String = 81
  optional associatedResource String = 82
  optional sop String = 83
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: plant with environmental package human-skin
message Human-skinMIGSPlant
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated dermatologyDisord String = 11
  optional timeSinceLastWash String = 12
  optional dominantHand DominantHandEnum = 13
  optional hostSubjectId String = 14
  optional hostAge QuantityValue = 15
  optional hostSex HostSexEnum = 16
  repeated ihmcMedicationCode Integer = 17
  repeated chemAdministration String = 18
  optional hostBodySite String = 19
  optional hostBodyProduct String = 20
  optional hostTotMass QuantityValue = 21
  optional hostHeight QuantityValue = 22
  repeated hostDiet String = 23
  repeated hostLastMeal String = 24
  repeated hostFamilyRelation String = 25
  optional hostGenotype String = 26
  optional hostPhenotype String = 27
  optional hostBodyTemp QuantityValue = 28
  optional hostBodyMassIndex QuantityValue = 29
  repeated ethnicity String = 30
  optional hostOccupation Integer = 31
  optional medicHistPerform String = 32
  optional hostPulse QuantityValue = 33
  repeated perturbation String = 34
  optional salinity QuantityValue = 35
  optional oxyStatSamp OxyStatSampEnum = 36
  repeated organismCount OrganismCountEnum = 37
  optional sampStoreTemp QuantityValue = 38
  optional sampStoreDur String = 39
  optional sampStoreLoc String = 40
  repeated hostSymbiont String = 41
  repeated miscParam String = 42
  sampName String = 43
  projectName String = 44
  optional hostDiseaseStat String = 45
  optional sampVolWeDnaExt QuantityValue = 46
  sampTaxonId String = 47
  optional experimentalFactor String = 48
  optional negContType NegContTypeEnum = 49
  optional posContType String = 50
  optional subspecfGenLin String = 51
  optional estimatedSize String = 52
  optional refBiomaterial String = 53
  optional sourceMatId String = 54
  optional specificHost String = 55
  optional hostSpecRange Integer = 56
  propagation String = 57
  optional encodedTraits String = 58
  isolGrowthCondt String = 59
  optional sampCollecDevice String = 60
  optional sampCollecMethod String = 61
  optional sampMatProcess String = 62
  optional sampSize QuantityValue = 63
  optional nuclAcidExt String = 64
  optional nuclAcidAmp String = 65
  optional libSize Integer = 66
  optional libReadsSeqd Integer = 67
  optional libLayout LibLayoutEnum = 68
  optional libVector String = 69
  optional libScreen String = 70
  optional adapters String = 71
  seqMeth String = 72
  optional taxIdent TaxIdentEnum = 73
  optional assemblyQual AssemblyQualEnum = 74
  optional assemblyName String = 75
  assemblySoftware String = 76
  optional annot String = 77
  optional numberContig Integer = 78
  optional featPred String = 79
  optional refDb String = 80
  optional simSearchMeth String = 81
  optional taxClass String = 82
  optional complScore String = 83
  optional complSoftware String = 84
  optional associatedResource String = 85
  optional sop String = 86
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package human-skin
message Human-skinMIGSVirus
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated dermatologyDisord String = 11
  optional timeSinceLastWash String = 12
  optional dominantHand DominantHandEnum = 13
  optional hostSubjectId String = 14
  optional hostAge QuantityValue = 15
  optional hostSex HostSexEnum = 16
  repeated ihmcMedicationCode Integer = 17
  repeated chemAdministration String = 18
  optional hostBodySite String = 19
  optional hostBodyProduct String = 20
  optional hostTotMass QuantityValue = 21
  optional hostHeight QuantityValue = 22
  repeated hostDiet String = 23
  repeated hostLastMeal String = 24
  repeated hostFamilyRelation String = 25
  optional hostGenotype String = 26
  optional hostPhenotype String = 27
  optional hostBodyTemp QuantityValue = 28
  optional hostBodyMassIndex QuantityValue = 29
  repeated ethnicity String = 30
  optional hostOccupation Integer = 31
  optional medicHistPerform String = 32
  optional hostPulse QuantityValue = 33
  repeated perturbation String = 34
  optional salinity QuantityValue = 35
  optional oxyStatSamp OxyStatSampEnum = 36
  repeated organismCount OrganismCountEnum = 37
  optional sampStoreTemp QuantityValue = 38
  optional sampStoreDur String = 39
  optional sampStoreLoc String = 40
  repeated hostSymbiont String = 41
  repeated miscParam String = 42
  sampName String = 43
  projectName String = 44
  optional hostDiseaseStat String = 45
  optional sampVolWeDnaExt QuantityValue = 46
  sampTaxonId String = 47
  optional experimentalFactor String = 48
  optional negContType NegContTypeEnum = 49
  optional posContType String = 50
  optional subspecfGenLin String = 51
  optional numReplicons Integer = 52
  optional estimatedSize String = 53
  optional refBiomaterial String = 54
  optional sourceMatId String = 55
  optional pathogenicity String = 56
  optional bioticRelationship BioticRelationshipEnum = 57
  optional specificHost String = 58
  optional hostSpecRange Integer = 59
  propagation String = 60
  optional encodedTraits String = 61
  isolGrowthCondt String = 62
  optional sampCollecDevice String = 63
  optional sampCollecMethod String = 64
  optional sampMatProcess String = 65
  optional sampSize QuantityValue = 66
  optional virusEnrichAppr VirusEnrichApprEnum = 67
  optional nuclAcidExt String = 68
  optional nuclAcidAmp String = 69
  optional libSize Integer = 70
  optional libReadsSeqd Integer = 71
  optional libLayout LibLayoutEnum = 72
  optional libVector String = 73
  optional libScreen String = 74
  optional adapters String = 75
  seqMeth String = 76
  optional taxIdent TaxIdentEnum = 77
  optional assemblyQual AssemblyQualEnum = 78
  optional assemblyName String = 79
  assemblySoftware String = 80
  optional annot String = 81
  optional numberContig Integer = 82
  optional featPred String = 83
  optional refDb String = 84
  optional simSearchMeth String = 85
  optional taxClass String = 86
  optional complScore String = 87
  optional complSoftware String = 88
  optional associatedResource String = 89
  optional sop String = 90
 }
// Combinatorial checklist Minimum Information About a Metagenome-Assembled Genome with environmental package human-skin
message Human-skinMIMAG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated dermatologyDisord String = 11
  optional timeSinceLastWash String = 12
  optional dominantHand DominantHandEnum = 13
  optional hostSubjectId String = 14
  optional hostAge QuantityValue = 15
  optional hostSex HostSexEnum = 16
  repeated ihmcMedicationCode Integer = 17
  repeated chemAdministration String = 18
  optional hostBodySite String = 19
  optional hostBodyProduct String = 20
  optional hostTotMass QuantityValue = 21
  optional hostHeight QuantityValue = 22
  repeated hostDiet String = 23
  repeated hostLastMeal String = 24
  repeated hostFamilyRelation String = 25
  optional hostGenotype String = 26
  optional hostPhenotype String = 27
  optional hostBodyTemp QuantityValue = 28
  optional hostBodyMassIndex QuantityValue = 29
  repeated ethnicity String = 30
  optional hostOccupation Integer = 31
  optional medicHistPerform String = 32
  optional hostPulse QuantityValue = 33
  repeated perturbation String = 34
  optional salinity QuantityValue = 35
  optional oxyStatSamp OxyStatSampEnum = 36
  repeated organismCount OrganismCountEnum = 37
  optional sampStoreTemp QuantityValue = 38
  optional sampStoreDur String = 39
  optional sampStoreLoc String = 40
  repeated hostSymbiont String = 41
  repeated miscParam String = 42
  sampName String = 43
  projectName String = 44
  optional hostDiseaseStat String = 45
  optional sampVolWeDnaExt QuantityValue = 46
  sampTaxonId String = 47
  optional experimentalFactor String = 48
  optional negContType NegContTypeEnum = 49
  optional posContType String = 50
  optional refBiomaterial String = 51
  optional sourceMatId String = 52
  optional relToOxygen RelToOxygenEnum = 53
  optional sampCollecDevice String = 54
  optional sampCollecMethod String = 55
  optional sampMatProcess String = 56
  optional sizeFrac String = 57
  optional sampSize QuantityValue = 58
  optional nuclAcidExt String = 59
  optional nuclAcidAmp String = 60
  optional libSize Integer = 61
  optional libReadsSeqd Integer = 62
  optional libLayout LibLayoutEnum = 63
  optional libVector String = 64
  optional libScreen String = 65
  optional mid String = 66
  optional adapters String = 67
  seqMeth String = 68
  taxIdent TaxIdentEnum = 69
  assemblyQual AssemblyQualEnum = 70
  optional assemblyName String = 71
  assemblySoftware String = 72
  optional annot String = 73
  optional numberContig Integer = 74
  optional featPred String = 75
  optional refDb String = 76
  optional simSearchMeth String = 77
  optional taxClass String = 78
  optional x16sRecover String = 79
  optional x16sRecoverSoftware String = 80
  optional trnas Integer = 81
  optional trnaExtSoftware String = 82
  complScore String = 83
  complSoftware String = 84
  optional complAppr ComplApprEnum = 85
  contamScore String = 86
  optional contamScreenInput String = 87
  optional contamScreenParam String = 88
  optional decontamSoftware DecontamSoftwareEnum = 89
  binParam BinParamEnum = 90
  binSoftware String = 91
  optional reassemblyBin String = 92
  optional magCovSoftware MagCovSoftwareEnum = 93
  optional associatedResource String = 94
  optional sop String = 95
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: specimen with environmental package human-skin
message Human-skinMIMARKSSpecimen
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated dermatologyDisord String = 11
  optional timeSinceLastWash String = 12
  optional dominantHand DominantHandEnum = 13
  optional hostSubjectId String = 14
  optional hostAge QuantityValue = 15
  optional hostSex HostSexEnum = 16
  repeated ihmcMedicationCode Integer = 17
  repeated chemAdministration String = 18
  optional hostBodySite String = 19
  optional hostBodyProduct String = 20
  optional hostTotMass QuantityValue = 21
  optional hostHeight QuantityValue = 22
  repeated hostDiet String = 23
  repeated hostLastMeal String = 24
  repeated hostFamilyRelation String = 25
  optional hostGenotype String = 26
  optional hostPhenotype String = 27
  optional hostBodyTemp QuantityValue = 28
  optional hostBodyMassIndex QuantityValue = 29
  repeated ethnicity String = 30
  optional hostOccupation Integer = 31
  optional medicHistPerform String = 32
  optional hostPulse QuantityValue = 33
  repeated perturbation String = 34
  optional salinity QuantityValue = 35
  optional oxyStatSamp OxyStatSampEnum = 36
  repeated organismCount OrganismCountEnum = 37
  optional sampStoreTemp QuantityValue = 38
  optional sampStoreDur String = 39
  optional sampStoreLoc String = 40
  repeated hostSymbiont String = 41
  repeated miscParam String = 42
  sampName String = 43
  projectName String = 44
  optional hostDiseaseStat String = 45
  optional sampVolWeDnaExt QuantityValue = 46
  sampTaxonId String = 47
  optional experimentalFactor String = 48
  optional negContType NegContTypeEnum = 49
  optional posContType String = 50
  optional sourceMatId String = 51
  optional relToOxygen RelToOxygenEnum = 52
  optional sampCollecDevice String = 53
  optional sampCollecMethod String = 54
  optional sampMatProcess String = 55
  optional sizeFrac String = 56
  optional sampSize QuantityValue = 57
  optional nuclAcidExt String = 58
  optional nuclAcidAmp String = 59
  optional libSize Integer = 60
  optional libReadsSeqd Integer = 61
  optional libLayout LibLayoutEnum = 62
  optional libVector String = 63
  optional libScreen String = 64
  targetGene String = 65
  optional targetSubfragment String = 66
  optional pcrPrimers String = 67
  optional mid String = 68
  optional adapters String = 69
  optional pcrCond String = 70
  seqMeth String = 71
  optional seqQualityCheck String = 72
  optional chimeraCheck String = 73
  optional assemblySoftware String = 74
  optional associatedResource String = 75
  optional sop String = 76
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: survey with environmental package human-skin
message Human-skinMIMARKSSurvey
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated dermatologyDisord String = 11
  optional timeSinceLastWash String = 12
  optional dominantHand DominantHandEnum = 13
  optional hostSubjectId String = 14
  optional hostAge QuantityValue = 15
  optional hostSex HostSexEnum = 16
  repeated ihmcMedicationCode Integer = 17
  repeated chemAdministration String = 18
  optional hostBodySite String = 19
  optional hostBodyProduct String = 20
  optional hostTotMass QuantityValue = 21
  optional hostHeight QuantityValue = 22
  repeated hostDiet String = 23
  repeated hostLastMeal String = 24
  repeated hostFamilyRelation String = 25
  optional hostGenotype String = 26
  optional hostPhenotype String = 27
  optional hostBodyTemp QuantityValue = 28
  optional hostBodyMassIndex QuantityValue = 29
  repeated ethnicity String = 30
  optional hostOccupation Integer = 31
  optional medicHistPerform String = 32
  optional hostPulse QuantityValue = 33
  repeated perturbation String = 34
  optional salinity QuantityValue = 35
  optional oxyStatSamp OxyStatSampEnum = 36
  repeated organismCount OrganismCountEnum = 37
  optional sampStoreTemp QuantityValue = 38
  optional sampStoreDur String = 39
  optional sampStoreLoc String = 40
  repeated hostSymbiont String = 41
  repeated miscParam String = 42
  sampName String = 43
  projectName String = 44
  optional hostDiseaseStat String = 45
  optional sampVolWeDnaExt QuantityValue = 46
  sampTaxonId String = 47
  optional experimentalFactor String = 48
  optional negContType NegContTypeEnum = 49
  optional posContType String = 50
  optional subspecfGenLin String = 51
  optional extrachromElements Integer = 52
  optional sourceMatId String = 53
  optional bioticRelationship BioticRelationshipEnum = 54
  optional trophicLevel TrophicLevelEnum = 55
  optional relToOxygen RelToOxygenEnum = 56
  isolGrowthCondt String = 57
  optional sampCollecDevice String = 58
  optional sampCollecMethod String = 59
  optional sampMatProcess String = 60
  optional sampSize QuantityValue = 61
  optional nuclAcidExt String = 62
  optional nuclAcidAmp String = 63
  targetGene String = 64
  optional targetSubfragment String = 65
  optional pcrPrimers String = 66
  optional pcrCond String = 67
  seqMeth String = 68
  optional seqQualityCheck String = 69
  optional chimeraCheck String = 70
  optional associatedResource String = 71
  optional sop String = 72
 }
// Combinatorial checklist Metagenome or Environmental with environmental package human-skin
message Human-skinMIMS
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated dermatologyDisord String = 11
  optional timeSinceLastWash String = 12
  optional dominantHand DominantHandEnum = 13
  optional hostSubjectId String = 14
  optional hostAge QuantityValue = 15
  optional hostSex HostSexEnum = 16
  repeated ihmcMedicationCode Integer = 17
  repeated chemAdministration String = 18
  optional hostBodySite String = 19
  optional hostBodyProduct String = 20
  optional hostTotMass QuantityValue = 21
  optional hostHeight QuantityValue = 22
  repeated hostDiet String = 23
  repeated hostLastMeal String = 24
  repeated hostFamilyRelation String = 25
  optional hostGenotype String = 26
  optional hostPhenotype String = 27
  optional hostBodyTemp QuantityValue = 28
  optional hostBodyMassIndex QuantityValue = 29
  repeated ethnicity String = 30
  optional hostOccupation Integer = 31
  optional medicHistPerform String = 32
  optional hostPulse QuantityValue = 33
  repeated perturbation String = 34
  optional salinity QuantityValue = 35
  optional oxyStatSamp OxyStatSampEnum = 36
  repeated organismCount OrganismCountEnum = 37
  optional sampStoreTemp QuantityValue = 38
  optional sampStoreDur String = 39
  optional sampStoreLoc String = 40
  repeated hostSymbiont String = 41
  repeated miscParam String = 42
  sampName String = 43
  projectName String = 44
  optional hostDiseaseStat String = 45
  optional sampVolWeDnaExt QuantityValue = 46
  sampTaxonId String = 47
  optional experimentalFactor String = 48
  optional negContType NegContTypeEnum = 49
  optional posContType String = 50
  optional refBiomaterial String = 51
  optional sourceMatId String = 52
  optional relToOxygen RelToOxygenEnum = 53
  optional sampCollecDevice String = 54
  optional sampCollecMethod String = 55
  optional sampMatProcess String = 56
  optional sizeFrac String = 57
  optional sampSize QuantityValue = 58
  optional nuclAcidExt String = 59
  optional nuclAcidAmp String = 60
  optional libSize Integer = 61
  optional libReadsSeqd Integer = 62
  optional libLayout LibLayoutEnum = 63
  optional libVector String = 64
  optional libScreen String = 65
  optional mid String = 66
  optional adapters String = 67
  seqMeth String = 68
  optional assemblyQual AssemblyQualEnum = 69
  optional assemblyName String = 70
  optional assemblySoftware String = 71
  optional annot String = 72
  optional numberContig Integer = 73
  optional featPred String = 74
  optional refDb String = 75
  optional simSearchMeth String = 76
  optional taxClass String = 77
  optional associatedResource String = 78
  optional sop String = 79
 }
// Combinatorial checklist Minimum Information About a Single Amplified Genome with environmental package human-skin
message Human-skinMISAG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated dermatologyDisord String = 11
  optional timeSinceLastWash String = 12
  optional dominantHand DominantHandEnum = 13
  optional hostSubjectId String = 14
  optional hostAge QuantityValue = 15
  optional hostSex HostSexEnum = 16
  repeated ihmcMedicationCode Integer = 17
  repeated chemAdministration String = 18
  optional hostBodySite String = 19
  optional hostBodyProduct String = 20
  optional hostTotMass QuantityValue = 21
  optional hostHeight QuantityValue = 22
  repeated hostDiet String = 23
  repeated hostLastMeal String = 24
  repeated hostFamilyRelation String = 25
  optional hostGenotype String = 26
  optional hostPhenotype String = 27
  optional hostBodyTemp QuantityValue = 28
  optional hostBodyMassIndex QuantityValue = 29
  repeated ethnicity String = 30
  optional hostOccupation Integer = 31
  optional medicHistPerform String = 32
  optional hostPulse QuantityValue = 33
  repeated perturbation String = 34
  optional salinity QuantityValue = 35
  optional oxyStatSamp OxyStatSampEnum = 36
  repeated organismCount OrganismCountEnum = 37
  optional sampStoreTemp QuantityValue = 38
  optional sampStoreDur String = 39
  optional sampStoreLoc String = 40
  repeated hostSymbiont String = 41
  repeated miscParam String = 42
  sampName String = 43
  projectName String = 44
  optional hostDiseaseStat String = 45
  optional sampVolWeDnaExt QuantityValue = 46
  sampTaxonId String = 47
  optional experimentalFactor String = 48
  optional negContType NegContTypeEnum = 49
  optional posContType String = 50
  optional refBiomaterial String = 51
  optional sourceMatId String = 52
  optional relToOxygen RelToOxygenEnum = 53
  optional sampCollecDevice String = 54
  optional sampCollecMethod String = 55
  optional sampMatProcess String = 56
  optional sizeFrac String = 57
  optional sampSize QuantityValue = 58
  optional nuclAcidExt String = 59
  optional nuclAcidAmp String = 60
  optional libSize Integer = 61
  optional libReadsSeqd Integer = 62
  optional libLayout LibLayoutEnum = 63
  optional libVector String = 64
  optional libScreen String = 65
  optional mid String = 66
  optional adapters String = 67
  seqMeth String = 68
  taxIdent TaxIdentEnum = 69
  assemblyQual AssemblyQualEnum = 70
  optional assemblyName String = 71
  assemblySoftware String = 72
  optional annot String = 73
  optional numberContig Integer = 74
  optional featPred String = 75
  optional refDb String = 76
  optional simSearchMeth String = 77
  optional taxClass String = 78
  optional x16sRecover String = 79
  optional x16sRecoverSoftware String = 80
  optional trnas Integer = 81
  optional trnaExtSoftware String = 82
  complScore String = 83
  complSoftware String = 84
  optional complAppr ComplApprEnum = 85
  contamScore String = 86
  optional contamScreenInput String = 87
  optional contamScreenParam String = 88
  optional decontamSoftware DecontamSoftwareEnum = 89
  sortTech SortTechEnum = 90
  singleCellLysisAppr SingleCellLysisApprEnum = 91
  optional singleCellLysisProt String = 92
  wgaAmpAppr String = 93
  optional wgaAmpKit String = 94
  optional associatedResource String = 95
  optional sop String = 96
 }
// Combinatorial checklist Minimum Information About an Uncultivated Virus Genome with environmental package human-skin
message Human-skinMIUVIG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated dermatologyDisord String = 11
  optional timeSinceLastWash String = 12
  optional dominantHand DominantHandEnum = 13
  optional hostSubjectId String = 14
  optional hostAge QuantityValue = 15
  optional hostSex HostSexEnum = 16
  repeated ihmcMedicationCode Integer = 17
  repeated chemAdministration String = 18
  optional hostBodySite String = 19
  optional hostBodyProduct String = 20
  optional hostTotMass QuantityValue = 21
  optional hostHeight QuantityValue = 22
  repeated hostDiet String = 23
  repeated hostLastMeal String = 24
  repeated hostFamilyRelation String = 25
  optional hostGenotype String = 26
  optional hostPhenotype String = 27
  optional hostBodyTemp QuantityValue = 28
  optional hostBodyMassIndex QuantityValue = 29
  repeated ethnicity String = 30
  optional hostOccupation Integer = 31
  optional medicHistPerform String = 32
  optional hostPulse QuantityValue = 33
  repeated perturbation String = 34
  optional salinity QuantityValue = 35
  optional oxyStatSamp OxyStatSampEnum = 36
  repeated organismCount OrganismCountEnum = 37
  optional sampStoreTemp QuantityValue = 38
  optional sampStoreDur String = 39
  optional sampStoreLoc String = 40
  repeated hostSymbiont String = 41
  repeated miscParam String = 42
  sampName String = 43
  projectName String = 44
  optional hostDiseaseStat String = 45
  optional sampVolWeDnaExt QuantityValue = 46
  sampTaxonId String = 47
  optional experimentalFactor String = 48
  optional negContType NegContTypeEnum = 49
  optional posContType String = 50
  optional estimatedSize String = 51
  optional refBiomaterial String = 52
  optional sourceMatId String = 53
  optional pathogenicity String = 54
  optional bioticRelationship BioticRelationshipEnum = 55
  optional specificHost String = 56
  optional hostSpecRange Integer = 57
  optional sampCollecDevice String = 58
  optional sampCollecMethod String = 59
  optional sampMatProcess String = 60
  optional sizeFrac String = 61
  optional sampSize QuantityValue = 62
  sourceUvig SourceUvigEnum = 63
  virusEnrichAppr VirusEnrichApprEnum = 64
  optional nuclAcidExt String = 65
  optional nuclAcidAmp String = 66
  optional libSize Integer = 67
  optional libReadsSeqd Integer = 68
  optional libLayout LibLayoutEnum = 69
  optional libVector String = 70
  optional libScreen String = 71
  optional mid String = 72
  optional adapters String = 73
  seqMeth String = 74
  optional taxIdent TaxIdentEnum = 75
  assemblyQual AssemblyQualEnum = 76
  optional assemblyName String = 77
  assemblySoftware String = 78
  optional annot String = 79
  numberContig Integer = 80
  optional featPred String = 81
  optional refDb String = 82
  optional simSearchMeth String = 83
  optional taxClass String = 84
  optional trnas Integer = 85
  optional trnaExtSoftware String = 86
  optional complScore String = 87
  optional complSoftware String = 88
  optional complAppr ComplApprEnum = 89
  optional sortTech SortTechEnum = 90
  optional singleCellLysisAppr SingleCellLysisApprEnum = 91
  optional singleCellLysisProt String = 92
  optional wgaAmpAppr String = 93
  optional wgaAmpKit String = 94
  optional binParam BinParamEnum = 95
  optional binSoftware String = 96
  optional reassemblyBin String = 97
  optional magCovSoftware MagCovSoftwareEnum = 98
  virIdentSoftware String = 99
  predGenomeType PredGenomeTypeEnum = 100
  predGenomeStruc PredGenomeStrucEnum = 101
  detecType String = 102
  optional otuClassAppr String = 103
  optional otuSeqCompAppr String = 104
  optional otuDb String = 105
  optional hostPredAppr HostPredApprEnum = 106
  optional hostPredEstAcc String = 107
  optional associatedResource String = 108
  optional sop String = 109
 }
// human-vaginal
message Human-vaginal
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional menarche Date = 11
  optional sexualAct String = 12
  optional pregnancy Date = 13
  optional douche Date = 14
  optional birthControl String = 15
  optional menopause Date = 16
  optional hrt Date = 17
  optional hysterectomy String = 18
  repeated gynecologicDisord String = 19
  repeated urogenitDisord String = 20
  optional hostSubjectId String = 21
  optional hostAge QuantityValue = 22
  optional hostSex HostSexEnum = 23
  repeated ihmcMedicationCode Integer = 24
  repeated chemAdministration String = 25
  optional hostBodySite String = 26
  optional hostBodyProduct String = 27
  optional hostTotMass QuantityValue = 28
  optional hostHeight QuantityValue = 29
  repeated hostDiet String = 30
  repeated hostLastMeal String = 31
  repeated hostFamilyRelation String = 32
  optional hostGenotype String = 33
  optional hostPhenotype String = 34
  optional hostBodyTemp QuantityValue = 35
  optional hostBodyMassIndex QuantityValue = 36
  repeated ethnicity String = 37
  optional hostOccupation Integer = 38
  optional medicHistPerform String = 39
  optional hostPulse QuantityValue = 40
  repeated perturbation String = 41
  optional sampSalinity QuantityValue = 42
  optional salinity QuantityValue = 43
  optional oxyStatSamp OxyStatSampEnum = 44
  repeated organismCount OrganismCountEnum = 45
  optional sampStoreTemp QuantityValue = 46
  optional sampStoreLoc String = 47
  optional sampStoreDur String = 48
  repeated hostSymbiont String = 49
  repeated miscParam String = 50
  sampName String = 51
  projectName String = 52
  optional hostDiseaseStat String = 53
  optional sampVolWeDnaExt QuantityValue = 54
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package human-vaginal
message Human-vaginalMIGSBacteria
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional menarche Date = 11
  optional sexualAct String = 12
  optional pregnancy Date = 13
  optional douche Date = 14
  optional birthControl String = 15
  optional menopause Date = 16
  optional hrt Date = 17
  optional hysterectomy String = 18
  repeated gynecologicDisord String = 19
  repeated urogenitDisord String = 20
  optional hostSubjectId String = 21
  optional hostAge QuantityValue = 22
  optional hostSex HostSexEnum = 23
  repeated ihmcMedicationCode Integer = 24
  repeated chemAdministration String = 25
  optional hostBodySite String = 26
  optional hostBodyProduct String = 27
  optional hostTotMass QuantityValue = 28
  optional hostHeight QuantityValue = 29
  repeated hostDiet String = 30
  repeated hostLastMeal String = 31
  repeated hostFamilyRelation String = 32
  optional hostGenotype String = 33
  optional hostPhenotype String = 34
  optional hostBodyTemp QuantityValue = 35
  optional hostBodyMassIndex QuantityValue = 36
  repeated ethnicity String = 37
  optional hostOccupation Integer = 38
  optional medicHistPerform String = 39
  optional hostPulse QuantityValue = 40
  repeated perturbation String = 41
  optional sampSalinity QuantityValue = 42
  optional salinity QuantityValue = 43
  optional oxyStatSamp OxyStatSampEnum = 44
  repeated organismCount OrganismCountEnum = 45
  optional sampStoreTemp QuantityValue = 46
  optional sampStoreLoc String = 47
  optional sampStoreDur String = 48
  repeated hostSymbiont String = 49
  repeated miscParam String = 50
  sampName String = 51
  projectName String = 52
  optional hostDiseaseStat String = 53
  optional sampVolWeDnaExt QuantityValue = 54
  sampTaxonId String = 55
  optional experimentalFactor String = 56
  optional negContType NegContTypeEnum = 57
  optional posContType String = 58
  optional subspecfGenLin String = 59
  numReplicons Integer = 60
  optional extrachromElements Integer = 61
  optional estimatedSize String = 62
  refBiomaterial String = 63
  optional sourceMatId String = 64
  optional pathogenicity String = 65
  optional bioticRelationship BioticRelationshipEnum = 66
  optional specificHost String = 67
  optional hostSpecRange Integer = 68
  optional trophicLevel TrophicLevelEnum = 69
  optional encodedTraits String = 70
  optional relToOxygen RelToOxygenEnum = 71
  isolGrowthCondt String = 72
  optional sampCollecDevice String = 73
  optional sampCollecMethod String = 74
  optional sampMatProcess String = 75
  optional sampSize QuantityValue = 76
  optional nuclAcidExt String = 77
  optional nuclAcidAmp String = 78
  optional libSize Integer = 79
  optional libReadsSeqd Integer = 80
  optional libLayout LibLayoutEnum = 81
  optional libVector String = 82
  optional libScreen String = 83
  optional adapters String = 84
  seqMeth String = 85
  optional taxIdent TaxIdentEnum = 86
  assemblyQual AssemblyQualEnum = 87
  optional assemblyName String = 88
  assemblySoftware String = 89
  optional annot String = 90
  numberContig Integer = 91
  optional featPred String = 92
  optional refDb String = 93
  optional simSearchMeth String = 94
  optional taxClass String = 95
  optional complScore String = 96
  optional complSoftware String = 97
  optional associatedResource String = 98
  optional sop String = 99
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: eukaryote with environmental package human-vaginal
message Human-vaginalMIGSEukaryote
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional menarche Date = 11
  optional sexualAct String = 12
  optional pregnancy Date = 13
  optional douche Date = 14
  optional birthControl String = 15
  optional menopause Date = 16
  optional hrt Date = 17
  optional hysterectomy String = 18
  repeated gynecologicDisord String = 19
  repeated urogenitDisord String = 20
  optional hostSubjectId String = 21
  optional hostAge QuantityValue = 22
  optional hostSex HostSexEnum = 23
  repeated ihmcMedicationCode Integer = 24
  repeated chemAdministration String = 25
  optional hostBodySite String = 26
  optional hostBodyProduct String = 27
  optional hostTotMass QuantityValue = 28
  optional hostHeight QuantityValue = 29
  repeated hostDiet String = 30
  repeated hostLastMeal String = 31
  repeated hostFamilyRelation String = 32
  optional hostGenotype String = 33
  optional hostPhenotype String = 34
  optional hostBodyTemp QuantityValue = 35
  optional hostBodyMassIndex QuantityValue = 36
  repeated ethnicity String = 37
  optional hostOccupation Integer = 38
  optional medicHistPerform String = 39
  optional hostPulse QuantityValue = 40
  repeated perturbation String = 41
  optional sampSalinity QuantityValue = 42
  optional salinity QuantityValue = 43
  optional oxyStatSamp OxyStatSampEnum = 44
  repeated organismCount OrganismCountEnum = 45
  optional sampStoreTemp QuantityValue = 46
  optional sampStoreLoc String = 47
  optional sampStoreDur String = 48
  repeated hostSymbiont String = 49
  repeated miscParam String = 50
  sampName String = 51
  projectName String = 52
  optional hostDiseaseStat String = 53
  optional sampVolWeDnaExt QuantityValue = 54
  sampTaxonId String = 55
  optional experimentalFactor String = 56
  optional negContType NegContTypeEnum = 57
  optional posContType String = 58
  optional subspecfGenLin String = 59
  optional ploidy String = 60
  optional numReplicons Integer = 61
  optional extrachromElements Integer = 62
  optional estimatedSize String = 63
  optional refBiomaterial String = 64
  optional sourceMatId String = 65
  optional pathogenicity String = 66
  optional bioticRelationship BioticRelationshipEnum = 67
  optional specificHost String = 68
  optional hostSpecRange Integer = 69
  optional trophicLevel TrophicLevelEnum = 70
  optional propagation String = 71
  isolGrowthCondt String = 72
  optional sampCollecDevice String = 73
  optional sampCollecMethod String = 74
  optional sampMatProcess String = 75
  optional sampSize QuantityValue = 76
  optional nuclAcidExt String = 77
  optional nuclAcidAmp String = 78
  optional libSize Integer = 79
  optional libReadsSeqd Integer = 80
  optional libLayout LibLayoutEnum = 81
  optional libVector String = 82
  optional libScreen String = 83
  optional adapters String = 84
  seqMeth String = 85
  optional taxIdent TaxIdentEnum = 86
  assemblyQual AssemblyQualEnum = 87
  optional assemblyName String = 88
  assemblySoftware String = 89
  optional annot String = 90
  numberContig Integer = 91
  optional featPred String = 92
  optional refDb String = 93
  optional simSearchMeth String = 94
  optional taxClass String = 95
  optional complScore String = 96
  optional complSoftware String = 97
  optional associatedResource String = 98
  optional sop String = 99
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: org with environmental package human-vaginal
message Human-vaginalMIGSOrg
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional menarche Date = 11
  optional sexualAct String = 12
  optional pregnancy Date = 13
  optional douche Date = 14
  optional birthControl String = 15
  optional menopause Date = 16
  optional hrt Date = 17
  optional hysterectomy String = 18
  repeated gynecologicDisord String = 19
  repeated urogenitDisord String = 20
  optional hostSubjectId String = 21
  optional hostAge QuantityValue = 22
  optional hostSex HostSexEnum = 23
  repeated ihmcMedicationCode Integer = 24
  repeated chemAdministration String = 25
  optional hostBodySite String = 26
  optional hostBodyProduct String = 27
  optional hostTotMass QuantityValue = 28
  optional hostHeight QuantityValue = 29
  repeated hostDiet String = 30
  repeated hostLastMeal String = 31
  repeated hostFamilyRelation String = 32
  optional hostGenotype String = 33
  optional hostPhenotype String = 34
  optional hostBodyTemp QuantityValue = 35
  optional hostBodyMassIndex QuantityValue = 36
  repeated ethnicity String = 37
  optional hostOccupation Integer = 38
  optional medicHistPerform String = 39
  optional hostPulse QuantityValue = 40
  repeated perturbation String = 41
  optional sampSalinity QuantityValue = 42
  optional salinity QuantityValue = 43
  optional oxyStatSamp OxyStatSampEnum = 44
  repeated organismCount OrganismCountEnum = 45
  optional sampStoreTemp QuantityValue = 46
  optional sampStoreLoc String = 47
  optional sampStoreDur String = 48
  repeated hostSymbiont String = 49
  repeated miscParam String = 50
  sampName String = 51
  projectName String = 52
  optional hostDiseaseStat String = 53
  optional sampVolWeDnaExt QuantityValue = 54
  sampTaxonId String = 55
  optional experimentalFactor String = 56
  optional negContType NegContTypeEnum = 57
  optional posContType String = 58
  optional subspecfGenLin String = 59
  optional extrachromElements Integer = 60
  optional estimatedSize String = 61
  optional refBiomaterial String = 62
  optional sourceMatId String = 63
  isolGrowthCondt String = 64
  optional sampCollecDevice String = 65
  optional sampCollecMethod String = 66
  optional sampMatProcess String = 67
  optional sampSize QuantityValue = 68
  optional nuclAcidExt String = 69
  optional nuclAcidAmp String = 70
  optional libSize Integer = 71
  optional libReadsSeqd Integer = 72
  optional libLayout LibLayoutEnum = 73
  optional libVector String = 74
  optional libScreen String = 75
  optional adapters String = 76
  seqMeth String = 77
  optional taxIdent TaxIdentEnum = 78
  optional assemblyQual AssemblyQualEnum = 79
  optional assemblyName String = 80
  assemblySoftware String = 81
  optional annot String = 82
  optional numberContig Integer = 83
  optional featPred String = 84
  optional refDb String = 85
  optional simSearchMeth String = 86
  optional taxClass String = 87
  optional complScore String = 88
  optional complSoftware String = 89
  optional associatedResource String = 90
  optional sop String = 91
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: plant with environmental package human-vaginal
message Human-vaginalMIGSPlant
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional menarche Date = 11
  optional sexualAct String = 12
  optional pregnancy Date = 13
  optional douche Date = 14
  optional birthControl String = 15
  optional menopause Date = 16
  optional hrt Date = 17
  optional hysterectomy String = 18
  repeated gynecologicDisord String = 19
  repeated urogenitDisord String = 20
  optional hostSubjectId String = 21
  optional hostAge QuantityValue = 22
  optional hostSex HostSexEnum = 23
  repeated ihmcMedicationCode Integer = 24
  repeated chemAdministration String = 25
  optional hostBodySite String = 26
  optional hostBodyProduct String = 27
  optional hostTotMass QuantityValue = 28
  optional hostHeight QuantityValue = 29
  repeated hostDiet String = 30
  repeated hostLastMeal String = 31
  repeated hostFamilyRelation String = 32
  optional hostGenotype String = 33
  optional hostPhenotype String = 34
  optional hostBodyTemp QuantityValue = 35
  optional hostBodyMassIndex QuantityValue = 36
  repeated ethnicity String = 37
  optional hostOccupation Integer = 38
  optional medicHistPerform String = 39
  optional hostPulse QuantityValue = 40
  repeated perturbation String = 41
  optional sampSalinity QuantityValue = 42
  optional salinity QuantityValue = 43
  optional oxyStatSamp OxyStatSampEnum = 44
  repeated organismCount OrganismCountEnum = 45
  optional sampStoreTemp QuantityValue = 46
  optional sampStoreLoc String = 47
  optional sampStoreDur String = 48
  repeated hostSymbiont String = 49
  repeated miscParam String = 50
  sampName String = 51
  projectName String = 52
  optional hostDiseaseStat String = 53
  optional sampVolWeDnaExt QuantityValue = 54
  sampTaxonId String = 55
  optional experimentalFactor String = 56
  optional negContType NegContTypeEnum = 57
  optional posContType String = 58
  optional subspecfGenLin String = 59
  optional estimatedSize String = 60
  optional refBiomaterial String = 61
  optional sourceMatId String = 62
  optional specificHost String = 63
  optional hostSpecRange Integer = 64
  propagation String = 65
  optional encodedTraits String = 66
  isolGrowthCondt String = 67
  optional sampCollecDevice String = 68
  optional sampCollecMethod String = 69
  optional sampMatProcess String = 70
  optional sampSize QuantityValue = 71
  optional nuclAcidExt String = 72
  optional nuclAcidAmp String = 73
  optional libSize Integer = 74
  optional libReadsSeqd Integer = 75
  optional libLayout LibLayoutEnum = 76
  optional libVector String = 77
  optional libScreen String = 78
  optional adapters String = 79
  seqMeth String = 80
  optional taxIdent TaxIdentEnum = 81
  optional assemblyQual AssemblyQualEnum = 82
  optional assemblyName String = 83
  assemblySoftware String = 84
  optional annot String = 85
  optional numberContig Integer = 86
  optional featPred String = 87
  optional refDb String = 88
  optional simSearchMeth String = 89
  optional taxClass String = 90
  optional complScore String = 91
  optional complSoftware String = 92
  optional associatedResource String = 93
  optional sop String = 94
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package human-vaginal
message Human-vaginalMIGSVirus
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional menarche Date = 11
  optional sexualAct String = 12
  optional pregnancy Date = 13
  optional douche Date = 14
  optional birthControl String = 15
  optional menopause Date = 16
  optional hrt Date = 17
  optional hysterectomy String = 18
  repeated gynecologicDisord String = 19
  repeated urogenitDisord String = 20
  optional hostSubjectId String = 21
  optional hostAge QuantityValue = 22
  optional hostSex HostSexEnum = 23
  repeated ihmcMedicationCode Integer = 24
  repeated chemAdministration String = 25
  optional hostBodySite String = 26
  optional hostBodyProduct String = 27
  optional hostTotMass QuantityValue = 28
  optional hostHeight QuantityValue = 29
  repeated hostDiet String = 30
  repeated hostLastMeal String = 31
  repeated hostFamilyRelation String = 32
  optional hostGenotype String = 33
  optional hostPhenotype String = 34
  optional hostBodyTemp QuantityValue = 35
  optional hostBodyMassIndex QuantityValue = 36
  repeated ethnicity String = 37
  optional hostOccupation Integer = 38
  optional medicHistPerform String = 39
  optional hostPulse QuantityValue = 40
  repeated perturbation String = 41
  optional sampSalinity QuantityValue = 42
  optional salinity QuantityValue = 43
  optional oxyStatSamp OxyStatSampEnum = 44
  repeated organismCount OrganismCountEnum = 45
  optional sampStoreTemp QuantityValue = 46
  optional sampStoreLoc String = 47
  optional sampStoreDur String = 48
  repeated hostSymbiont String = 49
  repeated miscParam String = 50
  sampName String = 51
  projectName String = 52
  optional hostDiseaseStat String = 53
  optional sampVolWeDnaExt QuantityValue = 54
  sampTaxonId String = 55
  optional experimentalFactor String = 56
  optional negContType NegContTypeEnum = 57
  optional posContType String = 58
  optional subspecfGenLin String = 59
  optional numReplicons Integer = 60
  optional estimatedSize String = 61
  optional refBiomaterial String = 62
  optional sourceMatId String = 63
  optional pathogenicity String = 64
  optional bioticRelationship BioticRelationshipEnum = 65
  optional specificHost String = 66
  optional hostSpecRange Integer = 67
  propagation String = 68
  optional encodedTraits String = 69
  isolGrowthCondt String = 70
  optional sampCollecDevice String = 71
  optional sampCollecMethod String = 72
  optional sampMatProcess String = 73
  optional sampSize QuantityValue = 74
  optional virusEnrichAppr VirusEnrichApprEnum = 75
  optional nuclAcidExt String = 76
  optional nuclAcidAmp String = 77
  optional libSize Integer = 78
  optional libReadsSeqd Integer = 79
  optional libLayout LibLayoutEnum = 80
  optional libVector String = 81
  optional libScreen String = 82
  optional adapters String = 83
  seqMeth String = 84
  optional taxIdent TaxIdentEnum = 85
  optional assemblyQual AssemblyQualEnum = 86
  optional assemblyName String = 87
  assemblySoftware String = 88
  optional annot String = 89
  optional numberContig Integer = 90
  optional featPred String = 91
  optional refDb String = 92
  optional simSearchMeth String = 93
  optional taxClass String = 94
  optional complScore String = 95
  optional complSoftware String = 96
  optional associatedResource String = 97
  optional sop String = 98
 }
// Combinatorial checklist Minimum Information About a Metagenome-Assembled Genome with environmental package human-vaginal
message Human-vaginalMIMAG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional menarche Date = 11
  optional sexualAct String = 12
  optional pregnancy Date = 13
  optional douche Date = 14
  optional birthControl String = 15
  optional menopause Date = 16
  optional hrt Date = 17
  optional hysterectomy String = 18
  repeated gynecologicDisord String = 19
  repeated urogenitDisord String = 20
  optional hostSubjectId String = 21
  optional hostAge QuantityValue = 22
  optional hostSex HostSexEnum = 23
  repeated ihmcMedicationCode Integer = 24
  repeated chemAdministration String = 25
  optional hostBodySite String = 26
  optional hostBodyProduct String = 27
  optional hostTotMass QuantityValue = 28
  optional hostHeight QuantityValue = 29
  repeated hostDiet String = 30
  repeated hostLastMeal String = 31
  repeated hostFamilyRelation String = 32
  optional hostGenotype String = 33
  optional hostPhenotype String = 34
  optional hostBodyTemp QuantityValue = 35
  optional hostBodyMassIndex QuantityValue = 36
  repeated ethnicity String = 37
  optional hostOccupation Integer = 38
  optional medicHistPerform String = 39
  optional hostPulse QuantityValue = 40
  repeated perturbation String = 41
  optional sampSalinity QuantityValue = 42
  optional salinity QuantityValue = 43
  optional oxyStatSamp OxyStatSampEnum = 44
  repeated organismCount OrganismCountEnum = 45
  optional sampStoreTemp QuantityValue = 46
  optional sampStoreLoc String = 47
  optional sampStoreDur String = 48
  repeated hostSymbiont String = 49
  repeated miscParam String = 50
  sampName String = 51
  projectName String = 52
  optional hostDiseaseStat String = 53
  optional sampVolWeDnaExt QuantityValue = 54
  sampTaxonId String = 55
  optional experimentalFactor String = 56
  optional negContType NegContTypeEnum = 57
  optional posContType String = 58
  optional refBiomaterial String = 59
  optional sourceMatId String = 60
  optional relToOxygen RelToOxygenEnum = 61
  optional sampCollecDevice String = 62
  optional sampCollecMethod String = 63
  optional sampMatProcess String = 64
  optional sizeFrac String = 65
  optional sampSize QuantityValue = 66
  optional nuclAcidExt String = 67
  optional nuclAcidAmp String = 68
  optional libSize Integer = 69
  optional libReadsSeqd Integer = 70
  optional libLayout LibLayoutEnum = 71
  optional libVector String = 72
  optional libScreen String = 73
  optional mid String = 74
  optional adapters String = 75
  seqMeth String = 76
  taxIdent TaxIdentEnum = 77
  assemblyQual AssemblyQualEnum = 78
  optional assemblyName String = 79
  assemblySoftware String = 80
  optional annot String = 81
  optional numberContig Integer = 82
  optional featPred String = 83
  optional refDb String = 84
  optional simSearchMeth String = 85
  optional taxClass String = 86
  optional x16sRecover String = 87
  optional x16sRecoverSoftware String = 88
  optional trnas Integer = 89
  optional trnaExtSoftware String = 90
  complScore String = 91
  complSoftware String = 92
  optional complAppr ComplApprEnum = 93
  contamScore String = 94
  optional contamScreenInput String = 95
  optional contamScreenParam String = 96
  optional decontamSoftware DecontamSoftwareEnum = 97
  binParam BinParamEnum = 98
  binSoftware String = 99
  optional reassemblyBin String = 100
  optional magCovSoftware MagCovSoftwareEnum = 101
  optional associatedResource String = 102
  optional sop String = 103
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: specimen with environmental package human-vaginal
message Human-vaginalMIMARKSSpecimen
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional menarche Date = 11
  optional sexualAct String = 12
  optional pregnancy Date = 13
  optional douche Date = 14
  optional birthControl String = 15
  optional menopause Date = 16
  optional hrt Date = 17
  optional hysterectomy String = 18
  repeated gynecologicDisord String = 19
  repeated urogenitDisord String = 20
  optional hostSubjectId String = 21
  optional hostAge QuantityValue = 22
  optional hostSex HostSexEnum = 23
  repeated ihmcMedicationCode Integer = 24
  repeated chemAdministration String = 25
  optional hostBodySite String = 26
  optional hostBodyProduct String = 27
  optional hostTotMass QuantityValue = 28
  optional hostHeight QuantityValue = 29
  repeated hostDiet String = 30
  repeated hostLastMeal String = 31
  repeated hostFamilyRelation String = 32
  optional hostGenotype String = 33
  optional hostPhenotype String = 34
  optional hostBodyTemp QuantityValue = 35
  optional hostBodyMassIndex QuantityValue = 36
  repeated ethnicity String = 37
  optional hostOccupation Integer = 38
  optional medicHistPerform String = 39
  optional hostPulse QuantityValue = 40
  repeated perturbation String = 41
  optional sampSalinity QuantityValue = 42
  optional salinity QuantityValue = 43
  optional oxyStatSamp OxyStatSampEnum = 44
  repeated organismCount OrganismCountEnum = 45
  optional sampStoreTemp QuantityValue = 46
  optional sampStoreLoc String = 47
  optional sampStoreDur String = 48
  repeated hostSymbiont String = 49
  repeated miscParam String = 50
  sampName String = 51
  projectName String = 52
  optional hostDiseaseStat String = 53
  optional sampVolWeDnaExt QuantityValue = 54
  sampTaxonId String = 55
  optional experimentalFactor String = 56
  optional negContType NegContTypeEnum = 57
  optional posContType String = 58
  optional sourceMatId String = 59
  optional relToOxygen RelToOxygenEnum = 60
  optional sampCollecDevice String = 61
  optional sampCollecMethod String = 62
  optional sampMatProcess String = 63
  optional sizeFrac String = 64
  optional sampSize QuantityValue = 65
  optional nuclAcidExt String = 66
  optional nuclAcidAmp String = 67
  optional libSize Integer = 68
  optional libReadsSeqd Integer = 69
  optional libLayout LibLayoutEnum = 70
  optional libVector String = 71
  optional libScreen String = 72
  targetGene String = 73
  optional targetSubfragment String = 74
  optional pcrPrimers String = 75
  optional mid String = 76
  optional adapters String = 77
  optional pcrCond String = 78
  seqMeth String = 79
  optional seqQualityCheck String = 80
  optional chimeraCheck String = 81
  optional assemblySoftware String = 82
  optional associatedResource String = 83
  optional sop String = 84
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: survey with environmental package human-vaginal
message Human-vaginalMIMARKSSurvey
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional menarche Date = 11
  optional sexualAct String = 12
  optional pregnancy Date = 13
  optional douche Date = 14
  optional birthControl String = 15
  optional menopause Date = 16
  optional hrt Date = 17
  optional hysterectomy String = 18
  repeated gynecologicDisord String = 19
  repeated urogenitDisord String = 20
  optional hostSubjectId String = 21
  optional hostAge QuantityValue = 22
  optional hostSex HostSexEnum = 23
  repeated ihmcMedicationCode Integer = 24
  repeated chemAdministration String = 25
  optional hostBodySite String = 26
  optional hostBodyProduct String = 27
  optional hostTotMass QuantityValue = 28
  optional hostHeight QuantityValue = 29
  repeated hostDiet String = 30
  repeated hostLastMeal String = 31
  repeated hostFamilyRelation String = 32
  optional hostGenotype String = 33
  optional hostPhenotype String = 34
  optional hostBodyTemp QuantityValue = 35
  optional hostBodyMassIndex QuantityValue = 36
  repeated ethnicity String = 37
  optional hostOccupation Integer = 38
  optional medicHistPerform String = 39
  optional hostPulse QuantityValue = 40
  repeated perturbation String = 41
  optional sampSalinity QuantityValue = 42
  optional salinity QuantityValue = 43
  optional oxyStatSamp OxyStatSampEnum = 44
  repeated organismCount OrganismCountEnum = 45
  optional sampStoreTemp QuantityValue = 46
  optional sampStoreLoc String = 47
  optional sampStoreDur String = 48
  repeated hostSymbiont String = 49
  repeated miscParam String = 50
  sampName String = 51
  projectName String = 52
  optional hostDiseaseStat String = 53
  optional sampVolWeDnaExt QuantityValue = 54
  sampTaxonId String = 55
  optional experimentalFactor String = 56
  optional negContType NegContTypeEnum = 57
  optional posContType String = 58
  optional subspecfGenLin String = 59
  optional extrachromElements Integer = 60
  optional sourceMatId String = 61
  optional bioticRelationship BioticRelationshipEnum = 62
  optional trophicLevel TrophicLevelEnum = 63
  optional relToOxygen RelToOxygenEnum = 64
  isolGrowthCondt String = 65
  optional sampCollecDevice String = 66
  optional sampCollecMethod String = 67
  optional sampMatProcess String = 68
  optional sampSize QuantityValue = 69
  optional nuclAcidExt String = 70
  optional nuclAcidAmp String = 71
  targetGene String = 72
  optional targetSubfragment String = 73
  optional pcrPrimers String = 74
  optional pcrCond String = 75
  seqMeth String = 76
  optional seqQualityCheck String = 77
  optional chimeraCheck String = 78
  optional associatedResource String = 79
  optional sop String = 80
 }
// Combinatorial checklist Metagenome or Environmental with environmental package human-vaginal
message Human-vaginalMIMS
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional menarche Date = 11
  optional sexualAct String = 12
  optional pregnancy Date = 13
  optional douche Date = 14
  optional birthControl String = 15
  optional menopause Date = 16
  optional hrt Date = 17
  optional hysterectomy String = 18
  repeated gynecologicDisord String = 19
  repeated urogenitDisord String = 20
  optional hostSubjectId String = 21
  optional hostAge QuantityValue = 22
  optional hostSex HostSexEnum = 23
  repeated ihmcMedicationCode Integer = 24
  repeated chemAdministration String = 25
  optional hostBodySite String = 26
  optional hostBodyProduct String = 27
  optional hostTotMass QuantityValue = 28
  optional hostHeight QuantityValue = 29
  repeated hostDiet String = 30
  repeated hostLastMeal String = 31
  repeated hostFamilyRelation String = 32
  optional hostGenotype String = 33
  optional hostPhenotype String = 34
  optional hostBodyTemp QuantityValue = 35
  optional hostBodyMassIndex QuantityValue = 36
  repeated ethnicity String = 37
  optional hostOccupation Integer = 38
  optional medicHistPerform String = 39
  optional hostPulse QuantityValue = 40
  repeated perturbation String = 41
  optional sampSalinity QuantityValue = 42
  optional salinity QuantityValue = 43
  optional oxyStatSamp OxyStatSampEnum = 44
  repeated organismCount OrganismCountEnum = 45
  optional sampStoreTemp QuantityValue = 46
  optional sampStoreLoc String = 47
  optional sampStoreDur String = 48
  repeated hostSymbiont String = 49
  repeated miscParam String = 50
  sampName String = 51
  projectName String = 52
  optional hostDiseaseStat String = 53
  optional sampVolWeDnaExt QuantityValue = 54
  sampTaxonId String = 55
  optional experimentalFactor String = 56
  optional negContType NegContTypeEnum = 57
  optional posContType String = 58
  optional refBiomaterial String = 59
  optional sourceMatId String = 60
  optional relToOxygen RelToOxygenEnum = 61
  optional sampCollecDevice String = 62
  optional sampCollecMethod String = 63
  optional sampMatProcess String = 64
  optional sizeFrac String = 65
  optional sampSize QuantityValue = 66
  optional nuclAcidExt String = 67
  optional nuclAcidAmp String = 68
  optional libSize Integer = 69
  optional libReadsSeqd Integer = 70
  optional libLayout LibLayoutEnum = 71
  optional libVector String = 72
  optional libScreen String = 73
  optional mid String = 74
  optional adapters String = 75
  seqMeth String = 76
  optional assemblyQual AssemblyQualEnum = 77
  optional assemblyName String = 78
  optional assemblySoftware String = 79
  optional annot String = 80
  optional numberContig Integer = 81
  optional featPred String = 82
  optional refDb String = 83
  optional simSearchMeth String = 84
  optional taxClass String = 85
  optional associatedResource String = 86
  optional sop String = 87
 }
// Combinatorial checklist Minimum Information About a Single Amplified Genome with environmental package human-vaginal
message Human-vaginalMISAG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional menarche Date = 11
  optional sexualAct String = 12
  optional pregnancy Date = 13
  optional douche Date = 14
  optional birthControl String = 15
  optional menopause Date = 16
  optional hrt Date = 17
  optional hysterectomy String = 18
  repeated gynecologicDisord String = 19
  repeated urogenitDisord String = 20
  optional hostSubjectId String = 21
  optional hostAge QuantityValue = 22
  optional hostSex HostSexEnum = 23
  repeated ihmcMedicationCode Integer = 24
  repeated chemAdministration String = 25
  optional hostBodySite String = 26
  optional hostBodyProduct String = 27
  optional hostTotMass QuantityValue = 28
  optional hostHeight QuantityValue = 29
  repeated hostDiet String = 30
  repeated hostLastMeal String = 31
  repeated hostFamilyRelation String = 32
  optional hostGenotype String = 33
  optional hostPhenotype String = 34
  optional hostBodyTemp QuantityValue = 35
  optional hostBodyMassIndex QuantityValue = 36
  repeated ethnicity String = 37
  optional hostOccupation Integer = 38
  optional medicHistPerform String = 39
  optional hostPulse QuantityValue = 40
  repeated perturbation String = 41
  optional sampSalinity QuantityValue = 42
  optional salinity QuantityValue = 43
  optional oxyStatSamp OxyStatSampEnum = 44
  repeated organismCount OrganismCountEnum = 45
  optional sampStoreTemp QuantityValue = 46
  optional sampStoreLoc String = 47
  optional sampStoreDur String = 48
  repeated hostSymbiont String = 49
  repeated miscParam String = 50
  sampName String = 51
  projectName String = 52
  optional hostDiseaseStat String = 53
  optional sampVolWeDnaExt QuantityValue = 54
  sampTaxonId String = 55
  optional experimentalFactor String = 56
  optional negContType NegContTypeEnum = 57
  optional posContType String = 58
  optional refBiomaterial String = 59
  optional sourceMatId String = 60
  optional relToOxygen RelToOxygenEnum = 61
  optional sampCollecDevice String = 62
  optional sampCollecMethod String = 63
  optional sampMatProcess String = 64
  optional sizeFrac String = 65
  optional sampSize QuantityValue = 66
  optional nuclAcidExt String = 67
  optional nuclAcidAmp String = 68
  optional libSize Integer = 69
  optional libReadsSeqd Integer = 70
  optional libLayout LibLayoutEnum = 71
  optional libVector String = 72
  optional libScreen String = 73
  optional mid String = 74
  optional adapters String = 75
  seqMeth String = 76
  taxIdent TaxIdentEnum = 77
  assemblyQual AssemblyQualEnum = 78
  optional assemblyName String = 79
  assemblySoftware String = 80
  optional annot String = 81
  optional numberContig Integer = 82
  optional featPred String = 83
  optional refDb String = 84
  optional simSearchMeth String = 85
  optional taxClass String = 86
  optional x16sRecover String = 87
  optional x16sRecoverSoftware String = 88
  optional trnas Integer = 89
  optional trnaExtSoftware String = 90
  complScore String = 91
  complSoftware String = 92
  optional complAppr ComplApprEnum = 93
  contamScore String = 94
  optional contamScreenInput String = 95
  optional contamScreenParam String = 96
  optional decontamSoftware DecontamSoftwareEnum = 97
  sortTech SortTechEnum = 98
  singleCellLysisAppr SingleCellLysisApprEnum = 99
  optional singleCellLysisProt String = 100
  wgaAmpAppr String = 101
  optional wgaAmpKit String = 102
  optional associatedResource String = 103
  optional sop String = 104
 }
// Combinatorial checklist Minimum Information About an Uncultivated Virus Genome with environmental package human-vaginal
message Human-vaginalMIUVIG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional menarche Date = 11
  optional sexualAct String = 12
  optional pregnancy Date = 13
  optional douche Date = 14
  optional birthControl String = 15
  optional menopause Date = 16
  optional hrt Date = 17
  optional hysterectomy String = 18
  repeated gynecologicDisord String = 19
  repeated urogenitDisord String = 20
  optional hostSubjectId String = 21
  optional hostAge QuantityValue = 22
  optional hostSex HostSexEnum = 23
  repeated ihmcMedicationCode Integer = 24
  repeated chemAdministration String = 25
  optional hostBodySite String = 26
  optional hostBodyProduct String = 27
  optional hostTotMass QuantityValue = 28
  optional hostHeight QuantityValue = 29
  repeated hostDiet String = 30
  repeated hostLastMeal String = 31
  repeated hostFamilyRelation String = 32
  optional hostGenotype String = 33
  optional hostPhenotype String = 34
  optional hostBodyTemp QuantityValue = 35
  optional hostBodyMassIndex QuantityValue = 36
  repeated ethnicity String = 37
  optional hostOccupation Integer = 38
  optional medicHistPerform String = 39
  optional hostPulse QuantityValue = 40
  repeated perturbation String = 41
  optional sampSalinity QuantityValue = 42
  optional salinity QuantityValue = 43
  optional oxyStatSamp OxyStatSampEnum = 44
  repeated organismCount OrganismCountEnum = 45
  optional sampStoreTemp QuantityValue = 46
  optional sampStoreLoc String = 47
  optional sampStoreDur String = 48
  repeated hostSymbiont String = 49
  repeated miscParam String = 50
  sampName String = 51
  projectName String = 52
  optional hostDiseaseStat String = 53
  optional sampVolWeDnaExt QuantityValue = 54
  sampTaxonId String = 55
  optional experimentalFactor String = 56
  optional negContType NegContTypeEnum = 57
  optional posContType String = 58
  optional estimatedSize String = 59
  optional refBiomaterial String = 60
  optional sourceMatId String = 61
  optional pathogenicity String = 62
  optional bioticRelationship BioticRelationshipEnum = 63
  optional specificHost String = 64
  optional hostSpecRange Integer = 65
  optional sampCollecDevice String = 66
  optional sampCollecMethod String = 67
  optional sampMatProcess String = 68
  optional sizeFrac String = 69
  optional sampSize QuantityValue = 70
  sourceUvig SourceUvigEnum = 71
  virusEnrichAppr VirusEnrichApprEnum = 72
  optional nuclAcidExt String = 73
  optional nuclAcidAmp String = 74
  optional libSize Integer = 75
  optional libReadsSeqd Integer = 76
  optional libLayout LibLayoutEnum = 77
  optional libVector String = 78
  optional libScreen String = 79
  optional mid String = 80
  optional adapters String = 81
  seqMeth String = 82
  optional taxIdent TaxIdentEnum = 83
  assemblyQual AssemblyQualEnum = 84
  optional assemblyName String = 85
  assemblySoftware String = 86
  optional annot String = 87
  numberContig Integer = 88
  optional featPred String = 89
  optional refDb String = 90
  optional simSearchMeth String = 91
  optional taxClass String = 92
  optional trnas Integer = 93
  optional trnaExtSoftware String = 94
  optional complScore String = 95
  optional complSoftware String = 96
  optional complAppr ComplApprEnum = 97
  optional sortTech SortTechEnum = 98
  optional singleCellLysisAppr SingleCellLysisApprEnum = 99
  optional singleCellLysisProt String = 100
  optional wgaAmpAppr String = 101
  optional wgaAmpKit String = 102
  optional binParam BinParamEnum = 103
  optional binSoftware String = 104
  optional reassemblyBin String = 105
  optional magCovSoftware MagCovSoftwareEnum = 106
  virIdentSoftware String = 107
  predGenomeType PredGenomeTypeEnum = 108
  predGenomeStruc PredGenomeStrucEnum = 109
  detecType String = 110
  optional otuClassAppr String = 111
  optional otuSeqCompAppr String = 112
  optional otuDb String = 113
  optional hostPredAppr HostPredApprEnum = 114
  optional hostPredEstAcc String = 115
  optional associatedResource String = 116
  optional sop String = 117
 }
// hydrocarbon resources-cores
message HydrocarbonResources-cores
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  hcr HcrEnum = 11
  hcProduced HcProducedEnum = 12
  basin String = 13
  optional field String = 14
  optional reservoir String = 15
  hcrTemp String = 16
  optional tvdssOfHcrTemp QuantityValue = 17
  optional hcrPressure String = 18
  optional tvdssOfHcrPress QuantityValue = 19
  optional permeability String = 20
  optional porosity String = 21
  optional lithology LithologyEnum = 22
  optional deposEnv DeposEnvEnum = 23
  optional hcrGeolAge HcrGeolAgeEnum = 24
  optional owcTvdss QuantityValue = 25
  optional hcrFwSalinity QuantityValue = 26
  sulfateFw QuantityValue = 27
  vfaFw QuantityValue = 28
  optional srKerogType SrKerogTypeEnum = 29
  optional srLithology SrLithologyEnum = 30
  optional srDepEnv SrDepEnvEnum = 31
  optional srGeolAge SrGeolAgeEnum = 32
  optional sampWellName String = 33
  optional win String = 34
  sampType String = 35
  optional sampSubtype SampSubtypeEnum = 36
  optional pressure QuantityValue = 37
  optional sampTvdss String = 38
  optional sampMd SampMdEnum = 39
  optional oxyStatSamp OxyStatSampEnum = 40
  optional sampTransportCond String = 41
  optional sampStoreTemp QuantityValue = 42
  optional sampStoreDur String = 43
  optional sampStoreLoc String = 44
  repeated organismCount OrganismCountEnum = 45
  optional orgCountQpcrInfo String = 46
  optional ph Double = 47
  optional salinity QuantityValue = 48
  optional alkalinity QuantityValue = 49
  optional alkalinityMethod String = 50
  optional sulfate QuantityValue = 51
  optional sulfide QuantityValue = 52
  optional totSulfur QuantityValue = 53
  optional nitrate QuantityValue = 54
  optional nitrite QuantityValue = 55
  optional ammonium QuantityValue = 56
  optional totNitro QuantityValue = 57
  optional dissIron QuantityValue = 58
  optional sodium QuantityValue = 59
  optional chloride QuantityValue = 60
  optional potassium QuantityValue = 61
  optional magnesium QuantityValue = 62
  optional calcium QuantityValue = 63
  optional totIron QuantityValue = 64
  optional dissOrgCarb QuantityValue = 65
  optional dissInorgCarb QuantityValue = 66
  optional dissInorgPhosp QuantityValue = 67
  optional totPhosp QuantityValue = 68
  repeated suspendSolids String = 69
  optional density QuantityValue = 70
  optional dissCarbDioxide QuantityValue = 71
  optional dissOxygenFluid QuantityValue = 72
  optional vfa QuantityValue = 73
  optional benzene QuantityValue = 74
  optional toluene QuantityValue = 75
  optional ethylbenzene QuantityValue = 76
  optional xylene QuantityValue = 77
  api QuantityValue = 78
  optional tan QuantityValue = 79
  optional viscosity String = 80
  optional pourPoint QuantityValue = 81
  optional saturatesPc String = 82
  optional aromaticsPc String = 83
  optional resinsPc String = 84
  optional asphaltenesPc String = 85
  repeated miscParam String = 86
  optional additionalInfo String = 87
  sampName String = 88
  projectName String = 89
  optional sampVolWeDnaExt QuantityValue = 90
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package hydrocarbon resources-cores
message HydrocarbonResources-coresMIGSBacteria
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  hcr HcrEnum = 11
  hcProduced HcProducedEnum = 12
  basin String = 13
  optional field String = 14
  optional reservoir String = 15
  hcrTemp String = 16
  optional tvdssOfHcrTemp QuantityValue = 17
  optional hcrPressure String = 18
  optional tvdssOfHcrPress QuantityValue = 19
  optional permeability String = 20
  optional porosity String = 21
  optional lithology LithologyEnum = 22
  optional deposEnv DeposEnvEnum = 23
  optional hcrGeolAge HcrGeolAgeEnum = 24
  optional owcTvdss QuantityValue = 25
  optional hcrFwSalinity QuantityValue = 26
  sulfateFw QuantityValue = 27
  vfaFw QuantityValue = 28
  optional srKerogType SrKerogTypeEnum = 29
  optional srLithology SrLithologyEnum = 30
  optional srDepEnv SrDepEnvEnum = 31
  optional srGeolAge SrGeolAgeEnum = 32
  optional sampWellName String = 33
  optional win String = 34
  sampType String = 35
  optional sampSubtype SampSubtypeEnum = 36
  optional pressure QuantityValue = 37
  optional sampTvdss String = 38
  optional sampMd SampMdEnum = 39
  optional oxyStatSamp OxyStatSampEnum = 40
  optional sampTransportCond String = 41
  optional sampStoreTemp QuantityValue = 42
  optional sampStoreDur String = 43
  optional sampStoreLoc String = 44
  repeated organismCount OrganismCountEnum = 45
  optional orgCountQpcrInfo String = 46
  optional ph Double = 47
  optional salinity QuantityValue = 48
  optional alkalinity QuantityValue = 49
  optional alkalinityMethod String = 50
  optional sulfate QuantityValue = 51
  optional sulfide QuantityValue = 52
  optional totSulfur QuantityValue = 53
  optional nitrate QuantityValue = 54
  optional nitrite QuantityValue = 55
  optional ammonium QuantityValue = 56
  optional totNitro QuantityValue = 57
  optional dissIron QuantityValue = 58
  optional sodium QuantityValue = 59
  optional chloride QuantityValue = 60
  optional potassium QuantityValue = 61
  optional magnesium QuantityValue = 62
  optional calcium QuantityValue = 63
  optional totIron QuantityValue = 64
  optional dissOrgCarb QuantityValue = 65
  optional dissInorgCarb QuantityValue = 66
  optional dissInorgPhosp QuantityValue = 67
  optional totPhosp QuantityValue = 68
  repeated suspendSolids String = 69
  optional density QuantityValue = 70
  optional dissCarbDioxide QuantityValue = 71
  optional dissOxygenFluid QuantityValue = 72
  optional vfa QuantityValue = 73
  optional benzene QuantityValue = 74
  optional toluene QuantityValue = 75
  optional ethylbenzene QuantityValue = 76
  optional xylene QuantityValue = 77
  api QuantityValue = 78
  optional tan QuantityValue = 79
  optional viscosity String = 80
  optional pourPoint QuantityValue = 81
  optional saturatesPc String = 82
  optional aromaticsPc String = 83
  optional resinsPc String = 84
  optional asphaltenesPc String = 85
  repeated miscParam String = 86
  optional additionalInfo String = 87
  sampName String = 88
  projectName String = 89
  optional sampVolWeDnaExt QuantityValue = 90
  sampTaxonId String = 91
  optional experimentalFactor String = 92
  optional negContType NegContTypeEnum = 93
  optional posContType String = 94
  optional subspecfGenLin String = 95
  numReplicons Integer = 96
  optional extrachromElements Integer = 97
  optional estimatedSize String = 98
  refBiomaterial String = 99
  optional sourceMatId String = 100
  optional pathogenicity String = 101
  optional bioticRelationship BioticRelationshipEnum = 102
  optional specificHost String = 103
  optional hostSpecRange Integer = 104
  optional hostDiseaseStat String = 105
  optional trophicLevel TrophicLevelEnum = 106
  optional encodedTraits String = 107
  optional relToOxygen RelToOxygenEnum = 108
  isolGrowthCondt String = 109
  optional sampCollecDevice String = 110
  optional sampCollecMethod String = 111
  optional sampMatProcess String = 112
  optional sampSize QuantityValue = 113
  optional nuclAcidExt String = 114
  optional nuclAcidAmp String = 115
  optional libSize Integer = 116
  optional libReadsSeqd Integer = 117
  optional libLayout LibLayoutEnum = 118
  optional libVector String = 119
  optional libScreen String = 120
  optional adapters String = 121
  seqMeth String = 122
  optional taxIdent TaxIdentEnum = 123
  assemblyQual AssemblyQualEnum = 124
  optional assemblyName String = 125
  assemblySoftware String = 126
  optional annot String = 127
  numberContig Integer = 128
  optional featPred String = 129
  optional refDb String = 130
  optional simSearchMeth String = 131
  optional taxClass String = 132
  optional complScore String = 133
  optional complSoftware String = 134
  optional associatedResource String = 135
  optional sop String = 136
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: eukaryote with environmental package hydrocarbon resources-cores
message HydrocarbonResources-coresMIGSEukaryote
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  hcr HcrEnum = 11
  hcProduced HcProducedEnum = 12
  basin String = 13
  optional field String = 14
  optional reservoir String = 15
  hcrTemp String = 16
  optional tvdssOfHcrTemp QuantityValue = 17
  optional hcrPressure String = 18
  optional tvdssOfHcrPress QuantityValue = 19
  optional permeability String = 20
  optional porosity String = 21
  optional lithology LithologyEnum = 22
  optional deposEnv DeposEnvEnum = 23
  optional hcrGeolAge HcrGeolAgeEnum = 24
  optional owcTvdss QuantityValue = 25
  optional hcrFwSalinity QuantityValue = 26
  sulfateFw QuantityValue = 27
  vfaFw QuantityValue = 28
  optional srKerogType SrKerogTypeEnum = 29
  optional srLithology SrLithologyEnum = 30
  optional srDepEnv SrDepEnvEnum = 31
  optional srGeolAge SrGeolAgeEnum = 32
  optional sampWellName String = 33
  optional win String = 34
  sampType String = 35
  optional sampSubtype SampSubtypeEnum = 36
  optional pressure QuantityValue = 37
  optional sampTvdss String = 38
  optional sampMd SampMdEnum = 39
  optional oxyStatSamp OxyStatSampEnum = 40
  optional sampTransportCond String = 41
  optional sampStoreTemp QuantityValue = 42
  optional sampStoreDur String = 43
  optional sampStoreLoc String = 44
  repeated organismCount OrganismCountEnum = 45
  optional orgCountQpcrInfo String = 46
  optional ph Double = 47
  optional salinity QuantityValue = 48
  optional alkalinity QuantityValue = 49
  optional alkalinityMethod String = 50
  optional sulfate QuantityValue = 51
  optional sulfide QuantityValue = 52
  optional totSulfur QuantityValue = 53
  optional nitrate QuantityValue = 54
  optional nitrite QuantityValue = 55
  optional ammonium QuantityValue = 56
  optional totNitro QuantityValue = 57
  optional dissIron QuantityValue = 58
  optional sodium QuantityValue = 59
  optional chloride QuantityValue = 60
  optional potassium QuantityValue = 61
  optional magnesium QuantityValue = 62
  optional calcium QuantityValue = 63
  optional totIron QuantityValue = 64
  optional dissOrgCarb QuantityValue = 65
  optional dissInorgCarb QuantityValue = 66
  optional dissInorgPhosp QuantityValue = 67
  optional totPhosp QuantityValue = 68
  repeated suspendSolids String = 69
  optional density QuantityValue = 70
  optional dissCarbDioxide QuantityValue = 71
  optional dissOxygenFluid QuantityValue = 72
  optional vfa QuantityValue = 73
  optional benzene QuantityValue = 74
  optional toluene QuantityValue = 75
  optional ethylbenzene QuantityValue = 76
  optional xylene QuantityValue = 77
  api QuantityValue = 78
  optional tan QuantityValue = 79
  optional viscosity String = 80
  optional pourPoint QuantityValue = 81
  optional saturatesPc String = 82
  optional aromaticsPc String = 83
  optional resinsPc String = 84
  optional asphaltenesPc String = 85
  repeated miscParam String = 86
  optional additionalInfo String = 87
  sampName String = 88
  projectName String = 89
  optional sampVolWeDnaExt QuantityValue = 90
  sampTaxonId String = 91
  optional experimentalFactor String = 92
  optional negContType NegContTypeEnum = 93
  optional posContType String = 94
  optional subspecfGenLin String = 95
  optional ploidy String = 96
  optional numReplicons Integer = 97
  optional extrachromElements Integer = 98
  optional estimatedSize String = 99
  optional refBiomaterial String = 100
  optional sourceMatId String = 101
  optional pathogenicity String = 102
  optional bioticRelationship BioticRelationshipEnum = 103
  optional specificHost String = 104
  optional hostSpecRange Integer = 105
  optional hostDiseaseStat String = 106
  optional trophicLevel TrophicLevelEnum = 107
  optional propagation String = 108
  isolGrowthCondt String = 109
  optional sampCollecDevice String = 110
  optional sampCollecMethod String = 111
  optional sampMatProcess String = 112
  optional sampSize QuantityValue = 113
  optional nuclAcidExt String = 114
  optional nuclAcidAmp String = 115
  optional libSize Integer = 116
  optional libReadsSeqd Integer = 117
  optional libLayout LibLayoutEnum = 118
  optional libVector String = 119
  optional libScreen String = 120
  optional adapters String = 121
  seqMeth String = 122
  optional taxIdent TaxIdentEnum = 123
  assemblyQual AssemblyQualEnum = 124
  optional assemblyName String = 125
  assemblySoftware String = 126
  optional annot String = 127
  numberContig Integer = 128
  optional featPred String = 129
  optional refDb String = 130
  optional simSearchMeth String = 131
  optional taxClass String = 132
  optional complScore String = 133
  optional complSoftware String = 134
  optional associatedResource String = 135
  optional sop String = 136
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: org with environmental package hydrocarbon resources-cores
message HydrocarbonResources-coresMIGSOrg
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  hcr HcrEnum = 11
  hcProduced HcProducedEnum = 12
  basin String = 13
  optional field String = 14
  optional reservoir String = 15
  hcrTemp String = 16
  optional tvdssOfHcrTemp QuantityValue = 17
  optional hcrPressure String = 18
  optional tvdssOfHcrPress QuantityValue = 19
  optional permeability String = 20
  optional porosity String = 21
  optional lithology LithologyEnum = 22
  optional deposEnv DeposEnvEnum = 23
  optional hcrGeolAge HcrGeolAgeEnum = 24
  optional owcTvdss QuantityValue = 25
  optional hcrFwSalinity QuantityValue = 26
  sulfateFw QuantityValue = 27
  vfaFw QuantityValue = 28
  optional srKerogType SrKerogTypeEnum = 29
  optional srLithology SrLithologyEnum = 30
  optional srDepEnv SrDepEnvEnum = 31
  optional srGeolAge SrGeolAgeEnum = 32
  optional sampWellName String = 33
  optional win String = 34
  sampType String = 35
  optional sampSubtype SampSubtypeEnum = 36
  optional pressure QuantityValue = 37
  optional sampTvdss String = 38
  optional sampMd SampMdEnum = 39
  optional oxyStatSamp OxyStatSampEnum = 40
  optional sampTransportCond String = 41
  optional sampStoreTemp QuantityValue = 42
  optional sampStoreDur String = 43
  optional sampStoreLoc String = 44
  repeated organismCount OrganismCountEnum = 45
  optional orgCountQpcrInfo String = 46
  optional ph Double = 47
  optional salinity QuantityValue = 48
  optional alkalinity QuantityValue = 49
  optional alkalinityMethod String = 50
  optional sulfate QuantityValue = 51
  optional sulfide QuantityValue = 52
  optional totSulfur QuantityValue = 53
  optional nitrate QuantityValue = 54
  optional nitrite QuantityValue = 55
  optional ammonium QuantityValue = 56
  optional totNitro QuantityValue = 57
  optional dissIron QuantityValue = 58
  optional sodium QuantityValue = 59
  optional chloride QuantityValue = 60
  optional potassium QuantityValue = 61
  optional magnesium QuantityValue = 62
  optional calcium QuantityValue = 63
  optional totIron QuantityValue = 64
  optional dissOrgCarb QuantityValue = 65
  optional dissInorgCarb QuantityValue = 66
  optional dissInorgPhosp QuantityValue = 67
  optional totPhosp QuantityValue = 68
  repeated suspendSolids String = 69
  optional density QuantityValue = 70
  optional dissCarbDioxide QuantityValue = 71
  optional dissOxygenFluid QuantityValue = 72
  optional vfa QuantityValue = 73
  optional benzene QuantityValue = 74
  optional toluene QuantityValue = 75
  optional ethylbenzene QuantityValue = 76
  optional xylene QuantityValue = 77
  api QuantityValue = 78
  optional tan QuantityValue = 79
  optional viscosity String = 80
  optional pourPoint QuantityValue = 81
  optional saturatesPc String = 82
  optional aromaticsPc String = 83
  optional resinsPc String = 84
  optional asphaltenesPc String = 85
  repeated miscParam String = 86
  optional additionalInfo String = 87
  sampName String = 88
  projectName String = 89
  optional sampVolWeDnaExt QuantityValue = 90
  sampTaxonId String = 91
  optional experimentalFactor String = 92
  optional negContType NegContTypeEnum = 93
  optional posContType String = 94
  optional subspecfGenLin String = 95
  optional extrachromElements Integer = 96
  optional estimatedSize String = 97
  optional refBiomaterial String = 98
  optional sourceMatId String = 99
  isolGrowthCondt String = 100
  optional sampCollecDevice String = 101
  optional sampCollecMethod String = 102
  optional sampMatProcess String = 103
  optional sampSize QuantityValue = 104
  optional nuclAcidExt String = 105
  optional nuclAcidAmp String = 106
  optional libSize Integer = 107
  optional libReadsSeqd Integer = 108
  optional libLayout LibLayoutEnum = 109
  optional libVector String = 110
  optional libScreen String = 111
  optional adapters String = 112
  seqMeth String = 113
  optional taxIdent TaxIdentEnum = 114
  optional assemblyQual AssemblyQualEnum = 115
  optional assemblyName String = 116
  assemblySoftware String = 117
  optional annot String = 118
  optional numberContig Integer = 119
  optional featPred String = 120
  optional refDb String = 121
  optional simSearchMeth String = 122
  optional taxClass String = 123
  optional complScore String = 124
  optional complSoftware String = 125
  optional associatedResource String = 126
  optional sop String = 127
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: plant with environmental package hydrocarbon resources-cores
message HydrocarbonResources-coresMIGSPlant
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  hcr HcrEnum = 11
  hcProduced HcProducedEnum = 12
  basin String = 13
  optional field String = 14
  optional reservoir String = 15
  hcrTemp String = 16
  optional tvdssOfHcrTemp QuantityValue = 17
  optional hcrPressure String = 18
  optional tvdssOfHcrPress QuantityValue = 19
  optional permeability String = 20
  optional porosity String = 21
  optional lithology LithologyEnum = 22
  optional deposEnv DeposEnvEnum = 23
  optional hcrGeolAge HcrGeolAgeEnum = 24
  optional owcTvdss QuantityValue = 25
  optional hcrFwSalinity QuantityValue = 26
  sulfateFw QuantityValue = 27
  vfaFw QuantityValue = 28
  optional srKerogType SrKerogTypeEnum = 29
  optional srLithology SrLithologyEnum = 30
  optional srDepEnv SrDepEnvEnum = 31
  optional srGeolAge SrGeolAgeEnum = 32
  optional sampWellName String = 33
  optional win String = 34
  sampType String = 35
  optional sampSubtype SampSubtypeEnum = 36
  optional pressure QuantityValue = 37
  optional sampTvdss String = 38
  optional sampMd SampMdEnum = 39
  optional oxyStatSamp OxyStatSampEnum = 40
  optional sampTransportCond String = 41
  optional sampStoreTemp QuantityValue = 42
  optional sampStoreDur String = 43
  optional sampStoreLoc String = 44
  repeated organismCount OrganismCountEnum = 45
  optional orgCountQpcrInfo String = 46
  optional ph Double = 47
  optional salinity QuantityValue = 48
  optional alkalinity QuantityValue = 49
  optional alkalinityMethod String = 50
  optional sulfate QuantityValue = 51
  optional sulfide QuantityValue = 52
  optional totSulfur QuantityValue = 53
  optional nitrate QuantityValue = 54
  optional nitrite QuantityValue = 55
  optional ammonium QuantityValue = 56
  optional totNitro QuantityValue = 57
  optional dissIron QuantityValue = 58
  optional sodium QuantityValue = 59
  optional chloride QuantityValue = 60
  optional potassium QuantityValue = 61
  optional magnesium QuantityValue = 62
  optional calcium QuantityValue = 63
  optional totIron QuantityValue = 64
  optional dissOrgCarb QuantityValue = 65
  optional dissInorgCarb QuantityValue = 66
  optional dissInorgPhosp QuantityValue = 67
  optional totPhosp QuantityValue = 68
  repeated suspendSolids String = 69
  optional density QuantityValue = 70
  optional dissCarbDioxide QuantityValue = 71
  optional dissOxygenFluid QuantityValue = 72
  optional vfa QuantityValue = 73
  optional benzene QuantityValue = 74
  optional toluene QuantityValue = 75
  optional ethylbenzene QuantityValue = 76
  optional xylene QuantityValue = 77
  api QuantityValue = 78
  optional tan QuantityValue = 79
  optional viscosity String = 80
  optional pourPoint QuantityValue = 81
  optional saturatesPc String = 82
  optional aromaticsPc String = 83
  optional resinsPc String = 84
  optional asphaltenesPc String = 85
  repeated miscParam String = 86
  optional additionalInfo String = 87
  sampName String = 88
  projectName String = 89
  optional sampVolWeDnaExt QuantityValue = 90
  sampTaxonId String = 91
  optional experimentalFactor String = 92
  optional negContType NegContTypeEnum = 93
  optional posContType String = 94
  optional subspecfGenLin String = 95
  optional estimatedSize String = 96
  optional refBiomaterial String = 97
  optional sourceMatId String = 98
  optional specificHost String = 99
  optional hostSpecRange Integer = 100
  propagation String = 101
  optional encodedTraits String = 102
  isolGrowthCondt String = 103
  optional sampCollecDevice String = 104
  optional sampCollecMethod String = 105
  optional sampMatProcess String = 106
  optional sampSize QuantityValue = 107
  optional nuclAcidExt String = 108
  optional nuclAcidAmp String = 109
  optional libSize Integer = 110
  optional libReadsSeqd Integer = 111
  optional libLayout LibLayoutEnum = 112
  optional libVector String = 113
  optional libScreen String = 114
  optional adapters String = 115
  seqMeth String = 116
  optional taxIdent TaxIdentEnum = 117
  optional assemblyQual AssemblyQualEnum = 118
  optional assemblyName String = 119
  assemblySoftware String = 120
  optional annot String = 121
  optional numberContig Integer = 122
  optional featPred String = 123
  optional refDb String = 124
  optional simSearchMeth String = 125
  optional taxClass String = 126
  optional complScore String = 127
  optional complSoftware String = 128
  optional associatedResource String = 129
  optional sop String = 130
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package hydrocarbon resources-cores
message HydrocarbonResources-coresMIGSVirus
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  hcr HcrEnum = 11
  hcProduced HcProducedEnum = 12
  basin String = 13
  optional field String = 14
  optional reservoir String = 15
  hcrTemp String = 16
  optional tvdssOfHcrTemp QuantityValue = 17
  optional hcrPressure String = 18
  optional tvdssOfHcrPress QuantityValue = 19
  optional permeability String = 20
  optional porosity String = 21
  optional lithology LithologyEnum = 22
  optional deposEnv DeposEnvEnum = 23
  optional hcrGeolAge HcrGeolAgeEnum = 24
  optional owcTvdss QuantityValue = 25
  optional hcrFwSalinity QuantityValue = 26
  sulfateFw QuantityValue = 27
  vfaFw QuantityValue = 28
  optional srKerogType SrKerogTypeEnum = 29
  optional srLithology SrLithologyEnum = 30
  optional srDepEnv SrDepEnvEnum = 31
  optional srGeolAge SrGeolAgeEnum = 32
  optional sampWellName String = 33
  optional win String = 34
  sampType String = 35
  optional sampSubtype SampSubtypeEnum = 36
  optional pressure QuantityValue = 37
  optional sampTvdss String = 38
  optional sampMd SampMdEnum = 39
  optional oxyStatSamp OxyStatSampEnum = 40
  optional sampTransportCond String = 41
  optional sampStoreTemp QuantityValue = 42
  optional sampStoreDur String = 43
  optional sampStoreLoc String = 44
  repeated organismCount OrganismCountEnum = 45
  optional orgCountQpcrInfo String = 46
  optional ph Double = 47
  optional salinity QuantityValue = 48
  optional alkalinity QuantityValue = 49
  optional alkalinityMethod String = 50
  optional sulfate QuantityValue = 51
  optional sulfide QuantityValue = 52
  optional totSulfur QuantityValue = 53
  optional nitrate QuantityValue = 54
  optional nitrite QuantityValue = 55
  optional ammonium QuantityValue = 56
  optional totNitro QuantityValue = 57
  optional dissIron QuantityValue = 58
  optional sodium QuantityValue = 59
  optional chloride QuantityValue = 60
  optional potassium QuantityValue = 61
  optional magnesium QuantityValue = 62
  optional calcium QuantityValue = 63
  optional totIron QuantityValue = 64
  optional dissOrgCarb QuantityValue = 65
  optional dissInorgCarb QuantityValue = 66
  optional dissInorgPhosp QuantityValue = 67
  optional totPhosp QuantityValue = 68
  repeated suspendSolids String = 69
  optional density QuantityValue = 70
  optional dissCarbDioxide QuantityValue = 71
  optional dissOxygenFluid QuantityValue = 72
  optional vfa QuantityValue = 73
  optional benzene QuantityValue = 74
  optional toluene QuantityValue = 75
  optional ethylbenzene QuantityValue = 76
  optional xylene QuantityValue = 77
  api QuantityValue = 78
  optional tan QuantityValue = 79
  optional viscosity String = 80
  optional pourPoint QuantityValue = 81
  optional saturatesPc String = 82
  optional aromaticsPc String = 83
  optional resinsPc String = 84
  optional asphaltenesPc String = 85
  repeated miscParam String = 86
  optional additionalInfo String = 87
  sampName String = 88
  projectName String = 89
  optional sampVolWeDnaExt QuantityValue = 90
  sampTaxonId String = 91
  optional experimentalFactor String = 92
  optional negContType NegContTypeEnum = 93
  optional posContType String = 94
  optional subspecfGenLin String = 95
  optional numReplicons Integer = 96
  optional estimatedSize String = 97
  optional refBiomaterial String = 98
  optional sourceMatId String = 99
  optional pathogenicity String = 100
  optional bioticRelationship BioticRelationshipEnum = 101
  optional specificHost String = 102
  optional hostSpecRange Integer = 103
  optional hostDiseaseStat String = 104
  propagation String = 105
  optional encodedTraits String = 106
  isolGrowthCondt String = 107
  optional sampCollecDevice String = 108
  optional sampCollecMethod String = 109
  optional sampMatProcess String = 110
  optional sampSize QuantityValue = 111
  optional virusEnrichAppr VirusEnrichApprEnum = 112
  optional nuclAcidExt String = 113
  optional nuclAcidAmp String = 114
  optional libSize Integer = 115
  optional libReadsSeqd Integer = 116
  optional libLayout LibLayoutEnum = 117
  optional libVector String = 118
  optional libScreen String = 119
  optional adapters String = 120
  seqMeth String = 121
  optional taxIdent TaxIdentEnum = 122
  optional assemblyQual AssemblyQualEnum = 123
  optional assemblyName String = 124
  assemblySoftware String = 125
  optional annot String = 126
  optional numberContig Integer = 127
  optional featPred String = 128
  optional refDb String = 129
  optional simSearchMeth String = 130
  optional taxClass String = 131
  optional complScore String = 132
  optional complSoftware String = 133
  optional associatedResource String = 134
  optional sop String = 135
 }
// Combinatorial checklist Minimum Information About a Metagenome-Assembled Genome with environmental package hydrocarbon resources-cores
message HydrocarbonResources-coresMIMAG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  hcr HcrEnum = 11
  hcProduced HcProducedEnum = 12
  basin String = 13
  optional field String = 14
  optional reservoir String = 15
  hcrTemp String = 16
  optional tvdssOfHcrTemp QuantityValue = 17
  optional hcrPressure String = 18
  optional tvdssOfHcrPress QuantityValue = 19
  optional permeability String = 20
  optional porosity String = 21
  optional lithology LithologyEnum = 22
  optional deposEnv DeposEnvEnum = 23
  optional hcrGeolAge HcrGeolAgeEnum = 24
  optional owcTvdss QuantityValue = 25
  optional hcrFwSalinity QuantityValue = 26
  sulfateFw QuantityValue = 27
  vfaFw QuantityValue = 28
  optional srKerogType SrKerogTypeEnum = 29
  optional srLithology SrLithologyEnum = 30
  optional srDepEnv SrDepEnvEnum = 31
  optional srGeolAge SrGeolAgeEnum = 32
  optional sampWellName String = 33
  optional win String = 34
  sampType String = 35
  optional sampSubtype SampSubtypeEnum = 36
  optional pressure QuantityValue = 37
  optional sampTvdss String = 38
  optional sampMd SampMdEnum = 39
  optional oxyStatSamp OxyStatSampEnum = 40
  optional sampTransportCond String = 41
  optional sampStoreTemp QuantityValue = 42
  optional sampStoreDur String = 43
  optional sampStoreLoc String = 44
  repeated organismCount OrganismCountEnum = 45
  optional orgCountQpcrInfo String = 46
  optional ph Double = 47
  optional salinity QuantityValue = 48
  optional alkalinity QuantityValue = 49
  optional alkalinityMethod String = 50
  optional sulfate QuantityValue = 51
  optional sulfide QuantityValue = 52
  optional totSulfur QuantityValue = 53
  optional nitrate QuantityValue = 54
  optional nitrite QuantityValue = 55
  optional ammonium QuantityValue = 56
  optional totNitro QuantityValue = 57
  optional dissIron QuantityValue = 58
  optional sodium QuantityValue = 59
  optional chloride QuantityValue = 60
  optional potassium QuantityValue = 61
  optional magnesium QuantityValue = 62
  optional calcium QuantityValue = 63
  optional totIron QuantityValue = 64
  optional dissOrgCarb QuantityValue = 65
  optional dissInorgCarb QuantityValue = 66
  optional dissInorgPhosp QuantityValue = 67
  optional totPhosp QuantityValue = 68
  repeated suspendSolids String = 69
  optional density QuantityValue = 70
  optional dissCarbDioxide QuantityValue = 71
  optional dissOxygenFluid QuantityValue = 72
  optional vfa QuantityValue = 73
  optional benzene QuantityValue = 74
  optional toluene QuantityValue = 75
  optional ethylbenzene QuantityValue = 76
  optional xylene QuantityValue = 77
  api QuantityValue = 78
  optional tan QuantityValue = 79
  optional viscosity String = 80
  optional pourPoint QuantityValue = 81
  optional saturatesPc String = 82
  optional aromaticsPc String = 83
  optional resinsPc String = 84
  optional asphaltenesPc String = 85
  repeated miscParam String = 86
  optional additionalInfo String = 87
  sampName String = 88
  projectName String = 89
  optional sampVolWeDnaExt QuantityValue = 90
  sampTaxonId String = 91
  optional experimentalFactor String = 92
  optional negContType NegContTypeEnum = 93
  optional posContType String = 94
  optional refBiomaterial String = 95
  optional sourceMatId String = 96
  optional relToOxygen RelToOxygenEnum = 97
  optional sampCollecDevice String = 98
  optional sampCollecMethod String = 99
  optional sampMatProcess String = 100
  optional sizeFrac String = 101
  optional sampSize QuantityValue = 102
  optional nuclAcidExt String = 103
  optional nuclAcidAmp String = 104
  optional libSize Integer = 105
  optional libReadsSeqd Integer = 106
  optional libLayout LibLayoutEnum = 107
  optional libVector String = 108
  optional libScreen String = 109
  optional mid String = 110
  optional adapters String = 111
  seqMeth String = 112
  taxIdent TaxIdentEnum = 113
  assemblyQual AssemblyQualEnum = 114
  optional assemblyName String = 115
  assemblySoftware String = 116
  optional annot String = 117
  optional numberContig Integer = 118
  optional featPred String = 119
  optional refDb String = 120
  optional simSearchMeth String = 121
  optional taxClass String = 122
  optional x16sRecover String = 123
  optional x16sRecoverSoftware String = 124
  optional trnas Integer = 125
  optional trnaExtSoftware String = 126
  complScore String = 127
  complSoftware String = 128
  optional complAppr ComplApprEnum = 129
  contamScore String = 130
  optional contamScreenInput String = 131
  optional contamScreenParam String = 132
  optional decontamSoftware DecontamSoftwareEnum = 133
  binParam BinParamEnum = 134
  binSoftware String = 135
  optional reassemblyBin String = 136
  optional magCovSoftware MagCovSoftwareEnum = 137
  optional associatedResource String = 138
  optional sop String = 139
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: specimen with environmental package hydrocarbon resources-cores
message HydrocarbonResources-coresMIMARKSSpecimen
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  hcr HcrEnum = 11
  hcProduced HcProducedEnum = 12
  basin String = 13
  optional field String = 14
  optional reservoir String = 15
  hcrTemp String = 16
  optional tvdssOfHcrTemp QuantityValue = 17
  optional hcrPressure String = 18
  optional tvdssOfHcrPress QuantityValue = 19
  optional permeability String = 20
  optional porosity String = 21
  optional lithology LithologyEnum = 22
  optional deposEnv DeposEnvEnum = 23
  optional hcrGeolAge HcrGeolAgeEnum = 24
  optional owcTvdss QuantityValue = 25
  optional hcrFwSalinity QuantityValue = 26
  sulfateFw QuantityValue = 27
  vfaFw QuantityValue = 28
  optional srKerogType SrKerogTypeEnum = 29
  optional srLithology SrLithologyEnum = 30
  optional srDepEnv SrDepEnvEnum = 31
  optional srGeolAge SrGeolAgeEnum = 32
  optional sampWellName String = 33
  optional win String = 34
  sampType String = 35
  optional sampSubtype SampSubtypeEnum = 36
  optional pressure QuantityValue = 37
  optional sampTvdss String = 38
  optional sampMd SampMdEnum = 39
  optional oxyStatSamp OxyStatSampEnum = 40
  optional sampTransportCond String = 41
  optional sampStoreTemp QuantityValue = 42
  optional sampStoreDur String = 43
  optional sampStoreLoc String = 44
  repeated organismCount OrganismCountEnum = 45
  optional orgCountQpcrInfo String = 46
  optional ph Double = 47
  optional salinity QuantityValue = 48
  optional alkalinity QuantityValue = 49
  optional alkalinityMethod String = 50
  optional sulfate QuantityValue = 51
  optional sulfide QuantityValue = 52
  optional totSulfur QuantityValue = 53
  optional nitrate QuantityValue = 54
  optional nitrite QuantityValue = 55
  optional ammonium QuantityValue = 56
  optional totNitro QuantityValue = 57
  optional dissIron QuantityValue = 58
  optional sodium QuantityValue = 59
  optional chloride QuantityValue = 60
  optional potassium QuantityValue = 61
  optional magnesium QuantityValue = 62
  optional calcium QuantityValue = 63
  optional totIron QuantityValue = 64
  optional dissOrgCarb QuantityValue = 65
  optional dissInorgCarb QuantityValue = 66
  optional dissInorgPhosp QuantityValue = 67
  optional totPhosp QuantityValue = 68
  repeated suspendSolids String = 69
  optional density QuantityValue = 70
  optional dissCarbDioxide QuantityValue = 71
  optional dissOxygenFluid QuantityValue = 72
  optional vfa QuantityValue = 73
  optional benzene QuantityValue = 74
  optional toluene QuantityValue = 75
  optional ethylbenzene QuantityValue = 76
  optional xylene QuantityValue = 77
  api QuantityValue = 78
  optional tan QuantityValue = 79
  optional viscosity String = 80
  optional pourPoint QuantityValue = 81
  optional saturatesPc String = 82
  optional aromaticsPc String = 83
  optional resinsPc String = 84
  optional asphaltenesPc String = 85
  repeated miscParam String = 86
  optional additionalInfo String = 87
  sampName String = 88
  projectName String = 89
  optional sampVolWeDnaExt QuantityValue = 90
  sampTaxonId String = 91
  optional experimentalFactor String = 92
  optional negContType NegContTypeEnum = 93
  optional posContType String = 94
  optional sourceMatId String = 95
  optional relToOxygen RelToOxygenEnum = 96
  optional sampCollecDevice String = 97
  optional sampCollecMethod String = 98
  optional sampMatProcess String = 99
  optional sizeFrac String = 100
  optional sampSize QuantityValue = 101
  optional nuclAcidExt String = 102
  optional nuclAcidAmp String = 103
  optional libSize Integer = 104
  optional libReadsSeqd Integer = 105
  optional libLayout LibLayoutEnum = 106
  optional libVector String = 107
  optional libScreen String = 108
  targetGene String = 109
  optional targetSubfragment String = 110
  optional pcrPrimers String = 111
  optional mid String = 112
  optional adapters String = 113
  optional pcrCond String = 114
  seqMeth String = 115
  optional seqQualityCheck String = 116
  optional chimeraCheck String = 117
  optional assemblySoftware String = 118
  optional associatedResource String = 119
  optional sop String = 120
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: survey with environmental package hydrocarbon resources-cores
message HydrocarbonResources-coresMIMARKSSurvey
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  hcr HcrEnum = 11
  hcProduced HcProducedEnum = 12
  basin String = 13
  optional field String = 14
  optional reservoir String = 15
  hcrTemp String = 16
  optional tvdssOfHcrTemp QuantityValue = 17
  optional hcrPressure String = 18
  optional tvdssOfHcrPress QuantityValue = 19
  optional permeability String = 20
  optional porosity String = 21
  optional lithology LithologyEnum = 22
  optional deposEnv DeposEnvEnum = 23
  optional hcrGeolAge HcrGeolAgeEnum = 24
  optional owcTvdss QuantityValue = 25
  optional hcrFwSalinity QuantityValue = 26
  sulfateFw QuantityValue = 27
  vfaFw QuantityValue = 28
  optional srKerogType SrKerogTypeEnum = 29
  optional srLithology SrLithologyEnum = 30
  optional srDepEnv SrDepEnvEnum = 31
  optional srGeolAge SrGeolAgeEnum = 32
  optional sampWellName String = 33
  optional win String = 34
  sampType String = 35
  optional sampSubtype SampSubtypeEnum = 36
  optional pressure QuantityValue = 37
  optional sampTvdss String = 38
  optional sampMd SampMdEnum = 39
  optional oxyStatSamp OxyStatSampEnum = 40
  optional sampTransportCond String = 41
  optional sampStoreTemp QuantityValue = 42
  optional sampStoreDur String = 43
  optional sampStoreLoc String = 44
  repeated organismCount OrganismCountEnum = 45
  optional orgCountQpcrInfo String = 46
  optional ph Double = 47
  optional salinity QuantityValue = 48
  optional alkalinity QuantityValue = 49
  optional alkalinityMethod String = 50
  optional sulfate QuantityValue = 51
  optional sulfide QuantityValue = 52
  optional totSulfur QuantityValue = 53
  optional nitrate QuantityValue = 54
  optional nitrite QuantityValue = 55
  optional ammonium QuantityValue = 56
  optional totNitro QuantityValue = 57
  optional dissIron QuantityValue = 58
  optional sodium QuantityValue = 59
  optional chloride QuantityValue = 60
  optional potassium QuantityValue = 61
  optional magnesium QuantityValue = 62
  optional calcium QuantityValue = 63
  optional totIron QuantityValue = 64
  optional dissOrgCarb QuantityValue = 65
  optional dissInorgCarb QuantityValue = 66
  optional dissInorgPhosp QuantityValue = 67
  optional totPhosp QuantityValue = 68
  repeated suspendSolids String = 69
  optional density QuantityValue = 70
  optional dissCarbDioxide QuantityValue = 71
  optional dissOxygenFluid QuantityValue = 72
  optional vfa QuantityValue = 73
  optional benzene QuantityValue = 74
  optional toluene QuantityValue = 75
  optional ethylbenzene QuantityValue = 76
  optional xylene QuantityValue = 77
  api QuantityValue = 78
  optional tan QuantityValue = 79
  optional viscosity String = 80
  optional pourPoint QuantityValue = 81
  optional saturatesPc String = 82
  optional aromaticsPc String = 83
  optional resinsPc String = 84
  optional asphaltenesPc String = 85
  repeated miscParam String = 86
  optional additionalInfo String = 87
  sampName String = 88
  projectName String = 89
  optional sampVolWeDnaExt QuantityValue = 90
  sampTaxonId String = 91
  optional experimentalFactor String = 92
  optional negContType NegContTypeEnum = 93
  optional posContType String = 94
  optional subspecfGenLin String = 95
  optional extrachromElements Integer = 96
  optional sourceMatId String = 97
  optional bioticRelationship BioticRelationshipEnum = 98
  optional trophicLevel TrophicLevelEnum = 99
  optional relToOxygen RelToOxygenEnum = 100
  isolGrowthCondt String = 101
  optional sampCollecDevice String = 102
  optional sampCollecMethod String = 103
  optional sampMatProcess String = 104
  optional sampSize QuantityValue = 105
  optional nuclAcidExt String = 106
  optional nuclAcidAmp String = 107
  targetGene String = 108
  optional targetSubfragment String = 109
  optional pcrPrimers String = 110
  optional pcrCond String = 111
  seqMeth String = 112
  optional seqQualityCheck String = 113
  optional chimeraCheck String = 114
  optional associatedResource String = 115
  optional sop String = 116
 }
// Combinatorial checklist Metagenome or Environmental with environmental package hydrocarbon resources-cores
message HydrocarbonResources-coresMIMS
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  hcr HcrEnum = 11
  hcProduced HcProducedEnum = 12
  basin String = 13
  optional field String = 14
  optional reservoir String = 15
  hcrTemp String = 16
  optional tvdssOfHcrTemp QuantityValue = 17
  optional hcrPressure String = 18
  optional tvdssOfHcrPress QuantityValue = 19
  optional permeability String = 20
  optional porosity String = 21
  optional lithology LithologyEnum = 22
  optional deposEnv DeposEnvEnum = 23
  optional hcrGeolAge HcrGeolAgeEnum = 24
  optional owcTvdss QuantityValue = 25
  optional hcrFwSalinity QuantityValue = 26
  sulfateFw QuantityValue = 27
  vfaFw QuantityValue = 28
  optional srKerogType SrKerogTypeEnum = 29
  optional srLithology SrLithologyEnum = 30
  optional srDepEnv SrDepEnvEnum = 31
  optional srGeolAge SrGeolAgeEnum = 32
  optional sampWellName String = 33
  optional win String = 34
  sampType String = 35
  optional sampSubtype SampSubtypeEnum = 36
  optional pressure QuantityValue = 37
  optional sampTvdss String = 38
  optional sampMd SampMdEnum = 39
  optional oxyStatSamp OxyStatSampEnum = 40
  optional sampTransportCond String = 41
  optional sampStoreTemp QuantityValue = 42
  optional sampStoreDur String = 43
  optional sampStoreLoc String = 44
  repeated organismCount OrganismCountEnum = 45
  optional orgCountQpcrInfo String = 46
  optional ph Double = 47
  optional salinity QuantityValue = 48
  optional alkalinity QuantityValue = 49
  optional alkalinityMethod String = 50
  optional sulfate QuantityValue = 51
  optional sulfide QuantityValue = 52
  optional totSulfur QuantityValue = 53
  optional nitrate QuantityValue = 54
  optional nitrite QuantityValue = 55
  optional ammonium QuantityValue = 56
  optional totNitro QuantityValue = 57
  optional dissIron QuantityValue = 58
  optional sodium QuantityValue = 59
  optional chloride QuantityValue = 60
  optional potassium QuantityValue = 61
  optional magnesium QuantityValue = 62
  optional calcium QuantityValue = 63
  optional totIron QuantityValue = 64
  optional dissOrgCarb QuantityValue = 65
  optional dissInorgCarb QuantityValue = 66
  optional dissInorgPhosp QuantityValue = 67
  optional totPhosp QuantityValue = 68
  repeated suspendSolids String = 69
  optional density QuantityValue = 70
  optional dissCarbDioxide QuantityValue = 71
  optional dissOxygenFluid QuantityValue = 72
  optional vfa QuantityValue = 73
  optional benzene QuantityValue = 74
  optional toluene QuantityValue = 75
  optional ethylbenzene QuantityValue = 76
  optional xylene QuantityValue = 77
  api QuantityValue = 78
  optional tan QuantityValue = 79
  optional viscosity String = 80
  optional pourPoint QuantityValue = 81
  optional saturatesPc String = 82
  optional aromaticsPc String = 83
  optional resinsPc String = 84
  optional asphaltenesPc String = 85
  repeated miscParam String = 86
  optional additionalInfo String = 87
  sampName String = 88
  projectName String = 89
  optional sampVolWeDnaExt QuantityValue = 90
  sampTaxonId String = 91
  optional experimentalFactor String = 92
  optional negContType NegContTypeEnum = 93
  optional posContType String = 94
  optional refBiomaterial String = 95
  optional sourceMatId String = 96
  optional relToOxygen RelToOxygenEnum = 97
  optional sampCollecDevice String = 98
  optional sampCollecMethod String = 99
  optional sampMatProcess String = 100
  optional sizeFrac String = 101
  optional sampSize QuantityValue = 102
  optional nuclAcidExt String = 103
  optional nuclAcidAmp String = 104
  optional libSize Integer = 105
  optional libReadsSeqd Integer = 106
  optional libLayout LibLayoutEnum = 107
  optional libVector String = 108
  optional libScreen String = 109
  optional mid String = 110
  optional adapters String = 111
  seqMeth String = 112
  optional assemblyQual AssemblyQualEnum = 113
  optional assemblyName String = 114
  optional assemblySoftware String = 115
  optional annot String = 116
  optional numberContig Integer = 117
  optional featPred String = 118
  optional refDb String = 119
  optional simSearchMeth String = 120
  optional taxClass String = 121
  optional associatedResource String = 122
  optional sop String = 123
 }
// Combinatorial checklist Minimum Information About a Single Amplified Genome with environmental package hydrocarbon resources-cores
message HydrocarbonResources-coresMISAG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  hcr HcrEnum = 11
  hcProduced HcProducedEnum = 12
  basin String = 13
  optional field String = 14
  optional reservoir String = 15
  hcrTemp String = 16
  optional tvdssOfHcrTemp QuantityValue = 17
  optional hcrPressure String = 18
  optional tvdssOfHcrPress QuantityValue = 19
  optional permeability String = 20
  optional porosity String = 21
  optional lithology LithologyEnum = 22
  optional deposEnv DeposEnvEnum = 23
  optional hcrGeolAge HcrGeolAgeEnum = 24
  optional owcTvdss QuantityValue = 25
  optional hcrFwSalinity QuantityValue = 26
  sulfateFw QuantityValue = 27
  vfaFw QuantityValue = 28
  optional srKerogType SrKerogTypeEnum = 29
  optional srLithology SrLithologyEnum = 30
  optional srDepEnv SrDepEnvEnum = 31
  optional srGeolAge SrGeolAgeEnum = 32
  optional sampWellName String = 33
  optional win String = 34
  sampType String = 35
  optional sampSubtype SampSubtypeEnum = 36
  optional pressure QuantityValue = 37
  optional sampTvdss String = 38
  optional sampMd SampMdEnum = 39
  optional oxyStatSamp OxyStatSampEnum = 40
  optional sampTransportCond String = 41
  optional sampStoreTemp QuantityValue = 42
  optional sampStoreDur String = 43
  optional sampStoreLoc String = 44
  repeated organismCount OrganismCountEnum = 45
  optional orgCountQpcrInfo String = 46
  optional ph Double = 47
  optional salinity QuantityValue = 48
  optional alkalinity QuantityValue = 49
  optional alkalinityMethod String = 50
  optional sulfate QuantityValue = 51
  optional sulfide QuantityValue = 52
  optional totSulfur QuantityValue = 53
  optional nitrate QuantityValue = 54
  optional nitrite QuantityValue = 55
  optional ammonium QuantityValue = 56
  optional totNitro QuantityValue = 57
  optional dissIron QuantityValue = 58
  optional sodium QuantityValue = 59
  optional chloride QuantityValue = 60
  optional potassium QuantityValue = 61
  optional magnesium QuantityValue = 62
  optional calcium QuantityValue = 63
  optional totIron QuantityValue = 64
  optional dissOrgCarb QuantityValue = 65
  optional dissInorgCarb QuantityValue = 66
  optional dissInorgPhosp QuantityValue = 67
  optional totPhosp QuantityValue = 68
  repeated suspendSolids String = 69
  optional density QuantityValue = 70
  optional dissCarbDioxide QuantityValue = 71
  optional dissOxygenFluid QuantityValue = 72
  optional vfa QuantityValue = 73
  optional benzene QuantityValue = 74
  optional toluene QuantityValue = 75
  optional ethylbenzene QuantityValue = 76
  optional xylene QuantityValue = 77
  api QuantityValue = 78
  optional tan QuantityValue = 79
  optional viscosity String = 80
  optional pourPoint QuantityValue = 81
  optional saturatesPc String = 82
  optional aromaticsPc String = 83
  optional resinsPc String = 84
  optional asphaltenesPc String = 85
  repeated miscParam String = 86
  optional additionalInfo String = 87
  sampName String = 88
  projectName String = 89
  optional sampVolWeDnaExt QuantityValue = 90
  sampTaxonId String = 91
  optional experimentalFactor String = 92
  optional negContType NegContTypeEnum = 93
  optional posContType String = 94
  optional refBiomaterial String = 95
  optional sourceMatId String = 96
  optional relToOxygen RelToOxygenEnum = 97
  optional sampCollecDevice String = 98
  optional sampCollecMethod String = 99
  optional sampMatProcess String = 100
  optional sizeFrac String = 101
  optional sampSize QuantityValue = 102
  optional nuclAcidExt String = 103
  optional nuclAcidAmp String = 104
  optional libSize Integer = 105
  optional libReadsSeqd Integer = 106
  optional libLayout LibLayoutEnum = 107
  optional libVector String = 108
  optional libScreen String = 109
  optional mid String = 110
  optional adapters String = 111
  seqMeth String = 112
  taxIdent TaxIdentEnum = 113
  assemblyQual AssemblyQualEnum = 114
  optional assemblyName String = 115
  assemblySoftware String = 116
  optional annot String = 117
  optional numberContig Integer = 118
  optional featPred String = 119
  optional refDb String = 120
  optional simSearchMeth String = 121
  optional taxClass String = 122
  optional x16sRecover String = 123
  optional x16sRecoverSoftware String = 124
  optional trnas Integer = 125
  optional trnaExtSoftware String = 126
  complScore String = 127
  complSoftware String = 128
  optional complAppr ComplApprEnum = 129
  contamScore String = 130
  optional contamScreenInput String = 131
  optional contamScreenParam String = 132
  optional decontamSoftware DecontamSoftwareEnum = 133
  sortTech SortTechEnum = 134
  singleCellLysisAppr SingleCellLysisApprEnum = 135
  optional singleCellLysisProt String = 136
  wgaAmpAppr String = 137
  optional wgaAmpKit String = 138
  optional associatedResource String = 139
  optional sop String = 140
 }
// Combinatorial checklist Minimum Information About an Uncultivated Virus Genome with environmental package hydrocarbon resources-cores
message HydrocarbonResources-coresMIUVIG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  hcr HcrEnum = 11
  hcProduced HcProducedEnum = 12
  basin String = 13
  optional field String = 14
  optional reservoir String = 15
  hcrTemp String = 16
  optional tvdssOfHcrTemp QuantityValue = 17
  optional hcrPressure String = 18
  optional tvdssOfHcrPress QuantityValue = 19
  optional permeability String = 20
  optional porosity String = 21
  optional lithology LithologyEnum = 22
  optional deposEnv DeposEnvEnum = 23
  optional hcrGeolAge HcrGeolAgeEnum = 24
  optional owcTvdss QuantityValue = 25
  optional hcrFwSalinity QuantityValue = 26
  sulfateFw QuantityValue = 27
  vfaFw QuantityValue = 28
  optional srKerogType SrKerogTypeEnum = 29
  optional srLithology SrLithologyEnum = 30
  optional srDepEnv SrDepEnvEnum = 31
  optional srGeolAge SrGeolAgeEnum = 32
  optional sampWellName String = 33
  optional win String = 34
  sampType String = 35
  optional sampSubtype SampSubtypeEnum = 36
  optional pressure QuantityValue = 37
  optional sampTvdss String = 38
  optional sampMd SampMdEnum = 39
  optional oxyStatSamp OxyStatSampEnum = 40
  optional sampTransportCond String = 41
  optional sampStoreTemp QuantityValue = 42
  optional sampStoreDur String = 43
  optional sampStoreLoc String = 44
  repeated organismCount OrganismCountEnum = 45
  optional orgCountQpcrInfo String = 46
  optional ph Double = 47
  optional salinity QuantityValue = 48
  optional alkalinity QuantityValue = 49
  optional alkalinityMethod String = 50
  optional sulfate QuantityValue = 51
  optional sulfide QuantityValue = 52
  optional totSulfur QuantityValue = 53
  optional nitrate QuantityValue = 54
  optional nitrite QuantityValue = 55
  optional ammonium QuantityValue = 56
  optional totNitro QuantityValue = 57
  optional dissIron QuantityValue = 58
  optional sodium QuantityValue = 59
  optional chloride QuantityValue = 60
  optional potassium QuantityValue = 61
  optional magnesium QuantityValue = 62
  optional calcium QuantityValue = 63
  optional totIron QuantityValue = 64
  optional dissOrgCarb QuantityValue = 65
  optional dissInorgCarb QuantityValue = 66
  optional dissInorgPhosp QuantityValue = 67
  optional totPhosp QuantityValue = 68
  repeated suspendSolids String = 69
  optional density QuantityValue = 70
  optional dissCarbDioxide QuantityValue = 71
  optional dissOxygenFluid QuantityValue = 72
  optional vfa QuantityValue = 73
  optional benzene QuantityValue = 74
  optional toluene QuantityValue = 75
  optional ethylbenzene QuantityValue = 76
  optional xylene QuantityValue = 77
  api QuantityValue = 78
  optional tan QuantityValue = 79
  optional viscosity String = 80
  optional pourPoint QuantityValue = 81
  optional saturatesPc String = 82
  optional aromaticsPc String = 83
  optional resinsPc String = 84
  optional asphaltenesPc String = 85
  repeated miscParam String = 86
  optional additionalInfo String = 87
  sampName String = 88
  projectName String = 89
  optional sampVolWeDnaExt QuantityValue = 90
  sampTaxonId String = 91
  optional experimentalFactor String = 92
  optional negContType NegContTypeEnum = 93
  optional posContType String = 94
  optional estimatedSize String = 95
  optional refBiomaterial String = 96
  optional sourceMatId String = 97
  optional pathogenicity String = 98
  optional bioticRelationship BioticRelationshipEnum = 99
  optional specificHost String = 100
  optional hostSpecRange Integer = 101
  optional hostDiseaseStat String = 102
  optional sampCollecDevice String = 103
  optional sampCollecMethod String = 104
  optional sampMatProcess String = 105
  optional sizeFrac String = 106
  optional sampSize QuantityValue = 107
  sourceUvig SourceUvigEnum = 108
  virusEnrichAppr VirusEnrichApprEnum = 109
  optional nuclAcidExt String = 110
  optional nuclAcidAmp String = 111
  optional libSize Integer = 112
  optional libReadsSeqd Integer = 113
  optional libLayout LibLayoutEnum = 114
  optional libVector String = 115
  optional libScreen String = 116
  optional mid String = 117
  optional adapters String = 118
  seqMeth String = 119
  optional taxIdent TaxIdentEnum = 120
  assemblyQual AssemblyQualEnum = 121
  optional assemblyName String = 122
  assemblySoftware String = 123
  optional annot String = 124
  numberContig Integer = 125
  optional featPred String = 126
  optional refDb String = 127
  optional simSearchMeth String = 128
  optional taxClass String = 129
  optional trnas Integer = 130
  optional trnaExtSoftware String = 131
  optional complScore String = 132
  optional complSoftware String = 133
  optional complAppr ComplApprEnum = 134
  optional sortTech SortTechEnum = 135
  optional singleCellLysisAppr SingleCellLysisApprEnum = 136
  optional singleCellLysisProt String = 137
  optional wgaAmpAppr String = 138
  optional wgaAmpKit String = 139
  optional binParam BinParamEnum = 140
  optional binSoftware String = 141
  optional reassemblyBin String = 142
  optional magCovSoftware MagCovSoftwareEnum = 143
  virIdentSoftware String = 144
  predGenomeType PredGenomeTypeEnum = 145
  predGenomeStruc PredGenomeStrucEnum = 146
  detecType String = 147
  optional otuClassAppr String = 148
  optional otuSeqCompAppr String = 149
  optional otuDb String = 150
  optional hostPredAppr HostPredApprEnum = 151
  optional hostPredEstAcc String = 152
  optional associatedResource String = 153
  optional sop String = 154
 }
// hydrocarbon resources-fluids/swabs
message HydrocarbonResources-fluidsSwabs
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  hcr HcrEnum = 11
  hcProduced HcProducedEnum = 12
  basin String = 13
  optional field String = 14
  optional reservoir String = 15
  optional hcrTemp String = 16
  optional tvdssOfHcrTemp QuantityValue = 17
  optional hcrPressure String = 18
  optional tvdssOfHcrPress QuantityValue = 19
  optional lithology LithologyEnum = 20
  optional deposEnv DeposEnvEnum = 21
  optional hcrGeolAge HcrGeolAgeEnum = 22
  optional hcrFwSalinity QuantityValue = 23
  optional sulfateFw QuantityValue = 24
  optional vfaFw QuantityValue = 25
  optional prodStartDate Date = 26
  optional prodRate QuantityValue = 27
  optional waterProdRate QuantityValue = 28
  waterCut QuantityValue = 29
  iwf QuantityValue = 30
  addRecovMethod String = 31
  optional iwBtDateWell Date = 32
  optional biocide String = 33
  optional biocideAdminMethod String = 34
  optional chemTreatment String = 35
  optional chemTreatMethod String = 36
  optional sampLocCorrRate String = 37
  optional sampWellName String = 38
  optional win String = 39
  sampType String = 40
  optional sampSubtype SampSubtypeEnum = 41
  sampCollectPoint SampCollectPointEnum = 42
  optional pressure QuantityValue = 43
  optional oxyStatSamp OxyStatSampEnum = 44
  optional sampPreserv String = 45
  optional sampTransportCond String = 46
  optional sampStoreTemp QuantityValue = 47
  optional sampStoreDur String = 48
  optional sampStoreLoc String = 49
  repeated organismCount OrganismCountEnum = 50
  optional orgCountQpcrInfo String = 51
  optional ph Double = 52
  optional salinity QuantityValue = 53
  optional alkalinity QuantityValue = 54
  optional alkalinityMethod String = 55
  sulfate QuantityValue = 56
  sulfide QuantityValue = 57
  optional totSulfur QuantityValue = 58
  nitrate QuantityValue = 59
  optional nitrite QuantityValue = 60
  optional ammonium QuantityValue = 61
  optional totNitro QuantityValue = 62
  optional dissIron QuantityValue = 63
  optional sodium QuantityValue = 64
  optional chloride QuantityValue = 65
  optional potassium QuantityValue = 66
  optional magnesium QuantityValue = 67
  optional calcium QuantityValue = 68
  optional totIron QuantityValue = 69
  optional dissOrgCarb QuantityValue = 70
  optional dissInorgCarb QuantityValue = 71
  optional dissInorgPhosp QuantityValue = 72
  optional totPhosp QuantityValue = 73
  repeated suspendSolids String = 74
  optional density QuantityValue = 75
  optional dissCarbDioxide QuantityValue = 76
  optional dissOxygenFluid QuantityValue = 77
  optional vfa QuantityValue = 78
  optional benzene QuantityValue = 79
  optional toluene QuantityValue = 80
  optional ethylbenzene QuantityValue = 81
  optional xylene QuantityValue = 82
  api QuantityValue = 83
  optional tan QuantityValue = 84
  optional viscosity String = 85
  optional pourPoint QuantityValue = 86
  optional saturatesPc String = 87
  optional aromaticsPc String = 88
  optional resinsPc String = 89
  optional asphaltenesPc String = 90
  repeated miscParam String = 91
  optional additionalInfo String = 92
  sampName String = 93
  projectName String = 94
  optional sampVolWeDnaExt QuantityValue = 95
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package hydrocarbon resources-fluids_swabs
message HydrocarbonResources-fluidsSwabsMIGSBacteria
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  hcr HcrEnum = 11
  hcProduced HcProducedEnum = 12
  basin String = 13
  optional field String = 14
  optional reservoir String = 15
  optional hcrTemp String = 16
  optional tvdssOfHcrTemp QuantityValue = 17
  optional hcrPressure String = 18
  optional tvdssOfHcrPress QuantityValue = 19
  optional lithology LithologyEnum = 20
  optional deposEnv DeposEnvEnum = 21
  optional hcrGeolAge HcrGeolAgeEnum = 22
  optional hcrFwSalinity QuantityValue = 23
  optional sulfateFw QuantityValue = 24
  optional vfaFw QuantityValue = 25
  optional prodStartDate Date = 26
  optional prodRate QuantityValue = 27
  optional waterProdRate QuantityValue = 28
  waterCut QuantityValue = 29
  iwf QuantityValue = 30
  addRecovMethod String = 31
  optional iwBtDateWell Date = 32
  optional biocide String = 33
  optional biocideAdminMethod String = 34
  optional chemTreatment String = 35
  optional chemTreatMethod String = 36
  optional sampLocCorrRate String = 37
  optional sampWellName String = 38
  optional win String = 39
  sampType String = 40
  optional sampSubtype SampSubtypeEnum = 41
  sampCollectPoint SampCollectPointEnum = 42
  optional pressure QuantityValue = 43
  optional oxyStatSamp OxyStatSampEnum = 44
  optional sampPreserv String = 45
  optional sampTransportCond String = 46
  optional sampStoreTemp QuantityValue = 47
  optional sampStoreDur String = 48
  optional sampStoreLoc String = 49
  repeated organismCount OrganismCountEnum = 50
  optional orgCountQpcrInfo String = 51
  optional ph Double = 52
  optional salinity QuantityValue = 53
  optional alkalinity QuantityValue = 54
  optional alkalinityMethod String = 55
  sulfate QuantityValue = 56
  sulfide QuantityValue = 57
  optional totSulfur QuantityValue = 58
  nitrate QuantityValue = 59
  optional nitrite QuantityValue = 60
  optional ammonium QuantityValue = 61
  optional totNitro QuantityValue = 62
  optional dissIron QuantityValue = 63
  optional sodium QuantityValue = 64
  optional chloride QuantityValue = 65
  optional potassium QuantityValue = 66
  optional magnesium QuantityValue = 67
  optional calcium QuantityValue = 68
  optional totIron QuantityValue = 69
  optional dissOrgCarb QuantityValue = 70
  optional dissInorgCarb QuantityValue = 71
  optional dissInorgPhosp QuantityValue = 72
  optional totPhosp QuantityValue = 73
  repeated suspendSolids String = 74
  optional density QuantityValue = 75
  optional dissCarbDioxide QuantityValue = 76
  optional dissOxygenFluid QuantityValue = 77
  optional vfa QuantityValue = 78
  optional benzene QuantityValue = 79
  optional toluene QuantityValue = 80
  optional ethylbenzene QuantityValue = 81
  optional xylene QuantityValue = 82
  api QuantityValue = 83
  optional tan QuantityValue = 84
  optional viscosity String = 85
  optional pourPoint QuantityValue = 86
  optional saturatesPc String = 87
  optional aromaticsPc String = 88
  optional resinsPc String = 89
  optional asphaltenesPc String = 90
  repeated miscParam String = 91
  optional additionalInfo String = 92
  sampName String = 93
  projectName String = 94
  optional sampVolWeDnaExt QuantityValue = 95
  sampTaxonId String = 96
  optional experimentalFactor String = 97
  optional negContType NegContTypeEnum = 98
  optional posContType String = 99
  optional subspecfGenLin String = 100
  numReplicons Integer = 101
  optional extrachromElements Integer = 102
  optional estimatedSize String = 103
  refBiomaterial String = 104
  optional sourceMatId String = 105
  optional pathogenicity String = 106
  optional bioticRelationship BioticRelationshipEnum = 107
  optional specificHost String = 108
  optional hostSpecRange Integer = 109
  optional hostDiseaseStat String = 110
  optional trophicLevel TrophicLevelEnum = 111
  optional encodedTraits String = 112
  optional relToOxygen RelToOxygenEnum = 113
  isolGrowthCondt String = 114
  optional sampCollecDevice String = 115
  optional sampCollecMethod String = 116
  optional sampMatProcess String = 117
  optional sampSize QuantityValue = 118
  optional nuclAcidExt String = 119
  optional nuclAcidAmp String = 120
  optional libSize Integer = 121
  optional libReadsSeqd Integer = 122
  optional libLayout LibLayoutEnum = 123
  optional libVector String = 124
  optional libScreen String = 125
  optional adapters String = 126
  seqMeth String = 127
  optional taxIdent TaxIdentEnum = 128
  assemblyQual AssemblyQualEnum = 129
  optional assemblyName String = 130
  assemblySoftware String = 131
  optional annot String = 132
  numberContig Integer = 133
  optional featPred String = 134
  optional refDb String = 135
  optional simSearchMeth String = 136
  optional taxClass String = 137
  optional complScore String = 138
  optional complSoftware String = 139
  optional associatedResource String = 140
  optional sop String = 141
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: eukaryote with environmental package hydrocarbon resources-fluids_swabs
message HydrocarbonResources-fluidsSwabsMIGSEukaryote
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  hcr HcrEnum = 11
  hcProduced HcProducedEnum = 12
  basin String = 13
  optional field String = 14
  optional reservoir String = 15
  optional hcrTemp String = 16
  optional tvdssOfHcrTemp QuantityValue = 17
  optional hcrPressure String = 18
  optional tvdssOfHcrPress QuantityValue = 19
  optional lithology LithologyEnum = 20
  optional deposEnv DeposEnvEnum = 21
  optional hcrGeolAge HcrGeolAgeEnum = 22
  optional hcrFwSalinity QuantityValue = 23
  optional sulfateFw QuantityValue = 24
  optional vfaFw QuantityValue = 25
  optional prodStartDate Date = 26
  optional prodRate QuantityValue = 27
  optional waterProdRate QuantityValue = 28
  waterCut QuantityValue = 29
  iwf QuantityValue = 30
  addRecovMethod String = 31
  optional iwBtDateWell Date = 32
  optional biocide String = 33
  optional biocideAdminMethod String = 34
  optional chemTreatment String = 35
  optional chemTreatMethod String = 36
  optional sampLocCorrRate String = 37
  optional sampWellName String = 38
  optional win String = 39
  sampType String = 40
  optional sampSubtype SampSubtypeEnum = 41
  sampCollectPoint SampCollectPointEnum = 42
  optional pressure QuantityValue = 43
  optional oxyStatSamp OxyStatSampEnum = 44
  optional sampPreserv String = 45
  optional sampTransportCond String = 46
  optional sampStoreTemp QuantityValue = 47
  optional sampStoreDur String = 48
  optional sampStoreLoc String = 49
  repeated organismCount OrganismCountEnum = 50
  optional orgCountQpcrInfo String = 51
  optional ph Double = 52
  optional salinity QuantityValue = 53
  optional alkalinity QuantityValue = 54
  optional alkalinityMethod String = 55
  sulfate QuantityValue = 56
  sulfide QuantityValue = 57
  optional totSulfur QuantityValue = 58
  nitrate QuantityValue = 59
  optional nitrite QuantityValue = 60
  optional ammonium QuantityValue = 61
  optional totNitro QuantityValue = 62
  optional dissIron QuantityValue = 63
  optional sodium QuantityValue = 64
  optional chloride QuantityValue = 65
  optional potassium QuantityValue = 66
  optional magnesium QuantityValue = 67
  optional calcium QuantityValue = 68
  optional totIron QuantityValue = 69
  optional dissOrgCarb QuantityValue = 70
  optional dissInorgCarb QuantityValue = 71
  optional dissInorgPhosp QuantityValue = 72
  optional totPhosp QuantityValue = 73
  repeated suspendSolids String = 74
  optional density QuantityValue = 75
  optional dissCarbDioxide QuantityValue = 76
  optional dissOxygenFluid QuantityValue = 77
  optional vfa QuantityValue = 78
  optional benzene QuantityValue = 79
  optional toluene QuantityValue = 80
  optional ethylbenzene QuantityValue = 81
  optional xylene QuantityValue = 82
  api QuantityValue = 83
  optional tan QuantityValue = 84
  optional viscosity String = 85
  optional pourPoint QuantityValue = 86
  optional saturatesPc String = 87
  optional aromaticsPc String = 88
  optional resinsPc String = 89
  optional asphaltenesPc String = 90
  repeated miscParam String = 91
  optional additionalInfo String = 92
  sampName String = 93
  projectName String = 94
  optional sampVolWeDnaExt QuantityValue = 95
  sampTaxonId String = 96
  optional experimentalFactor String = 97
  optional negContType NegContTypeEnum = 98
  optional posContType String = 99
  optional subspecfGenLin String = 100
  optional ploidy String = 101
  optional numReplicons Integer = 102
  optional extrachromElements Integer = 103
  optional estimatedSize String = 104
  optional refBiomaterial String = 105
  optional sourceMatId String = 106
  optional pathogenicity String = 107
  optional bioticRelationship BioticRelationshipEnum = 108
  optional specificHost String = 109
  optional hostSpecRange Integer = 110
  optional hostDiseaseStat String = 111
  optional trophicLevel TrophicLevelEnum = 112
  optional propagation String = 113
  isolGrowthCondt String = 114
  optional sampCollecDevice String = 115
  optional sampCollecMethod String = 116
  optional sampMatProcess String = 117
  optional sampSize QuantityValue = 118
  optional nuclAcidExt String = 119
  optional nuclAcidAmp String = 120
  optional libSize Integer = 121
  optional libReadsSeqd Integer = 122
  optional libLayout LibLayoutEnum = 123
  optional libVector String = 124
  optional libScreen String = 125
  optional adapters String = 126
  seqMeth String = 127
  optional taxIdent TaxIdentEnum = 128
  assemblyQual AssemblyQualEnum = 129
  optional assemblyName String = 130
  assemblySoftware String = 131
  optional annot String = 132
  numberContig Integer = 133
  optional featPred String = 134
  optional refDb String = 135
  optional simSearchMeth String = 136
  optional taxClass String = 137
  optional complScore String = 138
  optional complSoftware String = 139
  optional associatedResource String = 140
  optional sop String = 141
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: org with environmental package hydrocarbon resources-fluids_swabs
message HydrocarbonResources-fluidsSwabsMIGSOrg
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  hcr HcrEnum = 11
  hcProduced HcProducedEnum = 12
  basin String = 13
  optional field String = 14
  optional reservoir String = 15
  optional hcrTemp String = 16
  optional tvdssOfHcrTemp QuantityValue = 17
  optional hcrPressure String = 18
  optional tvdssOfHcrPress QuantityValue = 19
  optional lithology LithologyEnum = 20
  optional deposEnv DeposEnvEnum = 21
  optional hcrGeolAge HcrGeolAgeEnum = 22
  optional hcrFwSalinity QuantityValue = 23
  optional sulfateFw QuantityValue = 24
  optional vfaFw QuantityValue = 25
  optional prodStartDate Date = 26
  optional prodRate QuantityValue = 27
  optional waterProdRate QuantityValue = 28
  waterCut QuantityValue = 29
  iwf QuantityValue = 30
  addRecovMethod String = 31
  optional iwBtDateWell Date = 32
  optional biocide String = 33
  optional biocideAdminMethod String = 34
  optional chemTreatment String = 35
  optional chemTreatMethod String = 36
  optional sampLocCorrRate String = 37
  optional sampWellName String = 38
  optional win String = 39
  sampType String = 40
  optional sampSubtype SampSubtypeEnum = 41
  sampCollectPoint SampCollectPointEnum = 42
  optional pressure QuantityValue = 43
  optional oxyStatSamp OxyStatSampEnum = 44
  optional sampPreserv String = 45
  optional sampTransportCond String = 46
  optional sampStoreTemp QuantityValue = 47
  optional sampStoreDur String = 48
  optional sampStoreLoc String = 49
  repeated organismCount OrganismCountEnum = 50
  optional orgCountQpcrInfo String = 51
  optional ph Double = 52
  optional salinity QuantityValue = 53
  optional alkalinity QuantityValue = 54
  optional alkalinityMethod String = 55
  sulfate QuantityValue = 56
  sulfide QuantityValue = 57
  optional totSulfur QuantityValue = 58
  nitrate QuantityValue = 59
  optional nitrite QuantityValue = 60
  optional ammonium QuantityValue = 61
  optional totNitro QuantityValue = 62
  optional dissIron QuantityValue = 63
  optional sodium QuantityValue = 64
  optional chloride QuantityValue = 65
  optional potassium QuantityValue = 66
  optional magnesium QuantityValue = 67
  optional calcium QuantityValue = 68
  optional totIron QuantityValue = 69
  optional dissOrgCarb QuantityValue = 70
  optional dissInorgCarb QuantityValue = 71
  optional dissInorgPhosp QuantityValue = 72
  optional totPhosp QuantityValue = 73
  repeated suspendSolids String = 74
  optional density QuantityValue = 75
  optional dissCarbDioxide QuantityValue = 76
  optional dissOxygenFluid QuantityValue = 77
  optional vfa QuantityValue = 78
  optional benzene QuantityValue = 79
  optional toluene QuantityValue = 80
  optional ethylbenzene QuantityValue = 81
  optional xylene QuantityValue = 82
  api QuantityValue = 83
  optional tan QuantityValue = 84
  optional viscosity String = 85
  optional pourPoint QuantityValue = 86
  optional saturatesPc String = 87
  optional aromaticsPc String = 88
  optional resinsPc String = 89
  optional asphaltenesPc String = 90
  repeated miscParam String = 91
  optional additionalInfo String = 92
  sampName String = 93
  projectName String = 94
  optional sampVolWeDnaExt QuantityValue = 95
  sampTaxonId String = 96
  optional experimentalFactor String = 97
  optional negContType NegContTypeEnum = 98
  optional posContType String = 99
  optional subspecfGenLin String = 100
  optional extrachromElements Integer = 101
  optional estimatedSize String = 102
  optional refBiomaterial String = 103
  optional sourceMatId String = 104
  isolGrowthCondt String = 105
  optional sampCollecDevice String = 106
  optional sampCollecMethod String = 107
  optional sampMatProcess String = 108
  optional sampSize QuantityValue = 109
  optional nuclAcidExt String = 110
  optional nuclAcidAmp String = 111
  optional libSize Integer = 112
  optional libReadsSeqd Integer = 113
  optional libLayout LibLayoutEnum = 114
  optional libVector String = 115
  optional libScreen String = 116
  optional adapters String = 117
  seqMeth String = 118
  optional taxIdent TaxIdentEnum = 119
  optional assemblyQual AssemblyQualEnum = 120
  optional assemblyName String = 121
  assemblySoftware String = 122
  optional annot String = 123
  optional numberContig Integer = 124
  optional featPred String = 125
  optional refDb String = 126
  optional simSearchMeth String = 127
  optional taxClass String = 128
  optional complScore String = 129
  optional complSoftware String = 130
  optional associatedResource String = 131
  optional sop String = 132
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: plant with environmental package hydrocarbon resources-fluids_swabs
message HydrocarbonResources-fluidsSwabsMIGSPlant
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  hcr HcrEnum = 11
  hcProduced HcProducedEnum = 12
  basin String = 13
  optional field String = 14
  optional reservoir String = 15
  optional hcrTemp String = 16
  optional tvdssOfHcrTemp QuantityValue = 17
  optional hcrPressure String = 18
  optional tvdssOfHcrPress QuantityValue = 19
  optional lithology LithologyEnum = 20
  optional deposEnv DeposEnvEnum = 21
  optional hcrGeolAge HcrGeolAgeEnum = 22
  optional hcrFwSalinity QuantityValue = 23
  optional sulfateFw QuantityValue = 24
  optional vfaFw QuantityValue = 25
  optional prodStartDate Date = 26
  optional prodRate QuantityValue = 27
  optional waterProdRate QuantityValue = 28
  waterCut QuantityValue = 29
  iwf QuantityValue = 30
  addRecovMethod String = 31
  optional iwBtDateWell Date = 32
  optional biocide String = 33
  optional biocideAdminMethod String = 34
  optional chemTreatment String = 35
  optional chemTreatMethod String = 36
  optional sampLocCorrRate String = 37
  optional sampWellName String = 38
  optional win String = 39
  sampType String = 40
  optional sampSubtype SampSubtypeEnum = 41
  sampCollectPoint SampCollectPointEnum = 42
  optional pressure QuantityValue = 43
  optional oxyStatSamp OxyStatSampEnum = 44
  optional sampPreserv String = 45
  optional sampTransportCond String = 46
  optional sampStoreTemp QuantityValue = 47
  optional sampStoreDur String = 48
  optional sampStoreLoc String = 49
  repeated organismCount OrganismCountEnum = 50
  optional orgCountQpcrInfo String = 51
  optional ph Double = 52
  optional salinity QuantityValue = 53
  optional alkalinity QuantityValue = 54
  optional alkalinityMethod String = 55
  sulfate QuantityValue = 56
  sulfide QuantityValue = 57
  optional totSulfur QuantityValue = 58
  nitrate QuantityValue = 59
  optional nitrite QuantityValue = 60
  optional ammonium QuantityValue = 61
  optional totNitro QuantityValue = 62
  optional dissIron QuantityValue = 63
  optional sodium QuantityValue = 64
  optional chloride QuantityValue = 65
  optional potassium QuantityValue = 66
  optional magnesium QuantityValue = 67
  optional calcium QuantityValue = 68
  optional totIron QuantityValue = 69
  optional dissOrgCarb QuantityValue = 70
  optional dissInorgCarb QuantityValue = 71
  optional dissInorgPhosp QuantityValue = 72
  optional totPhosp QuantityValue = 73
  repeated suspendSolids String = 74
  optional density QuantityValue = 75
  optional dissCarbDioxide QuantityValue = 76
  optional dissOxygenFluid QuantityValue = 77
  optional vfa QuantityValue = 78
  optional benzene QuantityValue = 79
  optional toluene QuantityValue = 80
  optional ethylbenzene QuantityValue = 81
  optional xylene QuantityValue = 82
  api QuantityValue = 83
  optional tan QuantityValue = 84
  optional viscosity String = 85
  optional pourPoint QuantityValue = 86
  optional saturatesPc String = 87
  optional aromaticsPc String = 88
  optional resinsPc String = 89
  optional asphaltenesPc String = 90
  repeated miscParam String = 91
  optional additionalInfo String = 92
  sampName String = 93
  projectName String = 94
  optional sampVolWeDnaExt QuantityValue = 95
  sampTaxonId String = 96
  optional experimentalFactor String = 97
  optional negContType NegContTypeEnum = 98
  optional posContType String = 99
  optional subspecfGenLin String = 100
  optional estimatedSize String = 101
  optional refBiomaterial String = 102
  optional sourceMatId String = 103
  optional specificHost String = 104
  optional hostSpecRange Integer = 105
  propagation String = 106
  optional encodedTraits String = 107
  isolGrowthCondt String = 108
  optional sampCollecDevice String = 109
  optional sampCollecMethod String = 110
  optional sampMatProcess String = 111
  optional sampSize QuantityValue = 112
  optional nuclAcidExt String = 113
  optional nuclAcidAmp String = 114
  optional libSize Integer = 115
  optional libReadsSeqd Integer = 116
  optional libLayout LibLayoutEnum = 117
  optional libVector String = 118
  optional libScreen String = 119
  optional adapters String = 120
  seqMeth String = 121
  optional taxIdent TaxIdentEnum = 122
  optional assemblyQual AssemblyQualEnum = 123
  optional assemblyName String = 124
  assemblySoftware String = 125
  optional annot String = 126
  optional numberContig Integer = 127
  optional featPred String = 128
  optional refDb String = 129
  optional simSearchMeth String = 130
  optional taxClass String = 131
  optional complScore String = 132
  optional complSoftware String = 133
  optional associatedResource String = 134
  optional sop String = 135
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package hydrocarbon resources-fluids_swabs
message HydrocarbonResources-fluidsSwabsMIGSVirus
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  hcr HcrEnum = 11
  hcProduced HcProducedEnum = 12
  basin String = 13
  optional field String = 14
  optional reservoir String = 15
  optional hcrTemp String = 16
  optional tvdssOfHcrTemp QuantityValue = 17
  optional hcrPressure String = 18
  optional tvdssOfHcrPress QuantityValue = 19
  optional lithology LithologyEnum = 20
  optional deposEnv DeposEnvEnum = 21
  optional hcrGeolAge HcrGeolAgeEnum = 22
  optional hcrFwSalinity QuantityValue = 23
  optional sulfateFw QuantityValue = 24
  optional vfaFw QuantityValue = 25
  optional prodStartDate Date = 26
  optional prodRate QuantityValue = 27
  optional waterProdRate QuantityValue = 28
  waterCut QuantityValue = 29
  iwf QuantityValue = 30
  addRecovMethod String = 31
  optional iwBtDateWell Date = 32
  optional biocide String = 33
  optional biocideAdminMethod String = 34
  optional chemTreatment String = 35
  optional chemTreatMethod String = 36
  optional sampLocCorrRate String = 37
  optional sampWellName String = 38
  optional win String = 39
  sampType String = 40
  optional sampSubtype SampSubtypeEnum = 41
  sampCollectPoint SampCollectPointEnum = 42
  optional pressure QuantityValue = 43
  optional oxyStatSamp OxyStatSampEnum = 44
  optional sampPreserv String = 45
  optional sampTransportCond String = 46
  optional sampStoreTemp QuantityValue = 47
  optional sampStoreDur String = 48
  optional sampStoreLoc String = 49
  repeated organismCount OrganismCountEnum = 50
  optional orgCountQpcrInfo String = 51
  optional ph Double = 52
  optional salinity QuantityValue = 53
  optional alkalinity QuantityValue = 54
  optional alkalinityMethod String = 55
  sulfate QuantityValue = 56
  sulfide QuantityValue = 57
  optional totSulfur QuantityValue = 58
  nitrate QuantityValue = 59
  optional nitrite QuantityValue = 60
  optional ammonium QuantityValue = 61
  optional totNitro QuantityValue = 62
  optional dissIron QuantityValue = 63
  optional sodium QuantityValue = 64
  optional chloride QuantityValue = 65
  optional potassium QuantityValue = 66
  optional magnesium QuantityValue = 67
  optional calcium QuantityValue = 68
  optional totIron QuantityValue = 69
  optional dissOrgCarb QuantityValue = 70
  optional dissInorgCarb QuantityValue = 71
  optional dissInorgPhosp QuantityValue = 72
  optional totPhosp QuantityValue = 73
  repeated suspendSolids String = 74
  optional density QuantityValue = 75
  optional dissCarbDioxide QuantityValue = 76
  optional dissOxygenFluid QuantityValue = 77
  optional vfa QuantityValue = 78
  optional benzene QuantityValue = 79
  optional toluene QuantityValue = 80
  optional ethylbenzene QuantityValue = 81
  optional xylene QuantityValue = 82
  api QuantityValue = 83
  optional tan QuantityValue = 84
  optional viscosity String = 85
  optional pourPoint QuantityValue = 86
  optional saturatesPc String = 87
  optional aromaticsPc String = 88
  optional resinsPc String = 89
  optional asphaltenesPc String = 90
  repeated miscParam String = 91
  optional additionalInfo String = 92
  sampName String = 93
  projectName String = 94
  optional sampVolWeDnaExt QuantityValue = 95
  sampTaxonId String = 96
  optional experimentalFactor String = 97
  optional negContType NegContTypeEnum = 98
  optional posContType String = 99
  optional subspecfGenLin String = 100
  optional numReplicons Integer = 101
  optional estimatedSize String = 102
  optional refBiomaterial String = 103
  optional sourceMatId String = 104
  optional pathogenicity String = 105
  optional bioticRelationship BioticRelationshipEnum = 106
  optional specificHost String = 107
  optional hostSpecRange Integer = 108
  optional hostDiseaseStat String = 109
  propagation String = 110
  optional encodedTraits String = 111
  isolGrowthCondt String = 112
  optional sampCollecDevice String = 113
  optional sampCollecMethod String = 114
  optional sampMatProcess String = 115
  optional sampSize QuantityValue = 116
  optional virusEnrichAppr VirusEnrichApprEnum = 117
  optional nuclAcidExt String = 118
  optional nuclAcidAmp String = 119
  optional libSize Integer = 120
  optional libReadsSeqd Integer = 121
  optional libLayout LibLayoutEnum = 122
  optional libVector String = 123
  optional libScreen String = 124
  optional adapters String = 125
  seqMeth String = 126
  optional taxIdent TaxIdentEnum = 127
  optional assemblyQual AssemblyQualEnum = 128
  optional assemblyName String = 129
  assemblySoftware String = 130
  optional annot String = 131
  optional numberContig Integer = 132
  optional featPred String = 133
  optional refDb String = 134
  optional simSearchMeth String = 135
  optional taxClass String = 136
  optional complScore String = 137
  optional complSoftware String = 138
  optional associatedResource String = 139
  optional sop String = 140
 }
// Combinatorial checklist Minimum Information About a Metagenome-Assembled Genome with environmental package hydrocarbon resources-fluids_swabs
message HydrocarbonResources-fluidsSwabsMIMAG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  hcr HcrEnum = 11
  hcProduced HcProducedEnum = 12
  basin String = 13
  optional field String = 14
  optional reservoir String = 15
  optional hcrTemp String = 16
  optional tvdssOfHcrTemp QuantityValue = 17
  optional hcrPressure String = 18
  optional tvdssOfHcrPress QuantityValue = 19
  optional lithology LithologyEnum = 20
  optional deposEnv DeposEnvEnum = 21
  optional hcrGeolAge HcrGeolAgeEnum = 22
  optional hcrFwSalinity QuantityValue = 23
  optional sulfateFw QuantityValue = 24
  optional vfaFw QuantityValue = 25
  optional prodStartDate Date = 26
  optional prodRate QuantityValue = 27
  optional waterProdRate QuantityValue = 28
  waterCut QuantityValue = 29
  iwf QuantityValue = 30
  addRecovMethod String = 31
  optional iwBtDateWell Date = 32
  optional biocide String = 33
  optional biocideAdminMethod String = 34
  optional chemTreatment String = 35
  optional chemTreatMethod String = 36
  optional sampLocCorrRate String = 37
  optional sampWellName String = 38
  optional win String = 39
  sampType String = 40
  optional sampSubtype SampSubtypeEnum = 41
  sampCollectPoint SampCollectPointEnum = 42
  optional pressure QuantityValue = 43
  optional oxyStatSamp OxyStatSampEnum = 44
  optional sampPreserv String = 45
  optional sampTransportCond String = 46
  optional sampStoreTemp QuantityValue = 47
  optional sampStoreDur String = 48
  optional sampStoreLoc String = 49
  repeated organismCount OrganismCountEnum = 50
  optional orgCountQpcrInfo String = 51
  optional ph Double = 52
  optional salinity QuantityValue = 53
  optional alkalinity QuantityValue = 54
  optional alkalinityMethod String = 55
  sulfate QuantityValue = 56
  sulfide QuantityValue = 57
  optional totSulfur QuantityValue = 58
  nitrate QuantityValue = 59
  optional nitrite QuantityValue = 60
  optional ammonium QuantityValue = 61
  optional totNitro QuantityValue = 62
  optional dissIron QuantityValue = 63
  optional sodium QuantityValue = 64
  optional chloride QuantityValue = 65
  optional potassium QuantityValue = 66
  optional magnesium QuantityValue = 67
  optional calcium QuantityValue = 68
  optional totIron QuantityValue = 69
  optional dissOrgCarb QuantityValue = 70
  optional dissInorgCarb QuantityValue = 71
  optional dissInorgPhosp QuantityValue = 72
  optional totPhosp QuantityValue = 73
  repeated suspendSolids String = 74
  optional density QuantityValue = 75
  optional dissCarbDioxide QuantityValue = 76
  optional dissOxygenFluid QuantityValue = 77
  optional vfa QuantityValue = 78
  optional benzene QuantityValue = 79
  optional toluene QuantityValue = 80
  optional ethylbenzene QuantityValue = 81
  optional xylene QuantityValue = 82
  api QuantityValue = 83
  optional tan QuantityValue = 84
  optional viscosity String = 85
  optional pourPoint QuantityValue = 86
  optional saturatesPc String = 87
  optional aromaticsPc String = 88
  optional resinsPc String = 89
  optional asphaltenesPc String = 90
  repeated miscParam String = 91
  optional additionalInfo String = 92
  sampName String = 93
  projectName String = 94
  optional sampVolWeDnaExt QuantityValue = 95
  sampTaxonId String = 96
  optional experimentalFactor String = 97
  optional negContType NegContTypeEnum = 98
  optional posContType String = 99
  optional refBiomaterial String = 100
  optional sourceMatId String = 101
  optional relToOxygen RelToOxygenEnum = 102
  optional sampCollecDevice String = 103
  optional sampCollecMethod String = 104
  optional sampMatProcess String = 105
  optional sizeFrac String = 106
  optional sampSize QuantityValue = 107
  optional nuclAcidExt String = 108
  optional nuclAcidAmp String = 109
  optional libSize Integer = 110
  optional libReadsSeqd Integer = 111
  optional libLayout LibLayoutEnum = 112
  optional libVector String = 113
  optional libScreen String = 114
  optional mid String = 115
  optional adapters String = 116
  seqMeth String = 117
  taxIdent TaxIdentEnum = 118
  assemblyQual AssemblyQualEnum = 119
  optional assemblyName String = 120
  assemblySoftware String = 121
  optional annot String = 122
  optional numberContig Integer = 123
  optional featPred String = 124
  optional refDb String = 125
  optional simSearchMeth String = 126
  optional taxClass String = 127
  optional x16sRecover String = 128
  optional x16sRecoverSoftware String = 129
  optional trnas Integer = 130
  optional trnaExtSoftware String = 131
  complScore String = 132
  complSoftware String = 133
  optional complAppr ComplApprEnum = 134
  contamScore String = 135
  optional contamScreenInput String = 136
  optional contamScreenParam String = 137
  optional decontamSoftware DecontamSoftwareEnum = 138
  binParam BinParamEnum = 139
  binSoftware String = 140
  optional reassemblyBin String = 141
  optional magCovSoftware MagCovSoftwareEnum = 142
  optional associatedResource String = 143
  optional sop String = 144
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: specimen with environmental package hydrocarbon resources-fluids_swabs
message HydrocarbonResources-fluidsSwabsMIMARKSSpecimen
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  hcr HcrEnum = 11
  hcProduced HcProducedEnum = 12
  basin String = 13
  optional field String = 14
  optional reservoir String = 15
  optional hcrTemp String = 16
  optional tvdssOfHcrTemp QuantityValue = 17
  optional hcrPressure String = 18
  optional tvdssOfHcrPress QuantityValue = 19
  optional lithology LithologyEnum = 20
  optional deposEnv DeposEnvEnum = 21
  optional hcrGeolAge HcrGeolAgeEnum = 22
  optional hcrFwSalinity QuantityValue = 23
  optional sulfateFw QuantityValue = 24
  optional vfaFw QuantityValue = 25
  optional prodStartDate Date = 26
  optional prodRate QuantityValue = 27
  optional waterProdRate QuantityValue = 28
  waterCut QuantityValue = 29
  iwf QuantityValue = 30
  addRecovMethod String = 31
  optional iwBtDateWell Date = 32
  optional biocide String = 33
  optional biocideAdminMethod String = 34
  optional chemTreatment String = 35
  optional chemTreatMethod String = 36
  optional sampLocCorrRate String = 37
  optional sampWellName String = 38
  optional win String = 39
  sampType String = 40
  optional sampSubtype SampSubtypeEnum = 41
  sampCollectPoint SampCollectPointEnum = 42
  optional pressure QuantityValue = 43
  optional oxyStatSamp OxyStatSampEnum = 44
  optional sampPreserv String = 45
  optional sampTransportCond String = 46
  optional sampStoreTemp QuantityValue = 47
  optional sampStoreDur String = 48
  optional sampStoreLoc String = 49
  repeated organismCount OrganismCountEnum = 50
  optional orgCountQpcrInfo String = 51
  optional ph Double = 52
  optional salinity QuantityValue = 53
  optional alkalinity QuantityValue = 54
  optional alkalinityMethod String = 55
  sulfate QuantityValue = 56
  sulfide QuantityValue = 57
  optional totSulfur QuantityValue = 58
  nitrate QuantityValue = 59
  optional nitrite QuantityValue = 60
  optional ammonium QuantityValue = 61
  optional totNitro QuantityValue = 62
  optional dissIron QuantityValue = 63
  optional sodium QuantityValue = 64
  optional chloride QuantityValue = 65
  optional potassium QuantityValue = 66
  optional magnesium QuantityValue = 67
  optional calcium QuantityValue = 68
  optional totIron QuantityValue = 69
  optional dissOrgCarb QuantityValue = 70
  optional dissInorgCarb QuantityValue = 71
  optional dissInorgPhosp QuantityValue = 72
  optional totPhosp QuantityValue = 73
  repeated suspendSolids String = 74
  optional density QuantityValue = 75
  optional dissCarbDioxide QuantityValue = 76
  optional dissOxygenFluid QuantityValue = 77
  optional vfa QuantityValue = 78
  optional benzene QuantityValue = 79
  optional toluene QuantityValue = 80
  optional ethylbenzene QuantityValue = 81
  optional xylene QuantityValue = 82
  api QuantityValue = 83
  optional tan QuantityValue = 84
  optional viscosity String = 85
  optional pourPoint QuantityValue = 86
  optional saturatesPc String = 87
  optional aromaticsPc String = 88
  optional resinsPc String = 89
  optional asphaltenesPc String = 90
  repeated miscParam String = 91
  optional additionalInfo String = 92
  sampName String = 93
  projectName String = 94
  optional sampVolWeDnaExt QuantityValue = 95
  sampTaxonId String = 96
  optional experimentalFactor String = 97
  optional negContType NegContTypeEnum = 98
  optional posContType String = 99
  optional sourceMatId String = 100
  optional relToOxygen RelToOxygenEnum = 101
  optional sampCollecDevice String = 102
  optional sampCollecMethod String = 103
  optional sampMatProcess String = 104
  optional sizeFrac String = 105
  optional sampSize QuantityValue = 106
  optional nuclAcidExt String = 107
  optional nuclAcidAmp String = 108
  optional libSize Integer = 109
  optional libReadsSeqd Integer = 110
  optional libLayout LibLayoutEnum = 111
  optional libVector String = 112
  optional libScreen String = 113
  targetGene String = 114
  optional targetSubfragment String = 115
  optional pcrPrimers String = 116
  optional mid String = 117
  optional adapters String = 118
  optional pcrCond String = 119
  seqMeth String = 120
  optional seqQualityCheck String = 121
  optional chimeraCheck String = 122
  optional assemblySoftware String = 123
  optional associatedResource String = 124
  optional sop String = 125
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: survey with environmental package hydrocarbon resources-fluids_swabs
message HydrocarbonResources-fluidsSwabsMIMARKSSurvey
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  hcr HcrEnum = 11
  hcProduced HcProducedEnum = 12
  basin String = 13
  optional field String = 14
  optional reservoir String = 15
  optional hcrTemp String = 16
  optional tvdssOfHcrTemp QuantityValue = 17
  optional hcrPressure String = 18
  optional tvdssOfHcrPress QuantityValue = 19
  optional lithology LithologyEnum = 20
  optional deposEnv DeposEnvEnum = 21
  optional hcrGeolAge HcrGeolAgeEnum = 22
  optional hcrFwSalinity QuantityValue = 23
  optional sulfateFw QuantityValue = 24
  optional vfaFw QuantityValue = 25
  optional prodStartDate Date = 26
  optional prodRate QuantityValue = 27
  optional waterProdRate QuantityValue = 28
  waterCut QuantityValue = 29
  iwf QuantityValue = 30
  addRecovMethod String = 31
  optional iwBtDateWell Date = 32
  optional biocide String = 33
  optional biocideAdminMethod String = 34
  optional chemTreatment String = 35
  optional chemTreatMethod String = 36
  optional sampLocCorrRate String = 37
  optional sampWellName String = 38
  optional win String = 39
  sampType String = 40
  optional sampSubtype SampSubtypeEnum = 41
  sampCollectPoint SampCollectPointEnum = 42
  optional pressure QuantityValue = 43
  optional oxyStatSamp OxyStatSampEnum = 44
  optional sampPreserv String = 45
  optional sampTransportCond String = 46
  optional sampStoreTemp QuantityValue = 47
  optional sampStoreDur String = 48
  optional sampStoreLoc String = 49
  repeated organismCount OrganismCountEnum = 50
  optional orgCountQpcrInfo String = 51
  optional ph Double = 52
  optional salinity QuantityValue = 53
  optional alkalinity QuantityValue = 54
  optional alkalinityMethod String = 55
  sulfate QuantityValue = 56
  sulfide QuantityValue = 57
  optional totSulfur QuantityValue = 58
  nitrate QuantityValue = 59
  optional nitrite QuantityValue = 60
  optional ammonium QuantityValue = 61
  optional totNitro QuantityValue = 62
  optional dissIron QuantityValue = 63
  optional sodium QuantityValue = 64
  optional chloride QuantityValue = 65
  optional potassium QuantityValue = 66
  optional magnesium QuantityValue = 67
  optional calcium QuantityValue = 68
  optional totIron QuantityValue = 69
  optional dissOrgCarb QuantityValue = 70
  optional dissInorgCarb QuantityValue = 71
  optional dissInorgPhosp QuantityValue = 72
  optional totPhosp QuantityValue = 73
  repeated suspendSolids String = 74
  optional density QuantityValue = 75
  optional dissCarbDioxide QuantityValue = 76
  optional dissOxygenFluid QuantityValue = 77
  optional vfa QuantityValue = 78
  optional benzene QuantityValue = 79
  optional toluene QuantityValue = 80
  optional ethylbenzene QuantityValue = 81
  optional xylene QuantityValue = 82
  api QuantityValue = 83
  optional tan QuantityValue = 84
  optional viscosity String = 85
  optional pourPoint QuantityValue = 86
  optional saturatesPc String = 87
  optional aromaticsPc String = 88
  optional resinsPc String = 89
  optional asphaltenesPc String = 90
  repeated miscParam String = 91
  optional additionalInfo String = 92
  sampName String = 93
  projectName String = 94
  optional sampVolWeDnaExt QuantityValue = 95
  sampTaxonId String = 96
  optional experimentalFactor String = 97
  optional negContType NegContTypeEnum = 98
  optional posContType String = 99
  optional subspecfGenLin String = 100
  optional extrachromElements Integer = 101
  optional sourceMatId String = 102
  optional bioticRelationship BioticRelationshipEnum = 103
  optional trophicLevel TrophicLevelEnum = 104
  optional relToOxygen RelToOxygenEnum = 105
  isolGrowthCondt String = 106
  optional sampCollecDevice String = 107
  optional sampCollecMethod String = 108
  optional sampMatProcess String = 109
  optional sampSize QuantityValue = 110
  optional nuclAcidExt String = 111
  optional nuclAcidAmp String = 112
  targetGene String = 113
  optional targetSubfragment String = 114
  optional pcrPrimers String = 115
  optional pcrCond String = 116
  seqMeth String = 117
  optional seqQualityCheck String = 118
  optional chimeraCheck String = 119
  optional associatedResource String = 120
  optional sop String = 121
 }
// Combinatorial checklist Metagenome or Environmental with environmental package hydrocarbon resources-fluids_swabs
message HydrocarbonResources-fluidsSwabsMIMS
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  hcr HcrEnum = 11
  hcProduced HcProducedEnum = 12
  basin String = 13
  optional field String = 14
  optional reservoir String = 15
  optional hcrTemp String = 16
  optional tvdssOfHcrTemp QuantityValue = 17
  optional hcrPressure String = 18
  optional tvdssOfHcrPress QuantityValue = 19
  optional lithology LithologyEnum = 20
  optional deposEnv DeposEnvEnum = 21
  optional hcrGeolAge HcrGeolAgeEnum = 22
  optional hcrFwSalinity QuantityValue = 23
  optional sulfateFw QuantityValue = 24
  optional vfaFw QuantityValue = 25
  optional prodStartDate Date = 26
  optional prodRate QuantityValue = 27
  optional waterProdRate QuantityValue = 28
  waterCut QuantityValue = 29
  iwf QuantityValue = 30
  addRecovMethod String = 31
  optional iwBtDateWell Date = 32
  optional biocide String = 33
  optional biocideAdminMethod String = 34
  optional chemTreatment String = 35
  optional chemTreatMethod String = 36
  optional sampLocCorrRate String = 37
  optional sampWellName String = 38
  optional win String = 39
  sampType String = 40
  optional sampSubtype SampSubtypeEnum = 41
  sampCollectPoint SampCollectPointEnum = 42
  optional pressure QuantityValue = 43
  optional oxyStatSamp OxyStatSampEnum = 44
  optional sampPreserv String = 45
  optional sampTransportCond String = 46
  optional sampStoreTemp QuantityValue = 47
  optional sampStoreDur String = 48
  optional sampStoreLoc String = 49
  repeated organismCount OrganismCountEnum = 50
  optional orgCountQpcrInfo String = 51
  optional ph Double = 52
  optional salinity QuantityValue = 53
  optional alkalinity QuantityValue = 54
  optional alkalinityMethod String = 55
  sulfate QuantityValue = 56
  sulfide QuantityValue = 57
  optional totSulfur QuantityValue = 58
  nitrate QuantityValue = 59
  optional nitrite QuantityValue = 60
  optional ammonium QuantityValue = 61
  optional totNitro QuantityValue = 62
  optional dissIron QuantityValue = 63
  optional sodium QuantityValue = 64
  optional chloride QuantityValue = 65
  optional potassium QuantityValue = 66
  optional magnesium QuantityValue = 67
  optional calcium QuantityValue = 68
  optional totIron QuantityValue = 69
  optional dissOrgCarb QuantityValue = 70
  optional dissInorgCarb QuantityValue = 71
  optional dissInorgPhosp QuantityValue = 72
  optional totPhosp QuantityValue = 73
  repeated suspendSolids String = 74
  optional density QuantityValue = 75
  optional dissCarbDioxide QuantityValue = 76
  optional dissOxygenFluid QuantityValue = 77
  optional vfa QuantityValue = 78
  optional benzene QuantityValue = 79
  optional toluene QuantityValue = 80
  optional ethylbenzene QuantityValue = 81
  optional xylene QuantityValue = 82
  api QuantityValue = 83
  optional tan QuantityValue = 84
  optional viscosity String = 85
  optional pourPoint QuantityValue = 86
  optional saturatesPc String = 87
  optional aromaticsPc String = 88
  optional resinsPc String = 89
  optional asphaltenesPc String = 90
  repeated miscParam String = 91
  optional additionalInfo String = 92
  sampName String = 93
  projectName String = 94
  optional sampVolWeDnaExt QuantityValue = 95
  sampTaxonId String = 96
  optional experimentalFactor String = 97
  optional negContType NegContTypeEnum = 98
  optional posContType String = 99
  optional refBiomaterial String = 100
  optional sourceMatId String = 101
  optional relToOxygen RelToOxygenEnum = 102
  optional sampCollecDevice String = 103
  optional sampCollecMethod String = 104
  optional sampMatProcess String = 105
  optional sizeFrac String = 106
  optional sampSize QuantityValue = 107
  optional nuclAcidExt String = 108
  optional nuclAcidAmp String = 109
  optional libSize Integer = 110
  optional libReadsSeqd Integer = 111
  optional libLayout LibLayoutEnum = 112
  optional libVector String = 113
  optional libScreen String = 114
  optional mid String = 115
  optional adapters String = 116
  seqMeth String = 117
  optional assemblyQual AssemblyQualEnum = 118
  optional assemblyName String = 119
  optional assemblySoftware String = 120
  optional annot String = 121
  optional numberContig Integer = 122
  optional featPred String = 123
  optional refDb String = 124
  optional simSearchMeth String = 125
  optional taxClass String = 126
  optional associatedResource String = 127
  optional sop String = 128
 }
// Combinatorial checklist Minimum Information About a Single Amplified Genome with environmental package hydrocarbon resources-fluids_swabs
message HydrocarbonResources-fluidsSwabsMISAG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  hcr HcrEnum = 11
  hcProduced HcProducedEnum = 12
  basin String = 13
  optional field String = 14
  optional reservoir String = 15
  optional hcrTemp String = 16
  optional tvdssOfHcrTemp QuantityValue = 17
  optional hcrPressure String = 18
  optional tvdssOfHcrPress QuantityValue = 19
  optional lithology LithologyEnum = 20
  optional deposEnv DeposEnvEnum = 21
  optional hcrGeolAge HcrGeolAgeEnum = 22
  optional hcrFwSalinity QuantityValue = 23
  optional sulfateFw QuantityValue = 24
  optional vfaFw QuantityValue = 25
  optional prodStartDate Date = 26
  optional prodRate QuantityValue = 27
  optional waterProdRate QuantityValue = 28
  waterCut QuantityValue = 29
  iwf QuantityValue = 30
  addRecovMethod String = 31
  optional iwBtDateWell Date = 32
  optional biocide String = 33
  optional biocideAdminMethod String = 34
  optional chemTreatment String = 35
  optional chemTreatMethod String = 36
  optional sampLocCorrRate String = 37
  optional sampWellName String = 38
  optional win String = 39
  sampType String = 40
  optional sampSubtype SampSubtypeEnum = 41
  sampCollectPoint SampCollectPointEnum = 42
  optional pressure QuantityValue = 43
  optional oxyStatSamp OxyStatSampEnum = 44
  optional sampPreserv String = 45
  optional sampTransportCond String = 46
  optional sampStoreTemp QuantityValue = 47
  optional sampStoreDur String = 48
  optional sampStoreLoc String = 49
  repeated organismCount OrganismCountEnum = 50
  optional orgCountQpcrInfo String = 51
  optional ph Double = 52
  optional salinity QuantityValue = 53
  optional alkalinity QuantityValue = 54
  optional alkalinityMethod String = 55
  sulfate QuantityValue = 56
  sulfide QuantityValue = 57
  optional totSulfur QuantityValue = 58
  nitrate QuantityValue = 59
  optional nitrite QuantityValue = 60
  optional ammonium QuantityValue = 61
  optional totNitro QuantityValue = 62
  optional dissIron QuantityValue = 63
  optional sodium QuantityValue = 64
  optional chloride QuantityValue = 65
  optional potassium QuantityValue = 66
  optional magnesium QuantityValue = 67
  optional calcium QuantityValue = 68
  optional totIron QuantityValue = 69
  optional dissOrgCarb QuantityValue = 70
  optional dissInorgCarb QuantityValue = 71
  optional dissInorgPhosp QuantityValue = 72
  optional totPhosp QuantityValue = 73
  repeated suspendSolids String = 74
  optional density QuantityValue = 75
  optional dissCarbDioxide QuantityValue = 76
  optional dissOxygenFluid QuantityValue = 77
  optional vfa QuantityValue = 78
  optional benzene QuantityValue = 79
  optional toluene QuantityValue = 80
  optional ethylbenzene QuantityValue = 81
  optional xylene QuantityValue = 82
  api QuantityValue = 83
  optional tan QuantityValue = 84
  optional viscosity String = 85
  optional pourPoint QuantityValue = 86
  optional saturatesPc String = 87
  optional aromaticsPc String = 88
  optional resinsPc String = 89
  optional asphaltenesPc String = 90
  repeated miscParam String = 91
  optional additionalInfo String = 92
  sampName String = 93
  projectName String = 94
  optional sampVolWeDnaExt QuantityValue = 95
  sampTaxonId String = 96
  optional experimentalFactor String = 97
  optional negContType NegContTypeEnum = 98
  optional posContType String = 99
  optional refBiomaterial String = 100
  optional sourceMatId String = 101
  optional relToOxygen RelToOxygenEnum = 102
  optional sampCollecDevice String = 103
  optional sampCollecMethod String = 104
  optional sampMatProcess String = 105
  optional sizeFrac String = 106
  optional sampSize QuantityValue = 107
  optional nuclAcidExt String = 108
  optional nuclAcidAmp String = 109
  optional libSize Integer = 110
  optional libReadsSeqd Integer = 111
  optional libLayout LibLayoutEnum = 112
  optional libVector String = 113
  optional libScreen String = 114
  optional mid String = 115
  optional adapters String = 116
  seqMeth String = 117
  taxIdent TaxIdentEnum = 118
  assemblyQual AssemblyQualEnum = 119
  optional assemblyName String = 120
  assemblySoftware String = 121
  optional annot String = 122
  optional numberContig Integer = 123
  optional featPred String = 124
  optional refDb String = 125
  optional simSearchMeth String = 126
  optional taxClass String = 127
  optional x16sRecover String = 128
  optional x16sRecoverSoftware String = 129
  optional trnas Integer = 130
  optional trnaExtSoftware String = 131
  complScore String = 132
  complSoftware String = 133
  optional complAppr ComplApprEnum = 134
  contamScore String = 135
  optional contamScreenInput String = 136
  optional contamScreenParam String = 137
  optional decontamSoftware DecontamSoftwareEnum = 138
  sortTech SortTechEnum = 139
  singleCellLysisAppr SingleCellLysisApprEnum = 140
  optional singleCellLysisProt String = 141
  wgaAmpAppr String = 142
  optional wgaAmpKit String = 143
  optional associatedResource String = 144
  optional sop String = 145
 }
// Combinatorial checklist Minimum Information About an Uncultivated Virus Genome with environmental package hydrocarbon resources-fluids_swabs
message HydrocarbonResources-fluidsSwabsMIUVIG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  hcr HcrEnum = 11
  hcProduced HcProducedEnum = 12
  basin String = 13
  optional field String = 14
  optional reservoir String = 15
  optional hcrTemp String = 16
  optional tvdssOfHcrTemp QuantityValue = 17
  optional hcrPressure String = 18
  optional tvdssOfHcrPress QuantityValue = 19
  optional lithology LithologyEnum = 20
  optional deposEnv DeposEnvEnum = 21
  optional hcrGeolAge HcrGeolAgeEnum = 22
  optional hcrFwSalinity QuantityValue = 23
  optional sulfateFw QuantityValue = 24
  optional vfaFw QuantityValue = 25
  optional prodStartDate Date = 26
  optional prodRate QuantityValue = 27
  optional waterProdRate QuantityValue = 28
  waterCut QuantityValue = 29
  iwf QuantityValue = 30
  addRecovMethod String = 31
  optional iwBtDateWell Date = 32
  optional biocide String = 33
  optional biocideAdminMethod String = 34
  optional chemTreatment String = 35
  optional chemTreatMethod String = 36
  optional sampLocCorrRate String = 37
  optional sampWellName String = 38
  optional win String = 39
  sampType String = 40
  optional sampSubtype SampSubtypeEnum = 41
  sampCollectPoint SampCollectPointEnum = 42
  optional pressure QuantityValue = 43
  optional oxyStatSamp OxyStatSampEnum = 44
  optional sampPreserv String = 45
  optional sampTransportCond String = 46
  optional sampStoreTemp QuantityValue = 47
  optional sampStoreDur String = 48
  optional sampStoreLoc String = 49
  repeated organismCount OrganismCountEnum = 50
  optional orgCountQpcrInfo String = 51
  optional ph Double = 52
  optional salinity QuantityValue = 53
  optional alkalinity QuantityValue = 54
  optional alkalinityMethod String = 55
  sulfate QuantityValue = 56
  sulfide QuantityValue = 57
  optional totSulfur QuantityValue = 58
  nitrate QuantityValue = 59
  optional nitrite QuantityValue = 60
  optional ammonium QuantityValue = 61
  optional totNitro QuantityValue = 62
  optional dissIron QuantityValue = 63
  optional sodium QuantityValue = 64
  optional chloride QuantityValue = 65
  optional potassium QuantityValue = 66
  optional magnesium QuantityValue = 67
  optional calcium QuantityValue = 68
  optional totIron QuantityValue = 69
  optional dissOrgCarb QuantityValue = 70
  optional dissInorgCarb QuantityValue = 71
  optional dissInorgPhosp QuantityValue = 72
  optional totPhosp QuantityValue = 73
  repeated suspendSolids String = 74
  optional density QuantityValue = 75
  optional dissCarbDioxide QuantityValue = 76
  optional dissOxygenFluid QuantityValue = 77
  optional vfa QuantityValue = 78
  optional benzene QuantityValue = 79
  optional toluene QuantityValue = 80
  optional ethylbenzene QuantityValue = 81
  optional xylene QuantityValue = 82
  api QuantityValue = 83
  optional tan QuantityValue = 84
  optional viscosity String = 85
  optional pourPoint QuantityValue = 86
  optional saturatesPc String = 87
  optional aromaticsPc String = 88
  optional resinsPc String = 89
  optional asphaltenesPc String = 90
  repeated miscParam String = 91
  optional additionalInfo String = 92
  sampName String = 93
  projectName String = 94
  optional sampVolWeDnaExt QuantityValue = 95
  sampTaxonId String = 96
  optional experimentalFactor String = 97
  optional negContType NegContTypeEnum = 98
  optional posContType String = 99
  optional estimatedSize String = 100
  optional refBiomaterial String = 101
  optional sourceMatId String = 102
  optional pathogenicity String = 103
  optional bioticRelationship BioticRelationshipEnum = 104
  optional specificHost String = 105
  optional hostSpecRange Integer = 106
  optional hostDiseaseStat String = 107
  optional sampCollecDevice String = 108
  optional sampCollecMethod String = 109
  optional sampMatProcess String = 110
  optional sizeFrac String = 111
  optional sampSize QuantityValue = 112
  sourceUvig SourceUvigEnum = 113
  virusEnrichAppr VirusEnrichApprEnum = 114
  optional nuclAcidExt String = 115
  optional nuclAcidAmp String = 116
  optional libSize Integer = 117
  optional libReadsSeqd Integer = 118
  optional libLayout LibLayoutEnum = 119
  optional libVector String = 120
  optional libScreen String = 121
  optional mid String = 122
  optional adapters String = 123
  seqMeth String = 124
  optional taxIdent TaxIdentEnum = 125
  assemblyQual AssemblyQualEnum = 126
  optional assemblyName String = 127
  assemblySoftware String = 128
  optional annot String = 129
  numberContig Integer = 130
  optional featPred String = 131
  optional refDb String = 132
  optional simSearchMeth String = 133
  optional taxClass String = 134
  optional trnas Integer = 135
  optional trnaExtSoftware String = 136
  optional complScore String = 137
  optional complSoftware String = 138
  optional complAppr ComplApprEnum = 139
  optional sortTech SortTechEnum = 140
  optional singleCellLysisAppr SingleCellLysisApprEnum = 141
  optional singleCellLysisProt String = 142
  optional wgaAmpAppr String = 143
  optional wgaAmpKit String = 144
  optional binParam BinParamEnum = 145
  optional binSoftware String = 146
  optional reassemblyBin String = 147
  optional magCovSoftware MagCovSoftwareEnum = 148
  virIdentSoftware String = 149
  predGenomeType PredGenomeTypeEnum = 150
  predGenomeStruc PredGenomeStrucEnum = 151
  detecType String = 152
  optional otuClassAppr String = 153
  optional otuSeqCompAppr String = 154
  optional otuDb String = 155
  optional hostPredAppr HostPredApprEnum = 156
  optional hostPredEstAcc String = 157
  optional associatedResource String = 158
  optional sop String = 159
 }
// microbial mat/biofilm
message MicrobialMatBiofilm
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkylDiethers QuantityValue = 12
  optional aminopeptAct QuantityValue = 13
  optional ammonium QuantityValue = 14
  optional bacteriaCarbProd QuantityValue = 15
  repeated biomass String = 16
  optional bishomohopanol QuantityValue = 17
  optional bromide QuantityValue = 18
  optional calcium QuantityValue = 19
  optional carbNitroRatio QuantityValue = 20
  repeated chemAdministration String = 21
  optional chloride QuantityValue = 22
  optional chlorophyll QuantityValue = 23
  repeated dietherLipids String = 24
  optional dissCarbDioxide QuantityValue = 25
  optional dissHydrogen QuantityValue = 26
  optional dissInorgCarb QuantityValue = 27
  optional dissOrgCarb QuantityValue = 28
  optional dissOrgNitro QuantityValue = 29
  optional dissOxygen QuantityValue = 30
  optional glucosidaseAct QuantityValue = 31
  optional magnesium QuantityValue = 32
  optional meanFrictVel QuantityValue = 33
  optional meanPeakFrictVel QuantityValue = 34
  optional methane QuantityValue = 35
  repeated miscParam String = 36
  repeated nAlkanes String = 37
  optional nitrate QuantityValue = 38
  optional nitrite QuantityValue = 39
  optional nitro QuantityValue = 40
  optional orgCarb QuantityValue = 41
  optional orgMatter QuantityValue = 42
  optional orgNitro QuantityValue = 43
  repeated organismCount OrganismCountEnum = 44
  optional oxyStatSamp OxyStatSampEnum = 45
  optional ph Double = 46
  optional partOrgCarb QuantityValue = 47
  repeated perturbation String = 48
  optional petroleumHydrocarb QuantityValue = 49
  repeated phaeopigments String = 50
  optional phosphate QuantityValue = 51
  repeated phosplipidFattAcid String = 52
  optional potassium QuantityValue = 53
  optional pressure QuantityValue = 54
  optional redoxPotential QuantityValue = 55
  optional salinity QuantityValue = 56
  optional sampStoreDur String = 57
  optional sampStoreLoc String = 58
  optional sampStoreTemp QuantityValue = 59
  optional silicate QuantityValue = 60
  optional sodium QuantityValue = 61
  optional sulfate QuantityValue = 62
  optional sulfide QuantityValue = 63
  optional totCarb QuantityValue = 64
  optional totNitroContent QuantityValue = 65
  optional totOrgCarb QuantityValue = 66
  optional turbidity QuantityValue = 67
  optional waterContent QuantityValue = 68
  sampName String = 69
  projectName String = 70
  optional sampVolWeDnaExt QuantityValue = 71
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package microbial mat_biofilm
message MicrobialMatBiofilmMIGSBacteria
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkylDiethers QuantityValue = 12
  optional aminopeptAct QuantityValue = 13
  optional ammonium QuantityValue = 14
  optional bacteriaCarbProd QuantityValue = 15
  repeated biomass String = 16
  optional bishomohopanol QuantityValue = 17
  optional bromide QuantityValue = 18
  optional calcium QuantityValue = 19
  optional carbNitroRatio QuantityValue = 20
  repeated chemAdministration String = 21
  optional chloride QuantityValue = 22
  optional chlorophyll QuantityValue = 23
  repeated dietherLipids String = 24
  optional dissCarbDioxide QuantityValue = 25
  optional dissHydrogen QuantityValue = 26
  optional dissInorgCarb QuantityValue = 27
  optional dissOrgCarb QuantityValue = 28
  optional dissOrgNitro QuantityValue = 29
  optional dissOxygen QuantityValue = 30
  optional glucosidaseAct QuantityValue = 31
  optional magnesium QuantityValue = 32
  optional meanFrictVel QuantityValue = 33
  optional meanPeakFrictVel QuantityValue = 34
  optional methane QuantityValue = 35
  repeated miscParam String = 36
  repeated nAlkanes String = 37
  optional nitrate QuantityValue = 38
  optional nitrite QuantityValue = 39
  optional nitro QuantityValue = 40
  optional orgCarb QuantityValue = 41
  optional orgMatter QuantityValue = 42
  optional orgNitro QuantityValue = 43
  repeated organismCount OrganismCountEnum = 44
  optional oxyStatSamp OxyStatSampEnum = 45
  optional ph Double = 46
  optional partOrgCarb QuantityValue = 47
  repeated perturbation String = 48
  optional petroleumHydrocarb QuantityValue = 49
  repeated phaeopigments String = 50
  optional phosphate QuantityValue = 51
  repeated phosplipidFattAcid String = 52
  optional potassium QuantityValue = 53
  optional pressure QuantityValue = 54
  optional redoxPotential QuantityValue = 55
  optional salinity QuantityValue = 56
  optional sampStoreDur String = 57
  optional sampStoreLoc String = 58
  optional sampStoreTemp QuantityValue = 59
  optional silicate QuantityValue = 60
  optional sodium QuantityValue = 61
  optional sulfate QuantityValue = 62
  optional sulfide QuantityValue = 63
  optional totCarb QuantityValue = 64
  optional totNitroContent QuantityValue = 65
  optional totOrgCarb QuantityValue = 66
  optional turbidity QuantityValue = 67
  optional waterContent QuantityValue = 68
  sampName String = 69
  projectName String = 70
  optional sampVolWeDnaExt QuantityValue = 71
  sampTaxonId String = 72
  optional experimentalFactor String = 73
  optional negContType NegContTypeEnum = 74
  optional posContType String = 75
  optional subspecfGenLin String = 76
  numReplicons Integer = 77
  optional extrachromElements Integer = 78
  optional estimatedSize String = 79
  refBiomaterial String = 80
  optional sourceMatId String = 81
  optional pathogenicity String = 82
  optional bioticRelationship BioticRelationshipEnum = 83
  optional specificHost String = 84
  optional hostSpecRange Integer = 85
  optional hostDiseaseStat String = 86
  optional trophicLevel TrophicLevelEnum = 87
  optional encodedTraits String = 88
  optional relToOxygen RelToOxygenEnum = 89
  isolGrowthCondt String = 90
  optional sampCollecDevice String = 91
  optional sampCollecMethod String = 92
  optional sampMatProcess String = 93
  optional sampSize QuantityValue = 94
  optional nuclAcidExt String = 95
  optional nuclAcidAmp String = 96
  optional libSize Integer = 97
  optional libReadsSeqd Integer = 98
  optional libLayout LibLayoutEnum = 99
  optional libVector String = 100
  optional libScreen String = 101
  optional adapters String = 102
  seqMeth String = 103
  optional taxIdent TaxIdentEnum = 104
  assemblyQual AssemblyQualEnum = 105
  optional assemblyName String = 106
  assemblySoftware String = 107
  optional annot String = 108
  numberContig Integer = 109
  optional featPred String = 110
  optional refDb String = 111
  optional simSearchMeth String = 112
  optional taxClass String = 113
  optional complScore String = 114
  optional complSoftware String = 115
  optional associatedResource String = 116
  optional sop String = 117
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: eukaryote with environmental package microbial mat_biofilm
message MicrobialMatBiofilmMIGSEukaryote
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkylDiethers QuantityValue = 12
  optional aminopeptAct QuantityValue = 13
  optional ammonium QuantityValue = 14
  optional bacteriaCarbProd QuantityValue = 15
  repeated biomass String = 16
  optional bishomohopanol QuantityValue = 17
  optional bromide QuantityValue = 18
  optional calcium QuantityValue = 19
  optional carbNitroRatio QuantityValue = 20
  repeated chemAdministration String = 21
  optional chloride QuantityValue = 22
  optional chlorophyll QuantityValue = 23
  repeated dietherLipids String = 24
  optional dissCarbDioxide QuantityValue = 25
  optional dissHydrogen QuantityValue = 26
  optional dissInorgCarb QuantityValue = 27
  optional dissOrgCarb QuantityValue = 28
  optional dissOrgNitro QuantityValue = 29
  optional dissOxygen QuantityValue = 30
  optional glucosidaseAct QuantityValue = 31
  optional magnesium QuantityValue = 32
  optional meanFrictVel QuantityValue = 33
  optional meanPeakFrictVel QuantityValue = 34
  optional methane QuantityValue = 35
  repeated miscParam String = 36
  repeated nAlkanes String = 37
  optional nitrate QuantityValue = 38
  optional nitrite QuantityValue = 39
  optional nitro QuantityValue = 40
  optional orgCarb QuantityValue = 41
  optional orgMatter QuantityValue = 42
  optional orgNitro QuantityValue = 43
  repeated organismCount OrganismCountEnum = 44
  optional oxyStatSamp OxyStatSampEnum = 45
  optional ph Double = 46
  optional partOrgCarb QuantityValue = 47
  repeated perturbation String = 48
  optional petroleumHydrocarb QuantityValue = 49
  repeated phaeopigments String = 50
  optional phosphate QuantityValue = 51
  repeated phosplipidFattAcid String = 52
  optional potassium QuantityValue = 53
  optional pressure QuantityValue = 54
  optional redoxPotential QuantityValue = 55
  optional salinity QuantityValue = 56
  optional sampStoreDur String = 57
  optional sampStoreLoc String = 58
  optional sampStoreTemp QuantityValue = 59
  optional silicate QuantityValue = 60
  optional sodium QuantityValue = 61
  optional sulfate QuantityValue = 62
  optional sulfide QuantityValue = 63
  optional totCarb QuantityValue = 64
  optional totNitroContent QuantityValue = 65
  optional totOrgCarb QuantityValue = 66
  optional turbidity QuantityValue = 67
  optional waterContent QuantityValue = 68
  sampName String = 69
  projectName String = 70
  optional sampVolWeDnaExt QuantityValue = 71
  sampTaxonId String = 72
  optional experimentalFactor String = 73
  optional negContType NegContTypeEnum = 74
  optional posContType String = 75
  optional subspecfGenLin String = 76
  optional ploidy String = 77
  optional numReplicons Integer = 78
  optional extrachromElements Integer = 79
  optional estimatedSize String = 80
  optional refBiomaterial String = 81
  optional sourceMatId String = 82
  optional pathogenicity String = 83
  optional bioticRelationship BioticRelationshipEnum = 84
  optional specificHost String = 85
  optional hostSpecRange Integer = 86
  optional hostDiseaseStat String = 87
  optional trophicLevel TrophicLevelEnum = 88
  optional propagation String = 89
  isolGrowthCondt String = 90
  optional sampCollecDevice String = 91
  optional sampCollecMethod String = 92
  optional sampMatProcess String = 93
  optional sampSize QuantityValue = 94
  optional nuclAcidExt String = 95
  optional nuclAcidAmp String = 96
  optional libSize Integer = 97
  optional libReadsSeqd Integer = 98
  optional libLayout LibLayoutEnum = 99
  optional libVector String = 100
  optional libScreen String = 101
  optional adapters String = 102
  seqMeth String = 103
  optional taxIdent TaxIdentEnum = 104
  assemblyQual AssemblyQualEnum = 105
  optional assemblyName String = 106
  assemblySoftware String = 107
  optional annot String = 108
  numberContig Integer = 109
  optional featPred String = 110
  optional refDb String = 111
  optional simSearchMeth String = 112
  optional taxClass String = 113
  optional complScore String = 114
  optional complSoftware String = 115
  optional associatedResource String = 116
  optional sop String = 117
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: org with environmental package microbial mat_biofilm
message MicrobialMatBiofilmMIGSOrg
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkylDiethers QuantityValue = 12
  optional aminopeptAct QuantityValue = 13
  optional ammonium QuantityValue = 14
  optional bacteriaCarbProd QuantityValue = 15
  repeated biomass String = 16
  optional bishomohopanol QuantityValue = 17
  optional bromide QuantityValue = 18
  optional calcium QuantityValue = 19
  optional carbNitroRatio QuantityValue = 20
  repeated chemAdministration String = 21
  optional chloride QuantityValue = 22
  optional chlorophyll QuantityValue = 23
  repeated dietherLipids String = 24
  optional dissCarbDioxide QuantityValue = 25
  optional dissHydrogen QuantityValue = 26
  optional dissInorgCarb QuantityValue = 27
  optional dissOrgCarb QuantityValue = 28
  optional dissOrgNitro QuantityValue = 29
  optional dissOxygen QuantityValue = 30
  optional glucosidaseAct QuantityValue = 31
  optional magnesium QuantityValue = 32
  optional meanFrictVel QuantityValue = 33
  optional meanPeakFrictVel QuantityValue = 34
  optional methane QuantityValue = 35
  repeated miscParam String = 36
  repeated nAlkanes String = 37
  optional nitrate QuantityValue = 38
  optional nitrite QuantityValue = 39
  optional nitro QuantityValue = 40
  optional orgCarb QuantityValue = 41
  optional orgMatter QuantityValue = 42
  optional orgNitro QuantityValue = 43
  repeated organismCount OrganismCountEnum = 44
  optional oxyStatSamp OxyStatSampEnum = 45
  optional ph Double = 46
  optional partOrgCarb QuantityValue = 47
  repeated perturbation String = 48
  optional petroleumHydrocarb QuantityValue = 49
  repeated phaeopigments String = 50
  optional phosphate QuantityValue = 51
  repeated phosplipidFattAcid String = 52
  optional potassium QuantityValue = 53
  optional pressure QuantityValue = 54
  optional redoxPotential QuantityValue = 55
  optional salinity QuantityValue = 56
  optional sampStoreDur String = 57
  optional sampStoreLoc String = 58
  optional sampStoreTemp QuantityValue = 59
  optional silicate QuantityValue = 60
  optional sodium QuantityValue = 61
  optional sulfate QuantityValue = 62
  optional sulfide QuantityValue = 63
  optional totCarb QuantityValue = 64
  optional totNitroContent QuantityValue = 65
  optional totOrgCarb QuantityValue = 66
  optional turbidity QuantityValue = 67
  optional waterContent QuantityValue = 68
  sampName String = 69
  projectName String = 70
  optional sampVolWeDnaExt QuantityValue = 71
  sampTaxonId String = 72
  optional experimentalFactor String = 73
  optional negContType NegContTypeEnum = 74
  optional posContType String = 75
  optional subspecfGenLin String = 76
  optional extrachromElements Integer = 77
  optional estimatedSize String = 78
  optional refBiomaterial String = 79
  optional sourceMatId String = 80
  isolGrowthCondt String = 81
  optional sampCollecDevice String = 82
  optional sampCollecMethod String = 83
  optional sampMatProcess String = 84
  optional sampSize QuantityValue = 85
  optional nuclAcidExt String = 86
  optional nuclAcidAmp String = 87
  optional libSize Integer = 88
  optional libReadsSeqd Integer = 89
  optional libLayout LibLayoutEnum = 90
  optional libVector String = 91
  optional libScreen String = 92
  optional adapters String = 93
  seqMeth String = 94
  optional taxIdent TaxIdentEnum = 95
  optional assemblyQual AssemblyQualEnum = 96
  optional assemblyName String = 97
  assemblySoftware String = 98
  optional annot String = 99
  optional numberContig Integer = 100
  optional featPred String = 101
  optional refDb String = 102
  optional simSearchMeth String = 103
  optional taxClass String = 104
  optional complScore String = 105
  optional complSoftware String = 106
  optional associatedResource String = 107
  optional sop String = 108
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: plant with environmental package microbial mat_biofilm
message MicrobialMatBiofilmMIGSPlant
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkylDiethers QuantityValue = 12
  optional aminopeptAct QuantityValue = 13
  optional ammonium QuantityValue = 14
  optional bacteriaCarbProd QuantityValue = 15
  repeated biomass String = 16
  optional bishomohopanol QuantityValue = 17
  optional bromide QuantityValue = 18
  optional calcium QuantityValue = 19
  optional carbNitroRatio QuantityValue = 20
  repeated chemAdministration String = 21
  optional chloride QuantityValue = 22
  optional chlorophyll QuantityValue = 23
  repeated dietherLipids String = 24
  optional dissCarbDioxide QuantityValue = 25
  optional dissHydrogen QuantityValue = 26
  optional dissInorgCarb QuantityValue = 27
  optional dissOrgCarb QuantityValue = 28
  optional dissOrgNitro QuantityValue = 29
  optional dissOxygen QuantityValue = 30
  optional glucosidaseAct QuantityValue = 31
  optional magnesium QuantityValue = 32
  optional meanFrictVel QuantityValue = 33
  optional meanPeakFrictVel QuantityValue = 34
  optional methane QuantityValue = 35
  repeated miscParam String = 36
  repeated nAlkanes String = 37
  optional nitrate QuantityValue = 38
  optional nitrite QuantityValue = 39
  optional nitro QuantityValue = 40
  optional orgCarb QuantityValue = 41
  optional orgMatter QuantityValue = 42
  optional orgNitro QuantityValue = 43
  repeated organismCount OrganismCountEnum = 44
  optional oxyStatSamp OxyStatSampEnum = 45
  optional ph Double = 46
  optional partOrgCarb QuantityValue = 47
  repeated perturbation String = 48
  optional petroleumHydrocarb QuantityValue = 49
  repeated phaeopigments String = 50
  optional phosphate QuantityValue = 51
  repeated phosplipidFattAcid String = 52
  optional potassium QuantityValue = 53
  optional pressure QuantityValue = 54
  optional redoxPotential QuantityValue = 55
  optional salinity QuantityValue = 56
  optional sampStoreDur String = 57
  optional sampStoreLoc String = 58
  optional sampStoreTemp QuantityValue = 59
  optional silicate QuantityValue = 60
  optional sodium QuantityValue = 61
  optional sulfate QuantityValue = 62
  optional sulfide QuantityValue = 63
  optional totCarb QuantityValue = 64
  optional totNitroContent QuantityValue = 65
  optional totOrgCarb QuantityValue = 66
  optional turbidity QuantityValue = 67
  optional waterContent QuantityValue = 68
  sampName String = 69
  projectName String = 70
  optional sampVolWeDnaExt QuantityValue = 71
  sampTaxonId String = 72
  optional experimentalFactor String = 73
  optional negContType NegContTypeEnum = 74
  optional posContType String = 75
  optional subspecfGenLin String = 76
  optional estimatedSize String = 77
  optional refBiomaterial String = 78
  optional sourceMatId String = 79
  optional specificHost String = 80
  optional hostSpecRange Integer = 81
  propagation String = 82
  optional encodedTraits String = 83
  isolGrowthCondt String = 84
  optional sampCollecDevice String = 85
  optional sampCollecMethod String = 86
  optional sampMatProcess String = 87
  optional sampSize QuantityValue = 88
  optional nuclAcidExt String = 89
  optional nuclAcidAmp String = 90
  optional libSize Integer = 91
  optional libReadsSeqd Integer = 92
  optional libLayout LibLayoutEnum = 93
  optional libVector String = 94
  optional libScreen String = 95
  optional adapters String = 96
  seqMeth String = 97
  optional taxIdent TaxIdentEnum = 98
  optional assemblyQual AssemblyQualEnum = 99
  optional assemblyName String = 100
  assemblySoftware String = 101
  optional annot String = 102
  optional numberContig Integer = 103
  optional featPred String = 104
  optional refDb String = 105
  optional simSearchMeth String = 106
  optional taxClass String = 107
  optional complScore String = 108
  optional complSoftware String = 109
  optional associatedResource String = 110
  optional sop String = 111
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package microbial mat_biofilm
message MicrobialMatBiofilmMIGSVirus
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkylDiethers QuantityValue = 12
  optional aminopeptAct QuantityValue = 13
  optional ammonium QuantityValue = 14
  optional bacteriaCarbProd QuantityValue = 15
  repeated biomass String = 16
  optional bishomohopanol QuantityValue = 17
  optional bromide QuantityValue = 18
  optional calcium QuantityValue = 19
  optional carbNitroRatio QuantityValue = 20
  repeated chemAdministration String = 21
  optional chloride QuantityValue = 22
  optional chlorophyll QuantityValue = 23
  repeated dietherLipids String = 24
  optional dissCarbDioxide QuantityValue = 25
  optional dissHydrogen QuantityValue = 26
  optional dissInorgCarb QuantityValue = 27
  optional dissOrgCarb QuantityValue = 28
  optional dissOrgNitro QuantityValue = 29
  optional dissOxygen QuantityValue = 30
  optional glucosidaseAct QuantityValue = 31
  optional magnesium QuantityValue = 32
  optional meanFrictVel QuantityValue = 33
  optional meanPeakFrictVel QuantityValue = 34
  optional methane QuantityValue = 35
  repeated miscParam String = 36
  repeated nAlkanes String = 37
  optional nitrate QuantityValue = 38
  optional nitrite QuantityValue = 39
  optional nitro QuantityValue = 40
  optional orgCarb QuantityValue = 41
  optional orgMatter QuantityValue = 42
  optional orgNitro QuantityValue = 43
  repeated organismCount OrganismCountEnum = 44
  optional oxyStatSamp OxyStatSampEnum = 45
  optional ph Double = 46
  optional partOrgCarb QuantityValue = 47
  repeated perturbation String = 48
  optional petroleumHydrocarb QuantityValue = 49
  repeated phaeopigments String = 50
  optional phosphate QuantityValue = 51
  repeated phosplipidFattAcid String = 52
  optional potassium QuantityValue = 53
  optional pressure QuantityValue = 54
  optional redoxPotential QuantityValue = 55
  optional salinity QuantityValue = 56
  optional sampStoreDur String = 57
  optional sampStoreLoc String = 58
  optional sampStoreTemp QuantityValue = 59
  optional silicate QuantityValue = 60
  optional sodium QuantityValue = 61
  optional sulfate QuantityValue = 62
  optional sulfide QuantityValue = 63
  optional totCarb QuantityValue = 64
  optional totNitroContent QuantityValue = 65
  optional totOrgCarb QuantityValue = 66
  optional turbidity QuantityValue = 67
  optional waterContent QuantityValue = 68
  sampName String = 69
  projectName String = 70
  optional sampVolWeDnaExt QuantityValue = 71
  sampTaxonId String = 72
  optional experimentalFactor String = 73
  optional negContType NegContTypeEnum = 74
  optional posContType String = 75
  optional subspecfGenLin String = 76
  optional numReplicons Integer = 77
  optional estimatedSize String = 78
  optional refBiomaterial String = 79
  optional sourceMatId String = 80
  optional pathogenicity String = 81
  optional bioticRelationship BioticRelationshipEnum = 82
  optional specificHost String = 83
  optional hostSpecRange Integer = 84
  optional hostDiseaseStat String = 85
  propagation String = 86
  optional encodedTraits String = 87
  isolGrowthCondt String = 88
  optional sampCollecDevice String = 89
  optional sampCollecMethod String = 90
  optional sampMatProcess String = 91
  optional sampSize QuantityValue = 92
  optional virusEnrichAppr VirusEnrichApprEnum = 93
  optional nuclAcidExt String = 94
  optional nuclAcidAmp String = 95
  optional libSize Integer = 96
  optional libReadsSeqd Integer = 97
  optional libLayout LibLayoutEnum = 98
  optional libVector String = 99
  optional libScreen String = 100
  optional adapters String = 101
  seqMeth String = 102
  optional taxIdent TaxIdentEnum = 103
  optional assemblyQual AssemblyQualEnum = 104
  optional assemblyName String = 105
  assemblySoftware String = 106
  optional annot String = 107
  optional numberContig Integer = 108
  optional featPred String = 109
  optional refDb String = 110
  optional simSearchMeth String = 111
  optional taxClass String = 112
  optional complScore String = 113
  optional complSoftware String = 114
  optional associatedResource String = 115
  optional sop String = 116
 }
// Combinatorial checklist Minimum Information About a Metagenome-Assembled Genome with environmental package microbial mat_biofilm
message MicrobialMatBiofilmMIMAG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkylDiethers QuantityValue = 12
  optional aminopeptAct QuantityValue = 13
  optional ammonium QuantityValue = 14
  optional bacteriaCarbProd QuantityValue = 15
  repeated biomass String = 16
  optional bishomohopanol QuantityValue = 17
  optional bromide QuantityValue = 18
  optional calcium QuantityValue = 19
  optional carbNitroRatio QuantityValue = 20
  repeated chemAdministration String = 21
  optional chloride QuantityValue = 22
  optional chlorophyll QuantityValue = 23
  repeated dietherLipids String = 24
  optional dissCarbDioxide QuantityValue = 25
  optional dissHydrogen QuantityValue = 26
  optional dissInorgCarb QuantityValue = 27
  optional dissOrgCarb QuantityValue = 28
  optional dissOrgNitro QuantityValue = 29
  optional dissOxygen QuantityValue = 30
  optional glucosidaseAct QuantityValue = 31
  optional magnesium QuantityValue = 32
  optional meanFrictVel QuantityValue = 33
  optional meanPeakFrictVel QuantityValue = 34
  optional methane QuantityValue = 35
  repeated miscParam String = 36
  repeated nAlkanes String = 37
  optional nitrate QuantityValue = 38
  optional nitrite QuantityValue = 39
  optional nitro QuantityValue = 40
  optional orgCarb QuantityValue = 41
  optional orgMatter QuantityValue = 42
  optional orgNitro QuantityValue = 43
  repeated organismCount OrganismCountEnum = 44
  optional oxyStatSamp OxyStatSampEnum = 45
  optional ph Double = 46
  optional partOrgCarb QuantityValue = 47
  repeated perturbation String = 48
  optional petroleumHydrocarb QuantityValue = 49
  repeated phaeopigments String = 50
  optional phosphate QuantityValue = 51
  repeated phosplipidFattAcid String = 52
  optional potassium QuantityValue = 53
  optional pressure QuantityValue = 54
  optional redoxPotential QuantityValue = 55
  optional salinity QuantityValue = 56
  optional sampStoreDur String = 57
  optional sampStoreLoc String = 58
  optional sampStoreTemp QuantityValue = 59
  optional silicate QuantityValue = 60
  optional sodium QuantityValue = 61
  optional sulfate QuantityValue = 62
  optional sulfide QuantityValue = 63
  optional totCarb QuantityValue = 64
  optional totNitroContent QuantityValue = 65
  optional totOrgCarb QuantityValue = 66
  optional turbidity QuantityValue = 67
  optional waterContent QuantityValue = 68
  sampName String = 69
  projectName String = 70
  optional sampVolWeDnaExt QuantityValue = 71
  sampTaxonId String = 72
  optional experimentalFactor String = 73
  optional negContType NegContTypeEnum = 74
  optional posContType String = 75
  optional refBiomaterial String = 76
  optional sourceMatId String = 77
  optional relToOxygen RelToOxygenEnum = 78
  optional sampCollecDevice String = 79
  optional sampCollecMethod String = 80
  optional sampMatProcess String = 81
  optional sizeFrac String = 82
  optional sampSize QuantityValue = 83
  optional nuclAcidExt String = 84
  optional nuclAcidAmp String = 85
  optional libSize Integer = 86
  optional libReadsSeqd Integer = 87
  optional libLayout LibLayoutEnum = 88
  optional libVector String = 89
  optional libScreen String = 90
  optional mid String = 91
  optional adapters String = 92
  seqMeth String = 93
  taxIdent TaxIdentEnum = 94
  assemblyQual AssemblyQualEnum = 95
  optional assemblyName String = 96
  assemblySoftware String = 97
  optional annot String = 98
  optional numberContig Integer = 99
  optional featPred String = 100
  optional refDb String = 101
  optional simSearchMeth String = 102
  optional taxClass String = 103
  optional x16sRecover String = 104
  optional x16sRecoverSoftware String = 105
  optional trnas Integer = 106
  optional trnaExtSoftware String = 107
  complScore String = 108
  complSoftware String = 109
  optional complAppr ComplApprEnum = 110
  contamScore String = 111
  optional contamScreenInput String = 112
  optional contamScreenParam String = 113
  optional decontamSoftware DecontamSoftwareEnum = 114
  binParam BinParamEnum = 115
  binSoftware String = 116
  optional reassemblyBin String = 117
  optional magCovSoftware MagCovSoftwareEnum = 118
  optional associatedResource String = 119
  optional sop String = 120
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: specimen with environmental package microbial mat_biofilm
message MicrobialMatBiofilmMIMARKSSpecimen
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkylDiethers QuantityValue = 12
  optional aminopeptAct QuantityValue = 13
  optional ammonium QuantityValue = 14
  optional bacteriaCarbProd QuantityValue = 15
  repeated biomass String = 16
  optional bishomohopanol QuantityValue = 17
  optional bromide QuantityValue = 18
  optional calcium QuantityValue = 19
  optional carbNitroRatio QuantityValue = 20
  repeated chemAdministration String = 21
  optional chloride QuantityValue = 22
  optional chlorophyll QuantityValue = 23
  repeated dietherLipids String = 24
  optional dissCarbDioxide QuantityValue = 25
  optional dissHydrogen QuantityValue = 26
  optional dissInorgCarb QuantityValue = 27
  optional dissOrgCarb QuantityValue = 28
  optional dissOrgNitro QuantityValue = 29
  optional dissOxygen QuantityValue = 30
  optional glucosidaseAct QuantityValue = 31
  optional magnesium QuantityValue = 32
  optional meanFrictVel QuantityValue = 33
  optional meanPeakFrictVel QuantityValue = 34
  optional methane QuantityValue = 35
  repeated miscParam String = 36
  repeated nAlkanes String = 37
  optional nitrate QuantityValue = 38
  optional nitrite QuantityValue = 39
  optional nitro QuantityValue = 40
  optional orgCarb QuantityValue = 41
  optional orgMatter QuantityValue = 42
  optional orgNitro QuantityValue = 43
  repeated organismCount OrganismCountEnum = 44
  optional oxyStatSamp OxyStatSampEnum = 45
  optional ph Double = 46
  optional partOrgCarb QuantityValue = 47
  repeated perturbation String = 48
  optional petroleumHydrocarb QuantityValue = 49
  repeated phaeopigments String = 50
  optional phosphate QuantityValue = 51
  repeated phosplipidFattAcid String = 52
  optional potassium QuantityValue = 53
  optional pressure QuantityValue = 54
  optional redoxPotential QuantityValue = 55
  optional salinity QuantityValue = 56
  optional sampStoreDur String = 57
  optional sampStoreLoc String = 58
  optional sampStoreTemp QuantityValue = 59
  optional silicate QuantityValue = 60
  optional sodium QuantityValue = 61
  optional sulfate QuantityValue = 62
  optional sulfide QuantityValue = 63
  optional totCarb QuantityValue = 64
  optional totNitroContent QuantityValue = 65
  optional totOrgCarb QuantityValue = 66
  optional turbidity QuantityValue = 67
  optional waterContent QuantityValue = 68
  sampName String = 69
  projectName String = 70
  optional sampVolWeDnaExt QuantityValue = 71
  sampTaxonId String = 72
  optional experimentalFactor String = 73
  optional negContType NegContTypeEnum = 74
  optional posContType String = 75
  optional sourceMatId String = 76
  optional relToOxygen RelToOxygenEnum = 77
  optional sampCollecDevice String = 78
  optional sampCollecMethod String = 79
  optional sampMatProcess String = 80
  optional sizeFrac String = 81
  optional sampSize QuantityValue = 82
  optional nuclAcidExt String = 83
  optional nuclAcidAmp String = 84
  optional libSize Integer = 85
  optional libReadsSeqd Integer = 86
  optional libLayout LibLayoutEnum = 87
  optional libVector String = 88
  optional libScreen String = 89
  targetGene String = 90
  optional targetSubfragment String = 91
  optional pcrPrimers String = 92
  optional mid String = 93
  optional adapters String = 94
  optional pcrCond String = 95
  seqMeth String = 96
  optional seqQualityCheck String = 97
  optional chimeraCheck String = 98
  optional assemblySoftware String = 99
  optional associatedResource String = 100
  optional sop String = 101
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: survey with environmental package microbial mat_biofilm
message MicrobialMatBiofilmMIMARKSSurvey
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkylDiethers QuantityValue = 12
  optional aminopeptAct QuantityValue = 13
  optional ammonium QuantityValue = 14
  optional bacteriaCarbProd QuantityValue = 15
  repeated biomass String = 16
  optional bishomohopanol QuantityValue = 17
  optional bromide QuantityValue = 18
  optional calcium QuantityValue = 19
  optional carbNitroRatio QuantityValue = 20
  repeated chemAdministration String = 21
  optional chloride QuantityValue = 22
  optional chlorophyll QuantityValue = 23
  repeated dietherLipids String = 24
  optional dissCarbDioxide QuantityValue = 25
  optional dissHydrogen QuantityValue = 26
  optional dissInorgCarb QuantityValue = 27
  optional dissOrgCarb QuantityValue = 28
  optional dissOrgNitro QuantityValue = 29
  optional dissOxygen QuantityValue = 30
  optional glucosidaseAct QuantityValue = 31
  optional magnesium QuantityValue = 32
  optional meanFrictVel QuantityValue = 33
  optional meanPeakFrictVel QuantityValue = 34
  optional methane QuantityValue = 35
  repeated miscParam String = 36
  repeated nAlkanes String = 37
  optional nitrate QuantityValue = 38
  optional nitrite QuantityValue = 39
  optional nitro QuantityValue = 40
  optional orgCarb QuantityValue = 41
  optional orgMatter QuantityValue = 42
  optional orgNitro QuantityValue = 43
  repeated organismCount OrganismCountEnum = 44
  optional oxyStatSamp OxyStatSampEnum = 45
  optional ph Double = 46
  optional partOrgCarb QuantityValue = 47
  repeated perturbation String = 48
  optional petroleumHydrocarb QuantityValue = 49
  repeated phaeopigments String = 50
  optional phosphate QuantityValue = 51
  repeated phosplipidFattAcid String = 52
  optional potassium QuantityValue = 53
  optional pressure QuantityValue = 54
  optional redoxPotential QuantityValue = 55
  optional salinity QuantityValue = 56
  optional sampStoreDur String = 57
  optional sampStoreLoc String = 58
  optional sampStoreTemp QuantityValue = 59
  optional silicate QuantityValue = 60
  optional sodium QuantityValue = 61
  optional sulfate QuantityValue = 62
  optional sulfide QuantityValue = 63
  optional totCarb QuantityValue = 64
  optional totNitroContent QuantityValue = 65
  optional totOrgCarb QuantityValue = 66
  optional turbidity QuantityValue = 67
  optional waterContent QuantityValue = 68
  sampName String = 69
  projectName String = 70
  optional sampVolWeDnaExt QuantityValue = 71
  sampTaxonId String = 72
  optional experimentalFactor String = 73
  optional negContType NegContTypeEnum = 74
  optional posContType String = 75
  optional subspecfGenLin String = 76
  optional extrachromElements Integer = 77
  optional sourceMatId String = 78
  optional bioticRelationship BioticRelationshipEnum = 79
  optional trophicLevel TrophicLevelEnum = 80
  optional relToOxygen RelToOxygenEnum = 81
  isolGrowthCondt String = 82
  optional sampCollecDevice String = 83
  optional sampCollecMethod String = 84
  optional sampMatProcess String = 85
  optional sampSize QuantityValue = 86
  optional nuclAcidExt String = 87
  optional nuclAcidAmp String = 88
  targetGene String = 89
  optional targetSubfragment String = 90
  optional pcrPrimers String = 91
  optional pcrCond String = 92
  seqMeth String = 93
  optional seqQualityCheck String = 94
  optional chimeraCheck String = 95
  optional associatedResource String = 96
  optional sop String = 97
 }
// Combinatorial checklist Metagenome or Environmental with environmental package microbial mat_biofilm
message MicrobialMatBiofilmMIMS
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkylDiethers QuantityValue = 12
  optional aminopeptAct QuantityValue = 13
  optional ammonium QuantityValue = 14
  optional bacteriaCarbProd QuantityValue = 15
  repeated biomass String = 16
  optional bishomohopanol QuantityValue = 17
  optional bromide QuantityValue = 18
  optional calcium QuantityValue = 19
  optional carbNitroRatio QuantityValue = 20
  repeated chemAdministration String = 21
  optional chloride QuantityValue = 22
  optional chlorophyll QuantityValue = 23
  repeated dietherLipids String = 24
  optional dissCarbDioxide QuantityValue = 25
  optional dissHydrogen QuantityValue = 26
  optional dissInorgCarb QuantityValue = 27
  optional dissOrgCarb QuantityValue = 28
  optional dissOrgNitro QuantityValue = 29
  optional dissOxygen QuantityValue = 30
  optional glucosidaseAct QuantityValue = 31
  optional magnesium QuantityValue = 32
  optional meanFrictVel QuantityValue = 33
  optional meanPeakFrictVel QuantityValue = 34
  optional methane QuantityValue = 35
  repeated miscParam String = 36
  repeated nAlkanes String = 37
  optional nitrate QuantityValue = 38
  optional nitrite QuantityValue = 39
  optional nitro QuantityValue = 40
  optional orgCarb QuantityValue = 41
  optional orgMatter QuantityValue = 42
  optional orgNitro QuantityValue = 43
  repeated organismCount OrganismCountEnum = 44
  optional oxyStatSamp OxyStatSampEnum = 45
  optional ph Double = 46
  optional partOrgCarb QuantityValue = 47
  repeated perturbation String = 48
  optional petroleumHydrocarb QuantityValue = 49
  repeated phaeopigments String = 50
  optional phosphate QuantityValue = 51
  repeated phosplipidFattAcid String = 52
  optional potassium QuantityValue = 53
  optional pressure QuantityValue = 54
  optional redoxPotential QuantityValue = 55
  optional salinity QuantityValue = 56
  optional sampStoreDur String = 57
  optional sampStoreLoc String = 58
  optional sampStoreTemp QuantityValue = 59
  optional silicate QuantityValue = 60
  optional sodium QuantityValue = 61
  optional sulfate QuantityValue = 62
  optional sulfide QuantityValue = 63
  optional totCarb QuantityValue = 64
  optional totNitroContent QuantityValue = 65
  optional totOrgCarb QuantityValue = 66
  optional turbidity QuantityValue = 67
  optional waterContent QuantityValue = 68
  sampName String = 69
  projectName String = 70
  optional sampVolWeDnaExt QuantityValue = 71
  sampTaxonId String = 72
  optional experimentalFactor String = 73
  optional negContType NegContTypeEnum = 74
  optional posContType String = 75
  optional refBiomaterial String = 76
  optional sourceMatId String = 77
  optional relToOxygen RelToOxygenEnum = 78
  optional sampCollecDevice String = 79
  optional sampCollecMethod String = 80
  optional sampMatProcess String = 81
  optional sizeFrac String = 82
  optional sampSize QuantityValue = 83
  optional nuclAcidExt String = 84
  optional nuclAcidAmp String = 85
  optional libSize Integer = 86
  optional libReadsSeqd Integer = 87
  optional libLayout LibLayoutEnum = 88
  optional libVector String = 89
  optional libScreen String = 90
  optional mid String = 91
  optional adapters String = 92
  seqMeth String = 93
  optional assemblyQual AssemblyQualEnum = 94
  optional assemblyName String = 95
  optional assemblySoftware String = 96
  optional annot String = 97
  optional numberContig Integer = 98
  optional featPred String = 99
  optional refDb String = 100
  optional simSearchMeth String = 101
  optional taxClass String = 102
  optional associatedResource String = 103
  optional sop String = 104
 }
// Combinatorial checklist Minimum Information About a Single Amplified Genome with environmental package microbial mat_biofilm
message MicrobialMatBiofilmMISAG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkylDiethers QuantityValue = 12
  optional aminopeptAct QuantityValue = 13
  optional ammonium QuantityValue = 14
  optional bacteriaCarbProd QuantityValue = 15
  repeated biomass String = 16
  optional bishomohopanol QuantityValue = 17
  optional bromide QuantityValue = 18
  optional calcium QuantityValue = 19
  optional carbNitroRatio QuantityValue = 20
  repeated chemAdministration String = 21
  optional chloride QuantityValue = 22
  optional chlorophyll QuantityValue = 23
  repeated dietherLipids String = 24
  optional dissCarbDioxide QuantityValue = 25
  optional dissHydrogen QuantityValue = 26
  optional dissInorgCarb QuantityValue = 27
  optional dissOrgCarb QuantityValue = 28
  optional dissOrgNitro QuantityValue = 29
  optional dissOxygen QuantityValue = 30
  optional glucosidaseAct QuantityValue = 31
  optional magnesium QuantityValue = 32
  optional meanFrictVel QuantityValue = 33
  optional meanPeakFrictVel QuantityValue = 34
  optional methane QuantityValue = 35
  repeated miscParam String = 36
  repeated nAlkanes String = 37
  optional nitrate QuantityValue = 38
  optional nitrite QuantityValue = 39
  optional nitro QuantityValue = 40
  optional orgCarb QuantityValue = 41
  optional orgMatter QuantityValue = 42
  optional orgNitro QuantityValue = 43
  repeated organismCount OrganismCountEnum = 44
  optional oxyStatSamp OxyStatSampEnum = 45
  optional ph Double = 46
  optional partOrgCarb QuantityValue = 47
  repeated perturbation String = 48
  optional petroleumHydrocarb QuantityValue = 49
  repeated phaeopigments String = 50
  optional phosphate QuantityValue = 51
  repeated phosplipidFattAcid String = 52
  optional potassium QuantityValue = 53
  optional pressure QuantityValue = 54
  optional redoxPotential QuantityValue = 55
  optional salinity QuantityValue = 56
  optional sampStoreDur String = 57
  optional sampStoreLoc String = 58
  optional sampStoreTemp QuantityValue = 59
  optional silicate QuantityValue = 60
  optional sodium QuantityValue = 61
  optional sulfate QuantityValue = 62
  optional sulfide QuantityValue = 63
  optional totCarb QuantityValue = 64
  optional totNitroContent QuantityValue = 65
  optional totOrgCarb QuantityValue = 66
  optional turbidity QuantityValue = 67
  optional waterContent QuantityValue = 68
  sampName String = 69
  projectName String = 70
  optional sampVolWeDnaExt QuantityValue = 71
  sampTaxonId String = 72
  optional experimentalFactor String = 73
  optional negContType NegContTypeEnum = 74
  optional posContType String = 75
  optional refBiomaterial String = 76
  optional sourceMatId String = 77
  optional relToOxygen RelToOxygenEnum = 78
  optional sampCollecDevice String = 79
  optional sampCollecMethod String = 80
  optional sampMatProcess String = 81
  optional sizeFrac String = 82
  optional sampSize QuantityValue = 83
  optional nuclAcidExt String = 84
  optional nuclAcidAmp String = 85
  optional libSize Integer = 86
  optional libReadsSeqd Integer = 87
  optional libLayout LibLayoutEnum = 88
  optional libVector String = 89
  optional libScreen String = 90
  optional mid String = 91
  optional adapters String = 92
  seqMeth String = 93
  taxIdent TaxIdentEnum = 94
  assemblyQual AssemblyQualEnum = 95
  optional assemblyName String = 96
  assemblySoftware String = 97
  optional annot String = 98
  optional numberContig Integer = 99
  optional featPred String = 100
  optional refDb String = 101
  optional simSearchMeth String = 102
  optional taxClass String = 103
  optional x16sRecover String = 104
  optional x16sRecoverSoftware String = 105
  optional trnas Integer = 106
  optional trnaExtSoftware String = 107
  complScore String = 108
  complSoftware String = 109
  optional complAppr ComplApprEnum = 110
  contamScore String = 111
  optional contamScreenInput String = 112
  optional contamScreenParam String = 113
  optional decontamSoftware DecontamSoftwareEnum = 114
  sortTech SortTechEnum = 115
  singleCellLysisAppr SingleCellLysisApprEnum = 116
  optional singleCellLysisProt String = 117
  wgaAmpAppr String = 118
  optional wgaAmpKit String = 119
  optional associatedResource String = 120
  optional sop String = 121
 }
// Combinatorial checklist Minimum Information About an Uncultivated Virus Genome with environmental package microbial mat_biofilm
message MicrobialMatBiofilmMIUVIG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkylDiethers QuantityValue = 12
  optional aminopeptAct QuantityValue = 13
  optional ammonium QuantityValue = 14
  optional bacteriaCarbProd QuantityValue = 15
  repeated biomass String = 16
  optional bishomohopanol QuantityValue = 17
  optional bromide QuantityValue = 18
  optional calcium QuantityValue = 19
  optional carbNitroRatio QuantityValue = 20
  repeated chemAdministration String = 21
  optional chloride QuantityValue = 22
  optional chlorophyll QuantityValue = 23
  repeated dietherLipids String = 24
  optional dissCarbDioxide QuantityValue = 25
  optional dissHydrogen QuantityValue = 26
  optional dissInorgCarb QuantityValue = 27
  optional dissOrgCarb QuantityValue = 28
  optional dissOrgNitro QuantityValue = 29
  optional dissOxygen QuantityValue = 30
  optional glucosidaseAct QuantityValue = 31
  optional magnesium QuantityValue = 32
  optional meanFrictVel QuantityValue = 33
  optional meanPeakFrictVel QuantityValue = 34
  optional methane QuantityValue = 35
  repeated miscParam String = 36
  repeated nAlkanes String = 37
  optional nitrate QuantityValue = 38
  optional nitrite QuantityValue = 39
  optional nitro QuantityValue = 40
  optional orgCarb QuantityValue = 41
  optional orgMatter QuantityValue = 42
  optional orgNitro QuantityValue = 43
  repeated organismCount OrganismCountEnum = 44
  optional oxyStatSamp OxyStatSampEnum = 45
  optional ph Double = 46
  optional partOrgCarb QuantityValue = 47
  repeated perturbation String = 48
  optional petroleumHydrocarb QuantityValue = 49
  repeated phaeopigments String = 50
  optional phosphate QuantityValue = 51
  repeated phosplipidFattAcid String = 52
  optional potassium QuantityValue = 53
  optional pressure QuantityValue = 54
  optional redoxPotential QuantityValue = 55
  optional salinity QuantityValue = 56
  optional sampStoreDur String = 57
  optional sampStoreLoc String = 58
  optional sampStoreTemp QuantityValue = 59
  optional silicate QuantityValue = 60
  optional sodium QuantityValue = 61
  optional sulfate QuantityValue = 62
  optional sulfide QuantityValue = 63
  optional totCarb QuantityValue = 64
  optional totNitroContent QuantityValue = 65
  optional totOrgCarb QuantityValue = 66
  optional turbidity QuantityValue = 67
  optional waterContent QuantityValue = 68
  sampName String = 69
  projectName String = 70
  optional sampVolWeDnaExt QuantityValue = 71
  sampTaxonId String = 72
  optional experimentalFactor String = 73
  optional negContType NegContTypeEnum = 74
  optional posContType String = 75
  optional estimatedSize String = 76
  optional refBiomaterial String = 77
  optional sourceMatId String = 78
  optional pathogenicity String = 79
  optional bioticRelationship BioticRelationshipEnum = 80
  optional specificHost String = 81
  optional hostSpecRange Integer = 82
  optional hostDiseaseStat String = 83
  optional sampCollecDevice String = 84
  optional sampCollecMethod String = 85
  optional sampMatProcess String = 86
  optional sizeFrac String = 87
  optional sampSize QuantityValue = 88
  sourceUvig SourceUvigEnum = 89
  virusEnrichAppr VirusEnrichApprEnum = 90
  optional nuclAcidExt String = 91
  optional nuclAcidAmp String = 92
  optional libSize Integer = 93
  optional libReadsSeqd Integer = 94
  optional libLayout LibLayoutEnum = 95
  optional libVector String = 96
  optional libScreen String = 97
  optional mid String = 98
  optional adapters String = 99
  seqMeth String = 100
  optional taxIdent TaxIdentEnum = 101
  assemblyQual AssemblyQualEnum = 102
  optional assemblyName String = 103
  assemblySoftware String = 104
  optional annot String = 105
  numberContig Integer = 106
  optional featPred String = 107
  optional refDb String = 108
  optional simSearchMeth String = 109
  optional taxClass String = 110
  optional trnas Integer = 111
  optional trnaExtSoftware String = 112
  optional complScore String = 113
  optional complSoftware String = 114
  optional complAppr ComplApprEnum = 115
  optional sortTech SortTechEnum = 116
  optional singleCellLysisAppr SingleCellLysisApprEnum = 117
  optional singleCellLysisProt String = 118
  optional wgaAmpAppr String = 119
  optional wgaAmpKit String = 120
  optional binParam BinParamEnum = 121
  optional binSoftware String = 122
  optional reassemblyBin String = 123
  optional magCovSoftware MagCovSoftwareEnum = 124
  virIdentSoftware String = 125
  predGenomeType PredGenomeTypeEnum = 126
  predGenomeStruc PredGenomeStrucEnum = 127
  detecType String = 128
  optional otuClassAppr String = 129
  optional otuSeqCompAppr String = 130
  optional otuDb String = 131
  optional hostPredAppr HostPredApprEnum = 132
  optional hostPredEstAcc String = 133
  optional associatedResource String = 134
  optional sop String = 135
 }
// miscellaneous natural or artificial environment
message MiscellaneousNaturalOrArtificialEnvironment
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional ammonium QuantityValue = 12
  repeated biomass String = 13
  optional bromide QuantityValue = 14
  optional calcium QuantityValue = 15
  repeated chemAdministration String = 16
  optional chloride QuantityValue = 17
  optional chlorophyll QuantityValue = 18
  optional density QuantityValue = 19
  repeated dietherLipids String = 20
  optional dissCarbDioxide QuantityValue = 21
  optional dissHydrogen QuantityValue = 22
  optional dissInorgCarb QuantityValue = 23
  optional dissOrgNitro QuantityValue = 24
  optional dissOxygen QuantityValue = 25
  repeated miscParam String = 26
  optional nitrate QuantityValue = 27
  optional nitrite QuantityValue = 28
  optional nitro QuantityValue = 29
  optional orgCarb QuantityValue = 30
  optional orgMatter QuantityValue = 31
  optional orgNitro QuantityValue = 32
  repeated organismCount OrganismCountEnum = 33
  optional oxyStatSamp OxyStatSampEnum = 34
  optional ph Double = 35
  repeated perturbation String = 36
  optional phosphate QuantityValue = 37
  repeated phosplipidFattAcid String = 38
  optional potassium QuantityValue = 39
  optional pressure QuantityValue = 40
  optional salinity QuantityValue = 41
  optional sampStoreDur String = 42
  optional sampStoreLoc String = 43
  optional sampStoreTemp QuantityValue = 44
  optional silicate QuantityValue = 45
  optional sodium QuantityValue = 46
  optional sulfate QuantityValue = 47
  optional sulfide QuantityValue = 48
  optional waterCurrent QuantityValue = 49
  sampName String = 50
  projectName String = 51
  optional sampVolWeDnaExt QuantityValue = 52
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package miscellaneous natural or artificial environment
message MiscellaneousNaturalOrArtificialEnvironmentMIGSBacteria
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional ammonium QuantityValue = 12
  repeated biomass String = 13
  optional bromide QuantityValue = 14
  optional calcium QuantityValue = 15
  repeated chemAdministration String = 16
  optional chloride QuantityValue = 17
  optional chlorophyll QuantityValue = 18
  optional density QuantityValue = 19
  repeated dietherLipids String = 20
  optional dissCarbDioxide QuantityValue = 21
  optional dissHydrogen QuantityValue = 22
  optional dissInorgCarb QuantityValue = 23
  optional dissOrgNitro QuantityValue = 24
  optional dissOxygen QuantityValue = 25
  repeated miscParam String = 26
  optional nitrate QuantityValue = 27
  optional nitrite QuantityValue = 28
  optional nitro QuantityValue = 29
  optional orgCarb QuantityValue = 30
  optional orgMatter QuantityValue = 31
  optional orgNitro QuantityValue = 32
  repeated organismCount OrganismCountEnum = 33
  optional oxyStatSamp OxyStatSampEnum = 34
  optional ph Double = 35
  repeated perturbation String = 36
  optional phosphate QuantityValue = 37
  repeated phosplipidFattAcid String = 38
  optional potassium QuantityValue = 39
  optional pressure QuantityValue = 40
  optional salinity QuantityValue = 41
  optional sampStoreDur String = 42
  optional sampStoreLoc String = 43
  optional sampStoreTemp QuantityValue = 44
  optional silicate QuantityValue = 45
  optional sodium QuantityValue = 46
  optional sulfate QuantityValue = 47
  optional sulfide QuantityValue = 48
  optional waterCurrent QuantityValue = 49
  sampName String = 50
  projectName String = 51
  optional sampVolWeDnaExt QuantityValue = 52
  sampTaxonId String = 53
  optional experimentalFactor String = 54
  optional negContType NegContTypeEnum = 55
  optional posContType String = 56
  optional subspecfGenLin String = 57
  numReplicons Integer = 58
  optional extrachromElements Integer = 59
  optional estimatedSize String = 60
  refBiomaterial String = 61
  optional sourceMatId String = 62
  optional pathogenicity String = 63
  optional bioticRelationship BioticRelationshipEnum = 64
  optional specificHost String = 65
  optional hostSpecRange Integer = 66
  optional hostDiseaseStat String = 67
  optional trophicLevel TrophicLevelEnum = 68
  optional encodedTraits String = 69
  optional relToOxygen RelToOxygenEnum = 70
  isolGrowthCondt String = 71
  optional sampCollecDevice String = 72
  optional sampCollecMethod String = 73
  optional sampMatProcess String = 74
  optional sampSize QuantityValue = 75
  optional nuclAcidExt String = 76
  optional nuclAcidAmp String = 77
  optional libSize Integer = 78
  optional libReadsSeqd Integer = 79
  optional libLayout LibLayoutEnum = 80
  optional libVector String = 81
  optional libScreen String = 82
  optional adapters String = 83
  seqMeth String = 84
  optional taxIdent TaxIdentEnum = 85
  assemblyQual AssemblyQualEnum = 86
  optional assemblyName String = 87
  assemblySoftware String = 88
  optional annot String = 89
  numberContig Integer = 90
  optional featPred String = 91
  optional refDb String = 92
  optional simSearchMeth String = 93
  optional taxClass String = 94
  optional complScore String = 95
  optional complSoftware String = 96
  optional associatedResource String = 97
  optional sop String = 98
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: eukaryote with environmental package miscellaneous natural or artificial environment
message MiscellaneousNaturalOrArtificialEnvironmentMIGSEukaryote
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional ammonium QuantityValue = 12
  repeated biomass String = 13
  optional bromide QuantityValue = 14
  optional calcium QuantityValue = 15
  repeated chemAdministration String = 16
  optional chloride QuantityValue = 17
  optional chlorophyll QuantityValue = 18
  optional density QuantityValue = 19
  repeated dietherLipids String = 20
  optional dissCarbDioxide QuantityValue = 21
  optional dissHydrogen QuantityValue = 22
  optional dissInorgCarb QuantityValue = 23
  optional dissOrgNitro QuantityValue = 24
  optional dissOxygen QuantityValue = 25
  repeated miscParam String = 26
  optional nitrate QuantityValue = 27
  optional nitrite QuantityValue = 28
  optional nitro QuantityValue = 29
  optional orgCarb QuantityValue = 30
  optional orgMatter QuantityValue = 31
  optional orgNitro QuantityValue = 32
  repeated organismCount OrganismCountEnum = 33
  optional oxyStatSamp OxyStatSampEnum = 34
  optional ph Double = 35
  repeated perturbation String = 36
  optional phosphate QuantityValue = 37
  repeated phosplipidFattAcid String = 38
  optional potassium QuantityValue = 39
  optional pressure QuantityValue = 40
  optional salinity QuantityValue = 41
  optional sampStoreDur String = 42
  optional sampStoreLoc String = 43
  optional sampStoreTemp QuantityValue = 44
  optional silicate QuantityValue = 45
  optional sodium QuantityValue = 46
  optional sulfate QuantityValue = 47
  optional sulfide QuantityValue = 48
  optional waterCurrent QuantityValue = 49
  sampName String = 50
  projectName String = 51
  optional sampVolWeDnaExt QuantityValue = 52
  sampTaxonId String = 53
  optional experimentalFactor String = 54
  optional negContType NegContTypeEnum = 55
  optional posContType String = 56
  optional subspecfGenLin String = 57
  optional ploidy String = 58
  optional numReplicons Integer = 59
  optional extrachromElements Integer = 60
  optional estimatedSize String = 61
  optional refBiomaterial String = 62
  optional sourceMatId String = 63
  optional pathogenicity String = 64
  optional bioticRelationship BioticRelationshipEnum = 65
  optional specificHost String = 66
  optional hostSpecRange Integer = 67
  optional hostDiseaseStat String = 68
  optional trophicLevel TrophicLevelEnum = 69
  optional propagation String = 70
  isolGrowthCondt String = 71
  optional sampCollecDevice String = 72
  optional sampCollecMethod String = 73
  optional sampMatProcess String = 74
  optional sampSize QuantityValue = 75
  optional nuclAcidExt String = 76
  optional nuclAcidAmp String = 77
  optional libSize Integer = 78
  optional libReadsSeqd Integer = 79
  optional libLayout LibLayoutEnum = 80
  optional libVector String = 81
  optional libScreen String = 82
  optional adapters String = 83
  seqMeth String = 84
  optional taxIdent TaxIdentEnum = 85
  assemblyQual AssemblyQualEnum = 86
  optional assemblyName String = 87
  assemblySoftware String = 88
  optional annot String = 89
  numberContig Integer = 90
  optional featPred String = 91
  optional refDb String = 92
  optional simSearchMeth String = 93
  optional taxClass String = 94
  optional complScore String = 95
  optional complSoftware String = 96
  optional associatedResource String = 97
  optional sop String = 98
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: org with environmental package miscellaneous natural or artificial environment
message MiscellaneousNaturalOrArtificialEnvironmentMIGSOrg
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional ammonium QuantityValue = 12
  repeated biomass String = 13
  optional bromide QuantityValue = 14
  optional calcium QuantityValue = 15
  repeated chemAdministration String = 16
  optional chloride QuantityValue = 17
  optional chlorophyll QuantityValue = 18
  optional density QuantityValue = 19
  repeated dietherLipids String = 20
  optional dissCarbDioxide QuantityValue = 21
  optional dissHydrogen QuantityValue = 22
  optional dissInorgCarb QuantityValue = 23
  optional dissOrgNitro QuantityValue = 24
  optional dissOxygen QuantityValue = 25
  repeated miscParam String = 26
  optional nitrate QuantityValue = 27
  optional nitrite QuantityValue = 28
  optional nitro QuantityValue = 29
  optional orgCarb QuantityValue = 30
  optional orgMatter QuantityValue = 31
  optional orgNitro QuantityValue = 32
  repeated organismCount OrganismCountEnum = 33
  optional oxyStatSamp OxyStatSampEnum = 34
  optional ph Double = 35
  repeated perturbation String = 36
  optional phosphate QuantityValue = 37
  repeated phosplipidFattAcid String = 38
  optional potassium QuantityValue = 39
  optional pressure QuantityValue = 40
  optional salinity QuantityValue = 41
  optional sampStoreDur String = 42
  optional sampStoreLoc String = 43
  optional sampStoreTemp QuantityValue = 44
  optional silicate QuantityValue = 45
  optional sodium QuantityValue = 46
  optional sulfate QuantityValue = 47
  optional sulfide QuantityValue = 48
  optional waterCurrent QuantityValue = 49
  sampName String = 50
  projectName String = 51
  optional sampVolWeDnaExt QuantityValue = 52
  sampTaxonId String = 53
  optional experimentalFactor String = 54
  optional negContType NegContTypeEnum = 55
  optional posContType String = 56
  optional subspecfGenLin String = 57
  optional extrachromElements Integer = 58
  optional estimatedSize String = 59
  optional refBiomaterial String = 60
  optional sourceMatId String = 61
  isolGrowthCondt String = 62
  optional sampCollecDevice String = 63
  optional sampCollecMethod String = 64
  optional sampMatProcess String = 65
  optional sampSize QuantityValue = 66
  optional nuclAcidExt String = 67
  optional nuclAcidAmp String = 68
  optional libSize Integer = 69
  optional libReadsSeqd Integer = 70
  optional libLayout LibLayoutEnum = 71
  optional libVector String = 72
  optional libScreen String = 73
  optional adapters String = 74
  seqMeth String = 75
  optional taxIdent TaxIdentEnum = 76
  optional assemblyQual AssemblyQualEnum = 77
  optional assemblyName String = 78
  assemblySoftware String = 79
  optional annot String = 80
  optional numberContig Integer = 81
  optional featPred String = 82
  optional refDb String = 83
  optional simSearchMeth String = 84
  optional taxClass String = 85
  optional complScore String = 86
  optional complSoftware String = 87
  optional associatedResource String = 88
  optional sop String = 89
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: plant with environmental package miscellaneous natural or artificial environment
message MiscellaneousNaturalOrArtificialEnvironmentMIGSPlant
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional ammonium QuantityValue = 12
  repeated biomass String = 13
  optional bromide QuantityValue = 14
  optional calcium QuantityValue = 15
  repeated chemAdministration String = 16
  optional chloride QuantityValue = 17
  optional chlorophyll QuantityValue = 18
  optional density QuantityValue = 19
  repeated dietherLipids String = 20
  optional dissCarbDioxide QuantityValue = 21
  optional dissHydrogen QuantityValue = 22
  optional dissInorgCarb QuantityValue = 23
  optional dissOrgNitro QuantityValue = 24
  optional dissOxygen QuantityValue = 25
  repeated miscParam String = 26
  optional nitrate QuantityValue = 27
  optional nitrite QuantityValue = 28
  optional nitro QuantityValue = 29
  optional orgCarb QuantityValue = 30
  optional orgMatter QuantityValue = 31
  optional orgNitro QuantityValue = 32
  repeated organismCount OrganismCountEnum = 33
  optional oxyStatSamp OxyStatSampEnum = 34
  optional ph Double = 35
  repeated perturbation String = 36
  optional phosphate QuantityValue = 37
  repeated phosplipidFattAcid String = 38
  optional potassium QuantityValue = 39
  optional pressure QuantityValue = 40
  optional salinity QuantityValue = 41
  optional sampStoreDur String = 42
  optional sampStoreLoc String = 43
  optional sampStoreTemp QuantityValue = 44
  optional silicate QuantityValue = 45
  optional sodium QuantityValue = 46
  optional sulfate QuantityValue = 47
  optional sulfide QuantityValue = 48
  optional waterCurrent QuantityValue = 49
  sampName String = 50
  projectName String = 51
  optional sampVolWeDnaExt QuantityValue = 52
  sampTaxonId String = 53
  optional experimentalFactor String = 54
  optional negContType NegContTypeEnum = 55
  optional posContType String = 56
  optional subspecfGenLin String = 57
  optional estimatedSize String = 58
  optional refBiomaterial String = 59
  optional sourceMatId String = 60
  optional specificHost String = 61
  optional hostSpecRange Integer = 62
  propagation String = 63
  optional encodedTraits String = 64
  isolGrowthCondt String = 65
  optional sampCollecDevice String = 66
  optional sampCollecMethod String = 67
  optional sampMatProcess String = 68
  optional sampSize QuantityValue = 69
  optional nuclAcidExt String = 70
  optional nuclAcidAmp String = 71
  optional libSize Integer = 72
  optional libReadsSeqd Integer = 73
  optional libLayout LibLayoutEnum = 74
  optional libVector String = 75
  optional libScreen String = 76
  optional adapters String = 77
  seqMeth String = 78
  optional taxIdent TaxIdentEnum = 79
  optional assemblyQual AssemblyQualEnum = 80
  optional assemblyName String = 81
  assemblySoftware String = 82
  optional annot String = 83
  optional numberContig Integer = 84
  optional featPred String = 85
  optional refDb String = 86
  optional simSearchMeth String = 87
  optional taxClass String = 88
  optional complScore String = 89
  optional complSoftware String = 90
  optional associatedResource String = 91
  optional sop String = 92
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package miscellaneous natural or artificial environment
message MiscellaneousNaturalOrArtificialEnvironmentMIGSVirus
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional ammonium QuantityValue = 12
  repeated biomass String = 13
  optional bromide QuantityValue = 14
  optional calcium QuantityValue = 15
  repeated chemAdministration String = 16
  optional chloride QuantityValue = 17
  optional chlorophyll QuantityValue = 18
  optional density QuantityValue = 19
  repeated dietherLipids String = 20
  optional dissCarbDioxide QuantityValue = 21
  optional dissHydrogen QuantityValue = 22
  optional dissInorgCarb QuantityValue = 23
  optional dissOrgNitro QuantityValue = 24
  optional dissOxygen QuantityValue = 25
  repeated miscParam String = 26
  optional nitrate QuantityValue = 27
  optional nitrite QuantityValue = 28
  optional nitro QuantityValue = 29
  optional orgCarb QuantityValue = 30
  optional orgMatter QuantityValue = 31
  optional orgNitro QuantityValue = 32
  repeated organismCount OrganismCountEnum = 33
  optional oxyStatSamp OxyStatSampEnum = 34
  optional ph Double = 35
  repeated perturbation String = 36
  optional phosphate QuantityValue = 37
  repeated phosplipidFattAcid String = 38
  optional potassium QuantityValue = 39
  optional pressure QuantityValue = 40
  optional salinity QuantityValue = 41
  optional sampStoreDur String = 42
  optional sampStoreLoc String = 43
  optional sampStoreTemp QuantityValue = 44
  optional silicate QuantityValue = 45
  optional sodium QuantityValue = 46
  optional sulfate QuantityValue = 47
  optional sulfide QuantityValue = 48
  optional waterCurrent QuantityValue = 49
  sampName String = 50
  projectName String = 51
  optional sampVolWeDnaExt QuantityValue = 52
  sampTaxonId String = 53
  optional experimentalFactor String = 54
  optional negContType NegContTypeEnum = 55
  optional posContType String = 56
  optional subspecfGenLin String = 57
  optional numReplicons Integer = 58
  optional estimatedSize String = 59
  optional refBiomaterial String = 60
  optional sourceMatId String = 61
  optional pathogenicity String = 62
  optional bioticRelationship BioticRelationshipEnum = 63
  optional specificHost String = 64
  optional hostSpecRange Integer = 65
  optional hostDiseaseStat String = 66
  propagation String = 67
  optional encodedTraits String = 68
  isolGrowthCondt String = 69
  optional sampCollecDevice String = 70
  optional sampCollecMethod String = 71
  optional sampMatProcess String = 72
  optional sampSize QuantityValue = 73
  optional virusEnrichAppr VirusEnrichApprEnum = 74
  optional nuclAcidExt String = 75
  optional nuclAcidAmp String = 76
  optional libSize Integer = 77
  optional libReadsSeqd Integer = 78
  optional libLayout LibLayoutEnum = 79
  optional libVector String = 80
  optional libScreen String = 81
  optional adapters String = 82
  seqMeth String = 83
  optional taxIdent TaxIdentEnum = 84
  optional assemblyQual AssemblyQualEnum = 85
  optional assemblyName String = 86
  assemblySoftware String = 87
  optional annot String = 88
  optional numberContig Integer = 89
  optional featPred String = 90
  optional refDb String = 91
  optional simSearchMeth String = 92
  optional taxClass String = 93
  optional complScore String = 94
  optional complSoftware String = 95
  optional associatedResource String = 96
  optional sop String = 97
 }
// Combinatorial checklist Minimum Information About a Metagenome-Assembled Genome with environmental package miscellaneous natural or artificial environment
message MiscellaneousNaturalOrArtificialEnvironmentMIMAG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional ammonium QuantityValue = 12
  repeated biomass String = 13
  optional bromide QuantityValue = 14
  optional calcium QuantityValue = 15
  repeated chemAdministration String = 16
  optional chloride QuantityValue = 17
  optional chlorophyll QuantityValue = 18
  optional density QuantityValue = 19
  repeated dietherLipids String = 20
  optional dissCarbDioxide QuantityValue = 21
  optional dissHydrogen QuantityValue = 22
  optional dissInorgCarb QuantityValue = 23
  optional dissOrgNitro QuantityValue = 24
  optional dissOxygen QuantityValue = 25
  repeated miscParam String = 26
  optional nitrate QuantityValue = 27
  optional nitrite QuantityValue = 28
  optional nitro QuantityValue = 29
  optional orgCarb QuantityValue = 30
  optional orgMatter QuantityValue = 31
  optional orgNitro QuantityValue = 32
  repeated organismCount OrganismCountEnum = 33
  optional oxyStatSamp OxyStatSampEnum = 34
  optional ph Double = 35
  repeated perturbation String = 36
  optional phosphate QuantityValue = 37
  repeated phosplipidFattAcid String = 38
  optional potassium QuantityValue = 39
  optional pressure QuantityValue = 40
  optional salinity QuantityValue = 41
  optional sampStoreDur String = 42
  optional sampStoreLoc String = 43
  optional sampStoreTemp QuantityValue = 44
  optional silicate QuantityValue = 45
  optional sodium QuantityValue = 46
  optional sulfate QuantityValue = 47
  optional sulfide QuantityValue = 48
  optional waterCurrent QuantityValue = 49
  sampName String = 50
  projectName String = 51
  optional sampVolWeDnaExt QuantityValue = 52
  sampTaxonId String = 53
  optional experimentalFactor String = 54
  optional negContType NegContTypeEnum = 55
  optional posContType String = 56
  optional refBiomaterial String = 57
  optional sourceMatId String = 58
  optional relToOxygen RelToOxygenEnum = 59
  optional sampCollecDevice String = 60
  optional sampCollecMethod String = 61
  optional sampMatProcess String = 62
  optional sizeFrac String = 63
  optional sampSize QuantityValue = 64
  optional nuclAcidExt String = 65
  optional nuclAcidAmp String = 66
  optional libSize Integer = 67
  optional libReadsSeqd Integer = 68
  optional libLayout LibLayoutEnum = 69
  optional libVector String = 70
  optional libScreen String = 71
  optional mid String = 72
  optional adapters String = 73
  seqMeth String = 74
  taxIdent TaxIdentEnum = 75
  assemblyQual AssemblyQualEnum = 76
  optional assemblyName String = 77
  assemblySoftware String = 78
  optional annot String = 79
  optional numberContig Integer = 80
  optional featPred String = 81
  optional refDb String = 82
  optional simSearchMeth String = 83
  optional taxClass String = 84
  optional x16sRecover String = 85
  optional x16sRecoverSoftware String = 86
  optional trnas Integer = 87
  optional trnaExtSoftware String = 88
  complScore String = 89
  complSoftware String = 90
  optional complAppr ComplApprEnum = 91
  contamScore String = 92
  optional contamScreenInput String = 93
  optional contamScreenParam String = 94
  optional decontamSoftware DecontamSoftwareEnum = 95
  binParam BinParamEnum = 96
  binSoftware String = 97
  optional reassemblyBin String = 98
  optional magCovSoftware MagCovSoftwareEnum = 99
  optional associatedResource String = 100
  optional sop String = 101
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: specimen with environmental package miscellaneous natural or artificial environment
message MiscellaneousNaturalOrArtificialEnvironmentMIMARKSSpecimen
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional ammonium QuantityValue = 12
  repeated biomass String = 13
  optional bromide QuantityValue = 14
  optional calcium QuantityValue = 15
  repeated chemAdministration String = 16
  optional chloride QuantityValue = 17
  optional chlorophyll QuantityValue = 18
  optional density QuantityValue = 19
  repeated dietherLipids String = 20
  optional dissCarbDioxide QuantityValue = 21
  optional dissHydrogen QuantityValue = 22
  optional dissInorgCarb QuantityValue = 23
  optional dissOrgNitro QuantityValue = 24
  optional dissOxygen QuantityValue = 25
  repeated miscParam String = 26
  optional nitrate QuantityValue = 27
  optional nitrite QuantityValue = 28
  optional nitro QuantityValue = 29
  optional orgCarb QuantityValue = 30
  optional orgMatter QuantityValue = 31
  optional orgNitro QuantityValue = 32
  repeated organismCount OrganismCountEnum = 33
  optional oxyStatSamp OxyStatSampEnum = 34
  optional ph Double = 35
  repeated perturbation String = 36
  optional phosphate QuantityValue = 37
  repeated phosplipidFattAcid String = 38
  optional potassium QuantityValue = 39
  optional pressure QuantityValue = 40
  optional salinity QuantityValue = 41
  optional sampStoreDur String = 42
  optional sampStoreLoc String = 43
  optional sampStoreTemp QuantityValue = 44
  optional silicate QuantityValue = 45
  optional sodium QuantityValue = 46
  optional sulfate QuantityValue = 47
  optional sulfide QuantityValue = 48
  optional waterCurrent QuantityValue = 49
  sampName String = 50
  projectName String = 51
  optional sampVolWeDnaExt QuantityValue = 52
  sampTaxonId String = 53
  optional experimentalFactor String = 54
  optional negContType NegContTypeEnum = 55
  optional posContType String = 56
  optional sourceMatId String = 57
  optional relToOxygen RelToOxygenEnum = 58
  optional sampCollecDevice String = 59
  optional sampCollecMethod String = 60
  optional sampMatProcess String = 61
  optional sizeFrac String = 62
  optional sampSize QuantityValue = 63
  optional nuclAcidExt String = 64
  optional nuclAcidAmp String = 65
  optional libSize Integer = 66
  optional libReadsSeqd Integer = 67
  optional libLayout LibLayoutEnum = 68
  optional libVector String = 69
  optional libScreen String = 70
  targetGene String = 71
  optional targetSubfragment String = 72
  optional pcrPrimers String = 73
  optional mid String = 74
  optional adapters String = 75
  optional pcrCond String = 76
  seqMeth String = 77
  optional seqQualityCheck String = 78
  optional chimeraCheck String = 79
  optional assemblySoftware String = 80
  optional associatedResource String = 81
  optional sop String = 82
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: survey with environmental package miscellaneous natural or artificial environment
message MiscellaneousNaturalOrArtificialEnvironmentMIMARKSSurvey
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional ammonium QuantityValue = 12
  repeated biomass String = 13
  optional bromide QuantityValue = 14
  optional calcium QuantityValue = 15
  repeated chemAdministration String = 16
  optional chloride QuantityValue = 17
  optional chlorophyll QuantityValue = 18
  optional density QuantityValue = 19
  repeated dietherLipids String = 20
  optional dissCarbDioxide QuantityValue = 21
  optional dissHydrogen QuantityValue = 22
  optional dissInorgCarb QuantityValue = 23
  optional dissOrgNitro QuantityValue = 24
  optional dissOxygen QuantityValue = 25
  repeated miscParam String = 26
  optional nitrate QuantityValue = 27
  optional nitrite QuantityValue = 28
  optional nitro QuantityValue = 29
  optional orgCarb QuantityValue = 30
  optional orgMatter QuantityValue = 31
  optional orgNitro QuantityValue = 32
  repeated organismCount OrganismCountEnum = 33
  optional oxyStatSamp OxyStatSampEnum = 34
  optional ph Double = 35
  repeated perturbation String = 36
  optional phosphate QuantityValue = 37
  repeated phosplipidFattAcid String = 38
  optional potassium QuantityValue = 39
  optional pressure QuantityValue = 40
  optional salinity QuantityValue = 41
  optional sampStoreDur String = 42
  optional sampStoreLoc String = 43
  optional sampStoreTemp QuantityValue = 44
  optional silicate QuantityValue = 45
  optional sodium QuantityValue = 46
  optional sulfate QuantityValue = 47
  optional sulfide QuantityValue = 48
  optional waterCurrent QuantityValue = 49
  sampName String = 50
  projectName String = 51
  optional sampVolWeDnaExt QuantityValue = 52
  sampTaxonId String = 53
  optional experimentalFactor String = 54
  optional negContType NegContTypeEnum = 55
  optional posContType String = 56
  optional subspecfGenLin String = 57
  optional extrachromElements Integer = 58
  optional sourceMatId String = 59
  optional bioticRelationship BioticRelationshipEnum = 60
  optional trophicLevel TrophicLevelEnum = 61
  optional relToOxygen RelToOxygenEnum = 62
  isolGrowthCondt String = 63
  optional sampCollecDevice String = 64
  optional sampCollecMethod String = 65
  optional sampMatProcess String = 66
  optional sampSize QuantityValue = 67
  optional nuclAcidExt String = 68
  optional nuclAcidAmp String = 69
  targetGene String = 70
  optional targetSubfragment String = 71
  optional pcrPrimers String = 72
  optional pcrCond String = 73
  seqMeth String = 74
  optional seqQualityCheck String = 75
  optional chimeraCheck String = 76
  optional associatedResource String = 77
  optional sop String = 78
 }
// Combinatorial checklist Metagenome or Environmental with environmental package miscellaneous natural or artificial environment
message MiscellaneousNaturalOrArtificialEnvironmentMIMS
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional ammonium QuantityValue = 12
  repeated biomass String = 13
  optional bromide QuantityValue = 14
  optional calcium QuantityValue = 15
  repeated chemAdministration String = 16
  optional chloride QuantityValue = 17
  optional chlorophyll QuantityValue = 18
  optional density QuantityValue = 19
  repeated dietherLipids String = 20
  optional dissCarbDioxide QuantityValue = 21
  optional dissHydrogen QuantityValue = 22
  optional dissInorgCarb QuantityValue = 23
  optional dissOrgNitro QuantityValue = 24
  optional dissOxygen QuantityValue = 25
  repeated miscParam String = 26
  optional nitrate QuantityValue = 27
  optional nitrite QuantityValue = 28
  optional nitro QuantityValue = 29
  optional orgCarb QuantityValue = 30
  optional orgMatter QuantityValue = 31
  optional orgNitro QuantityValue = 32
  repeated organismCount OrganismCountEnum = 33
  optional oxyStatSamp OxyStatSampEnum = 34
  optional ph Double = 35
  repeated perturbation String = 36
  optional phosphate QuantityValue = 37
  repeated phosplipidFattAcid String = 38
  optional potassium QuantityValue = 39
  optional pressure QuantityValue = 40
  optional salinity QuantityValue = 41
  optional sampStoreDur String = 42
  optional sampStoreLoc String = 43
  optional sampStoreTemp QuantityValue = 44
  optional silicate QuantityValue = 45
  optional sodium QuantityValue = 46
  optional sulfate QuantityValue = 47
  optional sulfide QuantityValue = 48
  optional waterCurrent QuantityValue = 49
  sampName String = 50
  projectName String = 51
  optional sampVolWeDnaExt QuantityValue = 52
  sampTaxonId String = 53
  optional experimentalFactor String = 54
  optional negContType NegContTypeEnum = 55
  optional posContType String = 56
  optional refBiomaterial String = 57
  optional sourceMatId String = 58
  optional relToOxygen RelToOxygenEnum = 59
  optional sampCollecDevice String = 60
  optional sampCollecMethod String = 61
  optional sampMatProcess String = 62
  optional sizeFrac String = 63
  optional sampSize QuantityValue = 64
  optional nuclAcidExt String = 65
  optional nuclAcidAmp String = 66
  optional libSize Integer = 67
  optional libReadsSeqd Integer = 68
  optional libLayout LibLayoutEnum = 69
  optional libVector String = 70
  optional libScreen String = 71
  optional mid String = 72
  optional adapters String = 73
  seqMeth String = 74
  optional assemblyQual AssemblyQualEnum = 75
  optional assemblyName String = 76
  optional assemblySoftware String = 77
  optional annot String = 78
  optional numberContig Integer = 79
  optional featPred String = 80
  optional refDb String = 81
  optional simSearchMeth String = 82
  optional taxClass String = 83
  optional associatedResource String = 84
  optional sop String = 85
 }
// Combinatorial checklist Minimum Information About a Single Amplified Genome with environmental package miscellaneous natural or artificial environment
message MiscellaneousNaturalOrArtificialEnvironmentMISAG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional ammonium QuantityValue = 12
  repeated biomass String = 13
  optional bromide QuantityValue = 14
  optional calcium QuantityValue = 15
  repeated chemAdministration String = 16
  optional chloride QuantityValue = 17
  optional chlorophyll QuantityValue = 18
  optional density QuantityValue = 19
  repeated dietherLipids String = 20
  optional dissCarbDioxide QuantityValue = 21
  optional dissHydrogen QuantityValue = 22
  optional dissInorgCarb QuantityValue = 23
  optional dissOrgNitro QuantityValue = 24
  optional dissOxygen QuantityValue = 25
  repeated miscParam String = 26
  optional nitrate QuantityValue = 27
  optional nitrite QuantityValue = 28
  optional nitro QuantityValue = 29
  optional orgCarb QuantityValue = 30
  optional orgMatter QuantityValue = 31
  optional orgNitro QuantityValue = 32
  repeated organismCount OrganismCountEnum = 33
  optional oxyStatSamp OxyStatSampEnum = 34
  optional ph Double = 35
  repeated perturbation String = 36
  optional phosphate QuantityValue = 37
  repeated phosplipidFattAcid String = 38
  optional potassium QuantityValue = 39
  optional pressure QuantityValue = 40
  optional salinity QuantityValue = 41
  optional sampStoreDur String = 42
  optional sampStoreLoc String = 43
  optional sampStoreTemp QuantityValue = 44
  optional silicate QuantityValue = 45
  optional sodium QuantityValue = 46
  optional sulfate QuantityValue = 47
  optional sulfide QuantityValue = 48
  optional waterCurrent QuantityValue = 49
  sampName String = 50
  projectName String = 51
  optional sampVolWeDnaExt QuantityValue = 52
  sampTaxonId String = 53
  optional experimentalFactor String = 54
  optional negContType NegContTypeEnum = 55
  optional posContType String = 56
  optional refBiomaterial String = 57
  optional sourceMatId String = 58
  optional relToOxygen RelToOxygenEnum = 59
  optional sampCollecDevice String = 60
  optional sampCollecMethod String = 61
  optional sampMatProcess String = 62
  optional sizeFrac String = 63
  optional sampSize QuantityValue = 64
  optional nuclAcidExt String = 65
  optional nuclAcidAmp String = 66
  optional libSize Integer = 67
  optional libReadsSeqd Integer = 68
  optional libLayout LibLayoutEnum = 69
  optional libVector String = 70
  optional libScreen String = 71
  optional mid String = 72
  optional adapters String = 73
  seqMeth String = 74
  taxIdent TaxIdentEnum = 75
  assemblyQual AssemblyQualEnum = 76
  optional assemblyName String = 77
  assemblySoftware String = 78
  optional annot String = 79
  optional numberContig Integer = 80
  optional featPred String = 81
  optional refDb String = 82
  optional simSearchMeth String = 83
  optional taxClass String = 84
  optional x16sRecover String = 85
  optional x16sRecoverSoftware String = 86
  optional trnas Integer = 87
  optional trnaExtSoftware String = 88
  complScore String = 89
  complSoftware String = 90
  optional complAppr ComplApprEnum = 91
  contamScore String = 92
  optional contamScreenInput String = 93
  optional contamScreenParam String = 94
  optional decontamSoftware DecontamSoftwareEnum = 95
  sortTech SortTechEnum = 96
  singleCellLysisAppr SingleCellLysisApprEnum = 97
  optional singleCellLysisProt String = 98
  wgaAmpAppr String = 99
  optional wgaAmpKit String = 100
  optional associatedResource String = 101
  optional sop String = 102
 }
// Combinatorial checklist Minimum Information About an Uncultivated Virus Genome with environmental package miscellaneous natural or artificial environment
message MiscellaneousNaturalOrArtificialEnvironmentMIUVIG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional ammonium QuantityValue = 12
  repeated biomass String = 13
  optional bromide QuantityValue = 14
  optional calcium QuantityValue = 15
  repeated chemAdministration String = 16
  optional chloride QuantityValue = 17
  optional chlorophyll QuantityValue = 18
  optional density QuantityValue = 19
  repeated dietherLipids String = 20
  optional dissCarbDioxide QuantityValue = 21
  optional dissHydrogen QuantityValue = 22
  optional dissInorgCarb QuantityValue = 23
  optional dissOrgNitro QuantityValue = 24
  optional dissOxygen QuantityValue = 25
  repeated miscParam String = 26
  optional nitrate QuantityValue = 27
  optional nitrite QuantityValue = 28
  optional nitro QuantityValue = 29
  optional orgCarb QuantityValue = 30
  optional orgMatter QuantityValue = 31
  optional orgNitro QuantityValue = 32
  repeated organismCount OrganismCountEnum = 33
  optional oxyStatSamp OxyStatSampEnum = 34
  optional ph Double = 35
  repeated perturbation String = 36
  optional phosphate QuantityValue = 37
  repeated phosplipidFattAcid String = 38
  optional potassium QuantityValue = 39
  optional pressure QuantityValue = 40
  optional salinity QuantityValue = 41
  optional sampStoreDur String = 42
  optional sampStoreLoc String = 43
  optional sampStoreTemp QuantityValue = 44
  optional silicate QuantityValue = 45
  optional sodium QuantityValue = 46
  optional sulfate QuantityValue = 47
  optional sulfide QuantityValue = 48
  optional waterCurrent QuantityValue = 49
  sampName String = 50
  projectName String = 51
  optional sampVolWeDnaExt QuantityValue = 52
  sampTaxonId String = 53
  optional experimentalFactor String = 54
  optional negContType NegContTypeEnum = 55
  optional posContType String = 56
  optional estimatedSize String = 57
  optional refBiomaterial String = 58
  optional sourceMatId String = 59
  optional pathogenicity String = 60
  optional bioticRelationship BioticRelationshipEnum = 61
  optional specificHost String = 62
  optional hostSpecRange Integer = 63
  optional hostDiseaseStat String = 64
  optional sampCollecDevice String = 65
  optional sampCollecMethod String = 66
  optional sampMatProcess String = 67
  optional sizeFrac String = 68
  optional sampSize QuantityValue = 69
  sourceUvig SourceUvigEnum = 70
  virusEnrichAppr VirusEnrichApprEnum = 71
  optional nuclAcidExt String = 72
  optional nuclAcidAmp String = 73
  optional libSize Integer = 74
  optional libReadsSeqd Integer = 75
  optional libLayout LibLayoutEnum = 76
  optional libVector String = 77
  optional libScreen String = 78
  optional mid String = 79
  optional adapters String = 80
  seqMeth String = 81
  optional taxIdent TaxIdentEnum = 82
  assemblyQual AssemblyQualEnum = 83
  optional assemblyName String = 84
  assemblySoftware String = 85
  optional annot String = 86
  numberContig Integer = 87
  optional featPred String = 88
  optional refDb String = 89
  optional simSearchMeth String = 90
  optional taxClass String = 91
  optional trnas Integer = 92
  optional trnaExtSoftware String = 93
  optional complScore String = 94
  optional complSoftware String = 95
  optional complAppr ComplApprEnum = 96
  optional sortTech SortTechEnum = 97
  optional singleCellLysisAppr SingleCellLysisApprEnum = 98
  optional singleCellLysisProt String = 99
  optional wgaAmpAppr String = 100
  optional wgaAmpKit String = 101
  optional binParam BinParamEnum = 102
  optional binSoftware String = 103
  optional reassemblyBin String = 104
  optional magCovSoftware MagCovSoftwareEnum = 105
  virIdentSoftware String = 106
  predGenomeType PredGenomeTypeEnum = 107
  predGenomeStruc PredGenomeStrucEnum = 108
  detecType String = 109
  optional otuClassAppr String = 110
  optional otuSeqCompAppr String = 111
  optional otuDb String = 112
  optional hostPredAppr HostPredApprEnum = 113
  optional hostPredEstAcc String = 114
  optional associatedResource String = 115
  optional sop String = 116
 }
// plant-associated
message Plant-associated
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated airTempRegm String = 11
  optional ancesData String = 12
  repeated antibioticRegm String = 13
  optional biolStat BiolStatEnum = 14
  optional bioticRegm String = 15
  repeated chemAdministration String = 16
  repeated chemMutagen String = 17
  repeated climateEnvironment String = 18
  optional cultRootMed String = 19
  repeated fertilizerRegm String = 20
  repeated fungicideRegm String = 21
  repeated gaseousEnvironment String = 22
  optional geneticMod String = 23
  repeated gravity String = 24
  optional growthFacil String = 25
  optional growthHabit GrowthHabitEnum = 26
  repeated growthHormoneRegm String = 27
  repeated herbicideRegm String = 28
  optional hostAge QuantityValue = 29
  optional hostCommonName String = 30
  optional hostDryMass QuantityValue = 31
  optional hostGenotype String = 32
  optional hostHeight QuantityValue = 33
  repeated hostSubspecfGenlin String = 34
  optional hostLength QuantityValue = 35
  optional hostLifeStage String = 36
  optional hostPhenotype String = 37
  optional hostTaxid String = 38
  optional hostTotMass QuantityValue = 39
  optional hostWetMass QuantityValue = 40
  repeated humidityRegm String = 41
  optional lightRegm String = 42
  repeated mechanicalDamage String = 43
  repeated mineralNutrRegm String = 44
  repeated miscParam String = 45
  repeated nonMinNutrRegm String = 46
  repeated organismCount OrganismCountEnum = 47
  optional oxyStatSamp OxyStatSampEnum = 48
  repeated phRegm String = 49
  repeated perturbation String = 50
  repeated pesticideRegm String = 51
  optional plantGrowthMed PlantGrowthMedEnum = 52
  optional plantProduct String = 53
  optional plantSex PlantSexEnum = 54
  optional plantStruc String = 55
  repeated radiationRegm String = 56
  repeated rainfallRegm String = 57
  optional rootCond String = 58
  optional rootMedCarbon String = 59
  optional rootMedMacronutr String = 60
  optional rootMedMicronutr String = 61
  optional rootMedSuppl String = 62
  optional rootMedPh Double = 63
  optional rootMedRegl String = 64
  optional rootMedSolid String = 65
  repeated saltRegm String = 66
  optional sampCaptStatus SampCaptStatusEnum = 67
  optional sampDisStage SampDisStageEnum = 68
  optional salinity QuantityValue = 69
  optional sampStoreDur String = 70
  optional sampStoreLoc String = 71
  optional sampStoreTemp QuantityValue = 72
  repeated seasonEnvironment String = 73
  repeated standingWaterRegm String = 74
  optional tissCultGrowthMed String = 75
  repeated waterTempRegm String = 76
  repeated wateringRegm String = 77
  repeated hostSymbiont String = 78
  sampName String = 79
  projectName String = 80
  optional hostDiseaseStat String = 81
  optional sampVolWeDnaExt QuantityValue = 82
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package plant-associated
message Plant-associatedMIGSBacteria
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated airTempRegm String = 11
  optional ancesData String = 12
  repeated antibioticRegm String = 13
  optional biolStat BiolStatEnum = 14
  optional bioticRegm String = 15
  repeated chemAdministration String = 16
  repeated chemMutagen String = 17
  repeated climateEnvironment String = 18
  optional cultRootMed String = 19
  repeated fertilizerRegm String = 20
  repeated fungicideRegm String = 21
  repeated gaseousEnvironment String = 22
  optional geneticMod String = 23
  repeated gravity String = 24
  optional growthFacil String = 25
  optional growthHabit GrowthHabitEnum = 26
  repeated growthHormoneRegm String = 27
  repeated herbicideRegm String = 28
  optional hostAge QuantityValue = 29
  optional hostCommonName String = 30
  optional hostDryMass QuantityValue = 31
  optional hostGenotype String = 32
  optional hostHeight QuantityValue = 33
  repeated hostSubspecfGenlin String = 34
  optional hostLength QuantityValue = 35
  optional hostLifeStage String = 36
  optional hostPhenotype String = 37
  optional hostTaxid String = 38
  optional hostTotMass QuantityValue = 39
  optional hostWetMass QuantityValue = 40
  repeated humidityRegm String = 41
  optional lightRegm String = 42
  repeated mechanicalDamage String = 43
  repeated mineralNutrRegm String = 44
  repeated nonMinNutrRegm String = 45
  repeated organismCount OrganismCountEnum = 46
  optional oxyStatSamp OxyStatSampEnum = 47
  repeated phRegm String = 48
  repeated perturbation String = 49
  repeated pesticideRegm String = 50
  optional plantGrowthMed PlantGrowthMedEnum = 51
  optional plantProduct String = 52
  optional plantSex PlantSexEnum = 53
  optional plantStruc String = 54
  repeated radiationRegm String = 55
  repeated rainfallRegm String = 56
  optional rootCond String = 57
  optional rootMedCarbon String = 58
  optional rootMedMacronutr String = 59
  optional rootMedMicronutr String = 60
  optional rootMedSuppl String = 61
  optional rootMedPh Double = 62
  optional rootMedRegl String = 63
  optional rootMedSolid String = 64
  repeated saltRegm String = 65
  optional sampCaptStatus SampCaptStatusEnum = 66
  optional sampDisStage SampDisStageEnum = 67
  optional salinity QuantityValue = 68
  optional sampStoreDur String = 69
  optional sampStoreLoc String = 70
  optional sampStoreTemp QuantityValue = 71
  repeated seasonEnvironment String = 72
  repeated standingWaterRegm String = 73
  optional tissCultGrowthMed String = 74
  repeated waterTempRegm String = 75
  repeated wateringRegm String = 76
  repeated hostSymbiont String = 77
  repeated miscParam String = 78
  sampName String = 79
  projectName String = 80
  optional hostDiseaseStat String = 81
  optional sampVolWeDnaExt QuantityValue = 82
  sampTaxonId String = 83
  optional experimentalFactor String = 84
  optional negContType NegContTypeEnum = 85
  optional posContType String = 86
  optional subspecfGenLin String = 87
  numReplicons Integer = 88
  optional extrachromElements Integer = 89
  optional estimatedSize String = 90
  refBiomaterial String = 91
  optional sourceMatId String = 92
  optional pathogenicity String = 93
  optional bioticRelationship BioticRelationshipEnum = 94
  optional specificHost String = 95
  optional hostSpecRange Integer = 96
  optional trophicLevel TrophicLevelEnum = 97
  optional encodedTraits String = 98
  optional relToOxygen RelToOxygenEnum = 99
  isolGrowthCondt String = 100
  optional sampCollecDevice String = 101
  optional sampCollecMethod String = 102
  optional sampMatProcess String = 103
  optional sampSize QuantityValue = 104
  optional nuclAcidExt String = 105
  optional nuclAcidAmp String = 106
  optional libSize Integer = 107
  optional libReadsSeqd Integer = 108
  optional libLayout LibLayoutEnum = 109
  optional libVector String = 110
  optional libScreen String = 111
  optional adapters String = 112
  seqMeth String = 113
  optional taxIdent TaxIdentEnum = 114
  assemblyQual AssemblyQualEnum = 115
  optional assemblyName String = 116
  assemblySoftware String = 117
  optional annot String = 118
  numberContig Integer = 119
  optional featPred String = 120
  optional refDb String = 121
  optional simSearchMeth String = 122
  optional taxClass String = 123
  optional complScore String = 124
  optional complSoftware String = 125
  optional associatedResource String = 126
  optional sop String = 127
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: eukaryote with environmental package plant-associated
message Plant-associatedMIGSEukaryote
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated airTempRegm String = 11
  optional ancesData String = 12
  repeated antibioticRegm String = 13
  optional biolStat BiolStatEnum = 14
  optional bioticRegm String = 15
  repeated chemAdministration String = 16
  repeated chemMutagen String = 17
  repeated climateEnvironment String = 18
  optional cultRootMed String = 19
  repeated fertilizerRegm String = 20
  repeated fungicideRegm String = 21
  repeated gaseousEnvironment String = 22
  optional geneticMod String = 23
  repeated gravity String = 24
  optional growthFacil String = 25
  optional growthHabit GrowthHabitEnum = 26
  repeated growthHormoneRegm String = 27
  repeated herbicideRegm String = 28
  optional hostAge QuantityValue = 29
  optional hostCommonName String = 30
  optional hostDryMass QuantityValue = 31
  optional hostGenotype String = 32
  optional hostHeight QuantityValue = 33
  repeated hostSubspecfGenlin String = 34
  optional hostLength QuantityValue = 35
  optional hostLifeStage String = 36
  optional hostPhenotype String = 37
  optional hostTaxid String = 38
  optional hostTotMass QuantityValue = 39
  optional hostWetMass QuantityValue = 40
  repeated humidityRegm String = 41
  optional lightRegm String = 42
  repeated mechanicalDamage String = 43
  repeated mineralNutrRegm String = 44
  repeated nonMinNutrRegm String = 45
  repeated organismCount OrganismCountEnum = 46
  optional oxyStatSamp OxyStatSampEnum = 47
  repeated phRegm String = 48
  repeated perturbation String = 49
  repeated pesticideRegm String = 50
  optional plantGrowthMed PlantGrowthMedEnum = 51
  optional plantProduct String = 52
  optional plantSex PlantSexEnum = 53
  optional plantStruc String = 54
  repeated radiationRegm String = 55
  repeated rainfallRegm String = 56
  optional rootCond String = 57
  optional rootMedCarbon String = 58
  optional rootMedMacronutr String = 59
  optional rootMedMicronutr String = 60
  optional rootMedSuppl String = 61
  optional rootMedPh Double = 62
  optional rootMedRegl String = 63
  optional rootMedSolid String = 64
  repeated saltRegm String = 65
  optional sampCaptStatus SampCaptStatusEnum = 66
  optional sampDisStage SampDisStageEnum = 67
  optional salinity QuantityValue = 68
  optional sampStoreDur String = 69
  optional sampStoreLoc String = 70
  optional sampStoreTemp QuantityValue = 71
  repeated seasonEnvironment String = 72
  repeated standingWaterRegm String = 73
  optional tissCultGrowthMed String = 74
  repeated waterTempRegm String = 75
  repeated wateringRegm String = 76
  repeated hostSymbiont String = 77
  repeated miscParam String = 78
  sampName String = 79
  projectName String = 80
  optional hostDiseaseStat String = 81
  optional sampVolWeDnaExt QuantityValue = 82
  sampTaxonId String = 83
  optional experimentalFactor String = 84
  optional negContType NegContTypeEnum = 85
  optional posContType String = 86
  optional subspecfGenLin String = 87
  optional ploidy String = 88
  optional numReplicons Integer = 89
  optional extrachromElements Integer = 90
  optional estimatedSize String = 91
  optional refBiomaterial String = 92
  optional sourceMatId String = 93
  optional pathogenicity String = 94
  optional bioticRelationship BioticRelationshipEnum = 95
  optional specificHost String = 96
  optional hostSpecRange Integer = 97
  optional trophicLevel TrophicLevelEnum = 98
  optional propagation String = 99
  isolGrowthCondt String = 100
  optional sampCollecDevice String = 101
  optional sampCollecMethod String = 102
  optional sampMatProcess String = 103
  optional sampSize QuantityValue = 104
  optional nuclAcidExt String = 105
  optional nuclAcidAmp String = 106
  optional libSize Integer = 107
  optional libReadsSeqd Integer = 108
  optional libLayout LibLayoutEnum = 109
  optional libVector String = 110
  optional libScreen String = 111
  optional adapters String = 112
  seqMeth String = 113
  optional taxIdent TaxIdentEnum = 114
  assemblyQual AssemblyQualEnum = 115
  optional assemblyName String = 116
  assemblySoftware String = 117
  optional annot String = 118
  numberContig Integer = 119
  optional featPred String = 120
  optional refDb String = 121
  optional simSearchMeth String = 122
  optional taxClass String = 123
  optional complScore String = 124
  optional complSoftware String = 125
  optional associatedResource String = 126
  optional sop String = 127
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: org with environmental package plant-associated
message Plant-associatedMIGSOrg
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated airTempRegm String = 11
  optional ancesData String = 12
  repeated antibioticRegm String = 13
  optional biolStat BiolStatEnum = 14
  optional bioticRegm String = 15
  repeated chemAdministration String = 16
  repeated chemMutagen String = 17
  repeated climateEnvironment String = 18
  optional cultRootMed String = 19
  repeated fertilizerRegm String = 20
  repeated fungicideRegm String = 21
  repeated gaseousEnvironment String = 22
  optional geneticMod String = 23
  repeated gravity String = 24
  optional growthFacil String = 25
  optional growthHabit GrowthHabitEnum = 26
  repeated growthHormoneRegm String = 27
  repeated herbicideRegm String = 28
  optional hostAge QuantityValue = 29
  optional hostCommonName String = 30
  optional hostDryMass QuantityValue = 31
  optional hostGenotype String = 32
  optional hostHeight QuantityValue = 33
  repeated hostSubspecfGenlin String = 34
  optional hostLength QuantityValue = 35
  optional hostLifeStage String = 36
  optional hostPhenotype String = 37
  optional hostTaxid String = 38
  optional hostTotMass QuantityValue = 39
  optional hostWetMass QuantityValue = 40
  repeated humidityRegm String = 41
  optional lightRegm String = 42
  repeated mechanicalDamage String = 43
  repeated mineralNutrRegm String = 44
  repeated nonMinNutrRegm String = 45
  repeated organismCount OrganismCountEnum = 46
  optional oxyStatSamp OxyStatSampEnum = 47
  repeated phRegm String = 48
  repeated perturbation String = 49
  repeated pesticideRegm String = 50
  optional plantGrowthMed PlantGrowthMedEnum = 51
  optional plantProduct String = 52
  optional plantSex PlantSexEnum = 53
  optional plantStruc String = 54
  repeated radiationRegm String = 55
  repeated rainfallRegm String = 56
  optional rootCond String = 57
  optional rootMedCarbon String = 58
  optional rootMedMacronutr String = 59
  optional rootMedMicronutr String = 60
  optional rootMedSuppl String = 61
  optional rootMedPh Double = 62
  optional rootMedRegl String = 63
  optional rootMedSolid String = 64
  repeated saltRegm String = 65
  optional sampCaptStatus SampCaptStatusEnum = 66
  optional sampDisStage SampDisStageEnum = 67
  optional salinity QuantityValue = 68
  optional sampStoreDur String = 69
  optional sampStoreLoc String = 70
  optional sampStoreTemp QuantityValue = 71
  repeated seasonEnvironment String = 72
  repeated standingWaterRegm String = 73
  optional tissCultGrowthMed String = 74
  repeated waterTempRegm String = 75
  repeated wateringRegm String = 76
  repeated hostSymbiont String = 77
  repeated miscParam String = 78
  sampName String = 79
  projectName String = 80
  optional hostDiseaseStat String = 81
  optional sampVolWeDnaExt QuantityValue = 82
  sampTaxonId String = 83
  optional experimentalFactor String = 84
  optional negContType NegContTypeEnum = 85
  optional posContType String = 86
  optional subspecfGenLin String = 87
  optional extrachromElements Integer = 88
  optional estimatedSize String = 89
  optional refBiomaterial String = 90
  optional sourceMatId String = 91
  isolGrowthCondt String = 92
  optional sampCollecDevice String = 93
  optional sampCollecMethod String = 94
  optional sampMatProcess String = 95
  optional sampSize QuantityValue = 96
  optional nuclAcidExt String = 97
  optional nuclAcidAmp String = 98
  optional libSize Integer = 99
  optional libReadsSeqd Integer = 100
  optional libLayout LibLayoutEnum = 101
  optional libVector String = 102
  optional libScreen String = 103
  optional adapters String = 104
  seqMeth String = 105
  optional taxIdent TaxIdentEnum = 106
  optional assemblyQual AssemblyQualEnum = 107
  optional assemblyName String = 108
  assemblySoftware String = 109
  optional annot String = 110
  optional numberContig Integer = 111
  optional featPred String = 112
  optional refDb String = 113
  optional simSearchMeth String = 114
  optional taxClass String = 115
  optional complScore String = 116
  optional complSoftware String = 117
  optional associatedResource String = 118
  optional sop String = 119
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: plant with environmental package plant-associated
message Plant-associatedMIGSPlant
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated airTempRegm String = 11
  optional ancesData String = 12
  repeated antibioticRegm String = 13
  optional biolStat BiolStatEnum = 14
  optional bioticRegm String = 15
  repeated chemAdministration String = 16
  repeated chemMutagen String = 17
  repeated climateEnvironment String = 18
  optional cultRootMed String = 19
  repeated fertilizerRegm String = 20
  repeated fungicideRegm String = 21
  repeated gaseousEnvironment String = 22
  optional geneticMod String = 23
  repeated gravity String = 24
  optional growthFacil String = 25
  optional growthHabit GrowthHabitEnum = 26
  repeated growthHormoneRegm String = 27
  repeated herbicideRegm String = 28
  optional hostAge QuantityValue = 29
  optional hostCommonName String = 30
  optional hostDryMass QuantityValue = 31
  optional hostGenotype String = 32
  optional hostHeight QuantityValue = 33
  repeated hostSubspecfGenlin String = 34
  optional hostLength QuantityValue = 35
  optional hostLifeStage String = 36
  optional hostPhenotype String = 37
  optional hostTaxid String = 38
  optional hostTotMass QuantityValue = 39
  optional hostWetMass QuantityValue = 40
  repeated humidityRegm String = 41
  optional lightRegm String = 42
  repeated mechanicalDamage String = 43
  repeated mineralNutrRegm String = 44
  repeated nonMinNutrRegm String = 45
  repeated organismCount OrganismCountEnum = 46
  optional oxyStatSamp OxyStatSampEnum = 47
  repeated phRegm String = 48
  repeated perturbation String = 49
  repeated pesticideRegm String = 50
  optional plantGrowthMed PlantGrowthMedEnum = 51
  optional plantProduct String = 52
  optional plantSex PlantSexEnum = 53
  optional plantStruc String = 54
  repeated radiationRegm String = 55
  repeated rainfallRegm String = 56
  optional rootCond String = 57
  optional rootMedCarbon String = 58
  optional rootMedMacronutr String = 59
  optional rootMedMicronutr String = 60
  optional rootMedSuppl String = 61
  optional rootMedPh Double = 62
  optional rootMedRegl String = 63
  optional rootMedSolid String = 64
  repeated saltRegm String = 65
  optional sampCaptStatus SampCaptStatusEnum = 66
  optional sampDisStage SampDisStageEnum = 67
  optional salinity QuantityValue = 68
  optional sampStoreDur String = 69
  optional sampStoreLoc String = 70
  optional sampStoreTemp QuantityValue = 71
  repeated seasonEnvironment String = 72
  repeated standingWaterRegm String = 73
  optional tissCultGrowthMed String = 74
  repeated waterTempRegm String = 75
  repeated wateringRegm String = 76
  repeated hostSymbiont String = 77
  repeated miscParam String = 78
  sampName String = 79
  projectName String = 80
  optional hostDiseaseStat String = 81
  optional sampVolWeDnaExt QuantityValue = 82
  sampTaxonId String = 83
  optional experimentalFactor String = 84
  optional negContType NegContTypeEnum = 85
  optional posContType String = 86
  optional subspecfGenLin String = 87
  optional estimatedSize String = 88
  optional refBiomaterial String = 89
  optional sourceMatId String = 90
  optional specificHost String = 91
  optional hostSpecRange Integer = 92
  propagation String = 93
  optional encodedTraits String = 94
  isolGrowthCondt String = 95
  optional sampCollecDevice String = 96
  optional sampCollecMethod String = 97
  optional sampMatProcess String = 98
  optional sampSize QuantityValue = 99
  optional nuclAcidExt String = 100
  optional nuclAcidAmp String = 101
  optional libSize Integer = 102
  optional libReadsSeqd Integer = 103
  optional libLayout LibLayoutEnum = 104
  optional libVector String = 105
  optional libScreen String = 106
  optional adapters String = 107
  seqMeth String = 108
  optional taxIdent TaxIdentEnum = 109
  optional assemblyQual AssemblyQualEnum = 110
  optional assemblyName String = 111
  assemblySoftware String = 112
  optional annot String = 113
  optional numberContig Integer = 114
  optional featPred String = 115
  optional refDb String = 116
  optional simSearchMeth String = 117
  optional taxClass String = 118
  optional complScore String = 119
  optional complSoftware String = 120
  optional associatedResource String = 121
  optional sop String = 122
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package plant-associated
message Plant-associatedMIGSVirus
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated airTempRegm String = 11
  optional ancesData String = 12
  repeated antibioticRegm String = 13
  optional biolStat BiolStatEnum = 14
  optional bioticRegm String = 15
  repeated chemAdministration String = 16
  repeated chemMutagen String = 17
  repeated climateEnvironment String = 18
  optional cultRootMed String = 19
  repeated fertilizerRegm String = 20
  repeated fungicideRegm String = 21
  repeated gaseousEnvironment String = 22
  optional geneticMod String = 23
  repeated gravity String = 24
  optional growthFacil String = 25
  optional growthHabit GrowthHabitEnum = 26
  repeated growthHormoneRegm String = 27
  repeated herbicideRegm String = 28
  optional hostAge QuantityValue = 29
  optional hostCommonName String = 30
  optional hostDryMass QuantityValue = 31
  optional hostGenotype String = 32
  optional hostHeight QuantityValue = 33
  repeated hostSubspecfGenlin String = 34
  optional hostLength QuantityValue = 35
  optional hostLifeStage String = 36
  optional hostPhenotype String = 37
  optional hostTaxid String = 38
  optional hostTotMass QuantityValue = 39
  optional hostWetMass QuantityValue = 40
  repeated humidityRegm String = 41
  optional lightRegm String = 42
  repeated mechanicalDamage String = 43
  repeated mineralNutrRegm String = 44
  repeated nonMinNutrRegm String = 45
  repeated organismCount OrganismCountEnum = 46
  optional oxyStatSamp OxyStatSampEnum = 47
  repeated phRegm String = 48
  repeated perturbation String = 49
  repeated pesticideRegm String = 50
  optional plantGrowthMed PlantGrowthMedEnum = 51
  optional plantProduct String = 52
  optional plantSex PlantSexEnum = 53
  optional plantStruc String = 54
  repeated radiationRegm String = 55
  repeated rainfallRegm String = 56
  optional rootCond String = 57
  optional rootMedCarbon String = 58
  optional rootMedMacronutr String = 59
  optional rootMedMicronutr String = 60
  optional rootMedSuppl String = 61
  optional rootMedPh Double = 62
  optional rootMedRegl String = 63
  optional rootMedSolid String = 64
  repeated saltRegm String = 65
  optional sampCaptStatus SampCaptStatusEnum = 66
  optional sampDisStage SampDisStageEnum = 67
  optional salinity QuantityValue = 68
  optional sampStoreDur String = 69
  optional sampStoreLoc String = 70
  optional sampStoreTemp QuantityValue = 71
  repeated seasonEnvironment String = 72
  repeated standingWaterRegm String = 73
  optional tissCultGrowthMed String = 74
  repeated waterTempRegm String = 75
  repeated wateringRegm String = 76
  repeated hostSymbiont String = 77
  repeated miscParam String = 78
  sampName String = 79
  projectName String = 80
  optional hostDiseaseStat String = 81
  optional sampVolWeDnaExt QuantityValue = 82
  sampTaxonId String = 83
  optional experimentalFactor String = 84
  optional negContType NegContTypeEnum = 85
  optional posContType String = 86
  optional subspecfGenLin String = 87
  optional numReplicons Integer = 88
  optional estimatedSize String = 89
  optional refBiomaterial String = 90
  optional sourceMatId String = 91
  optional pathogenicity String = 92
  optional bioticRelationship BioticRelationshipEnum = 93
  optional specificHost String = 94
  optional hostSpecRange Integer = 95
  propagation String = 96
  optional encodedTraits String = 97
  isolGrowthCondt String = 98
  optional sampCollecDevice String = 99
  optional sampCollecMethod String = 100
  optional sampMatProcess String = 101
  optional sampSize QuantityValue = 102
  optional virusEnrichAppr VirusEnrichApprEnum = 103
  optional nuclAcidExt String = 104
  optional nuclAcidAmp String = 105
  optional libSize Integer = 106
  optional libReadsSeqd Integer = 107
  optional libLayout LibLayoutEnum = 108
  optional libVector String = 109
  optional libScreen String = 110
  optional adapters String = 111
  seqMeth String = 112
  optional taxIdent TaxIdentEnum = 113
  optional assemblyQual AssemblyQualEnum = 114
  optional assemblyName String = 115
  assemblySoftware String = 116
  optional annot String = 117
  optional numberContig Integer = 118
  optional featPred String = 119
  optional refDb String = 120
  optional simSearchMeth String = 121
  optional taxClass String = 122
  optional complScore String = 123
  optional complSoftware String = 124
  optional associatedResource String = 125
  optional sop String = 126
 }
// Combinatorial checklist Minimum Information About a Metagenome-Assembled Genome with environmental package plant-associated
message Plant-associatedMIMAG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated airTempRegm String = 11
  optional ancesData String = 12
  repeated antibioticRegm String = 13
  optional biolStat BiolStatEnum = 14
  optional bioticRegm String = 15
  repeated chemAdministration String = 16
  repeated chemMutagen String = 17
  repeated climateEnvironment String = 18
  optional cultRootMed String = 19
  repeated fertilizerRegm String = 20
  repeated fungicideRegm String = 21
  repeated gaseousEnvironment String = 22
  optional geneticMod String = 23
  repeated gravity String = 24
  optional growthFacil String = 25
  optional growthHabit GrowthHabitEnum = 26
  repeated growthHormoneRegm String = 27
  repeated herbicideRegm String = 28
  optional hostAge QuantityValue = 29
  optional hostCommonName String = 30
  optional hostDryMass QuantityValue = 31
  optional hostGenotype String = 32
  optional hostHeight QuantityValue = 33
  repeated hostSubspecfGenlin String = 34
  optional hostLength QuantityValue = 35
  optional hostLifeStage String = 36
  optional hostPhenotype String = 37
  optional hostTaxid String = 38
  optional hostTotMass QuantityValue = 39
  optional hostWetMass QuantityValue = 40
  repeated humidityRegm String = 41
  optional lightRegm String = 42
  repeated mechanicalDamage String = 43
  repeated mineralNutrRegm String = 44
  repeated nonMinNutrRegm String = 45
  repeated organismCount OrganismCountEnum = 46
  optional oxyStatSamp OxyStatSampEnum = 47
  repeated phRegm String = 48
  repeated perturbation String = 49
  repeated pesticideRegm String = 50
  optional plantGrowthMed PlantGrowthMedEnum = 51
  optional plantProduct String = 52
  optional plantSex PlantSexEnum = 53
  optional plantStruc String = 54
  repeated radiationRegm String = 55
  repeated rainfallRegm String = 56
  optional rootCond String = 57
  optional rootMedCarbon String = 58
  optional rootMedMacronutr String = 59
  optional rootMedMicronutr String = 60
  optional rootMedSuppl String = 61
  optional rootMedPh Double = 62
  optional rootMedRegl String = 63
  optional rootMedSolid String = 64
  repeated saltRegm String = 65
  optional sampCaptStatus SampCaptStatusEnum = 66
  optional sampDisStage SampDisStageEnum = 67
  optional salinity QuantityValue = 68
  optional sampStoreDur String = 69
  optional sampStoreLoc String = 70
  optional sampStoreTemp QuantityValue = 71
  repeated seasonEnvironment String = 72
  repeated standingWaterRegm String = 73
  optional tissCultGrowthMed String = 74
  repeated waterTempRegm String = 75
  repeated wateringRegm String = 76
  repeated hostSymbiont String = 77
  repeated miscParam String = 78
  sampName String = 79
  projectName String = 80
  optional hostDiseaseStat String = 81
  optional sampVolWeDnaExt QuantityValue = 82
  sampTaxonId String = 83
  optional experimentalFactor String = 84
  optional negContType NegContTypeEnum = 85
  optional posContType String = 86
  optional refBiomaterial String = 87
  optional sourceMatId String = 88
  optional relToOxygen RelToOxygenEnum = 89
  optional sampCollecDevice String = 90
  optional sampCollecMethod String = 91
  optional sampMatProcess String = 92
  optional sizeFrac String = 93
  optional sampSize QuantityValue = 94
  optional nuclAcidExt String = 95
  optional nuclAcidAmp String = 96
  optional libSize Integer = 97
  optional libReadsSeqd Integer = 98
  optional libLayout LibLayoutEnum = 99
  optional libVector String = 100
  optional libScreen String = 101
  optional mid String = 102
  optional adapters String = 103
  seqMeth String = 104
  taxIdent TaxIdentEnum = 105
  assemblyQual AssemblyQualEnum = 106
  optional assemblyName String = 107
  assemblySoftware String = 108
  optional annot String = 109
  optional numberContig Integer = 110
  optional featPred String = 111
  optional refDb String = 112
  optional simSearchMeth String = 113
  optional taxClass String = 114
  optional x16sRecover String = 115
  optional x16sRecoverSoftware String = 116
  optional trnas Integer = 117
  optional trnaExtSoftware String = 118
  complScore String = 119
  complSoftware String = 120
  optional complAppr ComplApprEnum = 121
  contamScore String = 122
  optional contamScreenInput String = 123
  optional contamScreenParam String = 124
  optional decontamSoftware DecontamSoftwareEnum = 125
  binParam BinParamEnum = 126
  binSoftware String = 127
  optional reassemblyBin String = 128
  optional magCovSoftware MagCovSoftwareEnum = 129
  optional associatedResource String = 130
  optional sop String = 131
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: specimen with environmental package plant-associated
message Plant-associatedMIMARKSSpecimen
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated airTempRegm String = 11
  optional ancesData String = 12
  repeated antibioticRegm String = 13
  optional biolStat BiolStatEnum = 14
  optional bioticRegm String = 15
  repeated chemAdministration String = 16
  repeated chemMutagen String = 17
  repeated climateEnvironment String = 18
  optional cultRootMed String = 19
  repeated fertilizerRegm String = 20
  repeated fungicideRegm String = 21
  repeated gaseousEnvironment String = 22
  optional geneticMod String = 23
  repeated gravity String = 24
  optional growthFacil String = 25
  optional growthHabit GrowthHabitEnum = 26
  repeated growthHormoneRegm String = 27
  repeated herbicideRegm String = 28
  optional hostAge QuantityValue = 29
  optional hostCommonName String = 30
  optional hostDryMass QuantityValue = 31
  optional hostGenotype String = 32
  optional hostHeight QuantityValue = 33
  repeated hostSubspecfGenlin String = 34
  optional hostLength QuantityValue = 35
  optional hostLifeStage String = 36
  optional hostPhenotype String = 37
  optional hostTaxid String = 38
  optional hostTotMass QuantityValue = 39
  optional hostWetMass QuantityValue = 40
  repeated humidityRegm String = 41
  optional lightRegm String = 42
  repeated mechanicalDamage String = 43
  repeated mineralNutrRegm String = 44
  repeated nonMinNutrRegm String = 45
  repeated organismCount OrganismCountEnum = 46
  optional oxyStatSamp OxyStatSampEnum = 47
  repeated phRegm String = 48
  repeated perturbation String = 49
  repeated pesticideRegm String = 50
  optional plantGrowthMed PlantGrowthMedEnum = 51
  optional plantProduct String = 52
  optional plantSex PlantSexEnum = 53
  optional plantStruc String = 54
  repeated radiationRegm String = 55
  repeated rainfallRegm String = 56
  optional rootCond String = 57
  optional rootMedCarbon String = 58
  optional rootMedMacronutr String = 59
  optional rootMedMicronutr String = 60
  optional rootMedSuppl String = 61
  optional rootMedPh Double = 62
  optional rootMedRegl String = 63
  optional rootMedSolid String = 64
  repeated saltRegm String = 65
  optional sampCaptStatus SampCaptStatusEnum = 66
  optional sampDisStage SampDisStageEnum = 67
  optional salinity QuantityValue = 68
  optional sampStoreDur String = 69
  optional sampStoreLoc String = 70
  optional sampStoreTemp QuantityValue = 71
  repeated seasonEnvironment String = 72
  repeated standingWaterRegm String = 73
  optional tissCultGrowthMed String = 74
  repeated waterTempRegm String = 75
  repeated wateringRegm String = 76
  repeated hostSymbiont String = 77
  repeated miscParam String = 78
  sampName String = 79
  projectName String = 80
  optional hostDiseaseStat String = 81
  optional sampVolWeDnaExt QuantityValue = 82
  sampTaxonId String = 83
  optional experimentalFactor String = 84
  optional negContType NegContTypeEnum = 85
  optional posContType String = 86
  optional sourceMatId String = 87
  optional relToOxygen RelToOxygenEnum = 88
  optional sampCollecDevice String = 89
  optional sampCollecMethod String = 90
  optional sampMatProcess String = 91
  optional sizeFrac String = 92
  optional sampSize QuantityValue = 93
  optional nuclAcidExt String = 94
  optional nuclAcidAmp String = 95
  optional libSize Integer = 96
  optional libReadsSeqd Integer = 97
  optional libLayout LibLayoutEnum = 98
  optional libVector String = 99
  optional libScreen String = 100
  targetGene String = 101
  optional targetSubfragment String = 102
  optional pcrPrimers String = 103
  optional mid String = 104
  optional adapters String = 105
  optional pcrCond String = 106
  seqMeth String = 107
  optional seqQualityCheck String = 108
  optional chimeraCheck String = 109
  optional assemblySoftware String = 110
  optional associatedResource String = 111
  optional sop String = 112
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: survey with environmental package plant-associated
message Plant-associatedMIMARKSSurvey
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated airTempRegm String = 11
  optional ancesData String = 12
  repeated antibioticRegm String = 13
  optional biolStat BiolStatEnum = 14
  optional bioticRegm String = 15
  repeated chemAdministration String = 16
  repeated chemMutagen String = 17
  repeated climateEnvironment String = 18
  optional cultRootMed String = 19
  repeated fertilizerRegm String = 20
  repeated fungicideRegm String = 21
  repeated gaseousEnvironment String = 22
  optional geneticMod String = 23
  repeated gravity String = 24
  optional growthFacil String = 25
  optional growthHabit GrowthHabitEnum = 26
  repeated growthHormoneRegm String = 27
  repeated herbicideRegm String = 28
  optional hostAge QuantityValue = 29
  optional hostCommonName String = 30
  optional hostDryMass QuantityValue = 31
  optional hostGenotype String = 32
  optional hostHeight QuantityValue = 33
  repeated hostSubspecfGenlin String = 34
  optional hostLength QuantityValue = 35
  optional hostLifeStage String = 36
  optional hostPhenotype String = 37
  optional hostTaxid String = 38
  optional hostTotMass QuantityValue = 39
  optional hostWetMass QuantityValue = 40
  repeated humidityRegm String = 41
  optional lightRegm String = 42
  repeated mechanicalDamage String = 43
  repeated mineralNutrRegm String = 44
  repeated nonMinNutrRegm String = 45
  repeated organismCount OrganismCountEnum = 46
  optional oxyStatSamp OxyStatSampEnum = 47
  repeated phRegm String = 48
  repeated perturbation String = 49
  repeated pesticideRegm String = 50
  optional plantGrowthMed PlantGrowthMedEnum = 51
  optional plantProduct String = 52
  optional plantSex PlantSexEnum = 53
  optional plantStruc String = 54
  repeated radiationRegm String = 55
  repeated rainfallRegm String = 56
  optional rootCond String = 57
  optional rootMedCarbon String = 58
  optional rootMedMacronutr String = 59
  optional rootMedMicronutr String = 60
  optional rootMedSuppl String = 61
  optional rootMedPh Double = 62
  optional rootMedRegl String = 63
  optional rootMedSolid String = 64
  repeated saltRegm String = 65
  optional sampCaptStatus SampCaptStatusEnum = 66
  optional sampDisStage SampDisStageEnum = 67
  optional salinity QuantityValue = 68
  optional sampStoreDur String = 69
  optional sampStoreLoc String = 70
  optional sampStoreTemp QuantityValue = 71
  repeated seasonEnvironment String = 72
  repeated standingWaterRegm String = 73
  optional tissCultGrowthMed String = 74
  repeated waterTempRegm String = 75
  repeated wateringRegm String = 76
  repeated hostSymbiont String = 77
  repeated miscParam String = 78
  sampName String = 79
  projectName String = 80
  optional hostDiseaseStat String = 81
  optional sampVolWeDnaExt QuantityValue = 82
  sampTaxonId String = 83
  optional experimentalFactor String = 84
  optional negContType NegContTypeEnum = 85
  optional posContType String = 86
  optional subspecfGenLin String = 87
  optional extrachromElements Integer = 88
  optional sourceMatId String = 89
  optional bioticRelationship BioticRelationshipEnum = 90
  optional trophicLevel TrophicLevelEnum = 91
  optional relToOxygen RelToOxygenEnum = 92
  isolGrowthCondt String = 93
  optional sampCollecDevice String = 94
  optional sampCollecMethod String = 95
  optional sampMatProcess String = 96
  optional sampSize QuantityValue = 97
  optional nuclAcidExt String = 98
  optional nuclAcidAmp String = 99
  targetGene String = 100
  optional targetSubfragment String = 101
  optional pcrPrimers String = 102
  optional pcrCond String = 103
  seqMeth String = 104
  optional seqQualityCheck String = 105
  optional chimeraCheck String = 106
  optional associatedResource String = 107
  optional sop String = 108
 }
// Combinatorial checklist Metagenome or Environmental with environmental package plant-associated
message Plant-associatedMIMS
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated airTempRegm String = 11
  optional ancesData String = 12
  repeated antibioticRegm String = 13
  optional biolStat BiolStatEnum = 14
  optional bioticRegm String = 15
  repeated chemAdministration String = 16
  repeated chemMutagen String = 17
  repeated climateEnvironment String = 18
  optional cultRootMed String = 19
  repeated fertilizerRegm String = 20
  repeated fungicideRegm String = 21
  repeated gaseousEnvironment String = 22
  optional geneticMod String = 23
  repeated gravity String = 24
  optional growthFacil String = 25
  optional growthHabit GrowthHabitEnum = 26
  repeated growthHormoneRegm String = 27
  repeated herbicideRegm String = 28
  optional hostAge QuantityValue = 29
  optional hostCommonName String = 30
  optional hostDryMass QuantityValue = 31
  optional hostGenotype String = 32
  optional hostHeight QuantityValue = 33
  repeated hostSubspecfGenlin String = 34
  optional hostLength QuantityValue = 35
  optional hostLifeStage String = 36
  optional hostPhenotype String = 37
  optional hostTaxid String = 38
  optional hostTotMass QuantityValue = 39
  optional hostWetMass QuantityValue = 40
  repeated humidityRegm String = 41
  optional lightRegm String = 42
  repeated mechanicalDamage String = 43
  repeated mineralNutrRegm String = 44
  repeated nonMinNutrRegm String = 45
  repeated organismCount OrganismCountEnum = 46
  optional oxyStatSamp OxyStatSampEnum = 47
  repeated phRegm String = 48
  repeated perturbation String = 49
  repeated pesticideRegm String = 50
  optional plantGrowthMed PlantGrowthMedEnum = 51
  optional plantProduct String = 52
  optional plantSex PlantSexEnum = 53
  optional plantStruc String = 54
  repeated radiationRegm String = 55
  repeated rainfallRegm String = 56
  optional rootCond String = 57
  optional rootMedCarbon String = 58
  optional rootMedMacronutr String = 59
  optional rootMedMicronutr String = 60
  optional rootMedSuppl String = 61
  optional rootMedPh Double = 62
  optional rootMedRegl String = 63
  optional rootMedSolid String = 64
  repeated saltRegm String = 65
  optional sampCaptStatus SampCaptStatusEnum = 66
  optional sampDisStage SampDisStageEnum = 67
  optional salinity QuantityValue = 68
  optional sampStoreDur String = 69
  optional sampStoreLoc String = 70
  optional sampStoreTemp QuantityValue = 71
  repeated seasonEnvironment String = 72
  repeated standingWaterRegm String = 73
  optional tissCultGrowthMed String = 74
  repeated waterTempRegm String = 75
  repeated wateringRegm String = 76
  repeated hostSymbiont String = 77
  repeated miscParam String = 78
  sampName String = 79
  projectName String = 80
  optional hostDiseaseStat String = 81
  optional sampVolWeDnaExt QuantityValue = 82
  sampTaxonId String = 83
  optional experimentalFactor String = 84
  optional negContType NegContTypeEnum = 85
  optional posContType String = 86
  optional refBiomaterial String = 87
  optional sourceMatId String = 88
  optional relToOxygen RelToOxygenEnum = 89
  optional sampCollecDevice String = 90
  optional sampCollecMethod String = 91
  optional sampMatProcess String = 92
  optional sizeFrac String = 93
  optional sampSize QuantityValue = 94
  optional nuclAcidExt String = 95
  optional nuclAcidAmp String = 96
  optional libSize Integer = 97
  optional libReadsSeqd Integer = 98
  optional libLayout LibLayoutEnum = 99
  optional libVector String = 100
  optional libScreen String = 101
  optional mid String = 102
  optional adapters String = 103
  seqMeth String = 104
  optional assemblyQual AssemblyQualEnum = 105
  optional assemblyName String = 106
  optional assemblySoftware String = 107
  optional annot String = 108
  optional numberContig Integer = 109
  optional featPred String = 110
  optional refDb String = 111
  optional simSearchMeth String = 112
  optional taxClass String = 113
  optional associatedResource String = 114
  optional sop String = 115
 }
// Combinatorial checklist Minimum Information About a Single Amplified Genome with environmental package plant-associated
message Plant-associatedMISAG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated airTempRegm String = 11
  optional ancesData String = 12
  repeated antibioticRegm String = 13
  optional biolStat BiolStatEnum = 14
  optional bioticRegm String = 15
  repeated chemAdministration String = 16
  repeated chemMutagen String = 17
  repeated climateEnvironment String = 18
  optional cultRootMed String = 19
  repeated fertilizerRegm String = 20
  repeated fungicideRegm String = 21
  repeated gaseousEnvironment String = 22
  optional geneticMod String = 23
  repeated gravity String = 24
  optional growthFacil String = 25
  optional growthHabit GrowthHabitEnum = 26
  repeated growthHormoneRegm String = 27
  repeated herbicideRegm String = 28
  optional hostAge QuantityValue = 29
  optional hostCommonName String = 30
  optional hostDryMass QuantityValue = 31
  optional hostGenotype String = 32
  optional hostHeight QuantityValue = 33
  repeated hostSubspecfGenlin String = 34
  optional hostLength QuantityValue = 35
  optional hostLifeStage String = 36
  optional hostPhenotype String = 37
  optional hostTaxid String = 38
  optional hostTotMass QuantityValue = 39
  optional hostWetMass QuantityValue = 40
  repeated humidityRegm String = 41
  optional lightRegm String = 42
  repeated mechanicalDamage String = 43
  repeated mineralNutrRegm String = 44
  repeated nonMinNutrRegm String = 45
  repeated organismCount OrganismCountEnum = 46
  optional oxyStatSamp OxyStatSampEnum = 47
  repeated phRegm String = 48
  repeated perturbation String = 49
  repeated pesticideRegm String = 50
  optional plantGrowthMed PlantGrowthMedEnum = 51
  optional plantProduct String = 52
  optional plantSex PlantSexEnum = 53
  optional plantStruc String = 54
  repeated radiationRegm String = 55
  repeated rainfallRegm String = 56
  optional rootCond String = 57
  optional rootMedCarbon String = 58
  optional rootMedMacronutr String = 59
  optional rootMedMicronutr String = 60
  optional rootMedSuppl String = 61
  optional rootMedPh Double = 62
  optional rootMedRegl String = 63
  optional rootMedSolid String = 64
  repeated saltRegm String = 65
  optional sampCaptStatus SampCaptStatusEnum = 66
  optional sampDisStage SampDisStageEnum = 67
  optional salinity QuantityValue = 68
  optional sampStoreDur String = 69
  optional sampStoreLoc String = 70
  optional sampStoreTemp QuantityValue = 71
  repeated seasonEnvironment String = 72
  repeated standingWaterRegm String = 73
  optional tissCultGrowthMed String = 74
  repeated waterTempRegm String = 75
  repeated wateringRegm String = 76
  repeated hostSymbiont String = 77
  repeated miscParam String = 78
  sampName String = 79
  projectName String = 80
  optional hostDiseaseStat String = 81
  optional sampVolWeDnaExt QuantityValue = 82
  sampTaxonId String = 83
  optional experimentalFactor String = 84
  optional negContType NegContTypeEnum = 85
  optional posContType String = 86
  optional refBiomaterial String = 87
  optional sourceMatId String = 88
  optional relToOxygen RelToOxygenEnum = 89
  optional sampCollecDevice String = 90
  optional sampCollecMethod String = 91
  optional sampMatProcess String = 92
  optional sizeFrac String = 93
  optional sampSize QuantityValue = 94
  optional nuclAcidExt String = 95
  optional nuclAcidAmp String = 96
  optional libSize Integer = 97
  optional libReadsSeqd Integer = 98
  optional libLayout LibLayoutEnum = 99
  optional libVector String = 100
  optional libScreen String = 101
  optional mid String = 102
  optional adapters String = 103
  seqMeth String = 104
  taxIdent TaxIdentEnum = 105
  assemblyQual AssemblyQualEnum = 106
  optional assemblyName String = 107
  assemblySoftware String = 108
  optional annot String = 109
  optional numberContig Integer = 110
  optional featPred String = 111
  optional refDb String = 112
  optional simSearchMeth String = 113
  optional taxClass String = 114
  optional x16sRecover String = 115
  optional x16sRecoverSoftware String = 116
  optional trnas Integer = 117
  optional trnaExtSoftware String = 118
  complScore String = 119
  complSoftware String = 120
  optional complAppr ComplApprEnum = 121
  contamScore String = 122
  optional contamScreenInput String = 123
  optional contamScreenParam String = 124
  optional decontamSoftware DecontamSoftwareEnum = 125
  sortTech SortTechEnum = 126
  singleCellLysisAppr SingleCellLysisApprEnum = 127
  optional singleCellLysisProt String = 128
  wgaAmpAppr String = 129
  optional wgaAmpKit String = 130
  optional associatedResource String = 131
  optional sop String = 132
 }
// Combinatorial checklist Minimum Information About an Uncultivated Virus Genome with environmental package plant-associated
message Plant-associatedMIUVIG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  repeated airTempRegm String = 11
  optional ancesData String = 12
  repeated antibioticRegm String = 13
  optional biolStat BiolStatEnum = 14
  optional bioticRegm String = 15
  repeated chemAdministration String = 16
  repeated chemMutagen String = 17
  repeated climateEnvironment String = 18
  optional cultRootMed String = 19
  repeated fertilizerRegm String = 20
  repeated fungicideRegm String = 21
  repeated gaseousEnvironment String = 22
  optional geneticMod String = 23
  repeated gravity String = 24
  optional growthFacil String = 25
  optional growthHabit GrowthHabitEnum = 26
  repeated growthHormoneRegm String = 27
  repeated herbicideRegm String = 28
  optional hostAge QuantityValue = 29
  optional hostCommonName String = 30
  optional hostDryMass QuantityValue = 31
  optional hostGenotype String = 32
  optional hostHeight QuantityValue = 33
  repeated hostSubspecfGenlin String = 34
  optional hostLength QuantityValue = 35
  optional hostLifeStage String = 36
  optional hostPhenotype String = 37
  optional hostTaxid String = 38
  optional hostTotMass QuantityValue = 39
  optional hostWetMass QuantityValue = 40
  repeated humidityRegm String = 41
  optional lightRegm String = 42
  repeated mechanicalDamage String = 43
  repeated mineralNutrRegm String = 44
  repeated nonMinNutrRegm String = 45
  repeated organismCount OrganismCountEnum = 46
  optional oxyStatSamp OxyStatSampEnum = 47
  repeated phRegm String = 48
  repeated perturbation String = 49
  repeated pesticideRegm String = 50
  optional plantGrowthMed PlantGrowthMedEnum = 51
  optional plantProduct String = 52
  optional plantSex PlantSexEnum = 53
  optional plantStruc String = 54
  repeated radiationRegm String = 55
  repeated rainfallRegm String = 56
  optional rootCond String = 57
  optional rootMedCarbon String = 58
  optional rootMedMacronutr String = 59
  optional rootMedMicronutr String = 60
  optional rootMedSuppl String = 61
  optional rootMedPh Double = 62
  optional rootMedRegl String = 63
  optional rootMedSolid String = 64
  repeated saltRegm String = 65
  optional sampCaptStatus SampCaptStatusEnum = 66
  optional sampDisStage SampDisStageEnum = 67
  optional salinity QuantityValue = 68
  optional sampStoreDur String = 69
  optional sampStoreLoc String = 70
  optional sampStoreTemp QuantityValue = 71
  repeated seasonEnvironment String = 72
  repeated standingWaterRegm String = 73
  optional tissCultGrowthMed String = 74
  repeated waterTempRegm String = 75
  repeated wateringRegm String = 76
  repeated hostSymbiont String = 77
  repeated miscParam String = 78
  sampName String = 79
  projectName String = 80
  optional hostDiseaseStat String = 81
  optional sampVolWeDnaExt QuantityValue = 82
  sampTaxonId String = 83
  optional experimentalFactor String = 84
  optional negContType NegContTypeEnum = 85
  optional posContType String = 86
  optional estimatedSize String = 87
  optional refBiomaterial String = 88
  optional sourceMatId String = 89
  optional pathogenicity String = 90
  optional bioticRelationship BioticRelationshipEnum = 91
  optional specificHost String = 92
  optional hostSpecRange Integer = 93
  optional sampCollecDevice String = 94
  optional sampCollecMethod String = 95
  optional sampMatProcess String = 96
  optional sizeFrac String = 97
  optional sampSize QuantityValue = 98
  sourceUvig SourceUvigEnum = 99
  virusEnrichAppr VirusEnrichApprEnum = 100
  optional nuclAcidExt String = 101
  optional nuclAcidAmp String = 102
  optional libSize Integer = 103
  optional libReadsSeqd Integer = 104
  optional libLayout LibLayoutEnum = 105
  optional libVector String = 106
  optional libScreen String = 107
  optional mid String = 108
  optional adapters String = 109
  seqMeth String = 110
  optional taxIdent TaxIdentEnum = 111
  assemblyQual AssemblyQualEnum = 112
  optional assemblyName String = 113
  assemblySoftware String = 114
  optional annot String = 115
  numberContig Integer = 116
  optional featPred String = 117
  optional refDb String = 118
  optional simSearchMeth String = 119
  optional taxClass String = 120
  optional trnas Integer = 121
  optional trnaExtSoftware String = 122
  optional complScore String = 123
  optional complSoftware String = 124
  optional complAppr ComplApprEnum = 125
  optional sortTech SortTechEnum = 126
  optional singleCellLysisAppr SingleCellLysisApprEnum = 127
  optional singleCellLysisProt String = 128
  optional wgaAmpAppr String = 129
  optional wgaAmpKit String = 130
  optional binParam BinParamEnum = 131
  optional binSoftware String = 132
  optional reassemblyBin String = 133
  optional magCovSoftware MagCovSoftwareEnum = 134
  virIdentSoftware String = 135
  predGenomeType PredGenomeTypeEnum = 136
  predGenomeStruc PredGenomeStrucEnum = 137
  detecType String = 138
  optional otuClassAppr String = 139
  optional otuSeqCompAppr String = 140
  optional otuDb String = 141
  optional hostPredAppr HostPredApprEnum = 142
  optional hostPredEstAcc String = 143
  optional associatedResource String = 144
  optional sop String = 145
 }
// used to record a measurement
message QuantityValue
 {
  optional hasUnit String = 1
  optional hasNumericValue Double = 2
  optional hasRawValue String = 3
 }
// sediment
message Sediment
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkylDiethers QuantityValue = 12
  optional aminopeptAct QuantityValue = 13
  optional ammonium QuantityValue = 14
  optional bacteriaCarbProd QuantityValue = 15
  repeated biomass String = 16
  optional bishomohopanol QuantityValue = 17
  optional bromide QuantityValue = 18
  optional calcium QuantityValue = 19
  optional carbNitroRatio QuantityValue = 20
  repeated chemAdministration String = 21
  optional chloride QuantityValue = 22
  optional chlorophyll QuantityValue = 23
  optional density QuantityValue = 24
  repeated dietherLipids String = 25
  optional dissCarbDioxide QuantityValue = 26
  optional dissHydrogen QuantityValue = 27
  optional dissInorgCarb QuantityValue = 28
  optional dissOrgCarb QuantityValue = 29
  optional dissOrgNitro QuantityValue = 30
  optional dissOxygen QuantityValue = 31
  optional glucosidaseAct QuantityValue = 32
  optional magnesium QuantityValue = 33
  optional meanFrictVel QuantityValue = 34
  optional meanPeakFrictVel QuantityValue = 35
  optional methane QuantityValue = 36
  repeated miscParam String = 37
  repeated nAlkanes String = 38
  optional nitrate QuantityValue = 39
  optional nitrite QuantityValue = 40
  optional nitro QuantityValue = 41
  optional orgCarb QuantityValue = 42
  optional orgMatter QuantityValue = 43
  optional orgNitro QuantityValue = 44
  repeated organismCount OrganismCountEnum = 45
  optional oxyStatSamp OxyStatSampEnum = 46
  optional ph Double = 47
  repeated particleClass String = 48
  optional partOrgCarb QuantityValue = 49
  repeated perturbation String = 50
  optional petroleumHydrocarb QuantityValue = 51
  repeated phaeopigments String = 52
  optional phosphate QuantityValue = 53
  repeated phosplipidFattAcid String = 54
  optional porosity String = 55
  optional potassium QuantityValue = 56
  optional pressure QuantityValue = 57
  optional redoxPotential QuantityValue = 58
  optional salinity QuantityValue = 59
  optional sampStoreDur String = 60
  optional sampStoreLoc String = 61
  optional sampStoreTemp QuantityValue = 62
  optional sedimentType SedimentTypeEnum = 63
  optional silicate QuantityValue = 64
  optional sodium QuantityValue = 65
  optional sulfate QuantityValue = 66
  optional sulfide QuantityValue = 67
  optional tidalStage TidalStageEnum = 68
  optional totCarb QuantityValue = 69
  optional totDepthWaterCol QuantityValue = 70
  optional totNitroContent QuantityValue = 71
  optional totOrgCarb QuantityValue = 72
  optional turbidity QuantityValue = 73
  optional waterContent QuantityValue = 74
  sampName String = 75
  projectName String = 76
  optional sampVolWeDnaExt QuantityValue = 77
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package sediment
message SedimentMIGSBacteria
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkylDiethers QuantityValue = 12
  optional aminopeptAct QuantityValue = 13
  optional ammonium QuantityValue = 14
  optional bacteriaCarbProd QuantityValue = 15
  repeated biomass String = 16
  optional bishomohopanol QuantityValue = 17
  optional bromide QuantityValue = 18
  optional calcium QuantityValue = 19
  optional carbNitroRatio QuantityValue = 20
  repeated chemAdministration String = 21
  optional chloride QuantityValue = 22
  optional chlorophyll QuantityValue = 23
  optional density QuantityValue = 24
  repeated dietherLipids String = 25
  optional dissCarbDioxide QuantityValue = 26
  optional dissHydrogen QuantityValue = 27
  optional dissInorgCarb QuantityValue = 28
  optional dissOrgCarb QuantityValue = 29
  optional dissOrgNitro QuantityValue = 30
  optional dissOxygen QuantityValue = 31
  optional glucosidaseAct QuantityValue = 32
  optional magnesium QuantityValue = 33
  optional meanFrictVel QuantityValue = 34
  optional meanPeakFrictVel QuantityValue = 35
  optional methane QuantityValue = 36
  repeated miscParam String = 37
  repeated nAlkanes String = 38
  optional nitrate QuantityValue = 39
  optional nitrite QuantityValue = 40
  optional nitro QuantityValue = 41
  optional orgCarb QuantityValue = 42
  optional orgMatter QuantityValue = 43
  optional orgNitro QuantityValue = 44
  repeated organismCount OrganismCountEnum = 45
  optional oxyStatSamp OxyStatSampEnum = 46
  optional ph Double = 47
  repeated particleClass String = 48
  optional partOrgCarb QuantityValue = 49
  repeated perturbation String = 50
  optional petroleumHydrocarb QuantityValue = 51
  repeated phaeopigments String = 52
  optional phosphate QuantityValue = 53
  repeated phosplipidFattAcid String = 54
  optional porosity String = 55
  optional potassium QuantityValue = 56
  optional pressure QuantityValue = 57
  optional redoxPotential QuantityValue = 58
  optional salinity QuantityValue = 59
  optional sampStoreDur String = 60
  optional sampStoreLoc String = 61
  optional sampStoreTemp QuantityValue = 62
  optional sedimentType SedimentTypeEnum = 63
  optional silicate QuantityValue = 64
  optional sodium QuantityValue = 65
  optional sulfate QuantityValue = 66
  optional sulfide QuantityValue = 67
  optional tidalStage TidalStageEnum = 68
  optional totCarb QuantityValue = 69
  optional totDepthWaterCol QuantityValue = 70
  optional totNitroContent QuantityValue = 71
  optional totOrgCarb QuantityValue = 72
  optional turbidity QuantityValue = 73
  optional waterContent QuantityValue = 74
  sampName String = 75
  projectName String = 76
  optional sampVolWeDnaExt QuantityValue = 77
  sampTaxonId String = 78
  optional experimentalFactor String = 79
  optional negContType NegContTypeEnum = 80
  optional posContType String = 81
  optional subspecfGenLin String = 82
  numReplicons Integer = 83
  optional extrachromElements Integer = 84
  optional estimatedSize String = 85
  refBiomaterial String = 86
  optional sourceMatId String = 87
  optional pathogenicity String = 88
  optional bioticRelationship BioticRelationshipEnum = 89
  optional specificHost String = 90
  optional hostSpecRange Integer = 91
  optional hostDiseaseStat String = 92
  optional trophicLevel TrophicLevelEnum = 93
  optional encodedTraits String = 94
  optional relToOxygen RelToOxygenEnum = 95
  isolGrowthCondt String = 96
  optional sampCollecDevice String = 97
  optional sampCollecMethod String = 98
  optional sampMatProcess String = 99
  optional sampSize QuantityValue = 100
  optional nuclAcidExt String = 101
  optional nuclAcidAmp String = 102
  optional libSize Integer = 103
  optional libReadsSeqd Integer = 104
  optional libLayout LibLayoutEnum = 105
  optional libVector String = 106
  optional libScreen String = 107
  optional adapters String = 108
  seqMeth String = 109
  optional taxIdent TaxIdentEnum = 110
  assemblyQual AssemblyQualEnum = 111
  optional assemblyName String = 112
  assemblySoftware String = 113
  optional annot String = 114
  numberContig Integer = 115
  optional featPred String = 116
  optional refDb String = 117
  optional simSearchMeth String = 118
  optional taxClass String = 119
  optional complScore String = 120
  optional complSoftware String = 121
  optional associatedResource String = 122
  optional sop String = 123
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: eukaryote with environmental package sediment
message SedimentMIGSEukaryote
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkylDiethers QuantityValue = 12
  optional aminopeptAct QuantityValue = 13
  optional ammonium QuantityValue = 14
  optional bacteriaCarbProd QuantityValue = 15
  repeated biomass String = 16
  optional bishomohopanol QuantityValue = 17
  optional bromide QuantityValue = 18
  optional calcium QuantityValue = 19
  optional carbNitroRatio QuantityValue = 20
  repeated chemAdministration String = 21
  optional chloride QuantityValue = 22
  optional chlorophyll QuantityValue = 23
  optional density QuantityValue = 24
  repeated dietherLipids String = 25
  optional dissCarbDioxide QuantityValue = 26
  optional dissHydrogen QuantityValue = 27
  optional dissInorgCarb QuantityValue = 28
  optional dissOrgCarb QuantityValue = 29
  optional dissOrgNitro QuantityValue = 30
  optional dissOxygen QuantityValue = 31
  optional glucosidaseAct QuantityValue = 32
  optional magnesium QuantityValue = 33
  optional meanFrictVel QuantityValue = 34
  optional meanPeakFrictVel QuantityValue = 35
  optional methane QuantityValue = 36
  repeated miscParam String = 37
  repeated nAlkanes String = 38
  optional nitrate QuantityValue = 39
  optional nitrite QuantityValue = 40
  optional nitro QuantityValue = 41
  optional orgCarb QuantityValue = 42
  optional orgMatter QuantityValue = 43
  optional orgNitro QuantityValue = 44
  repeated organismCount OrganismCountEnum = 45
  optional oxyStatSamp OxyStatSampEnum = 46
  optional ph Double = 47
  repeated particleClass String = 48
  optional partOrgCarb QuantityValue = 49
  repeated perturbation String = 50
  optional petroleumHydrocarb QuantityValue = 51
  repeated phaeopigments String = 52
  optional phosphate QuantityValue = 53
  repeated phosplipidFattAcid String = 54
  optional porosity String = 55
  optional potassium QuantityValue = 56
  optional pressure QuantityValue = 57
  optional redoxPotential QuantityValue = 58
  optional salinity QuantityValue = 59
  optional sampStoreDur String = 60
  optional sampStoreLoc String = 61
  optional sampStoreTemp QuantityValue = 62
  optional sedimentType SedimentTypeEnum = 63
  optional silicate QuantityValue = 64
  optional sodium QuantityValue = 65
  optional sulfate QuantityValue = 66
  optional sulfide QuantityValue = 67
  optional tidalStage TidalStageEnum = 68
  optional totCarb QuantityValue = 69
  optional totDepthWaterCol QuantityValue = 70
  optional totNitroContent QuantityValue = 71
  optional totOrgCarb QuantityValue = 72
  optional turbidity QuantityValue = 73
  optional waterContent QuantityValue = 74
  sampName String = 75
  projectName String = 76
  optional sampVolWeDnaExt QuantityValue = 77
  sampTaxonId String = 78
  optional experimentalFactor String = 79
  optional negContType NegContTypeEnum = 80
  optional posContType String = 81
  optional subspecfGenLin String = 82
  optional ploidy String = 83
  optional numReplicons Integer = 84
  optional extrachromElements Integer = 85
  optional estimatedSize String = 86
  optional refBiomaterial String = 87
  optional sourceMatId String = 88
  optional pathogenicity String = 89
  optional bioticRelationship BioticRelationshipEnum = 90
  optional specificHost String = 91
  optional hostSpecRange Integer = 92
  optional hostDiseaseStat String = 93
  optional trophicLevel TrophicLevelEnum = 94
  optional propagation String = 95
  isolGrowthCondt String = 96
  optional sampCollecDevice String = 97
  optional sampCollecMethod String = 98
  optional sampMatProcess String = 99
  optional sampSize QuantityValue = 100
  optional nuclAcidExt String = 101
  optional nuclAcidAmp String = 102
  optional libSize Integer = 103
  optional libReadsSeqd Integer = 104
  optional libLayout LibLayoutEnum = 105
  optional libVector String = 106
  optional libScreen String = 107
  optional adapters String = 108
  seqMeth String = 109
  optional taxIdent TaxIdentEnum = 110
  assemblyQual AssemblyQualEnum = 111
  optional assemblyName String = 112
  assemblySoftware String = 113
  optional annot String = 114
  numberContig Integer = 115
  optional featPred String = 116
  optional refDb String = 117
  optional simSearchMeth String = 118
  optional taxClass String = 119
  optional complScore String = 120
  optional complSoftware String = 121
  optional associatedResource String = 122
  optional sop String = 123
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: org with environmental package sediment
message SedimentMIGSOrg
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkylDiethers QuantityValue = 12
  optional aminopeptAct QuantityValue = 13
  optional ammonium QuantityValue = 14
  optional bacteriaCarbProd QuantityValue = 15
  repeated biomass String = 16
  optional bishomohopanol QuantityValue = 17
  optional bromide QuantityValue = 18
  optional calcium QuantityValue = 19
  optional carbNitroRatio QuantityValue = 20
  repeated chemAdministration String = 21
  optional chloride QuantityValue = 22
  optional chlorophyll QuantityValue = 23
  optional density QuantityValue = 24
  repeated dietherLipids String = 25
  optional dissCarbDioxide QuantityValue = 26
  optional dissHydrogen QuantityValue = 27
  optional dissInorgCarb QuantityValue = 28
  optional dissOrgCarb QuantityValue = 29
  optional dissOrgNitro QuantityValue = 30
  optional dissOxygen QuantityValue = 31
  optional glucosidaseAct QuantityValue = 32
  optional magnesium QuantityValue = 33
  optional meanFrictVel QuantityValue = 34
  optional meanPeakFrictVel QuantityValue = 35
  optional methane QuantityValue = 36
  repeated miscParam String = 37
  repeated nAlkanes String = 38
  optional nitrate QuantityValue = 39
  optional nitrite QuantityValue = 40
  optional nitro QuantityValue = 41
  optional orgCarb QuantityValue = 42
  optional orgMatter QuantityValue = 43
  optional orgNitro QuantityValue = 44
  repeated organismCount OrganismCountEnum = 45
  optional oxyStatSamp OxyStatSampEnum = 46
  optional ph Double = 47
  repeated particleClass String = 48
  optional partOrgCarb QuantityValue = 49
  repeated perturbation String = 50
  optional petroleumHydrocarb QuantityValue = 51
  repeated phaeopigments String = 52
  optional phosphate QuantityValue = 53
  repeated phosplipidFattAcid String = 54
  optional porosity String = 55
  optional potassium QuantityValue = 56
  optional pressure QuantityValue = 57
  optional redoxPotential QuantityValue = 58
  optional salinity QuantityValue = 59
  optional sampStoreDur String = 60
  optional sampStoreLoc String = 61
  optional sampStoreTemp QuantityValue = 62
  optional sedimentType SedimentTypeEnum = 63
  optional silicate QuantityValue = 64
  optional sodium QuantityValue = 65
  optional sulfate QuantityValue = 66
  optional sulfide QuantityValue = 67
  optional tidalStage TidalStageEnum = 68
  optional totCarb QuantityValue = 69
  optional totDepthWaterCol QuantityValue = 70
  optional totNitroContent QuantityValue = 71
  optional totOrgCarb QuantityValue = 72
  optional turbidity QuantityValue = 73
  optional waterContent QuantityValue = 74
  sampName String = 75
  projectName String = 76
  optional sampVolWeDnaExt QuantityValue = 77
  sampTaxonId String = 78
  optional experimentalFactor String = 79
  optional negContType NegContTypeEnum = 80
  optional posContType String = 81
  optional subspecfGenLin String = 82
  optional extrachromElements Integer = 83
  optional estimatedSize String = 84
  optional refBiomaterial String = 85
  optional sourceMatId String = 86
  isolGrowthCondt String = 87
  optional sampCollecDevice String = 88
  optional sampCollecMethod String = 89
  optional sampMatProcess String = 90
  optional sampSize QuantityValue = 91
  optional nuclAcidExt String = 92
  optional nuclAcidAmp String = 93
  optional libSize Integer = 94
  optional libReadsSeqd Integer = 95
  optional libLayout LibLayoutEnum = 96
  optional libVector String = 97
  optional libScreen String = 98
  optional adapters String = 99
  seqMeth String = 100
  optional taxIdent TaxIdentEnum = 101
  optional assemblyQual AssemblyQualEnum = 102
  optional assemblyName String = 103
  assemblySoftware String = 104
  optional annot String = 105
  optional numberContig Integer = 106
  optional featPred String = 107
  optional refDb String = 108
  optional simSearchMeth String = 109
  optional taxClass String = 110
  optional complScore String = 111
  optional complSoftware String = 112
  optional associatedResource String = 113
  optional sop String = 114
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: plant with environmental package sediment
message SedimentMIGSPlant
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkylDiethers QuantityValue = 12
  optional aminopeptAct QuantityValue = 13
  optional ammonium QuantityValue = 14
  optional bacteriaCarbProd QuantityValue = 15
  repeated biomass String = 16
  optional bishomohopanol QuantityValue = 17
  optional bromide QuantityValue = 18
  optional calcium QuantityValue = 19
  optional carbNitroRatio QuantityValue = 20
  repeated chemAdministration String = 21
  optional chloride QuantityValue = 22
  optional chlorophyll QuantityValue = 23
  optional density QuantityValue = 24
  repeated dietherLipids String = 25
  optional dissCarbDioxide QuantityValue = 26
  optional dissHydrogen QuantityValue = 27
  optional dissInorgCarb QuantityValue = 28
  optional dissOrgCarb QuantityValue = 29
  optional dissOrgNitro QuantityValue = 30
  optional dissOxygen QuantityValue = 31
  optional glucosidaseAct QuantityValue = 32
  optional magnesium QuantityValue = 33
  optional meanFrictVel QuantityValue = 34
  optional meanPeakFrictVel QuantityValue = 35
  optional methane QuantityValue = 36
  repeated miscParam String = 37
  repeated nAlkanes String = 38
  optional nitrate QuantityValue = 39
  optional nitrite QuantityValue = 40
  optional nitro QuantityValue = 41
  optional orgCarb QuantityValue = 42
  optional orgMatter QuantityValue = 43
  optional orgNitro QuantityValue = 44
  repeated organismCount OrganismCountEnum = 45
  optional oxyStatSamp OxyStatSampEnum = 46
  optional ph Double = 47
  repeated particleClass String = 48
  optional partOrgCarb QuantityValue = 49
  repeated perturbation String = 50
  optional petroleumHydrocarb QuantityValue = 51
  repeated phaeopigments String = 52
  optional phosphate QuantityValue = 53
  repeated phosplipidFattAcid String = 54
  optional porosity String = 55
  optional potassium QuantityValue = 56
  optional pressure QuantityValue = 57
  optional redoxPotential QuantityValue = 58
  optional salinity QuantityValue = 59
  optional sampStoreDur String = 60
  optional sampStoreLoc String = 61
  optional sampStoreTemp QuantityValue = 62
  optional sedimentType SedimentTypeEnum = 63
  optional silicate QuantityValue = 64
  optional sodium QuantityValue = 65
  optional sulfate QuantityValue = 66
  optional sulfide QuantityValue = 67
  optional tidalStage TidalStageEnum = 68
  optional totCarb QuantityValue = 69
  optional totDepthWaterCol QuantityValue = 70
  optional totNitroContent QuantityValue = 71
  optional totOrgCarb QuantityValue = 72
  optional turbidity QuantityValue = 73
  optional waterContent QuantityValue = 74
  sampName String = 75
  projectName String = 76
  optional sampVolWeDnaExt QuantityValue = 77
  sampTaxonId String = 78
  optional experimentalFactor String = 79
  optional negContType NegContTypeEnum = 80
  optional posContType String = 81
  optional subspecfGenLin String = 82
  optional estimatedSize String = 83
  optional refBiomaterial String = 84
  optional sourceMatId String = 85
  optional specificHost String = 86
  optional hostSpecRange Integer = 87
  propagation String = 88
  optional encodedTraits String = 89
  isolGrowthCondt String = 90
  optional sampCollecDevice String = 91
  optional sampCollecMethod String = 92
  optional sampMatProcess String = 93
  optional sampSize QuantityValue = 94
  optional nuclAcidExt String = 95
  optional nuclAcidAmp String = 96
  optional libSize Integer = 97
  optional libReadsSeqd Integer = 98
  optional libLayout LibLayoutEnum = 99
  optional libVector String = 100
  optional libScreen String = 101
  optional adapters String = 102
  seqMeth String = 103
  optional taxIdent TaxIdentEnum = 104
  optional assemblyQual AssemblyQualEnum = 105
  optional assemblyName String = 106
  assemblySoftware String = 107
  optional annot String = 108
  optional numberContig Integer = 109
  optional featPred String = 110
  optional refDb String = 111
  optional simSearchMeth String = 112
  optional taxClass String = 113
  optional complScore String = 114
  optional complSoftware String = 115
  optional associatedResource String = 116
  optional sop String = 117
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package sediment
message SedimentMIGSVirus
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkylDiethers QuantityValue = 12
  optional aminopeptAct QuantityValue = 13
  optional ammonium QuantityValue = 14
  optional bacteriaCarbProd QuantityValue = 15
  repeated biomass String = 16
  optional bishomohopanol QuantityValue = 17
  optional bromide QuantityValue = 18
  optional calcium QuantityValue = 19
  optional carbNitroRatio QuantityValue = 20
  repeated chemAdministration String = 21
  optional chloride QuantityValue = 22
  optional chlorophyll QuantityValue = 23
  optional density QuantityValue = 24
  repeated dietherLipids String = 25
  optional dissCarbDioxide QuantityValue = 26
  optional dissHydrogen QuantityValue = 27
  optional dissInorgCarb QuantityValue = 28
  optional dissOrgCarb QuantityValue = 29
  optional dissOrgNitro QuantityValue = 30
  optional dissOxygen QuantityValue = 31
  optional glucosidaseAct QuantityValue = 32
  optional magnesium QuantityValue = 33
  optional meanFrictVel QuantityValue = 34
  optional meanPeakFrictVel QuantityValue = 35
  optional methane QuantityValue = 36
  repeated miscParam String = 37
  repeated nAlkanes String = 38
  optional nitrate QuantityValue = 39
  optional nitrite QuantityValue = 40
  optional nitro QuantityValue = 41
  optional orgCarb QuantityValue = 42
  optional orgMatter QuantityValue = 43
  optional orgNitro QuantityValue = 44
  repeated organismCount OrganismCountEnum = 45
  optional oxyStatSamp OxyStatSampEnum = 46
  optional ph Double = 47
  repeated particleClass String = 48
  optional partOrgCarb QuantityValue = 49
  repeated perturbation String = 50
  optional petroleumHydrocarb QuantityValue = 51
  repeated phaeopigments String = 52
  optional phosphate QuantityValue = 53
  repeated phosplipidFattAcid String = 54
  optional porosity String = 55
  optional potassium QuantityValue = 56
  optional pressure QuantityValue = 57
  optional redoxPotential QuantityValue = 58
  optional salinity QuantityValue = 59
  optional sampStoreDur String = 60
  optional sampStoreLoc String = 61
  optional sampStoreTemp QuantityValue = 62
  optional sedimentType SedimentTypeEnum = 63
  optional silicate QuantityValue = 64
  optional sodium QuantityValue = 65
  optional sulfate QuantityValue = 66
  optional sulfide QuantityValue = 67
  optional tidalStage TidalStageEnum = 68
  optional totCarb QuantityValue = 69
  optional totDepthWaterCol QuantityValue = 70
  optional totNitroContent QuantityValue = 71
  optional totOrgCarb QuantityValue = 72
  optional turbidity QuantityValue = 73
  optional waterContent QuantityValue = 74
  sampName String = 75
  projectName String = 76
  optional sampVolWeDnaExt QuantityValue = 77
  sampTaxonId String = 78
  optional experimentalFactor String = 79
  optional negContType NegContTypeEnum = 80
  optional posContType String = 81
  optional subspecfGenLin String = 82
  optional numReplicons Integer = 83
  optional estimatedSize String = 84
  optional refBiomaterial String = 85
  optional sourceMatId String = 86
  optional pathogenicity String = 87
  optional bioticRelationship BioticRelationshipEnum = 88
  optional specificHost String = 89
  optional hostSpecRange Integer = 90
  optional hostDiseaseStat String = 91
  propagation String = 92
  optional encodedTraits String = 93
  isolGrowthCondt String = 94
  optional sampCollecDevice String = 95
  optional sampCollecMethod String = 96
  optional sampMatProcess String = 97
  optional sampSize QuantityValue = 98
  optional virusEnrichAppr VirusEnrichApprEnum = 99
  optional nuclAcidExt String = 100
  optional nuclAcidAmp String = 101
  optional libSize Integer = 102
  optional libReadsSeqd Integer = 103
  optional libLayout LibLayoutEnum = 104
  optional libVector String = 105
  optional libScreen String = 106
  optional adapters String = 107
  seqMeth String = 108
  optional taxIdent TaxIdentEnum = 109
  optional assemblyQual AssemblyQualEnum = 110
  optional assemblyName String = 111
  assemblySoftware String = 112
  optional annot String = 113
  optional numberContig Integer = 114
  optional featPred String = 115
  optional refDb String = 116
  optional simSearchMeth String = 117
  optional taxClass String = 118
  optional complScore String = 119
  optional complSoftware String = 120
  optional associatedResource String = 121
  optional sop String = 122
 }
// Combinatorial checklist Minimum Information About a Metagenome-Assembled Genome with environmental package sediment
message SedimentMIMAG
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkylDiethers QuantityValue = 12
  optional aminopeptAct QuantityValue = 13
  optional ammonium QuantityValue = 14
  optional bacteriaCarbProd QuantityValue = 15
  repeated biomass String = 16
  optional bishomohopanol QuantityValue = 17
  optional bromide QuantityValue = 18
  optional calcium QuantityValue = 19
  optional carbNitroRatio QuantityValue = 20
  repeated chemAdministration String = 21
  optional chloride QuantityValue = 22
  optional chlorophyll QuantityValue = 23
  optional density QuantityValue = 24
  repeated dietherLipids String = 25
  optional dissCarbDioxide QuantityValue = 26
  optional dissHydrogen QuantityValue = 27
  optional dissInorgCarb QuantityValue = 28
  optional dissOrgCarb QuantityValue = 29
  optional dissOrgNitro QuantityValue = 30
  optional dissOxygen QuantityValue = 31
  optional glucosidaseAct QuantityValue = 32
  optional magnesium QuantityValue = 33
  optional meanFrictVel QuantityValue = 34
  optional meanPeakFrictVel QuantityValue = 35
  optional methane QuantityValue = 36
  repeated miscParam String = 37
  repeated nAlkanes String = 38
  optional nitrate QuantityValue = 39
  optional nitrite QuantityValue = 40
  optional nitro QuantityValue = 41
  optional orgCarb QuantityValue = 42
  optional orgMatter QuantityValue = 43
  optional orgNitro QuantityValue = 44
  repeated organismCount OrganismCountEnum = 45
  optional oxyStatSamp OxyStatSampEnum = 46
  optional ph Double = 47
  repeated particleClass String = 48
  optional partOrgCarb QuantityValue = 49
  repeated perturbation String = 50
  optional petroleumHydrocarb QuantityValue = 51
  repeated phaeopigments String = 52
  optional phosphate QuantityValue = 53
  repeated phosplipidFattAcid String = 54
  optional porosity String = 55
  optional potassium QuantityValue = 56
  optional pressure QuantityValue = 57
  optional redoxPotential QuantityValue = 58
  optional salinity QuantityValue = 59
  optional sampStoreDur String = 60
  optional sampStoreLoc String = 61
  optional sampStoreTemp QuantityValue = 62
  optional sedimentType SedimentTypeEnum = 63
  optional silicate QuantityValue = 64
  optional sodium QuantityValue = 65
  optional sulfate QuantityValue = 66
  optional sulfide QuantityValue = 67
  optional tidalStage TidalStageEnum = 68
  optional totCarb QuantityValue = 69
  optional totDepthWaterCol QuantityValue = 70
  optional totNitroContent QuantityValue = 71
  optional totOrgCarb QuantityValue = 72
  optional turbidity QuantityValue = 73
  optional waterContent QuantityValue = 74
  sampName String = 75
  projectName String = 76
  optional sampVolWeDnaExt QuantityValue = 77
  sampTaxonId String = 78
  optional experimentalFactor String = 79
  optional negContType NegContTypeEnum = 80
  optional posContType String = 81
  optional refBiomaterial String = 82
  optional sourceMatId String = 83
  optional relToOxygen RelToOxygenEnum = 84
  optional sampCollecDevice String = 85
  optional sampCollecMethod String = 86
  optional sampMatProcess String = 87
  optional sizeFrac String = 88
  optional sampSize QuantityValue = 89
  optional nuclAcidExt String = 90
  optional nuclAcidAmp String = 91
  optional libSize Integer = 92
  optional libReadsSeqd Integer = 93
  optional libLayout LibLayoutEnum = 94
  optional libVector String = 95
  optional libScreen String = 96
  optional mid String = 97
  optional adapters String = 98
  seqMeth String = 99
  taxIdent TaxIdentEnum = 100
  assemblyQual AssemblyQualEnum = 101
  optional assemblyName String = 102
  assemblySoftware String = 103
  optional annot String = 104
  optional numberContig Integer = 105
  optional featPred String = 106
  optional refDb String = 107
  optional simSearchMeth String = 108
  optional taxClass String = 109
  optional x16sRecover String = 110
  optional x16sRecoverSoftware String = 111
  optional trnas Integer = 112
  optional trnaExtSoftware String = 113
  complScore String = 114
  complSoftware String = 115
  optional complAppr ComplApprEnum = 116
  contamScore String = 117
  optional contamScreenInput String = 118
  optional contamScreenParam String = 119
  optional decontamSoftware DecontamSoftwareEnum = 120
  binParam BinParamEnum = 121
  binSoftware String = 122
  optional reassemblyBin String = 123
  optional magCovSoftware MagCovSoftwareEnum = 124
  optional associatedResource String = 125
  optional sop String = 126
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: specimen with environmental package sediment
message SedimentMIMARKSSpecimen
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkylDiethers QuantityValue = 12
  optional aminopeptAct QuantityValue = 13
  optional ammonium QuantityValue = 14
  optional bacteriaCarbProd QuantityValue = 15
  repeated biomass String = 16
  optional bishomohopanol QuantityValue = 17
  optional bromide QuantityValue = 18
  optional calcium QuantityValue = 19
  optional carbNitroRatio QuantityValue = 20
  repeated chemAdministration String = 21
  optional chloride QuantityValue = 22
  optional chlorophyll QuantityValue = 23
  optional density QuantityValue = 24
  repeated dietherLipids String = 25
  optional dissCarbDioxide QuantityValue = 26
  optional dissHydrogen QuantityValue = 27
  optional dissInorgCarb QuantityValue = 28
  optional dissOrgCarb QuantityValue = 29
  optional dissOrgNitro QuantityValue = 30
  optional dissOxygen QuantityValue = 31
  optional glucosidaseAct QuantityValue = 32
  optional magnesium QuantityValue = 33
  optional meanFrictVel QuantityValue = 34
  optional meanPeakFrictVel QuantityValue = 35
  optional methane QuantityValue = 36
  repeated miscParam String = 37
  repeated nAlkanes String = 38
  optional nitrate QuantityValue = 39
  optional nitrite QuantityValue = 40
  optional nitro QuantityValue = 41
  optional orgCarb QuantityValue = 42
  optional orgMatter QuantityValue = 43
  optional orgNitro QuantityValue = 44
  repeated organismCount OrganismCountEnum = 45
  optional oxyStatSamp OxyStatSampEnum = 46
  optional ph Double = 47
  repeated particleClass String = 48
  optional partOrgCarb QuantityValue = 49
  repeated perturbation String = 50
  optional petroleumHydrocarb QuantityValue = 51
  repeated phaeopigments String = 52
  optional phosphate QuantityValue = 53
  repeated phosplipidFattAcid String = 54
  optional porosity String = 55
  optional potassium QuantityValue = 56
  optional pressure QuantityValue = 57
  optional redoxPotential QuantityValue = 58
  optional salinity QuantityValue = 59
  optional sampStoreDur String = 60
  optional sampStoreLoc String = 61
  optional sampStoreTemp QuantityValue = 62
  optional sedimentType SedimentTypeEnum = 63
  optional silicate QuantityValue = 64
  optional sodium QuantityValue = 65
  optional sulfate QuantityValue = 66
  optional sulfide QuantityValue = 67
  optional tidalStage TidalStageEnum = 68
  optional totCarb QuantityValue = 69
  optional totDepthWaterCol QuantityValue = 70
  optional totNitroContent QuantityValue = 71
  optional totOrgCarb QuantityValue = 72
  optional turbidity QuantityValue = 73
  optional waterContent QuantityValue = 74
  sampName String = 75
  projectName String = 76
  optional sampVolWeDnaExt QuantityValue = 77
  sampTaxonId String = 78
  optional experimentalFactor String = 79
  optional negContType NegContTypeEnum = 80
  optional posContType String = 81
  optional sourceMatId String = 82
  optional relToOxygen RelToOxygenEnum = 83
  optional sampCollecDevice String = 84
  optional sampCollecMethod String = 85
  optional sampMatProcess String = 86
  optional sizeFrac String = 87
  optional sampSize QuantityValue = 88
  optional nuclAcidExt String = 89
  optional nuclAcidAmp String = 90
  optional libSize Integer = 91
  optional libReadsSeqd Integer = 92
  optional libLayout LibLayoutEnum = 93
  optional libVector String = 94
  optional libScreen String = 95
  targetGene String = 96
  optional targetSubfragment String = 97
  optional pcrPrimers String = 98
  optional mid String = 99
  optional adapters String = 100
  optional pcrCond String = 101
  seqMeth String = 102
  optional seqQualityCheck String = 103
  optional chimeraCheck String = 104
  optional assemblySoftware String = 105
  optional associatedResource String = 106
  optional sop String = 107
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: survey with environmental package sediment
message SedimentMIMARKSSurvey
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkylDiethers QuantityValue = 12
  optional aminopeptAct QuantityValue = 13
  optional ammonium QuantityValue = 14
  optional bacteriaCarbProd QuantityValue = 15
  repeated biomass String = 16
  optional bishomohopanol QuantityValue = 17
  optional bromide QuantityValue = 18
  optional calcium QuantityValue = 19
  optional carbNitroRatio QuantityValue = 20
  repeated chemAdministration String = 21
  optional chloride QuantityValue = 22
  optional chlorophyll QuantityValue = 23
  optional density QuantityValue = 24
  repeated dietherLipids String = 25
  optional dissCarbDioxide QuantityValue = 26
  optional dissHydrogen QuantityValue = 27
  optional dissInorgCarb QuantityValue = 28
  optional dissOrgCarb QuantityValue = 29
  optional dissOrgNitro QuantityValue = 30
  optional dissOxygen QuantityValue = 31
  optional glucosidaseAct QuantityValue = 32
  optional magnesium QuantityValue = 33
  optional meanFrictVel QuantityValue = 34
  optional meanPeakFrictVel QuantityValue = 35
  optional methane QuantityValue = 36
  repeated miscParam String = 37
  repeated nAlkanes String = 38
  optional nitrate QuantityValue = 39
  optional nitrite QuantityValue = 40
  optional nitro QuantityValue = 41
  optional orgCarb QuantityValue = 42
  optional orgMatter QuantityValue = 43
  optional orgNitro QuantityValue = 44
  repeated organismCount OrganismCountEnum = 45
  optional oxyStatSamp OxyStatSampEnum = 46
  optional ph Double = 47
  repeated particleClass String = 48
  optional partOrgCarb QuantityValue = 49
  repeated perturbation String = 50
  optional petroleumHydrocarb QuantityValue = 51
  repeated phaeopigments String = 52
  optional phosphate QuantityValue = 53
  repeated phosplipidFattAcid String = 54
  optional porosity String = 55
  optional potassium QuantityValue = 56
  optional pressure QuantityValue = 57
  optional redoxPotential QuantityValue = 58
  optional salinity QuantityValue = 59
  optional sampStoreDur String = 60
  optional sampStoreLoc String = 61
  optional sampStoreTemp QuantityValue = 62
  optional sedimentType SedimentTypeEnum = 63
  optional silicate QuantityValue = 64
  optional sodium QuantityValue = 65
  optional sulfate QuantityValue = 66
  optional sulfide QuantityValue = 67
  optional tidalStage TidalStageEnum = 68
  optional totCarb QuantityValue = 69
  optional totDepthWaterCol QuantityValue = 70
  optional totNitroContent QuantityValue = 71
  optional totOrgCarb QuantityValue = 72
  optional turbidity QuantityValue = 73
  optional waterContent QuantityValue = 74
  sampName String = 75
  projectName String = 76
  optional sampVolWeDnaExt QuantityValue = 77
  sampTaxonId String = 78
  optional experimentalFactor String = 79
  optional negContType NegContTypeEnum = 80
  optional posContType String = 81
  optional subspecfGenLin String = 82
  optional extrachromElements Integer = 83
  optional sourceMatId String = 84
  optional bioticRelationship BioticRelationshipEnum = 85
  optional trophicLevel TrophicLevelEnum = 86
  optional relToOxygen RelToOxygenEnum = 87
  isolGrowthCondt String = 88
  optional sampCollecDevice String = 89
  optional sampCollecMethod String = 90
  optional sampMatProcess String = 91
  optional sampSize QuantityValue = 92
  optional nuclAcidExt String = 93
  optional nuclAcidAmp String = 94
  targetGene String = 95
  optional targetSubfragment String = 96
  optional pcrPrimers String = 97
  optional pcrCond String = 98
  seqMeth String = 99
  optional seqQualityCheck String = 100
  optional chimeraCheck String = 101
  optional associatedResource String = 102
  optional sop String = 103
 }
// Combinatorial checklist Metagenome or Environmental with environmental package sediment
message SedimentMIMS
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkylDiethers QuantityValue = 12
  optional aminopeptAct QuantityValue = 13
  optional ammonium QuantityValue = 14
  optional bacteriaCarbProd QuantityValue = 15
  repeated biomass String = 16
  optional bishomohopanol QuantityValue = 17
  optional bromide QuantityValue = 18
  optional calcium QuantityValue = 19
  optional carbNitroRatio QuantityValue = 20
  repeated chemAdministration String = 21
  optional chloride QuantityValue = 22
  optional chlorophyll QuantityValue = 23
  optional density QuantityValue = 24
  repeated dietherLipids String = 25
  optional dissCarbDioxide QuantityValue = 26
  optional dissHydrogen QuantityValue = 27
  optional dissInorgCarb QuantityValue = 28
  optional dissOrgCarb QuantityValue = 29
  optional dissOrgNitro QuantityValue = 30
  optional dissOxygen QuantityValue = 31
  optional glucosidaseAct QuantityValue = 32
  optional magnesium QuantityValue = 33
  optional meanFrictVel QuantityValue = 34
  optional meanPeakFrictVel QuantityValue = 35
  optional methane QuantityValue = 36
  repeated miscParam String = 37
  repeated nAlkanes String = 38
  optional nitrate QuantityValue = 39
  optional nitrite QuantityValue = 40
  optional nitro QuantityValue = 41
  optional orgCarb QuantityValue = 42
  optional orgMatter QuantityValue = 43
  optional orgNitro QuantityValue = 44
  repeated organismCount OrganismCountEnum = 45
  optional oxyStatSamp OxyStatSampEnum = 46
  optional ph Double = 47
  repeated particleClass String = 48
  optional partOrgCarb QuantityValue = 49
  repeated perturbation String = 50
  optional petroleumHydrocarb QuantityValue = 51
  repeated phaeopigments String = 52
  optional phosphate QuantityValue = 53
  repeated phosplipidFattAcid String = 54
  optional porosity String = 55
  optional potassium QuantityValue = 56
  optional pressure QuantityValue = 57
  optional redoxPotential QuantityValue = 58
  optional salinity QuantityValue = 59
  optional sampStoreDur String = 60
  optional sampStoreLoc String = 61
  optional sampStoreTemp QuantityValue = 62
  optional sedimentType SedimentTypeEnum = 63
  optional silicate QuantityValue = 64
  optional sodium QuantityValue = 65
  optional sulfate QuantityValue = 66
  optional sulfide QuantityValue = 67
  optional tidalStage TidalStageEnum = 68
  optional totCarb QuantityValue = 69
  optional totDepthWaterCol QuantityValue = 70
  optional totNitroContent QuantityValue = 71
  optional totOrgCarb QuantityValue = 72
  optional turbidity QuantityValue = 73
  optional waterContent QuantityValue = 74
  sampName String = 75
  projectName String = 76
  optional sampVolWeDnaExt QuantityValue = 77
  sampTaxonId String = 78
  optional experimentalFactor String = 79
  optional negContType NegContTypeEnum = 80
  optional posContType String = 81
  optional refBiomaterial String = 82
  optional sourceMatId String = 83
  optional relToOxygen RelToOxygenEnum = 84
  optional sampCollecDevice String = 85
  optional sampCollecMethod String = 86
  optional sampMatProcess String = 87
  optional sizeFrac String = 88
  optional sampSize QuantityValue = 89
  optional nuclAcidExt String = 90
  optional nuclAcidAmp String = 91
  optional libSize Integer = 92
  optional libReadsSeqd Integer = 93
  optional libLayout LibLayoutEnum = 94
  optional libVector String = 95
  optional libScreen String = 96
  optional mid String = 97
  optional adapters String = 98
  seqMeth String = 99
  optional assemblyQual AssemblyQualEnum = 100
  optional assemblyName String = 101
  optional assemblySoftware String = 102
  optional annot String = 103
  optional numberContig Integer = 104
  optional featPred String = 105
  optional refDb String = 106
  optional simSearchMeth String = 107
  optional taxClass String = 108
  optional associatedResource String = 109
  optional sop String = 110
 }
// Combinatorial checklist Minimum Information About a Single Amplified Genome with environmental package sediment
message SedimentMISAG
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkylDiethers QuantityValue = 12
  optional aminopeptAct QuantityValue = 13
  optional ammonium QuantityValue = 14
  optional bacteriaCarbProd QuantityValue = 15
  repeated biomass String = 16
  optional bishomohopanol QuantityValue = 17
  optional bromide QuantityValue = 18
  optional calcium QuantityValue = 19
  optional carbNitroRatio QuantityValue = 20
  repeated chemAdministration String = 21
  optional chloride QuantityValue = 22
  optional chlorophyll QuantityValue = 23
  optional density QuantityValue = 24
  repeated dietherLipids String = 25
  optional dissCarbDioxide QuantityValue = 26
  optional dissHydrogen QuantityValue = 27
  optional dissInorgCarb QuantityValue = 28
  optional dissOrgCarb QuantityValue = 29
  optional dissOrgNitro QuantityValue = 30
  optional dissOxygen QuantityValue = 31
  optional glucosidaseAct QuantityValue = 32
  optional magnesium QuantityValue = 33
  optional meanFrictVel QuantityValue = 34
  optional meanPeakFrictVel QuantityValue = 35
  optional methane QuantityValue = 36
  repeated miscParam String = 37
  repeated nAlkanes String = 38
  optional nitrate QuantityValue = 39
  optional nitrite QuantityValue = 40
  optional nitro QuantityValue = 41
  optional orgCarb QuantityValue = 42
  optional orgMatter QuantityValue = 43
  optional orgNitro QuantityValue = 44
  repeated organismCount OrganismCountEnum = 45
  optional oxyStatSamp OxyStatSampEnum = 46
  optional ph Double = 47
  repeated particleClass String = 48
  optional partOrgCarb QuantityValue = 49
  repeated perturbation String = 50
  optional petroleumHydrocarb QuantityValue = 51
  repeated phaeopigments String = 52
  optional phosphate QuantityValue = 53
  repeated phosplipidFattAcid String = 54
  optional porosity String = 55
  optional potassium QuantityValue = 56
  optional pressure QuantityValue = 57
  optional redoxPotential QuantityValue = 58
  optional salinity QuantityValue = 59
  optional sampStoreDur String = 60
  optional sampStoreLoc String = 61
  optional sampStoreTemp QuantityValue = 62
  optional sedimentType SedimentTypeEnum = 63
  optional silicate QuantityValue = 64
  optional sodium QuantityValue = 65
  optional sulfate QuantityValue = 66
  optional sulfide QuantityValue = 67
  optional tidalStage TidalStageEnum = 68
  optional totCarb QuantityValue = 69
  optional totDepthWaterCol QuantityValue = 70
  optional totNitroContent QuantityValue = 71
  optional totOrgCarb QuantityValue = 72
  optional turbidity QuantityValue = 73
  optional waterContent QuantityValue = 74
  sampName String = 75
  projectName String = 76
  optional sampVolWeDnaExt QuantityValue = 77
  sampTaxonId String = 78
  optional experimentalFactor String = 79
  optional negContType NegContTypeEnum = 80
  optional posContType String = 81
  optional refBiomaterial String = 82
  optional sourceMatId String = 83
  optional relToOxygen RelToOxygenEnum = 84
  optional sampCollecDevice String = 85
  optional sampCollecMethod String = 86
  optional sampMatProcess String = 87
  optional sizeFrac String = 88
  optional sampSize QuantityValue = 89
  optional nuclAcidExt String = 90
  optional nuclAcidAmp String = 91
  optional libSize Integer = 92
  optional libReadsSeqd Integer = 93
  optional libLayout LibLayoutEnum = 94
  optional libVector String = 95
  optional libScreen String = 96
  optional mid String = 97
  optional adapters String = 98
  seqMeth String = 99
  taxIdent TaxIdentEnum = 100
  assemblyQual AssemblyQualEnum = 101
  optional assemblyName String = 102
  assemblySoftware String = 103
  optional annot String = 104
  optional numberContig Integer = 105
  optional featPred String = 106
  optional refDb String = 107
  optional simSearchMeth String = 108
  optional taxClass String = 109
  optional x16sRecover String = 110
  optional x16sRecoverSoftware String = 111
  optional trnas Integer = 112
  optional trnaExtSoftware String = 113
  complScore String = 114
  complSoftware String = 115
  optional complAppr ComplApprEnum = 116
  contamScore String = 117
  optional contamScreenInput String = 118
  optional contamScreenParam String = 119
  optional decontamSoftware DecontamSoftwareEnum = 120
  sortTech SortTechEnum = 121
  singleCellLysisAppr SingleCellLysisApprEnum = 122
  optional singleCellLysisProt String = 123
  wgaAmpAppr String = 124
  optional wgaAmpKit String = 125
  optional associatedResource String = 126
  optional sop String = 127
 }
// Combinatorial checklist Minimum Information About an Uncultivated Virus Genome with environmental package sediment
message SedimentMIUVIG
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkylDiethers QuantityValue = 12
  optional aminopeptAct QuantityValue = 13
  optional ammonium QuantityValue = 14
  optional bacteriaCarbProd QuantityValue = 15
  repeated biomass String = 16
  optional bishomohopanol QuantityValue = 17
  optional bromide QuantityValue = 18
  optional calcium QuantityValue = 19
  optional carbNitroRatio QuantityValue = 20
  repeated chemAdministration String = 21
  optional chloride QuantityValue = 22
  optional chlorophyll QuantityValue = 23
  optional density QuantityValue = 24
  repeated dietherLipids String = 25
  optional dissCarbDioxide QuantityValue = 26
  optional dissHydrogen QuantityValue = 27
  optional dissInorgCarb QuantityValue = 28
  optional dissOrgCarb QuantityValue = 29
  optional dissOrgNitro QuantityValue = 30
  optional dissOxygen QuantityValue = 31
  optional glucosidaseAct QuantityValue = 32
  optional magnesium QuantityValue = 33
  optional meanFrictVel QuantityValue = 34
  optional meanPeakFrictVel QuantityValue = 35
  optional methane QuantityValue = 36
  repeated miscParam String = 37
  repeated nAlkanes String = 38
  optional nitrate QuantityValue = 39
  optional nitrite QuantityValue = 40
  optional nitro QuantityValue = 41
  optional orgCarb QuantityValue = 42
  optional orgMatter QuantityValue = 43
  optional orgNitro QuantityValue = 44
  repeated organismCount OrganismCountEnum = 45
  optional oxyStatSamp OxyStatSampEnum = 46
  optional ph Double = 47
  repeated particleClass String = 48
  optional partOrgCarb QuantityValue = 49
  repeated perturbation String = 50
  optional petroleumHydrocarb QuantityValue = 51
  repeated phaeopigments String = 52
  optional phosphate QuantityValue = 53
  repeated phosplipidFattAcid String = 54
  optional porosity String = 55
  optional potassium QuantityValue = 56
  optional pressure QuantityValue = 57
  optional redoxPotential QuantityValue = 58
  optional salinity QuantityValue = 59
  optional sampStoreDur String = 60
  optional sampStoreLoc String = 61
  optional sampStoreTemp QuantityValue = 62
  optional sedimentType SedimentTypeEnum = 63
  optional silicate QuantityValue = 64
  optional sodium QuantityValue = 65
  optional sulfate QuantityValue = 66
  optional sulfide QuantityValue = 67
  optional tidalStage TidalStageEnum = 68
  optional totCarb QuantityValue = 69
  optional totDepthWaterCol QuantityValue = 70
  optional totNitroContent QuantityValue = 71
  optional totOrgCarb QuantityValue = 72
  optional turbidity QuantityValue = 73
  optional waterContent QuantityValue = 74
  sampName String = 75
  projectName String = 76
  optional sampVolWeDnaExt QuantityValue = 77
  sampTaxonId String = 78
  optional experimentalFactor String = 79
  optional negContType NegContTypeEnum = 80
  optional posContType String = 81
  optional estimatedSize String = 82
  optional refBiomaterial String = 83
  optional sourceMatId String = 84
  optional pathogenicity String = 85
  optional bioticRelationship BioticRelationshipEnum = 86
  optional specificHost String = 87
  optional hostSpecRange Integer = 88
  optional hostDiseaseStat String = 89
  optional sampCollecDevice String = 90
  optional sampCollecMethod String = 91
  optional sampMatProcess String = 92
  optional sizeFrac String = 93
  optional sampSize QuantityValue = 94
  sourceUvig SourceUvigEnum = 95
  virusEnrichAppr VirusEnrichApprEnum = 96
  optional nuclAcidExt String = 97
  optional nuclAcidAmp String = 98
  optional libSize Integer = 99
  optional libReadsSeqd Integer = 100
  optional libLayout LibLayoutEnum = 101
  optional libVector String = 102
  optional libScreen String = 103
  optional mid String = 104
  optional adapters String = 105
  seqMeth String = 106
  optional taxIdent TaxIdentEnum = 107
  assemblyQual AssemblyQualEnum = 108
  optional assemblyName String = 109
  assemblySoftware String = 110
  optional annot String = 111
  numberContig Integer = 112
  optional featPred String = 113
  optional refDb String = 114
  optional simSearchMeth String = 115
  optional taxClass String = 116
  optional trnas Integer = 117
  optional trnaExtSoftware String = 118
  optional complScore String = 119
  optional complSoftware String = 120
  optional complAppr ComplApprEnum = 121
  optional sortTech SortTechEnum = 122
  optional singleCellLysisAppr SingleCellLysisApprEnum = 123
  optional singleCellLysisProt String = 124
  optional wgaAmpAppr String = 125
  optional wgaAmpKit String = 126
  optional binParam BinParamEnum = 127
  optional binSoftware String = 128
  optional reassemblyBin String = 129
  optional magCovSoftware MagCovSoftwareEnum = 130
  virIdentSoftware String = 131
  predGenomeType PredGenomeTypeEnum = 132
  predGenomeStruc PredGenomeStrucEnum = 133
  detecType String = 134
  optional otuClassAppr String = 135
  optional otuSeqCompAppr String = 136
  optional otuDb String = 137
  optional hostPredAppr HostPredApprEnum = 138
  optional hostPredEstAcc String = 139
  optional associatedResource String = 140
  optional sop String = 141
 }
// soil
message Soil
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional curLandUse CurLandUseEnum = 11
  optional curVegetation String = 12
  optional curVegetationMeth String = 13
  optional previousLandUse String = 14
  optional prevLandUseMeth String = 15
  optional cropRotation String = 16
  repeated agrochemAddition String = 17
  repeated tillage TillageEnum = 18
  optional fire Date = 19
  optional flooding Date = 20
  optional extremeEvent Date = 21
  optional soilHorizon SoilHorizonEnum = 22
  optional horizonMeth String = 23
  optional sieving String = 24
  optional waterContent QuantityValue = 25
  optional waterContSoilMeth String = 26
  optional poolDnaExtracts String = 27
  optional storeCond String = 28
  optional linkClimateInfo String = 29
  optional annualTemp QuantityValue = 30
  optional seasonTemp QuantityValue = 31
  optional annualPrecpt QuantityValue = 32
  optional seasonPrecpt QuantityValue = 33
  optional linkClassInfo String = 34
  optional faoClass FaoClassEnum = 35
  optional localClass String = 36
  optional localClassMeth String = 37
  optional orgNitro QuantityValue = 38
  optional soilType String = 39
  optional soilTypeMeth String = 40
  optional slopeGradient QuantityValue = 41
  optional slopeAspect QuantityValue = 42
  optional profilePosition ProfilePositionEnum = 43
  optional drainageClass DrainageClassEnum = 44
  optional soilTextMeasure QuantityValue = 45
  optional soilTextureMeth String = 46
  optional ph Double = 47
  optional phMeth String = 48
  optional orgMatter QuantityValue = 49
  optional totOrgCarb QuantityValue = 50
  optional totOrgCMeth String = 51
  optional totNitroContent QuantityValue = 52
  optional totNitroContMeth String = 53
  optional microbialBiomass QuantityValue = 54
  optional microBiomassMeth String = 55
  optional linkAdditAnalys String = 56
  optional salinityMeth String = 57
  repeated heavyMetals String = 58
  optional heavyMetalsMeth String = 59
  optional alSat QuantityValue = 60
  optional alSatMeth String = 61
  repeated miscParam String = 62
  sampName String = 63
  projectName String = 64
  optional sampVolWeDnaExt QuantityValue = 65
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package soil
message SoilMIGSBacteria
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional curLandUse CurLandUseEnum = 11
  optional curVegetation String = 12
  optional curVegetationMeth String = 13
  optional previousLandUse String = 14
  optional prevLandUseMeth String = 15
  optional cropRotation String = 16
  repeated agrochemAddition String = 17
  repeated tillage TillageEnum = 18
  optional fire Date = 19
  optional flooding Date = 20
  optional extremeEvent Date = 21
  optional soilHorizon SoilHorizonEnum = 22
  optional horizonMeth String = 23
  optional sieving String = 24
  optional waterContent QuantityValue = 25
  optional waterContSoilMeth String = 26
  optional poolDnaExtracts String = 27
  optional storeCond String = 28
  optional linkClimateInfo String = 29
  optional annualTemp QuantityValue = 30
  optional seasonTemp QuantityValue = 31
  optional annualPrecpt QuantityValue = 32
  optional seasonPrecpt QuantityValue = 33
  optional linkClassInfo String = 34
  optional faoClass FaoClassEnum = 35
  optional localClass String = 36
  optional localClassMeth String = 37
  optional orgNitro QuantityValue = 38
  optional soilType String = 39
  optional soilTypeMeth String = 40
  optional slopeGradient QuantityValue = 41
  optional slopeAspect QuantityValue = 42
  optional profilePosition ProfilePositionEnum = 43
  optional drainageClass DrainageClassEnum = 44
  optional soilTextMeasure QuantityValue = 45
  optional soilTextureMeth String = 46
  optional ph Double = 47
  optional phMeth String = 48
  optional orgMatter QuantityValue = 49
  optional totOrgCarb QuantityValue = 50
  optional totOrgCMeth String = 51
  optional totNitroContent QuantityValue = 52
  optional totNitroContMeth String = 53
  optional microbialBiomass QuantityValue = 54
  optional microBiomassMeth String = 55
  optional linkAdditAnalys String = 56
  optional salinityMeth String = 57
  repeated heavyMetals String = 58
  optional heavyMetalsMeth String = 59
  optional alSat QuantityValue = 60
  optional alSatMeth String = 61
  repeated miscParam String = 62
  sampName String = 63
  projectName String = 64
  optional sampVolWeDnaExt QuantityValue = 65
  sampTaxonId String = 66
  optional experimentalFactor String = 67
  optional negContType NegContTypeEnum = 68
  optional posContType String = 69
  optional subspecfGenLin String = 70
  numReplicons Integer = 71
  optional extrachromElements Integer = 72
  optional estimatedSize String = 73
  refBiomaterial String = 74
  optional sourceMatId String = 75
  optional pathogenicity String = 76
  optional bioticRelationship BioticRelationshipEnum = 77
  optional specificHost String = 78
  optional hostSpecRange Integer = 79
  optional hostDiseaseStat String = 80
  optional trophicLevel TrophicLevelEnum = 81
  optional encodedTraits String = 82
  optional relToOxygen RelToOxygenEnum = 83
  isolGrowthCondt String = 84
  optional sampCollecDevice String = 85
  optional sampCollecMethod String = 86
  optional sampMatProcess String = 87
  optional sampSize QuantityValue = 88
  optional nuclAcidExt String = 89
  optional nuclAcidAmp String = 90
  optional libSize Integer = 91
  optional libReadsSeqd Integer = 92
  optional libLayout LibLayoutEnum = 93
  optional libVector String = 94
  optional libScreen String = 95
  optional adapters String = 96
  seqMeth String = 97
  optional taxIdent TaxIdentEnum = 98
  assemblyQual AssemblyQualEnum = 99
  optional assemblyName String = 100
  assemblySoftware String = 101
  optional annot String = 102
  numberContig Integer = 103
  optional featPred String = 104
  optional refDb String = 105
  optional simSearchMeth String = 106
  optional taxClass String = 107
  optional complScore String = 108
  optional complSoftware String = 109
  optional associatedResource String = 110
  optional sop String = 111
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: eukaryote with environmental package soil
message SoilMIGSEukaryote
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional curLandUse CurLandUseEnum = 11
  optional curVegetation String = 12
  optional curVegetationMeth String = 13
  optional previousLandUse String = 14
  optional prevLandUseMeth String = 15
  optional cropRotation String = 16
  repeated agrochemAddition String = 17
  repeated tillage TillageEnum = 18
  optional fire Date = 19
  optional flooding Date = 20
  optional extremeEvent Date = 21
  optional soilHorizon SoilHorizonEnum = 22
  optional horizonMeth String = 23
  optional sieving String = 24
  optional waterContent QuantityValue = 25
  optional waterContSoilMeth String = 26
  optional poolDnaExtracts String = 27
  optional storeCond String = 28
  optional linkClimateInfo String = 29
  optional annualTemp QuantityValue = 30
  optional seasonTemp QuantityValue = 31
  optional annualPrecpt QuantityValue = 32
  optional seasonPrecpt QuantityValue = 33
  optional linkClassInfo String = 34
  optional faoClass FaoClassEnum = 35
  optional localClass String = 36
  optional localClassMeth String = 37
  optional orgNitro QuantityValue = 38
  optional soilType String = 39
  optional soilTypeMeth String = 40
  optional slopeGradient QuantityValue = 41
  optional slopeAspect QuantityValue = 42
  optional profilePosition ProfilePositionEnum = 43
  optional drainageClass DrainageClassEnum = 44
  optional soilTextMeasure QuantityValue = 45
  optional soilTextureMeth String = 46
  optional ph Double = 47
  optional phMeth String = 48
  optional orgMatter QuantityValue = 49
  optional totOrgCarb QuantityValue = 50
  optional totOrgCMeth String = 51
  optional totNitroContent QuantityValue = 52
  optional totNitroContMeth String = 53
  optional microbialBiomass QuantityValue = 54
  optional microBiomassMeth String = 55
  optional linkAdditAnalys String = 56
  optional salinityMeth String = 57
  repeated heavyMetals String = 58
  optional heavyMetalsMeth String = 59
  optional alSat QuantityValue = 60
  optional alSatMeth String = 61
  repeated miscParam String = 62
  sampName String = 63
  projectName String = 64
  optional sampVolWeDnaExt QuantityValue = 65
  sampTaxonId String = 66
  optional experimentalFactor String = 67
  optional negContType NegContTypeEnum = 68
  optional posContType String = 69
  optional subspecfGenLin String = 70
  optional ploidy String = 71
  optional numReplicons Integer = 72
  optional extrachromElements Integer = 73
  optional estimatedSize String = 74
  optional refBiomaterial String = 75
  optional sourceMatId String = 76
  optional pathogenicity String = 77
  optional bioticRelationship BioticRelationshipEnum = 78
  optional specificHost String = 79
  optional hostSpecRange Integer = 80
  optional hostDiseaseStat String = 81
  optional trophicLevel TrophicLevelEnum = 82
  optional propagation String = 83
  isolGrowthCondt String = 84
  optional sampCollecDevice String = 85
  optional sampCollecMethod String = 86
  optional sampMatProcess String = 87
  optional sampSize QuantityValue = 88
  optional nuclAcidExt String = 89
  optional nuclAcidAmp String = 90
  optional libSize Integer = 91
  optional libReadsSeqd Integer = 92
  optional libLayout LibLayoutEnum = 93
  optional libVector String = 94
  optional libScreen String = 95
  optional adapters String = 96
  seqMeth String = 97
  optional taxIdent TaxIdentEnum = 98
  assemblyQual AssemblyQualEnum = 99
  optional assemblyName String = 100
  assemblySoftware String = 101
  optional annot String = 102
  numberContig Integer = 103
  optional featPred String = 104
  optional refDb String = 105
  optional simSearchMeth String = 106
  optional taxClass String = 107
  optional complScore String = 108
  optional complSoftware String = 109
  optional associatedResource String = 110
  optional sop String = 111
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: org with environmental package soil
message SoilMIGSOrg
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional curLandUse CurLandUseEnum = 11
  optional curVegetation String = 12
  optional curVegetationMeth String = 13
  optional previousLandUse String = 14
  optional prevLandUseMeth String = 15
  optional cropRotation String = 16
  repeated agrochemAddition String = 17
  repeated tillage TillageEnum = 18
  optional fire Date = 19
  optional flooding Date = 20
  optional extremeEvent Date = 21
  optional soilHorizon SoilHorizonEnum = 22
  optional horizonMeth String = 23
  optional sieving String = 24
  optional waterContent QuantityValue = 25
  optional waterContSoilMeth String = 26
  optional poolDnaExtracts String = 27
  optional storeCond String = 28
  optional linkClimateInfo String = 29
  optional annualTemp QuantityValue = 30
  optional seasonTemp QuantityValue = 31
  optional annualPrecpt QuantityValue = 32
  optional seasonPrecpt QuantityValue = 33
  optional linkClassInfo String = 34
  optional faoClass FaoClassEnum = 35
  optional localClass String = 36
  optional localClassMeth String = 37
  optional orgNitro QuantityValue = 38
  optional soilType String = 39
  optional soilTypeMeth String = 40
  optional slopeGradient QuantityValue = 41
  optional slopeAspect QuantityValue = 42
  optional profilePosition ProfilePositionEnum = 43
  optional drainageClass DrainageClassEnum = 44
  optional soilTextMeasure QuantityValue = 45
  optional soilTextureMeth String = 46
  optional ph Double = 47
  optional phMeth String = 48
  optional orgMatter QuantityValue = 49
  optional totOrgCarb QuantityValue = 50
  optional totOrgCMeth String = 51
  optional totNitroContent QuantityValue = 52
  optional totNitroContMeth String = 53
  optional microbialBiomass QuantityValue = 54
  optional microBiomassMeth String = 55
  optional linkAdditAnalys String = 56
  optional salinityMeth String = 57
  repeated heavyMetals String = 58
  optional heavyMetalsMeth String = 59
  optional alSat QuantityValue = 60
  optional alSatMeth String = 61
  repeated miscParam String = 62
  sampName String = 63
  projectName String = 64
  optional sampVolWeDnaExt QuantityValue = 65
  sampTaxonId String = 66
  optional experimentalFactor String = 67
  optional negContType NegContTypeEnum = 68
  optional posContType String = 69
  optional subspecfGenLin String = 70
  optional extrachromElements Integer = 71
  optional estimatedSize String = 72
  optional refBiomaterial String = 73
  optional sourceMatId String = 74
  isolGrowthCondt String = 75
  optional sampCollecDevice String = 76
  optional sampCollecMethod String = 77
  optional sampMatProcess String = 78
  optional sampSize QuantityValue = 79
  optional nuclAcidExt String = 80
  optional nuclAcidAmp String = 81
  optional libSize Integer = 82
  optional libReadsSeqd Integer = 83
  optional libLayout LibLayoutEnum = 84
  optional libVector String = 85
  optional libScreen String = 86
  optional adapters String = 87
  seqMeth String = 88
  optional taxIdent TaxIdentEnum = 89
  optional assemblyQual AssemblyQualEnum = 90
  optional assemblyName String = 91
  assemblySoftware String = 92
  optional annot String = 93
  optional numberContig Integer = 94
  optional featPred String = 95
  optional refDb String = 96
  optional simSearchMeth String = 97
  optional taxClass String = 98
  optional complScore String = 99
  optional complSoftware String = 100
  optional associatedResource String = 101
  optional sop String = 102
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: plant with environmental package soil
message SoilMIGSPlant
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional curLandUse CurLandUseEnum = 11
  optional curVegetation String = 12
  optional curVegetationMeth String = 13
  optional previousLandUse String = 14
  optional prevLandUseMeth String = 15
  optional cropRotation String = 16
  repeated agrochemAddition String = 17
  repeated tillage TillageEnum = 18
  optional fire Date = 19
  optional flooding Date = 20
  optional extremeEvent Date = 21
  optional soilHorizon SoilHorizonEnum = 22
  optional horizonMeth String = 23
  optional sieving String = 24
  optional waterContent QuantityValue = 25
  optional waterContSoilMeth String = 26
  optional poolDnaExtracts String = 27
  optional storeCond String = 28
  optional linkClimateInfo String = 29
  optional annualTemp QuantityValue = 30
  optional seasonTemp QuantityValue = 31
  optional annualPrecpt QuantityValue = 32
  optional seasonPrecpt QuantityValue = 33
  optional linkClassInfo String = 34
  optional faoClass FaoClassEnum = 35
  optional localClass String = 36
  optional localClassMeth String = 37
  optional orgNitro QuantityValue = 38
  optional soilType String = 39
  optional soilTypeMeth String = 40
  optional slopeGradient QuantityValue = 41
  optional slopeAspect QuantityValue = 42
  optional profilePosition ProfilePositionEnum = 43
  optional drainageClass DrainageClassEnum = 44
  optional soilTextMeasure QuantityValue = 45
  optional soilTextureMeth String = 46
  optional ph Double = 47
  optional phMeth String = 48
  optional orgMatter QuantityValue = 49
  optional totOrgCarb QuantityValue = 50
  optional totOrgCMeth String = 51
  optional totNitroContent QuantityValue = 52
  optional totNitroContMeth String = 53
  optional microbialBiomass QuantityValue = 54
  optional microBiomassMeth String = 55
  optional linkAdditAnalys String = 56
  optional salinityMeth String = 57
  repeated heavyMetals String = 58
  optional heavyMetalsMeth String = 59
  optional alSat QuantityValue = 60
  optional alSatMeth String = 61
  repeated miscParam String = 62
  sampName String = 63
  projectName String = 64
  optional sampVolWeDnaExt QuantityValue = 65
  sampTaxonId String = 66
  optional experimentalFactor String = 67
  optional negContType NegContTypeEnum = 68
  optional posContType String = 69
  optional subspecfGenLin String = 70
  optional estimatedSize String = 71
  optional refBiomaterial String = 72
  optional sourceMatId String = 73
  optional specificHost String = 74
  optional hostSpecRange Integer = 75
  propagation String = 76
  optional encodedTraits String = 77
  isolGrowthCondt String = 78
  optional sampCollecDevice String = 79
  optional sampCollecMethod String = 80
  optional sampMatProcess String = 81
  optional sampSize QuantityValue = 82
  optional nuclAcidExt String = 83
  optional nuclAcidAmp String = 84
  optional libSize Integer = 85
  optional libReadsSeqd Integer = 86
  optional libLayout LibLayoutEnum = 87
  optional libVector String = 88
  optional libScreen String = 89
  optional adapters String = 90
  seqMeth String = 91
  optional taxIdent TaxIdentEnum = 92
  optional assemblyQual AssemblyQualEnum = 93
  optional assemblyName String = 94
  assemblySoftware String = 95
  optional annot String = 96
  optional numberContig Integer = 97
  optional featPred String = 98
  optional refDb String = 99
  optional simSearchMeth String = 100
  optional taxClass String = 101
  optional complScore String = 102
  optional complSoftware String = 103
  optional associatedResource String = 104
  optional sop String = 105
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package soil
message SoilMIGSVirus
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional curLandUse CurLandUseEnum = 11
  optional curVegetation String = 12
  optional curVegetationMeth String = 13
  optional previousLandUse String = 14
  optional prevLandUseMeth String = 15
  optional cropRotation String = 16
  repeated agrochemAddition String = 17
  repeated tillage TillageEnum = 18
  optional fire Date = 19
  optional flooding Date = 20
  optional extremeEvent Date = 21
  optional soilHorizon SoilHorizonEnum = 22
  optional horizonMeth String = 23
  optional sieving String = 24
  optional waterContent QuantityValue = 25
  optional waterContSoilMeth String = 26
  optional poolDnaExtracts String = 27
  optional storeCond String = 28
  optional linkClimateInfo String = 29
  optional annualTemp QuantityValue = 30
  optional seasonTemp QuantityValue = 31
  optional annualPrecpt QuantityValue = 32
  optional seasonPrecpt QuantityValue = 33
  optional linkClassInfo String = 34
  optional faoClass FaoClassEnum = 35
  optional localClass String = 36
  optional localClassMeth String = 37
  optional orgNitro QuantityValue = 38
  optional soilType String = 39
  optional soilTypeMeth String = 40
  optional slopeGradient QuantityValue = 41
  optional slopeAspect QuantityValue = 42
  optional profilePosition ProfilePositionEnum = 43
  optional drainageClass DrainageClassEnum = 44
  optional soilTextMeasure QuantityValue = 45
  optional soilTextureMeth String = 46
  optional ph Double = 47
  optional phMeth String = 48
  optional orgMatter QuantityValue = 49
  optional totOrgCarb QuantityValue = 50
  optional totOrgCMeth String = 51
  optional totNitroContent QuantityValue = 52
  optional totNitroContMeth String = 53
  optional microbialBiomass QuantityValue = 54
  optional microBiomassMeth String = 55
  optional linkAdditAnalys String = 56
  optional salinityMeth String = 57
  repeated heavyMetals String = 58
  optional heavyMetalsMeth String = 59
  optional alSat QuantityValue = 60
  optional alSatMeth String = 61
  repeated miscParam String = 62
  sampName String = 63
  projectName String = 64
  optional sampVolWeDnaExt QuantityValue = 65
  sampTaxonId String = 66
  optional experimentalFactor String = 67
  optional negContType NegContTypeEnum = 68
  optional posContType String = 69
  optional subspecfGenLin String = 70
  optional numReplicons Integer = 71
  optional estimatedSize String = 72
  optional refBiomaterial String = 73
  optional sourceMatId String = 74
  optional pathogenicity String = 75
  optional bioticRelationship BioticRelationshipEnum = 76
  optional specificHost String = 77
  optional hostSpecRange Integer = 78
  optional hostDiseaseStat String = 79
  propagation String = 80
  optional encodedTraits String = 81
  isolGrowthCondt String = 82
  optional sampCollecDevice String = 83
  optional sampCollecMethod String = 84
  optional sampMatProcess String = 85
  optional sampSize QuantityValue = 86
  optional virusEnrichAppr VirusEnrichApprEnum = 87
  optional nuclAcidExt String = 88
  optional nuclAcidAmp String = 89
  optional libSize Integer = 90
  optional libReadsSeqd Integer = 91
  optional libLayout LibLayoutEnum = 92
  optional libVector String = 93
  optional libScreen String = 94
  optional adapters String = 95
  seqMeth String = 96
  optional taxIdent TaxIdentEnum = 97
  optional assemblyQual AssemblyQualEnum = 98
  optional assemblyName String = 99
  assemblySoftware String = 100
  optional annot String = 101
  optional numberContig Integer = 102
  optional featPred String = 103
  optional refDb String = 104
  optional simSearchMeth String = 105
  optional taxClass String = 106
  optional complScore String = 107
  optional complSoftware String = 108
  optional associatedResource String = 109
  optional sop String = 110
 }
// Combinatorial checklist Minimum Information About a Metagenome-Assembled Genome with environmental package soil
message SoilMIMAG
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional curLandUse CurLandUseEnum = 11
  optional curVegetation String = 12
  optional curVegetationMeth String = 13
  optional previousLandUse String = 14
  optional prevLandUseMeth String = 15
  optional cropRotation String = 16
  repeated agrochemAddition String = 17
  repeated tillage TillageEnum = 18
  optional fire Date = 19
  optional flooding Date = 20
  optional extremeEvent Date = 21
  optional soilHorizon SoilHorizonEnum = 22
  optional horizonMeth String = 23
  optional sieving String = 24
  optional waterContent QuantityValue = 25
  optional waterContSoilMeth String = 26
  optional poolDnaExtracts String = 27
  optional storeCond String = 28
  optional linkClimateInfo String = 29
  optional annualTemp QuantityValue = 30
  optional seasonTemp QuantityValue = 31
  optional annualPrecpt QuantityValue = 32
  optional seasonPrecpt QuantityValue = 33
  optional linkClassInfo String = 34
  optional faoClass FaoClassEnum = 35
  optional localClass String = 36
  optional localClassMeth String = 37
  optional orgNitro QuantityValue = 38
  optional soilType String = 39
  optional soilTypeMeth String = 40
  optional slopeGradient QuantityValue = 41
  optional slopeAspect QuantityValue = 42
  optional profilePosition ProfilePositionEnum = 43
  optional drainageClass DrainageClassEnum = 44
  optional soilTextMeasure QuantityValue = 45
  optional soilTextureMeth String = 46
  optional ph Double = 47
  optional phMeth String = 48
  optional orgMatter QuantityValue = 49
  optional totOrgCarb QuantityValue = 50
  optional totOrgCMeth String = 51
  optional totNitroContent QuantityValue = 52
  optional totNitroContMeth String = 53
  optional microbialBiomass QuantityValue = 54
  optional microBiomassMeth String = 55
  optional linkAdditAnalys String = 56
  optional salinityMeth String = 57
  repeated heavyMetals String = 58
  optional heavyMetalsMeth String = 59
  optional alSat QuantityValue = 60
  optional alSatMeth String = 61
  repeated miscParam String = 62
  sampName String = 63
  projectName String = 64
  optional sampVolWeDnaExt QuantityValue = 65
  sampTaxonId String = 66
  optional experimentalFactor String = 67
  optional negContType NegContTypeEnum = 68
  optional posContType String = 69
  optional refBiomaterial String = 70
  optional sourceMatId String = 71
  optional relToOxygen RelToOxygenEnum = 72
  optional sampCollecDevice String = 73
  optional sampCollecMethod String = 74
  optional sampMatProcess String = 75
  optional sizeFrac String = 76
  optional sampSize QuantityValue = 77
  optional nuclAcidExt String = 78
  optional nuclAcidAmp String = 79
  optional libSize Integer = 80
  optional libReadsSeqd Integer = 81
  optional libLayout LibLayoutEnum = 82
  optional libVector String = 83
  optional libScreen String = 84
  optional mid String = 85
  optional adapters String = 86
  seqMeth String = 87
  taxIdent TaxIdentEnum = 88
  assemblyQual AssemblyQualEnum = 89
  optional assemblyName String = 90
  assemblySoftware String = 91
  optional annot String = 92
  optional numberContig Integer = 93
  optional featPred String = 94
  optional refDb String = 95
  optional simSearchMeth String = 96
  optional taxClass String = 97
  optional x16sRecover String = 98
  optional x16sRecoverSoftware String = 99
  optional trnas Integer = 100
  optional trnaExtSoftware String = 101
  complScore String = 102
  complSoftware String = 103
  optional complAppr ComplApprEnum = 104
  contamScore String = 105
  optional contamScreenInput String = 106
  optional contamScreenParam String = 107
  optional decontamSoftware DecontamSoftwareEnum = 108
  binParam BinParamEnum = 109
  binSoftware String = 110
  optional reassemblyBin String = 111
  optional magCovSoftware MagCovSoftwareEnum = 112
  optional associatedResource String = 113
  optional sop String = 114
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: specimen with environmental package soil
message SoilMIMARKSSpecimen
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional curLandUse CurLandUseEnum = 11
  optional curVegetation String = 12
  optional curVegetationMeth String = 13
  optional previousLandUse String = 14
  optional prevLandUseMeth String = 15
  optional cropRotation String = 16
  repeated agrochemAddition String = 17
  repeated tillage TillageEnum = 18
  optional fire Date = 19
  optional flooding Date = 20
  optional extremeEvent Date = 21
  optional soilHorizon SoilHorizonEnum = 22
  optional horizonMeth String = 23
  optional sieving String = 24
  optional waterContent QuantityValue = 25
  optional waterContSoilMeth String = 26
  optional poolDnaExtracts String = 27
  optional storeCond String = 28
  optional linkClimateInfo String = 29
  optional annualTemp QuantityValue = 30
  optional seasonTemp QuantityValue = 31
  optional annualPrecpt QuantityValue = 32
  optional seasonPrecpt QuantityValue = 33
  optional linkClassInfo String = 34
  optional faoClass FaoClassEnum = 35
  optional localClass String = 36
  optional localClassMeth String = 37
  optional orgNitro QuantityValue = 38
  optional soilType String = 39
  optional soilTypeMeth String = 40
  optional slopeGradient QuantityValue = 41
  optional slopeAspect QuantityValue = 42
  optional profilePosition ProfilePositionEnum = 43
  optional drainageClass DrainageClassEnum = 44
  optional soilTextMeasure QuantityValue = 45
  optional soilTextureMeth String = 46
  optional ph Double = 47
  optional phMeth String = 48
  optional orgMatter QuantityValue = 49
  optional totOrgCarb QuantityValue = 50
  optional totOrgCMeth String = 51
  optional totNitroContent QuantityValue = 52
  optional totNitroContMeth String = 53
  optional microbialBiomass QuantityValue = 54
  optional microBiomassMeth String = 55
  optional linkAdditAnalys String = 56
  optional salinityMeth String = 57
  repeated heavyMetals String = 58
  optional heavyMetalsMeth String = 59
  optional alSat QuantityValue = 60
  optional alSatMeth String = 61
  repeated miscParam String = 62
  sampName String = 63
  projectName String = 64
  optional sampVolWeDnaExt QuantityValue = 65
  sampTaxonId String = 66
  optional experimentalFactor String = 67
  optional negContType NegContTypeEnum = 68
  optional posContType String = 69
  optional sourceMatId String = 70
  optional relToOxygen RelToOxygenEnum = 71
  optional sampCollecDevice String = 72
  optional sampCollecMethod String = 73
  optional sampMatProcess String = 74
  optional sizeFrac String = 75
  optional sampSize QuantityValue = 76
  optional nuclAcidExt String = 77
  optional nuclAcidAmp String = 78
  optional libSize Integer = 79
  optional libReadsSeqd Integer = 80
  optional libLayout LibLayoutEnum = 81
  optional libVector String = 82
  optional libScreen String = 83
  targetGene String = 84
  optional targetSubfragment String = 85
  optional pcrPrimers String = 86
  optional mid String = 87
  optional adapters String = 88
  optional pcrCond String = 89
  seqMeth String = 90
  optional seqQualityCheck String = 91
  optional chimeraCheck String = 92
  optional assemblySoftware String = 93
  optional associatedResource String = 94
  optional sop String = 95
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: survey with environmental package soil
message SoilMIMARKSSurvey
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional curLandUse CurLandUseEnum = 11
  optional curVegetation String = 12
  optional curVegetationMeth String = 13
  optional previousLandUse String = 14
  optional prevLandUseMeth String = 15
  optional cropRotation String = 16
  repeated agrochemAddition String = 17
  repeated tillage TillageEnum = 18
  optional fire Date = 19
  optional flooding Date = 20
  optional extremeEvent Date = 21
  optional soilHorizon SoilHorizonEnum = 22
  optional horizonMeth String = 23
  optional sieving String = 24
  optional waterContent QuantityValue = 25
  optional waterContSoilMeth String = 26
  optional poolDnaExtracts String = 27
  optional storeCond String = 28
  optional linkClimateInfo String = 29
  optional annualTemp QuantityValue = 30
  optional seasonTemp QuantityValue = 31
  optional annualPrecpt QuantityValue = 32
  optional seasonPrecpt QuantityValue = 33
  optional linkClassInfo String = 34
  optional faoClass FaoClassEnum = 35
  optional localClass String = 36
  optional localClassMeth String = 37
  optional orgNitro QuantityValue = 38
  optional soilType String = 39
  optional soilTypeMeth String = 40
  optional slopeGradient QuantityValue = 41
  optional slopeAspect QuantityValue = 42
  optional profilePosition ProfilePositionEnum = 43
  optional drainageClass DrainageClassEnum = 44
  optional soilTextMeasure QuantityValue = 45
  optional soilTextureMeth String = 46
  optional ph Double = 47
  optional phMeth String = 48
  optional orgMatter QuantityValue = 49
  optional totOrgCarb QuantityValue = 50
  optional totOrgCMeth String = 51
  optional totNitroContent QuantityValue = 52
  optional totNitroContMeth String = 53
  optional microbialBiomass QuantityValue = 54
  optional microBiomassMeth String = 55
  optional linkAdditAnalys String = 56
  optional salinityMeth String = 57
  repeated heavyMetals String = 58
  optional heavyMetalsMeth String = 59
  optional alSat QuantityValue = 60
  optional alSatMeth String = 61
  repeated miscParam String = 62
  sampName String = 63
  projectName String = 64
  optional sampVolWeDnaExt QuantityValue = 65
  sampTaxonId String = 66
  optional experimentalFactor String = 67
  optional negContType NegContTypeEnum = 68
  optional posContType String = 69
  optional subspecfGenLin String = 70
  optional extrachromElements Integer = 71
  optional sourceMatId String = 72
  optional bioticRelationship BioticRelationshipEnum = 73
  optional trophicLevel TrophicLevelEnum = 74
  optional relToOxygen RelToOxygenEnum = 75
  isolGrowthCondt String = 76
  optional sampCollecDevice String = 77
  optional sampCollecMethod String = 78
  optional sampMatProcess String = 79
  optional sampSize QuantityValue = 80
  optional nuclAcidExt String = 81
  optional nuclAcidAmp String = 82
  targetGene String = 83
  optional targetSubfragment String = 84
  optional pcrPrimers String = 85
  optional pcrCond String = 86
  seqMeth String = 87
  optional seqQualityCheck String = 88
  optional chimeraCheck String = 89
  optional associatedResource String = 90
  optional sop String = 91
 }
// Combinatorial checklist Metagenome or Environmental with environmental package soil
message SoilMIMS
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional curLandUse CurLandUseEnum = 11
  optional curVegetation String = 12
  optional curVegetationMeth String = 13
  optional previousLandUse String = 14
  optional prevLandUseMeth String = 15
  optional cropRotation String = 16
  repeated agrochemAddition String = 17
  repeated tillage TillageEnum = 18
  optional fire Date = 19
  optional flooding Date = 20
  optional extremeEvent Date = 21
  optional soilHorizon SoilHorizonEnum = 22
  optional horizonMeth String = 23
  optional sieving String = 24
  optional waterContent QuantityValue = 25
  optional waterContSoilMeth String = 26
  optional poolDnaExtracts String = 27
  optional storeCond String = 28
  optional linkClimateInfo String = 29
  optional annualTemp QuantityValue = 30
  optional seasonTemp QuantityValue = 31
  optional annualPrecpt QuantityValue = 32
  optional seasonPrecpt QuantityValue = 33
  optional linkClassInfo String = 34
  optional faoClass FaoClassEnum = 35
  optional localClass String = 36
  optional localClassMeth String = 37
  optional orgNitro QuantityValue = 38
  optional soilType String = 39
  optional soilTypeMeth String = 40
  optional slopeGradient QuantityValue = 41
  optional slopeAspect QuantityValue = 42
  optional profilePosition ProfilePositionEnum = 43
  optional drainageClass DrainageClassEnum = 44
  optional soilTextMeasure QuantityValue = 45
  optional soilTextureMeth String = 46
  optional ph Double = 47
  optional phMeth String = 48
  optional orgMatter QuantityValue = 49
  optional totOrgCarb QuantityValue = 50
  optional totOrgCMeth String = 51
  optional totNitroContent QuantityValue = 52
  optional totNitroContMeth String = 53
  optional microbialBiomass QuantityValue = 54
  optional microBiomassMeth String = 55
  optional linkAdditAnalys String = 56
  optional salinityMeth String = 57
  repeated heavyMetals String = 58
  optional heavyMetalsMeth String = 59
  optional alSat QuantityValue = 60
  optional alSatMeth String = 61
  repeated miscParam String = 62
  sampName String = 63
  projectName String = 64
  optional sampVolWeDnaExt QuantityValue = 65
  sampTaxonId String = 66
  optional experimentalFactor String = 67
  optional negContType NegContTypeEnum = 68
  optional posContType String = 69
  optional refBiomaterial String = 70
  optional sourceMatId String = 71
  optional relToOxygen RelToOxygenEnum = 72
  optional sampCollecDevice String = 73
  optional sampCollecMethod String = 74
  optional sampMatProcess String = 75
  optional sizeFrac String = 76
  optional sampSize QuantityValue = 77
  optional nuclAcidExt String = 78
  optional nuclAcidAmp String = 79
  optional libSize Integer = 80
  optional libReadsSeqd Integer = 81
  optional libLayout LibLayoutEnum = 82
  optional libVector String = 83
  optional libScreen String = 84
  optional mid String = 85
  optional adapters String = 86
  seqMeth String = 87
  optional assemblyQual AssemblyQualEnum = 88
  optional assemblyName String = 89
  optional assemblySoftware String = 90
  optional annot String = 91
  optional numberContig Integer = 92
  optional featPred String = 93
  optional refDb String = 94
  optional simSearchMeth String = 95
  optional taxClass String = 96
  optional associatedResource String = 97
  optional sop String = 98
 }
// Combinatorial checklist Minimum Information About a Single Amplified Genome with environmental package soil
message SoilMISAG
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional curLandUse CurLandUseEnum = 11
  optional curVegetation String = 12
  optional curVegetationMeth String = 13
  optional previousLandUse String = 14
  optional prevLandUseMeth String = 15
  optional cropRotation String = 16
  repeated agrochemAddition String = 17
  repeated tillage TillageEnum = 18
  optional fire Date = 19
  optional flooding Date = 20
  optional extremeEvent Date = 21
  optional soilHorizon SoilHorizonEnum = 22
  optional horizonMeth String = 23
  optional sieving String = 24
  optional waterContent QuantityValue = 25
  optional waterContSoilMeth String = 26
  optional poolDnaExtracts String = 27
  optional storeCond String = 28
  optional linkClimateInfo String = 29
  optional annualTemp QuantityValue = 30
  optional seasonTemp QuantityValue = 31
  optional annualPrecpt QuantityValue = 32
  optional seasonPrecpt QuantityValue = 33
  optional linkClassInfo String = 34
  optional faoClass FaoClassEnum = 35
  optional localClass String = 36
  optional localClassMeth String = 37
  optional orgNitro QuantityValue = 38
  optional soilType String = 39
  optional soilTypeMeth String = 40
  optional slopeGradient QuantityValue = 41
  optional slopeAspect QuantityValue = 42
  optional profilePosition ProfilePositionEnum = 43
  optional drainageClass DrainageClassEnum = 44
  optional soilTextMeasure QuantityValue = 45
  optional soilTextureMeth String = 46
  optional ph Double = 47
  optional phMeth String = 48
  optional orgMatter QuantityValue = 49
  optional totOrgCarb QuantityValue = 50
  optional totOrgCMeth String = 51
  optional totNitroContent QuantityValue = 52
  optional totNitroContMeth String = 53
  optional microbialBiomass QuantityValue = 54
  optional microBiomassMeth String = 55
  optional linkAdditAnalys String = 56
  optional salinityMeth String = 57
  repeated heavyMetals String = 58
  optional heavyMetalsMeth String = 59
  optional alSat QuantityValue = 60
  optional alSatMeth String = 61
  repeated miscParam String = 62
  sampName String = 63
  projectName String = 64
  optional sampVolWeDnaExt QuantityValue = 65
  sampTaxonId String = 66
  optional experimentalFactor String = 67
  optional negContType NegContTypeEnum = 68
  optional posContType String = 69
  optional refBiomaterial String = 70
  optional sourceMatId String = 71
  optional relToOxygen RelToOxygenEnum = 72
  optional sampCollecDevice String = 73
  optional sampCollecMethod String = 74
  optional sampMatProcess String = 75
  optional sizeFrac String = 76
  optional sampSize QuantityValue = 77
  optional nuclAcidExt String = 78
  optional nuclAcidAmp String = 79
  optional libSize Integer = 80
  optional libReadsSeqd Integer = 81
  optional libLayout LibLayoutEnum = 82
  optional libVector String = 83
  optional libScreen String = 84
  optional mid String = 85
  optional adapters String = 86
  seqMeth String = 87
  taxIdent TaxIdentEnum = 88
  assemblyQual AssemblyQualEnum = 89
  optional assemblyName String = 90
  assemblySoftware String = 91
  optional annot String = 92
  optional numberContig Integer = 93
  optional featPred String = 94
  optional refDb String = 95
  optional simSearchMeth String = 96
  optional taxClass String = 97
  optional x16sRecover String = 98
  optional x16sRecoverSoftware String = 99
  optional trnas Integer = 100
  optional trnaExtSoftware String = 101
  complScore String = 102
  complSoftware String = 103
  optional complAppr ComplApprEnum = 104
  contamScore String = 105
  optional contamScreenInput String = 106
  optional contamScreenParam String = 107
  optional decontamSoftware DecontamSoftwareEnum = 108
  sortTech SortTechEnum = 109
  singleCellLysisAppr SingleCellLysisApprEnum = 110
  optional singleCellLysisProt String = 111
  wgaAmpAppr String = 112
  optional wgaAmpKit String = 113
  optional associatedResource String = 114
  optional sop String = 115
 }
// Combinatorial checklist Minimum Information About an Uncultivated Virus Genome with environmental package soil
message SoilMIUVIG
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional curLandUse CurLandUseEnum = 11
  optional curVegetation String = 12
  optional curVegetationMeth String = 13
  optional previousLandUse String = 14
  optional prevLandUseMeth String = 15
  optional cropRotation String = 16
  repeated agrochemAddition String = 17
  repeated tillage TillageEnum = 18
  optional fire Date = 19
  optional flooding Date = 20
  optional extremeEvent Date = 21
  optional soilHorizon SoilHorizonEnum = 22
  optional horizonMeth String = 23
  optional sieving String = 24
  optional waterContent QuantityValue = 25
  optional waterContSoilMeth String = 26
  optional poolDnaExtracts String = 27
  optional storeCond String = 28
  optional linkClimateInfo String = 29
  optional annualTemp QuantityValue = 30
  optional seasonTemp QuantityValue = 31
  optional annualPrecpt QuantityValue = 32
  optional seasonPrecpt QuantityValue = 33
  optional linkClassInfo String = 34
  optional faoClass FaoClassEnum = 35
  optional localClass String = 36
  optional localClassMeth String = 37
  optional orgNitro QuantityValue = 38
  optional soilType String = 39
  optional soilTypeMeth String = 40
  optional slopeGradient QuantityValue = 41
  optional slopeAspect QuantityValue = 42
  optional profilePosition ProfilePositionEnum = 43
  optional drainageClass DrainageClassEnum = 44
  optional soilTextMeasure QuantityValue = 45
  optional soilTextureMeth String = 46
  optional ph Double = 47
  optional phMeth String = 48
  optional orgMatter QuantityValue = 49
  optional totOrgCarb QuantityValue = 50
  optional totOrgCMeth String = 51
  optional totNitroContent QuantityValue = 52
  optional totNitroContMeth String = 53
  optional microbialBiomass QuantityValue = 54
  optional microBiomassMeth String = 55
  optional linkAdditAnalys String = 56
  optional salinityMeth String = 57
  repeated heavyMetals String = 58
  optional heavyMetalsMeth String = 59
  optional alSat QuantityValue = 60
  optional alSatMeth String = 61
  repeated miscParam String = 62
  sampName String = 63
  projectName String = 64
  optional sampVolWeDnaExt QuantityValue = 65
  sampTaxonId String = 66
  optional experimentalFactor String = 67
  optional negContType NegContTypeEnum = 68
  optional posContType String = 69
  optional estimatedSize String = 70
  optional refBiomaterial String = 71
  optional sourceMatId String = 72
  optional pathogenicity String = 73
  optional bioticRelationship BioticRelationshipEnum = 74
  optional specificHost String = 75
  optional hostSpecRange Integer = 76
  optional hostDiseaseStat String = 77
  optional sampCollecDevice String = 78
  optional sampCollecMethod String = 79
  optional sampMatProcess String = 80
  optional sizeFrac String = 81
  optional sampSize QuantityValue = 82
  sourceUvig SourceUvigEnum = 83
  virusEnrichAppr VirusEnrichApprEnum = 84
  optional nuclAcidExt String = 85
  optional nuclAcidAmp String = 86
  optional libSize Integer = 87
  optional libReadsSeqd Integer = 88
  optional libLayout LibLayoutEnum = 89
  optional libVector String = 90
  optional libScreen String = 91
  optional mid String = 92
  optional adapters String = 93
  seqMeth String = 94
  optional taxIdent TaxIdentEnum = 95
  assemblyQual AssemblyQualEnum = 96
  optional assemblyName String = 97
  assemblySoftware String = 98
  optional annot String = 99
  numberContig Integer = 100
  optional featPred String = 101
  optional refDb String = 102
  optional simSearchMeth String = 103
  optional taxClass String = 104
  optional trnas Integer = 105
  optional trnaExtSoftware String = 106
  optional complScore String = 107
  optional complSoftware String = 108
  optional complAppr ComplApprEnum = 109
  optional sortTech SortTechEnum = 110
  optional singleCellLysisAppr SingleCellLysisApprEnum = 111
  optional singleCellLysisProt String = 112
  optional wgaAmpAppr String = 113
  optional wgaAmpKit String = 114
  optional binParam BinParamEnum = 115
  optional binSoftware String = 116
  optional reassemblyBin String = 117
  optional magCovSoftware MagCovSoftwareEnum = 118
  virIdentSoftware String = 119
  predGenomeType PredGenomeTypeEnum = 120
  predGenomeStruc PredGenomeStrucEnum = 121
  detecType String = 122
  optional otuClassAppr String = 123
  optional otuSeqCompAppr String = 124
  optional otuDb String = 125
  optional hostPredAppr HostPredApprEnum = 126
  optional hostPredEstAcc String = 127
  optional associatedResource String = 128
  optional sop String = 129
 }
// symbiont-associated
message Symbiont-associated
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  sampleName String = 11
  optional hostSubjectId String = 12
  optional hostCommonName String = 13
  optional hostTaxid String = 14
  hostDependence String = 15
  optional typeOfSymbiosis TypeOfSymbiosisEnum = 16
  symLifeCycleType String = 17
  hostLifeStage String = 18
  optional hostAge QuantityValue = 19
  optional hostSex HostSexEnum = 20
  optional modeTransmission ModeTransmissionEnum = 21
  optional routeTransmission RouteTransmissionEnum = 22
  optional hostBodyHabitat String = 23
  optional hostBodySite String = 24
  optional hostBodyProduct String = 25
  optional hostTotMass QuantityValue = 26
  optional hostHeight QuantityValue = 27
  optional hostLength QuantityValue = 28
  optional hostGrowthCond String = 29
  optional hostSubstrate String = 30
  optional hostFamilyRelationship String = 31
  optional hostInfraSpecificName String = 32
  optional hostInfraSpecificRank String = 33
  optional hostGenotype String = 34
  optional hostPhenotype String = 35
  optional hostDryMass QuantityValue = 36
  optional hostColor String = 37
  optional hostShape String = 38
  optional gravidity String = 39
  optional hostNumber String = 40
  repeated hostSymbiont String = 41
  optional hostSpecificity HostSpecificityEnum = 42
  optional symbiontHostRole SymbiontHostRoleEnum = 43
  optional hostCellularLoc HostCellularLocEnum = 44
  optional associationDuration QuantityValue = 45
  optional hostOfHostCoinf String = 46
  optional hostOfHostName String = 47
  repeated hostOfHostEnvLoc String = 48
  optional hostOfHostEnvMed String = 49
  optional hostOfHostTaxid Integer = 50
  optional hostOfHostSubId String = 51
  repeated hostOfHostDisease String = 52
  repeated hostOfHostFamRel String = 53
  optional hostOfHostInfname String = 54
  optional hostOfHostInfrank String = 55
  optional hostOfHostGeno String = 56
  optional hostOfHostPheno String = 57
  optional hostOfHostGravid String = 58
  optional hostOfHostTotmass QuantityValue = 59
  repeated chemAdministration String = 60
  repeated perturbation String = 61
  optional sampSalinity QuantityValue = 62
  optional oxyStatSamp OxyStatSampEnum = 63
  repeated organismCount OrganismCountEnum = 64
  optional sampStoreTemp QuantityValue = 65
  optional sampStoreDur String = 66
  optional sampStoreLoc String = 67
  optional sampStoreSol String = 68
  repeated miscParam String = 69
  projectName String = 70
  optional sourceMatId String = 71
  optional sampVolWeDnaExt QuantityValue = 72
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package symbiont-associated
message Symbiont-associatedMIGSBacteria
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  sampleName String = 11
  optional hostSubjectId String = 12
  optional hostCommonName String = 13
  optional hostTaxid String = 14
  hostDependence String = 15
  optional typeOfSymbiosis TypeOfSymbiosisEnum = 16
  symLifeCycleType String = 17
  hostLifeStage String = 18
  optional hostAge QuantityValue = 19
  optional hostSex HostSexEnum = 20
  optional modeTransmission ModeTransmissionEnum = 21
  optional routeTransmission RouteTransmissionEnum = 22
  optional hostBodyHabitat String = 23
  optional hostBodySite String = 24
  optional hostBodyProduct String = 25
  optional hostTotMass QuantityValue = 26
  optional hostHeight QuantityValue = 27
  optional hostLength QuantityValue = 28
  optional hostGrowthCond String = 29
  optional hostSubstrate String = 30
  optional hostFamilyRelationship String = 31
  optional hostInfraSpecificName String = 32
  optional hostInfraSpecificRank String = 33
  optional hostGenotype String = 34
  optional hostPhenotype String = 35
  optional hostDryMass QuantityValue = 36
  optional hostColor String = 37
  optional hostShape String = 38
  optional gravidity String = 39
  optional hostNumber String = 40
  repeated hostSymbiont String = 41
  optional hostSpecificity HostSpecificityEnum = 42
  optional symbiontHostRole SymbiontHostRoleEnum = 43
  optional hostCellularLoc HostCellularLocEnum = 44
  optional associationDuration QuantityValue = 45
  optional hostOfHostCoinf String = 46
  optional hostOfHostName String = 47
  repeated hostOfHostEnvLoc String = 48
  optional hostOfHostEnvMed String = 49
  optional hostOfHostTaxid Integer = 50
  optional hostOfHostSubId String = 51
  repeated hostOfHostDisease String = 52
  repeated hostOfHostFamRel String = 53
  optional hostOfHostInfname String = 54
  optional hostOfHostInfrank String = 55
  optional hostOfHostGeno String = 56
  optional hostOfHostPheno String = 57
  optional hostOfHostGravid String = 58
  optional hostOfHostTotmass QuantityValue = 59
  repeated chemAdministration String = 60
  repeated perturbation String = 61
  optional sampSalinity QuantityValue = 62
  optional oxyStatSamp OxyStatSampEnum = 63
  repeated organismCount OrganismCountEnum = 64
  optional sampStoreTemp QuantityValue = 65
  optional sampStoreDur String = 66
  optional sampStoreLoc String = 67
  optional sampStoreSol String = 68
  repeated miscParam String = 69
  projectName String = 70
  optional sourceMatId String = 71
  optional sampVolWeDnaExt QuantityValue = 72
  sampName String = 73
  sampTaxonId String = 74
  optional experimentalFactor String = 75
  optional negContType NegContTypeEnum = 76
  optional posContType String = 77
  optional subspecfGenLin String = 78
  numReplicons Integer = 79
  optional extrachromElements Integer = 80
  optional estimatedSize String = 81
  refBiomaterial String = 82
  optional pathogenicity String = 83
  optional bioticRelationship BioticRelationshipEnum = 84
  optional specificHost String = 85
  optional hostSpecRange Integer = 86
  optional hostDiseaseStat String = 87
  optional trophicLevel TrophicLevelEnum = 88
  optional encodedTraits String = 89
  optional relToOxygen RelToOxygenEnum = 90
  isolGrowthCondt String = 91
  optional sampCollecDevice String = 92
  optional sampCollecMethod String = 93
  optional sampMatProcess String = 94
  optional sampSize QuantityValue = 95
  optional nuclAcidExt String = 96
  optional nuclAcidAmp String = 97
  optional libSize Integer = 98
  optional libReadsSeqd Integer = 99
  optional libLayout LibLayoutEnum = 100
  optional libVector String = 101
  optional libScreen String = 102
  optional adapters String = 103
  seqMeth String = 104
  optional taxIdent TaxIdentEnum = 105
  assemblyQual AssemblyQualEnum = 106
  optional assemblyName String = 107
  assemblySoftware String = 108
  optional annot String = 109
  numberContig Integer = 110
  optional featPred String = 111
  optional refDb String = 112
  optional simSearchMeth String = 113
  optional taxClass String = 114
  optional complScore String = 115
  optional complSoftware String = 116
  optional associatedResource String = 117
  optional sop String = 118
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: eukaryote with environmental package symbiont-associated
message Symbiont-associatedMIGSEukaryote
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  sampleName String = 11
  optional hostSubjectId String = 12
  optional hostCommonName String = 13
  optional hostTaxid String = 14
  hostDependence String = 15
  optional typeOfSymbiosis TypeOfSymbiosisEnum = 16
  symLifeCycleType String = 17
  hostLifeStage String = 18
  optional hostAge QuantityValue = 19
  optional hostSex HostSexEnum = 20
  optional modeTransmission ModeTransmissionEnum = 21
  optional routeTransmission RouteTransmissionEnum = 22
  optional hostBodyHabitat String = 23
  optional hostBodySite String = 24
  optional hostBodyProduct String = 25
  optional hostTotMass QuantityValue = 26
  optional hostHeight QuantityValue = 27
  optional hostLength QuantityValue = 28
  optional hostGrowthCond String = 29
  optional hostSubstrate String = 30
  optional hostFamilyRelationship String = 31
  optional hostInfraSpecificName String = 32
  optional hostInfraSpecificRank String = 33
  optional hostGenotype String = 34
  optional hostPhenotype String = 35
  optional hostDryMass QuantityValue = 36
  optional hostColor String = 37
  optional hostShape String = 38
  optional gravidity String = 39
  optional hostNumber String = 40
  repeated hostSymbiont String = 41
  optional hostSpecificity HostSpecificityEnum = 42
  optional symbiontHostRole SymbiontHostRoleEnum = 43
  optional hostCellularLoc HostCellularLocEnum = 44
  optional associationDuration QuantityValue = 45
  optional hostOfHostCoinf String = 46
  optional hostOfHostName String = 47
  repeated hostOfHostEnvLoc String = 48
  optional hostOfHostEnvMed String = 49
  optional hostOfHostTaxid Integer = 50
  optional hostOfHostSubId String = 51
  repeated hostOfHostDisease String = 52
  repeated hostOfHostFamRel String = 53
  optional hostOfHostInfname String = 54
  optional hostOfHostInfrank String = 55
  optional hostOfHostGeno String = 56
  optional hostOfHostPheno String = 57
  optional hostOfHostGravid String = 58
  optional hostOfHostTotmass QuantityValue = 59
  repeated chemAdministration String = 60
  repeated perturbation String = 61
  optional sampSalinity QuantityValue = 62
  optional oxyStatSamp OxyStatSampEnum = 63
  repeated organismCount OrganismCountEnum = 64
  optional sampStoreTemp QuantityValue = 65
  optional sampStoreDur String = 66
  optional sampStoreLoc String = 67
  optional sampStoreSol String = 68
  repeated miscParam String = 69
  projectName String = 70
  optional sourceMatId String = 71
  optional sampVolWeDnaExt QuantityValue = 72
  sampName String = 73
  sampTaxonId String = 74
  optional experimentalFactor String = 75
  optional negContType NegContTypeEnum = 76
  optional posContType String = 77
  optional subspecfGenLin String = 78
  optional ploidy String = 79
  optional numReplicons Integer = 80
  optional extrachromElements Integer = 81
  optional estimatedSize String = 82
  optional refBiomaterial String = 83
  optional pathogenicity String = 84
  optional bioticRelationship BioticRelationshipEnum = 85
  optional specificHost String = 86
  optional hostSpecRange Integer = 87
  optional hostDiseaseStat String = 88
  optional trophicLevel TrophicLevelEnum = 89
  optional propagation String = 90
  isolGrowthCondt String = 91
  optional sampCollecDevice String = 92
  optional sampCollecMethod String = 93
  optional sampMatProcess String = 94
  optional sampSize QuantityValue = 95
  optional nuclAcidExt String = 96
  optional nuclAcidAmp String = 97
  optional libSize Integer = 98
  optional libReadsSeqd Integer = 99
  optional libLayout LibLayoutEnum = 100
  optional libVector String = 101
  optional libScreen String = 102
  optional adapters String = 103
  seqMeth String = 104
  optional taxIdent TaxIdentEnum = 105
  assemblyQual AssemblyQualEnum = 106
  optional assemblyName String = 107
  assemblySoftware String = 108
  optional annot String = 109
  numberContig Integer = 110
  optional featPred String = 111
  optional refDb String = 112
  optional simSearchMeth String = 113
  optional taxClass String = 114
  optional complScore String = 115
  optional complSoftware String = 116
  optional associatedResource String = 117
  optional sop String = 118
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: org with environmental package symbiont-associated
message Symbiont-associatedMIGSOrg
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  sampleName String = 11
  optional hostSubjectId String = 12
  optional hostCommonName String = 13
  optional hostTaxid String = 14
  hostDependence String = 15
  optional typeOfSymbiosis TypeOfSymbiosisEnum = 16
  symLifeCycleType String = 17
  hostLifeStage String = 18
  optional hostAge QuantityValue = 19
  optional hostSex HostSexEnum = 20
  optional modeTransmission ModeTransmissionEnum = 21
  optional routeTransmission RouteTransmissionEnum = 22
  optional hostBodyHabitat String = 23
  optional hostBodySite String = 24
  optional hostBodyProduct String = 25
  optional hostTotMass QuantityValue = 26
  optional hostHeight QuantityValue = 27
  optional hostLength QuantityValue = 28
  optional hostGrowthCond String = 29
  optional hostSubstrate String = 30
  optional hostFamilyRelationship String = 31
  optional hostInfraSpecificName String = 32
  optional hostInfraSpecificRank String = 33
  optional hostGenotype String = 34
  optional hostPhenotype String = 35
  optional hostDryMass QuantityValue = 36
  optional hostColor String = 37
  optional hostShape String = 38
  optional gravidity String = 39
  optional hostNumber String = 40
  repeated hostSymbiont String = 41
  optional hostSpecificity HostSpecificityEnum = 42
  optional symbiontHostRole SymbiontHostRoleEnum = 43
  optional hostCellularLoc HostCellularLocEnum = 44
  optional associationDuration QuantityValue = 45
  optional hostOfHostCoinf String = 46
  optional hostOfHostName String = 47
  repeated hostOfHostEnvLoc String = 48
  optional hostOfHostEnvMed String = 49
  optional hostOfHostTaxid Integer = 50
  optional hostOfHostSubId String = 51
  repeated hostOfHostDisease String = 52
  repeated hostOfHostFamRel String = 53
  optional hostOfHostInfname String = 54
  optional hostOfHostInfrank String = 55
  optional hostOfHostGeno String = 56
  optional hostOfHostPheno String = 57
  optional hostOfHostGravid String = 58
  optional hostOfHostTotmass QuantityValue = 59
  repeated chemAdministration String = 60
  repeated perturbation String = 61
  optional sampSalinity QuantityValue = 62
  optional oxyStatSamp OxyStatSampEnum = 63
  repeated organismCount OrganismCountEnum = 64
  optional sampStoreTemp QuantityValue = 65
  optional sampStoreDur String = 66
  optional sampStoreLoc String = 67
  optional sampStoreSol String = 68
  repeated miscParam String = 69
  projectName String = 70
  optional sourceMatId String = 71
  optional sampVolWeDnaExt QuantityValue = 72
  sampName String = 73
  sampTaxonId String = 74
  optional experimentalFactor String = 75
  optional negContType NegContTypeEnum = 76
  optional posContType String = 77
  optional subspecfGenLin String = 78
  optional extrachromElements Integer = 79
  optional estimatedSize String = 80
  optional refBiomaterial String = 81
  isolGrowthCondt String = 82
  optional sampCollecDevice String = 83
  optional sampCollecMethod String = 84
  optional sampMatProcess String = 85
  optional sampSize QuantityValue = 86
  optional nuclAcidExt String = 87
  optional nuclAcidAmp String = 88
  optional libSize Integer = 89
  optional libReadsSeqd Integer = 90
  optional libLayout LibLayoutEnum = 91
  optional libVector String = 92
  optional libScreen String = 93
  optional adapters String = 94
  seqMeth String = 95
  optional taxIdent TaxIdentEnum = 96
  optional assemblyQual AssemblyQualEnum = 97
  optional assemblyName String = 98
  assemblySoftware String = 99
  optional annot String = 100
  optional numberContig Integer = 101
  optional featPred String = 102
  optional refDb String = 103
  optional simSearchMeth String = 104
  optional taxClass String = 105
  optional complScore String = 106
  optional complSoftware String = 107
  optional associatedResource String = 108
  optional sop String = 109
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: plant with environmental package symbiont-associated
message Symbiont-associatedMIGSPlant
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  sampleName String = 11
  optional hostSubjectId String = 12
  optional hostCommonName String = 13
  optional hostTaxid String = 14
  hostDependence String = 15
  optional typeOfSymbiosis TypeOfSymbiosisEnum = 16
  symLifeCycleType String = 17
  hostLifeStage String = 18
  optional hostAge QuantityValue = 19
  optional hostSex HostSexEnum = 20
  optional modeTransmission ModeTransmissionEnum = 21
  optional routeTransmission RouteTransmissionEnum = 22
  optional hostBodyHabitat String = 23
  optional hostBodySite String = 24
  optional hostBodyProduct String = 25
  optional hostTotMass QuantityValue = 26
  optional hostHeight QuantityValue = 27
  optional hostLength QuantityValue = 28
  optional hostGrowthCond String = 29
  optional hostSubstrate String = 30
  optional hostFamilyRelationship String = 31
  optional hostInfraSpecificName String = 32
  optional hostInfraSpecificRank String = 33
  optional hostGenotype String = 34
  optional hostPhenotype String = 35
  optional hostDryMass QuantityValue = 36
  optional hostColor String = 37
  optional hostShape String = 38
  optional gravidity String = 39
  optional hostNumber String = 40
  repeated hostSymbiont String = 41
  optional hostSpecificity HostSpecificityEnum = 42
  optional symbiontHostRole SymbiontHostRoleEnum = 43
  optional hostCellularLoc HostCellularLocEnum = 44
  optional associationDuration QuantityValue = 45
  optional hostOfHostCoinf String = 46
  optional hostOfHostName String = 47
  repeated hostOfHostEnvLoc String = 48
  optional hostOfHostEnvMed String = 49
  optional hostOfHostTaxid Integer = 50
  optional hostOfHostSubId String = 51
  repeated hostOfHostDisease String = 52
  repeated hostOfHostFamRel String = 53
  optional hostOfHostInfname String = 54
  optional hostOfHostInfrank String = 55
  optional hostOfHostGeno String = 56
  optional hostOfHostPheno String = 57
  optional hostOfHostGravid String = 58
  optional hostOfHostTotmass QuantityValue = 59
  repeated chemAdministration String = 60
  repeated perturbation String = 61
  optional sampSalinity QuantityValue = 62
  optional oxyStatSamp OxyStatSampEnum = 63
  repeated organismCount OrganismCountEnum = 64
  optional sampStoreTemp QuantityValue = 65
  optional sampStoreDur String = 66
  optional sampStoreLoc String = 67
  optional sampStoreSol String = 68
  repeated miscParam String = 69
  projectName String = 70
  optional sourceMatId String = 71
  optional sampVolWeDnaExt QuantityValue = 72
  sampName String = 73
  sampTaxonId String = 74
  optional experimentalFactor String = 75
  optional negContType NegContTypeEnum = 76
  optional posContType String = 77
  optional subspecfGenLin String = 78
  optional estimatedSize String = 79
  optional refBiomaterial String = 80
  optional specificHost String = 81
  optional hostSpecRange Integer = 82
  propagation String = 83
  optional encodedTraits String = 84
  isolGrowthCondt String = 85
  optional sampCollecDevice String = 86
  optional sampCollecMethod String = 87
  optional sampMatProcess String = 88
  optional sampSize QuantityValue = 89
  optional nuclAcidExt String = 90
  optional nuclAcidAmp String = 91
  optional libSize Integer = 92
  optional libReadsSeqd Integer = 93
  optional libLayout LibLayoutEnum = 94
  optional libVector String = 95
  optional libScreen String = 96
  optional adapters String = 97
  seqMeth String = 98
  optional taxIdent TaxIdentEnum = 99
  optional assemblyQual AssemblyQualEnum = 100
  optional assemblyName String = 101
  assemblySoftware String = 102
  optional annot String = 103
  optional numberContig Integer = 104
  optional featPred String = 105
  optional refDb String = 106
  optional simSearchMeth String = 107
  optional taxClass String = 108
  optional complScore String = 109
  optional complSoftware String = 110
  optional associatedResource String = 111
  optional sop String = 112
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package symbiont-associated
message Symbiont-associatedMIGSVirus
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  sampleName String = 11
  optional hostSubjectId String = 12
  optional hostCommonName String = 13
  optional hostTaxid String = 14
  hostDependence String = 15
  optional typeOfSymbiosis TypeOfSymbiosisEnum = 16
  symLifeCycleType String = 17
  hostLifeStage String = 18
  optional hostAge QuantityValue = 19
  optional hostSex HostSexEnum = 20
  optional modeTransmission ModeTransmissionEnum = 21
  optional routeTransmission RouteTransmissionEnum = 22
  optional hostBodyHabitat String = 23
  optional hostBodySite String = 24
  optional hostBodyProduct String = 25
  optional hostTotMass QuantityValue = 26
  optional hostHeight QuantityValue = 27
  optional hostLength QuantityValue = 28
  optional hostGrowthCond String = 29
  optional hostSubstrate String = 30
  optional hostFamilyRelationship String = 31
  optional hostInfraSpecificName String = 32
  optional hostInfraSpecificRank String = 33
  optional hostGenotype String = 34
  optional hostPhenotype String = 35
  optional hostDryMass QuantityValue = 36
  optional hostColor String = 37
  optional hostShape String = 38
  optional gravidity String = 39
  optional hostNumber String = 40
  repeated hostSymbiont String = 41
  optional hostSpecificity HostSpecificityEnum = 42
  optional symbiontHostRole SymbiontHostRoleEnum = 43
  optional hostCellularLoc HostCellularLocEnum = 44
  optional associationDuration QuantityValue = 45
  optional hostOfHostCoinf String = 46
  optional hostOfHostName String = 47
  repeated hostOfHostEnvLoc String = 48
  optional hostOfHostEnvMed String = 49
  optional hostOfHostTaxid Integer = 50
  optional hostOfHostSubId String = 51
  repeated hostOfHostDisease String = 52
  repeated hostOfHostFamRel String = 53
  optional hostOfHostInfname String = 54
  optional hostOfHostInfrank String = 55
  optional hostOfHostGeno String = 56
  optional hostOfHostPheno String = 57
  optional hostOfHostGravid String = 58
  optional hostOfHostTotmass QuantityValue = 59
  repeated chemAdministration String = 60
  repeated perturbation String = 61
  optional sampSalinity QuantityValue = 62
  optional oxyStatSamp OxyStatSampEnum = 63
  repeated organismCount OrganismCountEnum = 64
  optional sampStoreTemp QuantityValue = 65
  optional sampStoreDur String = 66
  optional sampStoreLoc String = 67
  optional sampStoreSol String = 68
  repeated miscParam String = 69
  projectName String = 70
  optional sourceMatId String = 71
  optional sampVolWeDnaExt QuantityValue = 72
  sampName String = 73
  sampTaxonId String = 74
  optional experimentalFactor String = 75
  optional negContType NegContTypeEnum = 76
  optional posContType String = 77
  optional subspecfGenLin String = 78
  optional numReplicons Integer = 79
  optional estimatedSize String = 80
  optional refBiomaterial String = 81
  optional pathogenicity String = 82
  optional bioticRelationship BioticRelationshipEnum = 83
  optional specificHost String = 84
  optional hostSpecRange Integer = 85
  optional hostDiseaseStat String = 86
  propagation String = 87
  optional encodedTraits String = 88
  isolGrowthCondt String = 89
  optional sampCollecDevice String = 90
  optional sampCollecMethod String = 91
  optional sampMatProcess String = 92
  optional sampSize QuantityValue = 93
  optional virusEnrichAppr VirusEnrichApprEnum = 94
  optional nuclAcidExt String = 95
  optional nuclAcidAmp String = 96
  optional libSize Integer = 97
  optional libReadsSeqd Integer = 98
  optional libLayout LibLayoutEnum = 99
  optional libVector String = 100
  optional libScreen String = 101
  optional adapters String = 102
  seqMeth String = 103
  optional taxIdent TaxIdentEnum = 104
  optional assemblyQual AssemblyQualEnum = 105
  optional assemblyName String = 106
  assemblySoftware String = 107
  optional annot String = 108
  optional numberContig Integer = 109
  optional featPred String = 110
  optional refDb String = 111
  optional simSearchMeth String = 112
  optional taxClass String = 113
  optional complScore String = 114
  optional complSoftware String = 115
  optional associatedResource String = 116
  optional sop String = 117
 }
// Combinatorial checklist Minimum Information About a Metagenome-Assembled Genome with environmental package symbiont-associated
message Symbiont-associatedMIMAG
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  sampleName String = 11
  optional hostSubjectId String = 12
  optional hostCommonName String = 13
  optional hostTaxid String = 14
  hostDependence String = 15
  optional typeOfSymbiosis TypeOfSymbiosisEnum = 16
  symLifeCycleType String = 17
  hostLifeStage String = 18
  optional hostAge QuantityValue = 19
  optional hostSex HostSexEnum = 20
  optional modeTransmission ModeTransmissionEnum = 21
  optional routeTransmission RouteTransmissionEnum = 22
  optional hostBodyHabitat String = 23
  optional hostBodySite String = 24
  optional hostBodyProduct String = 25
  optional hostTotMass QuantityValue = 26
  optional hostHeight QuantityValue = 27
  optional hostLength QuantityValue = 28
  optional hostGrowthCond String = 29
  optional hostSubstrate String = 30
  optional hostFamilyRelationship String = 31
  optional hostInfraSpecificName String = 32
  optional hostInfraSpecificRank String = 33
  optional hostGenotype String = 34
  optional hostPhenotype String = 35
  optional hostDryMass QuantityValue = 36
  optional hostColor String = 37
  optional hostShape String = 38
  optional gravidity String = 39
  optional hostNumber String = 40
  repeated hostSymbiont String = 41
  optional hostSpecificity HostSpecificityEnum = 42
  optional symbiontHostRole SymbiontHostRoleEnum = 43
  optional hostCellularLoc HostCellularLocEnum = 44
  optional associationDuration QuantityValue = 45
  optional hostOfHostCoinf String = 46
  optional hostOfHostName String = 47
  repeated hostOfHostEnvLoc String = 48
  optional hostOfHostEnvMed String = 49
  optional hostOfHostTaxid Integer = 50
  optional hostOfHostSubId String = 51
  repeated hostOfHostDisease String = 52
  repeated hostOfHostFamRel String = 53
  optional hostOfHostInfname String = 54
  optional hostOfHostInfrank String = 55
  optional hostOfHostGeno String = 56
  optional hostOfHostPheno String = 57
  optional hostOfHostGravid String = 58
  optional hostOfHostTotmass QuantityValue = 59
  repeated chemAdministration String = 60
  repeated perturbation String = 61
  optional sampSalinity QuantityValue = 62
  optional oxyStatSamp OxyStatSampEnum = 63
  repeated organismCount OrganismCountEnum = 64
  optional sampStoreTemp QuantityValue = 65
  optional sampStoreDur String = 66
  optional sampStoreLoc String = 67
  optional sampStoreSol String = 68
  repeated miscParam String = 69
  projectName String = 70
  optional sourceMatId String = 71
  optional sampVolWeDnaExt QuantityValue = 72
  sampName String = 73
  sampTaxonId String = 74
  optional experimentalFactor String = 75
  optional negContType NegContTypeEnum = 76
  optional posContType String = 77
  optional refBiomaterial String = 78
  optional relToOxygen RelToOxygenEnum = 79
  optional sampCollecDevice String = 80
  optional sampCollecMethod String = 81
  optional sampMatProcess String = 82
  optional sizeFrac String = 83
  optional sampSize QuantityValue = 84
  optional nuclAcidExt String = 85
  optional nuclAcidAmp String = 86
  optional libSize Integer = 87
  optional libReadsSeqd Integer = 88
  optional libLayout LibLayoutEnum = 89
  optional libVector String = 90
  optional libScreen String = 91
  optional mid String = 92
  optional adapters String = 93
  seqMeth String = 94
  taxIdent TaxIdentEnum = 95
  assemblyQual AssemblyQualEnum = 96
  optional assemblyName String = 97
  assemblySoftware String = 98
  optional annot String = 99
  optional numberContig Integer = 100
  optional featPred String = 101
  optional refDb String = 102
  optional simSearchMeth String = 103
  optional taxClass String = 104
  optional x16sRecover String = 105
  optional x16sRecoverSoftware String = 106
  optional trnas Integer = 107
  optional trnaExtSoftware String = 108
  complScore String = 109
  complSoftware String = 110
  optional complAppr ComplApprEnum = 111
  contamScore String = 112
  optional contamScreenInput String = 113
  optional contamScreenParam String = 114
  optional decontamSoftware DecontamSoftwareEnum = 115
  binParam BinParamEnum = 116
  binSoftware String = 117
  optional reassemblyBin String = 118
  optional magCovSoftware MagCovSoftwareEnum = 119
  optional associatedResource String = 120
  optional sop String = 121
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: specimen with environmental package symbiont-associated
message Symbiont-associatedMIMARKSSpecimen
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  sampleName String = 11
  optional hostSubjectId String = 12
  optional hostCommonName String = 13
  optional hostTaxid String = 14
  hostDependence String = 15
  optional typeOfSymbiosis TypeOfSymbiosisEnum = 16
  symLifeCycleType String = 17
  hostLifeStage String = 18
  optional hostAge QuantityValue = 19
  optional hostSex HostSexEnum = 20
  optional modeTransmission ModeTransmissionEnum = 21
  optional routeTransmission RouteTransmissionEnum = 22
  optional hostBodyHabitat String = 23
  optional hostBodySite String = 24
  optional hostBodyProduct String = 25
  optional hostTotMass QuantityValue = 26
  optional hostHeight QuantityValue = 27
  optional hostLength QuantityValue = 28
  optional hostGrowthCond String = 29
  optional hostSubstrate String = 30
  optional hostFamilyRelationship String = 31
  optional hostInfraSpecificName String = 32
  optional hostInfraSpecificRank String = 33
  optional hostGenotype String = 34
  optional hostPhenotype String = 35
  optional hostDryMass QuantityValue = 36
  optional hostColor String = 37
  optional hostShape String = 38
  optional gravidity String = 39
  optional hostNumber String = 40
  repeated hostSymbiont String = 41
  optional hostSpecificity HostSpecificityEnum = 42
  optional symbiontHostRole SymbiontHostRoleEnum = 43
  optional hostCellularLoc HostCellularLocEnum = 44
  optional associationDuration QuantityValue = 45
  optional hostOfHostCoinf String = 46
  optional hostOfHostName String = 47
  repeated hostOfHostEnvLoc String = 48
  optional hostOfHostEnvMed String = 49
  optional hostOfHostTaxid Integer = 50
  optional hostOfHostSubId String = 51
  repeated hostOfHostDisease String = 52
  repeated hostOfHostFamRel String = 53
  optional hostOfHostInfname String = 54
  optional hostOfHostInfrank String = 55
  optional hostOfHostGeno String = 56
  optional hostOfHostPheno String = 57
  optional hostOfHostGravid String = 58
  optional hostOfHostTotmass QuantityValue = 59
  repeated chemAdministration String = 60
  repeated perturbation String = 61
  optional sampSalinity QuantityValue = 62
  optional oxyStatSamp OxyStatSampEnum = 63
  repeated organismCount OrganismCountEnum = 64
  optional sampStoreTemp QuantityValue = 65
  optional sampStoreDur String = 66
  optional sampStoreLoc String = 67
  optional sampStoreSol String = 68
  repeated miscParam String = 69
  projectName String = 70
  optional sourceMatId String = 71
  optional sampVolWeDnaExt QuantityValue = 72
  sampName String = 73
  sampTaxonId String = 74
  optional experimentalFactor String = 75
  optional negContType NegContTypeEnum = 76
  optional posContType String = 77
  optional relToOxygen RelToOxygenEnum = 78
  optional sampCollecDevice String = 79
  optional sampCollecMethod String = 80
  optional sampMatProcess String = 81
  optional sizeFrac String = 82
  optional sampSize QuantityValue = 83
  optional nuclAcidExt String = 84
  optional nuclAcidAmp String = 85
  optional libSize Integer = 86
  optional libReadsSeqd Integer = 87
  optional libLayout LibLayoutEnum = 88
  optional libVector String = 89
  optional libScreen String = 90
  targetGene String = 91
  optional targetSubfragment String = 92
  optional pcrPrimers String = 93
  optional mid String = 94
  optional adapters String = 95
  optional pcrCond String = 96
  seqMeth String = 97
  optional seqQualityCheck String = 98
  optional chimeraCheck String = 99
  optional assemblySoftware String = 100
  optional associatedResource String = 101
  optional sop String = 102
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: survey with environmental package symbiont-associated
message Symbiont-associatedMIMARKSSurvey
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  sampleName String = 11
  optional hostSubjectId String = 12
  optional hostCommonName String = 13
  optional hostTaxid String = 14
  hostDependence String = 15
  optional typeOfSymbiosis TypeOfSymbiosisEnum = 16
  symLifeCycleType String = 17
  hostLifeStage String = 18
  optional hostAge QuantityValue = 19
  optional hostSex HostSexEnum = 20
  optional modeTransmission ModeTransmissionEnum = 21
  optional routeTransmission RouteTransmissionEnum = 22
  optional hostBodyHabitat String = 23
  optional hostBodySite String = 24
  optional hostBodyProduct String = 25
  optional hostTotMass QuantityValue = 26
  optional hostHeight QuantityValue = 27
  optional hostLength QuantityValue = 28
  optional hostGrowthCond String = 29
  optional hostSubstrate String = 30
  optional hostFamilyRelationship String = 31
  optional hostInfraSpecificName String = 32
  optional hostInfraSpecificRank String = 33
  optional hostGenotype String = 34
  optional hostPhenotype String = 35
  optional hostDryMass QuantityValue = 36
  optional hostColor String = 37
  optional hostShape String = 38
  optional gravidity String = 39
  optional hostNumber String = 40
  repeated hostSymbiont String = 41
  optional hostSpecificity HostSpecificityEnum = 42
  optional symbiontHostRole SymbiontHostRoleEnum = 43
  optional hostCellularLoc HostCellularLocEnum = 44
  optional associationDuration QuantityValue = 45
  optional hostOfHostCoinf String = 46
  optional hostOfHostName String = 47
  repeated hostOfHostEnvLoc String = 48
  optional hostOfHostEnvMed String = 49
  optional hostOfHostTaxid Integer = 50
  optional hostOfHostSubId String = 51
  repeated hostOfHostDisease String = 52
  repeated hostOfHostFamRel String = 53
  optional hostOfHostInfname String = 54
  optional hostOfHostInfrank String = 55
  optional hostOfHostGeno String = 56
  optional hostOfHostPheno String = 57
  optional hostOfHostGravid String = 58
  optional hostOfHostTotmass QuantityValue = 59
  repeated chemAdministration String = 60
  repeated perturbation String = 61
  optional sampSalinity QuantityValue = 62
  optional oxyStatSamp OxyStatSampEnum = 63
  repeated organismCount OrganismCountEnum = 64
  optional sampStoreTemp QuantityValue = 65
  optional sampStoreDur String = 66
  optional sampStoreLoc String = 67
  optional sampStoreSol String = 68
  repeated miscParam String = 69
  projectName String = 70
  optional sourceMatId String = 71
  optional sampVolWeDnaExt QuantityValue = 72
  sampName String = 73
  sampTaxonId String = 74
  optional experimentalFactor String = 75
  optional negContType NegContTypeEnum = 76
  optional posContType String = 77
  optional subspecfGenLin String = 78
  optional extrachromElements Integer = 79
  optional bioticRelationship BioticRelationshipEnum = 80
  optional trophicLevel TrophicLevelEnum = 81
  optional relToOxygen RelToOxygenEnum = 82
  isolGrowthCondt String = 83
  optional sampCollecDevice String = 84
  optional sampCollecMethod String = 85
  optional sampMatProcess String = 86
  optional sampSize QuantityValue = 87
  optional nuclAcidExt String = 88
  optional nuclAcidAmp String = 89
  targetGene String = 90
  optional targetSubfragment String = 91
  optional pcrPrimers String = 92
  optional pcrCond String = 93
  seqMeth String = 94
  optional seqQualityCheck String = 95
  optional chimeraCheck String = 96
  optional associatedResource String = 97
  optional sop String = 98
 }
// Combinatorial checklist Metagenome or Environmental with environmental package symbiont-associated
message Symbiont-associatedMIMS
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  sampleName String = 11
  optional hostSubjectId String = 12
  optional hostCommonName String = 13
  optional hostTaxid String = 14
  hostDependence String = 15
  optional typeOfSymbiosis TypeOfSymbiosisEnum = 16
  symLifeCycleType String = 17
  hostLifeStage String = 18
  optional hostAge QuantityValue = 19
  optional hostSex HostSexEnum = 20
  optional modeTransmission ModeTransmissionEnum = 21
  optional routeTransmission RouteTransmissionEnum = 22
  optional hostBodyHabitat String = 23
  optional hostBodySite String = 24
  optional hostBodyProduct String = 25
  optional hostTotMass QuantityValue = 26
  optional hostHeight QuantityValue = 27
  optional hostLength QuantityValue = 28
  optional hostGrowthCond String = 29
  optional hostSubstrate String = 30
  optional hostFamilyRelationship String = 31
  optional hostInfraSpecificName String = 32
  optional hostInfraSpecificRank String = 33
  optional hostGenotype String = 34
  optional hostPhenotype String = 35
  optional hostDryMass QuantityValue = 36
  optional hostColor String = 37
  optional hostShape String = 38
  optional gravidity String = 39
  optional hostNumber String = 40
  repeated hostSymbiont String = 41
  optional hostSpecificity HostSpecificityEnum = 42
  optional symbiontHostRole SymbiontHostRoleEnum = 43
  optional hostCellularLoc HostCellularLocEnum = 44
  optional associationDuration QuantityValue = 45
  optional hostOfHostCoinf String = 46
  optional hostOfHostName String = 47
  repeated hostOfHostEnvLoc String = 48
  optional hostOfHostEnvMed String = 49
  optional hostOfHostTaxid Integer = 50
  optional hostOfHostSubId String = 51
  repeated hostOfHostDisease String = 52
  repeated hostOfHostFamRel String = 53
  optional hostOfHostInfname String = 54
  optional hostOfHostInfrank String = 55
  optional hostOfHostGeno String = 56
  optional hostOfHostPheno String = 57
  optional hostOfHostGravid String = 58
  optional hostOfHostTotmass QuantityValue = 59
  repeated chemAdministration String = 60
  repeated perturbation String = 61
  optional sampSalinity QuantityValue = 62
  optional oxyStatSamp OxyStatSampEnum = 63
  repeated organismCount OrganismCountEnum = 64
  optional sampStoreTemp QuantityValue = 65
  optional sampStoreDur String = 66
  optional sampStoreLoc String = 67
  optional sampStoreSol String = 68
  repeated miscParam String = 69
  projectName String = 70
  optional sourceMatId String = 71
  optional sampVolWeDnaExt QuantityValue = 72
  sampName String = 73
  sampTaxonId String = 74
  optional experimentalFactor String = 75
  optional negContType NegContTypeEnum = 76
  optional posContType String = 77
  optional refBiomaterial String = 78
  optional relToOxygen RelToOxygenEnum = 79
  optional sampCollecDevice String = 80
  optional sampCollecMethod String = 81
  optional sampMatProcess String = 82
  optional sizeFrac String = 83
  optional sampSize QuantityValue = 84
  optional nuclAcidExt String = 85
  optional nuclAcidAmp String = 86
  optional libSize Integer = 87
  optional libReadsSeqd Integer = 88
  optional libLayout LibLayoutEnum = 89
  optional libVector String = 90
  optional libScreen String = 91
  optional mid String = 92
  optional adapters String = 93
  seqMeth String = 94
  optional assemblyQual AssemblyQualEnum = 95
  optional assemblyName String = 96
  optional assemblySoftware String = 97
  optional annot String = 98
  optional numberContig Integer = 99
  optional featPred String = 100
  optional refDb String = 101
  optional simSearchMeth String = 102
  optional taxClass String = 103
  optional associatedResource String = 104
  optional sop String = 105
 }
// Combinatorial checklist Minimum Information About a Single Amplified Genome with environmental package symbiont-associated
message Symbiont-associatedMISAG
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  sampleName String = 11
  optional hostSubjectId String = 12
  optional hostCommonName String = 13
  optional hostTaxid String = 14
  hostDependence String = 15
  optional typeOfSymbiosis TypeOfSymbiosisEnum = 16
  symLifeCycleType String = 17
  hostLifeStage String = 18
  optional hostAge QuantityValue = 19
  optional hostSex HostSexEnum = 20
  optional modeTransmission ModeTransmissionEnum = 21
  optional routeTransmission RouteTransmissionEnum = 22
  optional hostBodyHabitat String = 23
  optional hostBodySite String = 24
  optional hostBodyProduct String = 25
  optional hostTotMass QuantityValue = 26
  optional hostHeight QuantityValue = 27
  optional hostLength QuantityValue = 28
  optional hostGrowthCond String = 29
  optional hostSubstrate String = 30
  optional hostFamilyRelationship String = 31
  optional hostInfraSpecificName String = 32
  optional hostInfraSpecificRank String = 33
  optional hostGenotype String = 34
  optional hostPhenotype String = 35
  optional hostDryMass QuantityValue = 36
  optional hostColor String = 37
  optional hostShape String = 38
  optional gravidity String = 39
  optional hostNumber String = 40
  repeated hostSymbiont String = 41
  optional hostSpecificity HostSpecificityEnum = 42
  optional symbiontHostRole SymbiontHostRoleEnum = 43
  optional hostCellularLoc HostCellularLocEnum = 44
  optional associationDuration QuantityValue = 45
  optional hostOfHostCoinf String = 46
  optional hostOfHostName String = 47
  repeated hostOfHostEnvLoc String = 48
  optional hostOfHostEnvMed String = 49
  optional hostOfHostTaxid Integer = 50
  optional hostOfHostSubId String = 51
  repeated hostOfHostDisease String = 52
  repeated hostOfHostFamRel String = 53
  optional hostOfHostInfname String = 54
  optional hostOfHostInfrank String = 55
  optional hostOfHostGeno String = 56
  optional hostOfHostPheno String = 57
  optional hostOfHostGravid String = 58
  optional hostOfHostTotmass QuantityValue = 59
  repeated chemAdministration String = 60
  repeated perturbation String = 61
  optional sampSalinity QuantityValue = 62
  optional oxyStatSamp OxyStatSampEnum = 63
  repeated organismCount OrganismCountEnum = 64
  optional sampStoreTemp QuantityValue = 65
  optional sampStoreDur String = 66
  optional sampStoreLoc String = 67
  optional sampStoreSol String = 68
  repeated miscParam String = 69
  projectName String = 70
  optional sourceMatId String = 71
  optional sampVolWeDnaExt QuantityValue = 72
  sampName String = 73
  sampTaxonId String = 74
  optional experimentalFactor String = 75
  optional negContType NegContTypeEnum = 76
  optional posContType String = 77
  optional refBiomaterial String = 78
  optional relToOxygen RelToOxygenEnum = 79
  optional sampCollecDevice String = 80
  optional sampCollecMethod String = 81
  optional sampMatProcess String = 82
  optional sizeFrac String = 83
  optional sampSize QuantityValue = 84
  optional nuclAcidExt String = 85
  optional nuclAcidAmp String = 86
  optional libSize Integer = 87
  optional libReadsSeqd Integer = 88
  optional libLayout LibLayoutEnum = 89
  optional libVector String = 90
  optional libScreen String = 91
  optional mid String = 92
  optional adapters String = 93
  seqMeth String = 94
  taxIdent TaxIdentEnum = 95
  assemblyQual AssemblyQualEnum = 96
  optional assemblyName String = 97
  assemblySoftware String = 98
  optional annot String = 99
  optional numberContig Integer = 100
  optional featPred String = 101
  optional refDb String = 102
  optional simSearchMeth String = 103
  optional taxClass String = 104
  optional x16sRecover String = 105
  optional x16sRecoverSoftware String = 106
  optional trnas Integer = 107
  optional trnaExtSoftware String = 108
  complScore String = 109
  complSoftware String = 110
  optional complAppr ComplApprEnum = 111
  contamScore String = 112
  optional contamScreenInput String = 113
  optional contamScreenParam String = 114
  optional decontamSoftware DecontamSoftwareEnum = 115
  sortTech SortTechEnum = 116
  singleCellLysisAppr SingleCellLysisApprEnum = 117
  optional singleCellLysisProt String = 118
  wgaAmpAppr String = 119
  optional wgaAmpKit String = 120
  optional associatedResource String = 121
  optional sop String = 122
 }
// Combinatorial checklist Minimum Information About an Uncultivated Virus Genome with environmental package symbiont-associated
message Symbiont-associatedMIUVIG
 {
  latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  geoLocName String = 6
  collectionDate Date = 7
  envBroadScale String = 8
  envLocalScale String = 9
  envMedium String = 10
  sampleName String = 11
  optional hostSubjectId String = 12
  optional hostCommonName String = 13
  optional hostTaxid String = 14
  hostDependence String = 15
  optional typeOfSymbiosis TypeOfSymbiosisEnum = 16
  symLifeCycleType String = 17
  hostLifeStage String = 18
  optional hostAge QuantityValue = 19
  optional hostSex HostSexEnum = 20
  optional modeTransmission ModeTransmissionEnum = 21
  optional routeTransmission RouteTransmissionEnum = 22
  optional hostBodyHabitat String = 23
  optional hostBodySite String = 24
  optional hostBodyProduct String = 25
  optional hostTotMass QuantityValue = 26
  optional hostHeight QuantityValue = 27
  optional hostLength QuantityValue = 28
  optional hostGrowthCond String = 29
  optional hostSubstrate String = 30
  optional hostFamilyRelationship String = 31
  optional hostInfraSpecificName String = 32
  optional hostInfraSpecificRank String = 33
  optional hostGenotype String = 34
  optional hostPhenotype String = 35
  optional hostDryMass QuantityValue = 36
  optional hostColor String = 37
  optional hostShape String = 38
  optional gravidity String = 39
  optional hostNumber String = 40
  repeated hostSymbiont String = 41
  optional hostSpecificity HostSpecificityEnum = 42
  optional symbiontHostRole SymbiontHostRoleEnum = 43
  optional hostCellularLoc HostCellularLocEnum = 44
  optional associationDuration QuantityValue = 45
  optional hostOfHostCoinf String = 46
  optional hostOfHostName String = 47
  repeated hostOfHostEnvLoc String = 48
  optional hostOfHostEnvMed String = 49
  optional hostOfHostTaxid Integer = 50
  optional hostOfHostSubId String = 51
  repeated hostOfHostDisease String = 52
  repeated hostOfHostFamRel String = 53
  optional hostOfHostInfname String = 54
  optional hostOfHostInfrank String = 55
  optional hostOfHostGeno String = 56
  optional hostOfHostPheno String = 57
  optional hostOfHostGravid String = 58
  optional hostOfHostTotmass QuantityValue = 59
  repeated chemAdministration String = 60
  repeated perturbation String = 61
  optional sampSalinity QuantityValue = 62
  optional oxyStatSamp OxyStatSampEnum = 63
  repeated organismCount OrganismCountEnum = 64
  optional sampStoreTemp QuantityValue = 65
  optional sampStoreDur String = 66
  optional sampStoreLoc String = 67
  optional sampStoreSol String = 68
  repeated miscParam String = 69
  projectName String = 70
  optional sourceMatId String = 71
  optional sampVolWeDnaExt QuantityValue = 72
  sampName String = 73
  sampTaxonId String = 74
  optional experimentalFactor String = 75
  optional negContType NegContTypeEnum = 76
  optional posContType String = 77
  optional estimatedSize String = 78
  optional refBiomaterial String = 79
  optional pathogenicity String = 80
  optional bioticRelationship BioticRelationshipEnum = 81
  optional specificHost String = 82
  optional hostSpecRange Integer = 83
  optional hostDiseaseStat String = 84
  optional sampCollecDevice String = 85
  optional sampCollecMethod String = 86
  optional sampMatProcess String = 87
  optional sizeFrac String = 88
  optional sampSize QuantityValue = 89
  sourceUvig SourceUvigEnum = 90
  virusEnrichAppr VirusEnrichApprEnum = 91
  optional nuclAcidExt String = 92
  optional nuclAcidAmp String = 93
  optional libSize Integer = 94
  optional libReadsSeqd Integer = 95
  optional libLayout LibLayoutEnum = 96
  optional libVector String = 97
  optional libScreen String = 98
  optional mid String = 99
  optional adapters String = 100
  seqMeth String = 101
  optional taxIdent TaxIdentEnum = 102
  assemblyQual AssemblyQualEnum = 103
  optional assemblyName String = 104
  assemblySoftware String = 105
  optional annot String = 106
  numberContig Integer = 107
  optional featPred String = 108
  optional refDb String = 109
  optional simSearchMeth String = 110
  optional taxClass String = 111
  optional trnas Integer = 112
  optional trnaExtSoftware String = 113
  optional complScore String = 114
  optional complSoftware String = 115
  optional complAppr ComplApprEnum = 116
  optional sortTech SortTechEnum = 117
  optional singleCellLysisAppr SingleCellLysisApprEnum = 118
  optional singleCellLysisProt String = 119
  optional wgaAmpAppr String = 120
  optional wgaAmpKit String = 121
  optional binParam BinParamEnum = 122
  optional binSoftware String = 123
  optional reassemblyBin String = 124
  optional magCovSoftware MagCovSoftwareEnum = 125
  virIdentSoftware String = 126
  predGenomeType PredGenomeTypeEnum = 127
  predGenomeStruc PredGenomeStrucEnum = 128
  detecType String = 129
  optional otuClassAppr String = 130
  optional otuSeqCompAppr String = 131
  optional otuDb String = 132
  optional hostPredAppr HostPredApprEnum = 133
  optional hostPredEstAcc String = 134
  optional associatedResource String = 135
  optional sop String = 136
 }
// wastewater/sludge
message WastewaterSludge
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional biochemOxygenDem QuantityValue = 12
  repeated chemAdministration String = 13
  optional chemOxygenDem QuantityValue = 14
  optional efficiencyPercent QuantityValue = 15
  repeated emulsions String = 16
  repeated gaseousSubstances String = 17
  optional industEffPercent QuantityValue = 18
  repeated inorgParticles String = 19
  repeated miscParam String = 20
  optional nitrate QuantityValue = 21
  repeated orgParticles String = 22
  repeated organismCount OrganismCountEnum = 23
  optional oxyStatSamp OxyStatSampEnum = 24
  optional ph Double = 25
  repeated perturbation String = 26
  optional phosphate QuantityValue = 27
  optional preTreatment String = 28
  optional primaryTreatment String = 29
  optional reactorType String = 30
  optional salinity QuantityValue = 31
  optional sampStoreDur String = 32
  optional sampStoreLoc String = 33
  optional sampStoreTemp QuantityValue = 34
  optional secondaryTreatment String = 35
  optional sewageType String = 36
  optional sludgeRetentTime QuantityValue = 37
  optional sodium QuantityValue = 38
  repeated solubleInorgMat String = 39
  repeated solubleOrgMat String = 40
  repeated suspendSolids String = 41
  optional tertiaryTreatment String = 42
  optional totNitro QuantityValue = 43
  optional totPhosphate QuantityValue = 44
  optional wastewaterType String = 45
  sampName String = 46
  projectName String = 47
  optional sampVolWeDnaExt QuantityValue = 48
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package wastewater_sludge
message WastewaterSludgeMIGSBacteria
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional biochemOxygenDem QuantityValue = 12
  repeated chemAdministration String = 13
  optional chemOxygenDem QuantityValue = 14
  optional efficiencyPercent QuantityValue = 15
  repeated emulsions String = 16
  repeated gaseousSubstances String = 17
  optional industEffPercent QuantityValue = 18
  repeated inorgParticles String = 19
  repeated miscParam String = 20
  optional nitrate QuantityValue = 21
  repeated orgParticles String = 22
  repeated organismCount OrganismCountEnum = 23
  optional oxyStatSamp OxyStatSampEnum = 24
  optional ph Double = 25
  repeated perturbation String = 26
  optional phosphate QuantityValue = 27
  optional preTreatment String = 28
  optional primaryTreatment String = 29
  optional reactorType String = 30
  optional salinity QuantityValue = 31
  optional sampStoreDur String = 32
  optional sampStoreLoc String = 33
  optional sampStoreTemp QuantityValue = 34
  optional secondaryTreatment String = 35
  optional sewageType String = 36
  optional sludgeRetentTime QuantityValue = 37
  optional sodium QuantityValue = 38
  repeated solubleInorgMat String = 39
  repeated solubleOrgMat String = 40
  repeated suspendSolids String = 41
  optional tertiaryTreatment String = 42
  optional totNitro QuantityValue = 43
  optional totPhosphate QuantityValue = 44
  optional wastewaterType String = 45
  sampName String = 46
  projectName String = 47
  optional sampVolWeDnaExt QuantityValue = 48
  sampTaxonId String = 49
  optional experimentalFactor String = 50
  optional negContType NegContTypeEnum = 51
  optional posContType String = 52
  optional subspecfGenLin String = 53
  numReplicons Integer = 54
  optional extrachromElements Integer = 55
  optional estimatedSize String = 56
  refBiomaterial String = 57
  optional sourceMatId String = 58
  optional pathogenicity String = 59
  optional bioticRelationship BioticRelationshipEnum = 60
  optional specificHost String = 61
  optional hostSpecRange Integer = 62
  optional hostDiseaseStat String = 63
  optional trophicLevel TrophicLevelEnum = 64
  optional encodedTraits String = 65
  optional relToOxygen RelToOxygenEnum = 66
  isolGrowthCondt String = 67
  optional sampCollecDevice String = 68
  optional sampCollecMethod String = 69
  optional sampMatProcess String = 70
  optional sampSize QuantityValue = 71
  optional nuclAcidExt String = 72
  optional nuclAcidAmp String = 73
  optional libSize Integer = 74
  optional libReadsSeqd Integer = 75
  optional libLayout LibLayoutEnum = 76
  optional libVector String = 77
  optional libScreen String = 78
  optional adapters String = 79
  seqMeth String = 80
  optional taxIdent TaxIdentEnum = 81
  assemblyQual AssemblyQualEnum = 82
  optional assemblyName String = 83
  assemblySoftware String = 84
  optional annot String = 85
  numberContig Integer = 86
  optional featPred String = 87
  optional refDb String = 88
  optional simSearchMeth String = 89
  optional taxClass String = 90
  optional complScore String = 91
  optional complSoftware String = 92
  optional associatedResource String = 93
  optional sop String = 94
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: eukaryote with environmental package wastewater_sludge
message WastewaterSludgeMIGSEukaryote
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional biochemOxygenDem QuantityValue = 12
  repeated chemAdministration String = 13
  optional chemOxygenDem QuantityValue = 14
  optional efficiencyPercent QuantityValue = 15
  repeated emulsions String = 16
  repeated gaseousSubstances String = 17
  optional industEffPercent QuantityValue = 18
  repeated inorgParticles String = 19
  repeated miscParam String = 20
  optional nitrate QuantityValue = 21
  repeated orgParticles String = 22
  repeated organismCount OrganismCountEnum = 23
  optional oxyStatSamp OxyStatSampEnum = 24
  optional ph Double = 25
  repeated perturbation String = 26
  optional phosphate QuantityValue = 27
  optional preTreatment String = 28
  optional primaryTreatment String = 29
  optional reactorType String = 30
  optional salinity QuantityValue = 31
  optional sampStoreDur String = 32
  optional sampStoreLoc String = 33
  optional sampStoreTemp QuantityValue = 34
  optional secondaryTreatment String = 35
  optional sewageType String = 36
  optional sludgeRetentTime QuantityValue = 37
  optional sodium QuantityValue = 38
  repeated solubleInorgMat String = 39
  repeated solubleOrgMat String = 40
  repeated suspendSolids String = 41
  optional tertiaryTreatment String = 42
  optional totNitro QuantityValue = 43
  optional totPhosphate QuantityValue = 44
  optional wastewaterType String = 45
  sampName String = 46
  projectName String = 47
  optional sampVolWeDnaExt QuantityValue = 48
  sampTaxonId String = 49
  optional experimentalFactor String = 50
  optional negContType NegContTypeEnum = 51
  optional posContType String = 52
  optional subspecfGenLin String = 53
  optional ploidy String = 54
  optional numReplicons Integer = 55
  optional extrachromElements Integer = 56
  optional estimatedSize String = 57
  optional refBiomaterial String = 58
  optional sourceMatId String = 59
  optional pathogenicity String = 60
  optional bioticRelationship BioticRelationshipEnum = 61
  optional specificHost String = 62
  optional hostSpecRange Integer = 63
  optional hostDiseaseStat String = 64
  optional trophicLevel TrophicLevelEnum = 65
  optional propagation String = 66
  isolGrowthCondt String = 67
  optional sampCollecDevice String = 68
  optional sampCollecMethod String = 69
  optional sampMatProcess String = 70
  optional sampSize QuantityValue = 71
  optional nuclAcidExt String = 72
  optional nuclAcidAmp String = 73
  optional libSize Integer = 74
  optional libReadsSeqd Integer = 75
  optional libLayout LibLayoutEnum = 76
  optional libVector String = 77
  optional libScreen String = 78
  optional adapters String = 79
  seqMeth String = 80
  optional taxIdent TaxIdentEnum = 81
  assemblyQual AssemblyQualEnum = 82
  optional assemblyName String = 83
  assemblySoftware String = 84
  optional annot String = 85
  numberContig Integer = 86
  optional featPred String = 87
  optional refDb String = 88
  optional simSearchMeth String = 89
  optional taxClass String = 90
  optional complScore String = 91
  optional complSoftware String = 92
  optional associatedResource String = 93
  optional sop String = 94
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: org with environmental package wastewater_sludge
message WastewaterSludgeMIGSOrg
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional biochemOxygenDem QuantityValue = 12
  repeated chemAdministration String = 13
  optional chemOxygenDem QuantityValue = 14
  optional efficiencyPercent QuantityValue = 15
  repeated emulsions String = 16
  repeated gaseousSubstances String = 17
  optional industEffPercent QuantityValue = 18
  repeated inorgParticles String = 19
  repeated miscParam String = 20
  optional nitrate QuantityValue = 21
  repeated orgParticles String = 22
  repeated organismCount OrganismCountEnum = 23
  optional oxyStatSamp OxyStatSampEnum = 24
  optional ph Double = 25
  repeated perturbation String = 26
  optional phosphate QuantityValue = 27
  optional preTreatment String = 28
  optional primaryTreatment String = 29
  optional reactorType String = 30
  optional salinity QuantityValue = 31
  optional sampStoreDur String = 32
  optional sampStoreLoc String = 33
  optional sampStoreTemp QuantityValue = 34
  optional secondaryTreatment String = 35
  optional sewageType String = 36
  optional sludgeRetentTime QuantityValue = 37
  optional sodium QuantityValue = 38
  repeated solubleInorgMat String = 39
  repeated solubleOrgMat String = 40
  repeated suspendSolids String = 41
  optional tertiaryTreatment String = 42
  optional totNitro QuantityValue = 43
  optional totPhosphate QuantityValue = 44
  optional wastewaterType String = 45
  sampName String = 46
  projectName String = 47
  optional sampVolWeDnaExt QuantityValue = 48
  sampTaxonId String = 49
  optional experimentalFactor String = 50
  optional negContType NegContTypeEnum = 51
  optional posContType String = 52
  optional subspecfGenLin String = 53
  optional extrachromElements Integer = 54
  optional estimatedSize String = 55
  optional refBiomaterial String = 56
  optional sourceMatId String = 57
  isolGrowthCondt String = 58
  optional sampCollecDevice String = 59
  optional sampCollecMethod String = 60
  optional sampMatProcess String = 61
  optional sampSize QuantityValue = 62
  optional nuclAcidExt String = 63
  optional nuclAcidAmp String = 64
  optional libSize Integer = 65
  optional libReadsSeqd Integer = 66
  optional libLayout LibLayoutEnum = 67
  optional libVector String = 68
  optional libScreen String = 69
  optional adapters String = 70
  seqMeth String = 71
  optional taxIdent TaxIdentEnum = 72
  optional assemblyQual AssemblyQualEnum = 73
  optional assemblyName String = 74
  assemblySoftware String = 75
  optional annot String = 76
  optional numberContig Integer = 77
  optional featPred String = 78
  optional refDb String = 79
  optional simSearchMeth String = 80
  optional taxClass String = 81
  optional complScore String = 82
  optional complSoftware String = 83
  optional associatedResource String = 84
  optional sop String = 85
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: plant with environmental package wastewater_sludge
message WastewaterSludgeMIGSPlant
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional biochemOxygenDem QuantityValue = 12
  repeated chemAdministration String = 13
  optional chemOxygenDem QuantityValue = 14
  optional efficiencyPercent QuantityValue = 15
  repeated emulsions String = 16
  repeated gaseousSubstances String = 17
  optional industEffPercent QuantityValue = 18
  repeated inorgParticles String = 19
  repeated miscParam String = 20
  optional nitrate QuantityValue = 21
  repeated orgParticles String = 22
  repeated organismCount OrganismCountEnum = 23
  optional oxyStatSamp OxyStatSampEnum = 24
  optional ph Double = 25
  repeated perturbation String = 26
  optional phosphate QuantityValue = 27
  optional preTreatment String = 28
  optional primaryTreatment String = 29
  optional reactorType String = 30
  optional salinity QuantityValue = 31
  optional sampStoreDur String = 32
  optional sampStoreLoc String = 33
  optional sampStoreTemp QuantityValue = 34
  optional secondaryTreatment String = 35
  optional sewageType String = 36
  optional sludgeRetentTime QuantityValue = 37
  optional sodium QuantityValue = 38
  repeated solubleInorgMat String = 39
  repeated solubleOrgMat String = 40
  repeated suspendSolids String = 41
  optional tertiaryTreatment String = 42
  optional totNitro QuantityValue = 43
  optional totPhosphate QuantityValue = 44
  optional wastewaterType String = 45
  sampName String = 46
  projectName String = 47
  optional sampVolWeDnaExt QuantityValue = 48
  sampTaxonId String = 49
  optional experimentalFactor String = 50
  optional negContType NegContTypeEnum = 51
  optional posContType String = 52
  optional subspecfGenLin String = 53
  optional estimatedSize String = 54
  optional refBiomaterial String = 55
  optional sourceMatId String = 56
  optional specificHost String = 57
  optional hostSpecRange Integer = 58
  propagation String = 59
  optional encodedTraits String = 60
  isolGrowthCondt String = 61
  optional sampCollecDevice String = 62
  optional sampCollecMethod String = 63
  optional sampMatProcess String = 64
  optional sampSize QuantityValue = 65
  optional nuclAcidExt String = 66
  optional nuclAcidAmp String = 67
  optional libSize Integer = 68
  optional libReadsSeqd Integer = 69
  optional libLayout LibLayoutEnum = 70
  optional libVector String = 71
  optional libScreen String = 72
  optional adapters String = 73
  seqMeth String = 74
  optional taxIdent TaxIdentEnum = 75
  optional assemblyQual AssemblyQualEnum = 76
  optional assemblyName String = 77
  assemblySoftware String = 78
  optional annot String = 79
  optional numberContig Integer = 80
  optional featPred String = 81
  optional refDb String = 82
  optional simSearchMeth String = 83
  optional taxClass String = 84
  optional complScore String = 85
  optional complSoftware String = 86
  optional associatedResource String = 87
  optional sop String = 88
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package wastewater_sludge
message WastewaterSludgeMIGSVirus
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional biochemOxygenDem QuantityValue = 12
  repeated chemAdministration String = 13
  optional chemOxygenDem QuantityValue = 14
  optional efficiencyPercent QuantityValue = 15
  repeated emulsions String = 16
  repeated gaseousSubstances String = 17
  optional industEffPercent QuantityValue = 18
  repeated inorgParticles String = 19
  repeated miscParam String = 20
  optional nitrate QuantityValue = 21
  repeated orgParticles String = 22
  repeated organismCount OrganismCountEnum = 23
  optional oxyStatSamp OxyStatSampEnum = 24
  optional ph Double = 25
  repeated perturbation String = 26
  optional phosphate QuantityValue = 27
  optional preTreatment String = 28
  optional primaryTreatment String = 29
  optional reactorType String = 30
  optional salinity QuantityValue = 31
  optional sampStoreDur String = 32
  optional sampStoreLoc String = 33
  optional sampStoreTemp QuantityValue = 34
  optional secondaryTreatment String = 35
  optional sewageType String = 36
  optional sludgeRetentTime QuantityValue = 37
  optional sodium QuantityValue = 38
  repeated solubleInorgMat String = 39
  repeated solubleOrgMat String = 40
  repeated suspendSolids String = 41
  optional tertiaryTreatment String = 42
  optional totNitro QuantityValue = 43
  optional totPhosphate QuantityValue = 44
  optional wastewaterType String = 45
  sampName String = 46
  projectName String = 47
  optional sampVolWeDnaExt QuantityValue = 48
  sampTaxonId String = 49
  optional experimentalFactor String = 50
  optional negContType NegContTypeEnum = 51
  optional posContType String = 52
  optional subspecfGenLin String = 53
  optional numReplicons Integer = 54
  optional estimatedSize String = 55
  optional refBiomaterial String = 56
  optional sourceMatId String = 57
  optional pathogenicity String = 58
  optional bioticRelationship BioticRelationshipEnum = 59
  optional specificHost String = 60
  optional hostSpecRange Integer = 61
  optional hostDiseaseStat String = 62
  propagation String = 63
  optional encodedTraits String = 64
  isolGrowthCondt String = 65
  optional sampCollecDevice String = 66
  optional sampCollecMethod String = 67
  optional sampMatProcess String = 68
  optional sampSize QuantityValue = 69
  optional virusEnrichAppr VirusEnrichApprEnum = 70
  optional nuclAcidExt String = 71
  optional nuclAcidAmp String = 72
  optional libSize Integer = 73
  optional libReadsSeqd Integer = 74
  optional libLayout LibLayoutEnum = 75
  optional libVector String = 76
  optional libScreen String = 77
  optional adapters String = 78
  seqMeth String = 79
  optional taxIdent TaxIdentEnum = 80
  optional assemblyQual AssemblyQualEnum = 81
  optional assemblyName String = 82
  assemblySoftware String = 83
  optional annot String = 84
  optional numberContig Integer = 85
  optional featPred String = 86
  optional refDb String = 87
  optional simSearchMeth String = 88
  optional taxClass String = 89
  optional complScore String = 90
  optional complSoftware String = 91
  optional associatedResource String = 92
  optional sop String = 93
 }
// Combinatorial checklist Minimum Information About a Metagenome-Assembled Genome with environmental package wastewater_sludge
message WastewaterSludgeMIMAG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional biochemOxygenDem QuantityValue = 12
  repeated chemAdministration String = 13
  optional chemOxygenDem QuantityValue = 14
  optional efficiencyPercent QuantityValue = 15
  repeated emulsions String = 16
  repeated gaseousSubstances String = 17
  optional industEffPercent QuantityValue = 18
  repeated inorgParticles String = 19
  repeated miscParam String = 20
  optional nitrate QuantityValue = 21
  repeated orgParticles String = 22
  repeated organismCount OrganismCountEnum = 23
  optional oxyStatSamp OxyStatSampEnum = 24
  optional ph Double = 25
  repeated perturbation String = 26
  optional phosphate QuantityValue = 27
  optional preTreatment String = 28
  optional primaryTreatment String = 29
  optional reactorType String = 30
  optional salinity QuantityValue = 31
  optional sampStoreDur String = 32
  optional sampStoreLoc String = 33
  optional sampStoreTemp QuantityValue = 34
  optional secondaryTreatment String = 35
  optional sewageType String = 36
  optional sludgeRetentTime QuantityValue = 37
  optional sodium QuantityValue = 38
  repeated solubleInorgMat String = 39
  repeated solubleOrgMat String = 40
  repeated suspendSolids String = 41
  optional tertiaryTreatment String = 42
  optional totNitro QuantityValue = 43
  optional totPhosphate QuantityValue = 44
  optional wastewaterType String = 45
  sampName String = 46
  projectName String = 47
  optional sampVolWeDnaExt QuantityValue = 48
  sampTaxonId String = 49
  optional experimentalFactor String = 50
  optional negContType NegContTypeEnum = 51
  optional posContType String = 52
  optional refBiomaterial String = 53
  optional sourceMatId String = 54
  optional relToOxygen RelToOxygenEnum = 55
  optional sampCollecDevice String = 56
  optional sampCollecMethod String = 57
  optional sampMatProcess String = 58
  optional sizeFrac String = 59
  optional sampSize QuantityValue = 60
  optional nuclAcidExt String = 61
  optional nuclAcidAmp String = 62
  optional libSize Integer = 63
  optional libReadsSeqd Integer = 64
  optional libLayout LibLayoutEnum = 65
  optional libVector String = 66
  optional libScreen String = 67
  optional mid String = 68
  optional adapters String = 69
  seqMeth String = 70
  taxIdent TaxIdentEnum = 71
  assemblyQual AssemblyQualEnum = 72
  optional assemblyName String = 73
  assemblySoftware String = 74
  optional annot String = 75
  optional numberContig Integer = 76
  optional featPred String = 77
  optional refDb String = 78
  optional simSearchMeth String = 79
  optional taxClass String = 80
  optional x16sRecover String = 81
  optional x16sRecoverSoftware String = 82
  optional trnas Integer = 83
  optional trnaExtSoftware String = 84
  complScore String = 85
  complSoftware String = 86
  optional complAppr ComplApprEnum = 87
  contamScore String = 88
  optional contamScreenInput String = 89
  optional contamScreenParam String = 90
  optional decontamSoftware DecontamSoftwareEnum = 91
  binParam BinParamEnum = 92
  binSoftware String = 93
  optional reassemblyBin String = 94
  optional magCovSoftware MagCovSoftwareEnum = 95
  optional associatedResource String = 96
  optional sop String = 97
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: specimen with environmental package wastewater_sludge
message WastewaterSludgeMIMARKSSpecimen
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional biochemOxygenDem QuantityValue = 12
  repeated chemAdministration String = 13
  optional chemOxygenDem QuantityValue = 14
  optional efficiencyPercent QuantityValue = 15
  repeated emulsions String = 16
  repeated gaseousSubstances String = 17
  optional industEffPercent QuantityValue = 18
  repeated inorgParticles String = 19
  repeated miscParam String = 20
  optional nitrate QuantityValue = 21
  repeated orgParticles String = 22
  repeated organismCount OrganismCountEnum = 23
  optional oxyStatSamp OxyStatSampEnum = 24
  optional ph Double = 25
  repeated perturbation String = 26
  optional phosphate QuantityValue = 27
  optional preTreatment String = 28
  optional primaryTreatment String = 29
  optional reactorType String = 30
  optional salinity QuantityValue = 31
  optional sampStoreDur String = 32
  optional sampStoreLoc String = 33
  optional sampStoreTemp QuantityValue = 34
  optional secondaryTreatment String = 35
  optional sewageType String = 36
  optional sludgeRetentTime QuantityValue = 37
  optional sodium QuantityValue = 38
  repeated solubleInorgMat String = 39
  repeated solubleOrgMat String = 40
  repeated suspendSolids String = 41
  optional tertiaryTreatment String = 42
  optional totNitro QuantityValue = 43
  optional totPhosphate QuantityValue = 44
  optional wastewaterType String = 45
  sampName String = 46
  projectName String = 47
  optional sampVolWeDnaExt QuantityValue = 48
  sampTaxonId String = 49
  optional experimentalFactor String = 50
  optional negContType NegContTypeEnum = 51
  optional posContType String = 52
  optional sourceMatId String = 53
  optional relToOxygen RelToOxygenEnum = 54
  optional sampCollecDevice String = 55
  optional sampCollecMethod String = 56
  optional sampMatProcess String = 57
  optional sizeFrac String = 58
  optional sampSize QuantityValue = 59
  optional nuclAcidExt String = 60
  optional nuclAcidAmp String = 61
  optional libSize Integer = 62
  optional libReadsSeqd Integer = 63
  optional libLayout LibLayoutEnum = 64
  optional libVector String = 65
  optional libScreen String = 66
  targetGene String = 67
  optional targetSubfragment String = 68
  optional pcrPrimers String = 69
  optional mid String = 70
  optional adapters String = 71
  optional pcrCond String = 72
  seqMeth String = 73
  optional seqQualityCheck String = 74
  optional chimeraCheck String = 75
  optional assemblySoftware String = 76
  optional associatedResource String = 77
  optional sop String = 78
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: survey with environmental package wastewater_sludge
message WastewaterSludgeMIMARKSSurvey
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional biochemOxygenDem QuantityValue = 12
  repeated chemAdministration String = 13
  optional chemOxygenDem QuantityValue = 14
  optional efficiencyPercent QuantityValue = 15
  repeated emulsions String = 16
  repeated gaseousSubstances String = 17
  optional industEffPercent QuantityValue = 18
  repeated inorgParticles String = 19
  repeated miscParam String = 20
  optional nitrate QuantityValue = 21
  repeated orgParticles String = 22
  repeated organismCount OrganismCountEnum = 23
  optional oxyStatSamp OxyStatSampEnum = 24
  optional ph Double = 25
  repeated perturbation String = 26
  optional phosphate QuantityValue = 27
  optional preTreatment String = 28
  optional primaryTreatment String = 29
  optional reactorType String = 30
  optional salinity QuantityValue = 31
  optional sampStoreDur String = 32
  optional sampStoreLoc String = 33
  optional sampStoreTemp QuantityValue = 34
  optional secondaryTreatment String = 35
  optional sewageType String = 36
  optional sludgeRetentTime QuantityValue = 37
  optional sodium QuantityValue = 38
  repeated solubleInorgMat String = 39
  repeated solubleOrgMat String = 40
  repeated suspendSolids String = 41
  optional tertiaryTreatment String = 42
  optional totNitro QuantityValue = 43
  optional totPhosphate QuantityValue = 44
  optional wastewaterType String = 45
  sampName String = 46
  projectName String = 47
  optional sampVolWeDnaExt QuantityValue = 48
  sampTaxonId String = 49
  optional experimentalFactor String = 50
  optional negContType NegContTypeEnum = 51
  optional posContType String = 52
  optional subspecfGenLin String = 53
  optional extrachromElements Integer = 54
  optional sourceMatId String = 55
  optional bioticRelationship BioticRelationshipEnum = 56
  optional trophicLevel TrophicLevelEnum = 57
  optional relToOxygen RelToOxygenEnum = 58
  isolGrowthCondt String = 59
  optional sampCollecDevice String = 60
  optional sampCollecMethod String = 61
  optional sampMatProcess String = 62
  optional sampSize QuantityValue = 63
  optional nuclAcidExt String = 64
  optional nuclAcidAmp String = 65
  targetGene String = 66
  optional targetSubfragment String = 67
  optional pcrPrimers String = 68
  optional pcrCond String = 69
  seqMeth String = 70
  optional seqQualityCheck String = 71
  optional chimeraCheck String = 72
  optional associatedResource String = 73
  optional sop String = 74
 }
// Combinatorial checklist Metagenome or Environmental with environmental package wastewater_sludge
message WastewaterSludgeMIMS
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional biochemOxygenDem QuantityValue = 12
  repeated chemAdministration String = 13
  optional chemOxygenDem QuantityValue = 14
  optional efficiencyPercent QuantityValue = 15
  repeated emulsions String = 16
  repeated gaseousSubstances String = 17
  optional industEffPercent QuantityValue = 18
  repeated inorgParticles String = 19
  repeated miscParam String = 20
  optional nitrate QuantityValue = 21
  repeated orgParticles String = 22
  repeated organismCount OrganismCountEnum = 23
  optional oxyStatSamp OxyStatSampEnum = 24
  optional ph Double = 25
  repeated perturbation String = 26
  optional phosphate QuantityValue = 27
  optional preTreatment String = 28
  optional primaryTreatment String = 29
  optional reactorType String = 30
  optional salinity QuantityValue = 31
  optional sampStoreDur String = 32
  optional sampStoreLoc String = 33
  optional sampStoreTemp QuantityValue = 34
  optional secondaryTreatment String = 35
  optional sewageType String = 36
  optional sludgeRetentTime QuantityValue = 37
  optional sodium QuantityValue = 38
  repeated solubleInorgMat String = 39
  repeated solubleOrgMat String = 40
  repeated suspendSolids String = 41
  optional tertiaryTreatment String = 42
  optional totNitro QuantityValue = 43
  optional totPhosphate QuantityValue = 44
  optional wastewaterType String = 45
  sampName String = 46
  projectName String = 47
  optional sampVolWeDnaExt QuantityValue = 48
  sampTaxonId String = 49
  optional experimentalFactor String = 50
  optional negContType NegContTypeEnum = 51
  optional posContType String = 52
  optional refBiomaterial String = 53
  optional sourceMatId String = 54
  optional relToOxygen RelToOxygenEnum = 55
  optional sampCollecDevice String = 56
  optional sampCollecMethod String = 57
  optional sampMatProcess String = 58
  optional sizeFrac String = 59
  optional sampSize QuantityValue = 60
  optional nuclAcidExt String = 61
  optional nuclAcidAmp String = 62
  optional libSize Integer = 63
  optional libReadsSeqd Integer = 64
  optional libLayout LibLayoutEnum = 65
  optional libVector String = 66
  optional libScreen String = 67
  optional mid String = 68
  optional adapters String = 69
  seqMeth String = 70
  optional assemblyQual AssemblyQualEnum = 71
  optional assemblyName String = 72
  optional assemblySoftware String = 73
  optional annot String = 74
  optional numberContig Integer = 75
  optional featPred String = 76
  optional refDb String = 77
  optional simSearchMeth String = 78
  optional taxClass String = 79
  optional associatedResource String = 80
  optional sop String = 81
 }
// Combinatorial checklist Minimum Information About a Single Amplified Genome with environmental package wastewater_sludge
message WastewaterSludgeMISAG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional biochemOxygenDem QuantityValue = 12
  repeated chemAdministration String = 13
  optional chemOxygenDem QuantityValue = 14
  optional efficiencyPercent QuantityValue = 15
  repeated emulsions String = 16
  repeated gaseousSubstances String = 17
  optional industEffPercent QuantityValue = 18
  repeated inorgParticles String = 19
  repeated miscParam String = 20
  optional nitrate QuantityValue = 21
  repeated orgParticles String = 22
  repeated organismCount OrganismCountEnum = 23
  optional oxyStatSamp OxyStatSampEnum = 24
  optional ph Double = 25
  repeated perturbation String = 26
  optional phosphate QuantityValue = 27
  optional preTreatment String = 28
  optional primaryTreatment String = 29
  optional reactorType String = 30
  optional salinity QuantityValue = 31
  optional sampStoreDur String = 32
  optional sampStoreLoc String = 33
  optional sampStoreTemp QuantityValue = 34
  optional secondaryTreatment String = 35
  optional sewageType String = 36
  optional sludgeRetentTime QuantityValue = 37
  optional sodium QuantityValue = 38
  repeated solubleInorgMat String = 39
  repeated solubleOrgMat String = 40
  repeated suspendSolids String = 41
  optional tertiaryTreatment String = 42
  optional totNitro QuantityValue = 43
  optional totPhosphate QuantityValue = 44
  optional wastewaterType String = 45
  sampName String = 46
  projectName String = 47
  optional sampVolWeDnaExt QuantityValue = 48
  sampTaxonId String = 49
  optional experimentalFactor String = 50
  optional negContType NegContTypeEnum = 51
  optional posContType String = 52
  optional refBiomaterial String = 53
  optional sourceMatId String = 54
  optional relToOxygen RelToOxygenEnum = 55
  optional sampCollecDevice String = 56
  optional sampCollecMethod String = 57
  optional sampMatProcess String = 58
  optional sizeFrac String = 59
  optional sampSize QuantityValue = 60
  optional nuclAcidExt String = 61
  optional nuclAcidAmp String = 62
  optional libSize Integer = 63
  optional libReadsSeqd Integer = 64
  optional libLayout LibLayoutEnum = 65
  optional libVector String = 66
  optional libScreen String = 67
  optional mid String = 68
  optional adapters String = 69
  seqMeth String = 70
  taxIdent TaxIdentEnum = 71
  assemblyQual AssemblyQualEnum = 72
  optional assemblyName String = 73
  assemblySoftware String = 74
  optional annot String = 75
  optional numberContig Integer = 76
  optional featPred String = 77
  optional refDb String = 78
  optional simSearchMeth String = 79
  optional taxClass String = 80
  optional x16sRecover String = 81
  optional x16sRecoverSoftware String = 82
  optional trnas Integer = 83
  optional trnaExtSoftware String = 84
  complScore String = 85
  complSoftware String = 86
  optional complAppr ComplApprEnum = 87
  contamScore String = 88
  optional contamScreenInput String = 89
  optional contamScreenParam String = 90
  optional decontamSoftware DecontamSoftwareEnum = 91
  sortTech SortTechEnum = 92
  singleCellLysisAppr SingleCellLysisApprEnum = 93
  optional singleCellLysisProt String = 94
  wgaAmpAppr String = 95
  optional wgaAmpKit String = 96
  optional associatedResource String = 97
  optional sop String = 98
 }
// Combinatorial checklist Minimum Information About an Uncultivated Virus Genome with environmental package wastewater_sludge
message WastewaterSludgeMIUVIG
 {
  optional latLon String = 1
  optional depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional biochemOxygenDem QuantityValue = 12
  repeated chemAdministration String = 13
  optional chemOxygenDem QuantityValue = 14
  optional efficiencyPercent QuantityValue = 15
  repeated emulsions String = 16
  repeated gaseousSubstances String = 17
  optional industEffPercent QuantityValue = 18
  repeated inorgParticles String = 19
  repeated miscParam String = 20
  optional nitrate QuantityValue = 21
  repeated orgParticles String = 22
  repeated organismCount OrganismCountEnum = 23
  optional oxyStatSamp OxyStatSampEnum = 24
  optional ph Double = 25
  repeated perturbation String = 26
  optional phosphate QuantityValue = 27
  optional preTreatment String = 28
  optional primaryTreatment String = 29
  optional reactorType String = 30
  optional salinity QuantityValue = 31
  optional sampStoreDur String = 32
  optional sampStoreLoc String = 33
  optional sampStoreTemp QuantityValue = 34
  optional secondaryTreatment String = 35
  optional sewageType String = 36
  optional sludgeRetentTime QuantityValue = 37
  optional sodium QuantityValue = 38
  repeated solubleInorgMat String = 39
  repeated solubleOrgMat String = 40
  repeated suspendSolids String = 41
  optional tertiaryTreatment String = 42
  optional totNitro QuantityValue = 43
  optional totPhosphate QuantityValue = 44
  optional wastewaterType String = 45
  sampName String = 46
  projectName String = 47
  optional sampVolWeDnaExt QuantityValue = 48
  sampTaxonId String = 49
  optional experimentalFactor String = 50
  optional negContType NegContTypeEnum = 51
  optional posContType String = 52
  optional estimatedSize String = 53
  optional refBiomaterial String = 54
  optional sourceMatId String = 55
  optional pathogenicity String = 56
  optional bioticRelationship BioticRelationshipEnum = 57
  optional specificHost String = 58
  optional hostSpecRange Integer = 59
  optional hostDiseaseStat String = 60
  optional sampCollecDevice String = 61
  optional sampCollecMethod String = 62
  optional sampMatProcess String = 63
  optional sizeFrac String = 64
  optional sampSize QuantityValue = 65
  sourceUvig SourceUvigEnum = 66
  virusEnrichAppr VirusEnrichApprEnum = 67
  optional nuclAcidExt String = 68
  optional nuclAcidAmp String = 69
  optional libSize Integer = 70
  optional libReadsSeqd Integer = 71
  optional libLayout LibLayoutEnum = 72
  optional libVector String = 73
  optional libScreen String = 74
  optional mid String = 75
  optional adapters String = 76
  seqMeth String = 77
  optional taxIdent TaxIdentEnum = 78
  assemblyQual AssemblyQualEnum = 79
  optional assemblyName String = 80
  assemblySoftware String = 81
  optional annot String = 82
  numberContig Integer = 83
  optional featPred String = 84
  optional refDb String = 85
  optional simSearchMeth String = 86
  optional taxClass String = 87
  optional trnas Integer = 88
  optional trnaExtSoftware String = 89
  optional complScore String = 90
  optional complSoftware String = 91
  optional complAppr ComplApprEnum = 92
  optional sortTech SortTechEnum = 93
  optional singleCellLysisAppr SingleCellLysisApprEnum = 94
  optional singleCellLysisProt String = 95
  optional wgaAmpAppr String = 96
  optional wgaAmpKit String = 97
  optional binParam BinParamEnum = 98
  optional binSoftware String = 99
  optional reassemblyBin String = 100
  optional magCovSoftware MagCovSoftwareEnum = 101
  virIdentSoftware String = 102
  predGenomeType PredGenomeTypeEnum = 103
  predGenomeStruc PredGenomeStrucEnum = 104
  detecType String = 105
  optional otuClassAppr String = 106
  optional otuSeqCompAppr String = 107
  optional otuDb String = 108
  optional hostPredAppr HostPredApprEnum = 109
  optional hostPredEstAcc String = 110
  optional associatedResource String = 111
  optional sop String = 112
 }
// water
message Water
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkalinityMethod String = 12
  optional alkylDiethers QuantityValue = 13
  optional aminopeptAct QuantityValue = 14
  optional ammonium QuantityValue = 15
  repeated atmosphericData String = 16
  optional bacteriaCarbProd QuantityValue = 17
  optional bacProd QuantityValue = 18
  optional bacResp QuantityValue = 19
  repeated biomass String = 20
  optional bishomohopanol QuantityValue = 21
  optional bromide QuantityValue = 22
  optional calcium QuantityValue = 23
  optional carbNitroRatio QuantityValue = 24
  repeated chemAdministration String = 25
  optional chloride QuantityValue = 26
  optional chlorophyll QuantityValue = 27
  optional conduc QuantityValue = 28
  optional density QuantityValue = 29
  repeated dietherLipids String = 30
  optional dissCarbDioxide QuantityValue = 31
  optional dissHydrogen QuantityValue = 32
  optional dissInorgCarb QuantityValue = 33
  optional dissInorgNitro QuantityValue = 34
  optional dissInorgPhosp QuantityValue = 35
  optional dissOrgCarb QuantityValue = 36
  optional dissOrgNitro QuantityValue = 37
  optional dissOxygen QuantityValue = 38
  optional downPar QuantityValue = 39
  optional fluor QuantityValue = 40
  optional glucosidaseAct QuantityValue = 41
  optional lightIntensity QuantityValue = 42
  optional magnesium QuantityValue = 43
  optional meanFrictVel QuantityValue = 44
  optional meanPeakFrictVel QuantityValue = 45
  repeated miscParam String = 46
  repeated nAlkanes String = 47
  optional nitrate QuantityValue = 48
  optional nitrite QuantityValue = 49
  optional nitro QuantityValue = 50
  optional orgCarb QuantityValue = 51
  optional orgMatter QuantityValue = 52
  optional orgNitro QuantityValue = 53
  repeated organismCount OrganismCountEnum = 54
  optional oxyStatSamp OxyStatSampEnum = 55
  optional ph Double = 56
  optional partOrgCarb QuantityValue = 57
  optional partOrgNitro QuantityValue = 58
  repeated perturbation String = 59
  optional petroleumHydrocarb QuantityValue = 60
  repeated phaeopigments String = 61
  optional phosphate QuantityValue = 62
  repeated phosplipidFattAcid String = 63
  optional photonFlux QuantityValue = 64
  optional potassium QuantityValue = 65
  optional pressure QuantityValue = 66
  optional primaryProd QuantityValue = 67
  optional redoxPotential QuantityValue = 68
  optional salinity QuantityValue = 69
  optional sampStoreDur String = 70
  optional sampStoreLoc String = 71
  optional sampStoreTemp QuantityValue = 72
  optional silicate QuantityValue = 73
  optional sizeFracLow QuantityValue = 74
  optional sizeFracUp QuantityValue = 75
  optional sodium QuantityValue = 76
  optional solubleReactPhosp QuantityValue = 77
  optional sulfate QuantityValue = 78
  optional sulfide QuantityValue = 79
  optional suspendPartMatter QuantityValue = 80
  optional tidalStage TidalStageEnum = 81
  optional totDepthWaterCol QuantityValue = 82
  optional totDissNitro QuantityValue = 83
  optional totInorgNitro QuantityValue = 84
  optional totNitro QuantityValue = 85
  optional totPartCarb QuantityValue = 86
  optional totPhosp QuantityValue = 87
  optional turbidity QuantityValue = 88
  optional waterCurrent QuantityValue = 89
  sampName String = 90
  projectName String = 91
  optional sampVolWeDnaExt QuantityValue = 92
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package water
message WaterMIGSBacteria
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkalinityMethod String = 12
  optional alkylDiethers QuantityValue = 13
  optional aminopeptAct QuantityValue = 14
  optional ammonium QuantityValue = 15
  repeated atmosphericData String = 16
  optional bacteriaCarbProd QuantityValue = 17
  optional bacProd QuantityValue = 18
  optional bacResp QuantityValue = 19
  repeated biomass String = 20
  optional bishomohopanol QuantityValue = 21
  optional bromide QuantityValue = 22
  optional calcium QuantityValue = 23
  optional carbNitroRatio QuantityValue = 24
  repeated chemAdministration String = 25
  optional chloride QuantityValue = 26
  optional chlorophyll QuantityValue = 27
  optional conduc QuantityValue = 28
  optional density QuantityValue = 29
  repeated dietherLipids String = 30
  optional dissCarbDioxide QuantityValue = 31
  optional dissHydrogen QuantityValue = 32
  optional dissInorgCarb QuantityValue = 33
  optional dissInorgNitro QuantityValue = 34
  optional dissInorgPhosp QuantityValue = 35
  optional dissOrgCarb QuantityValue = 36
  optional dissOrgNitro QuantityValue = 37
  optional dissOxygen QuantityValue = 38
  optional downPar QuantityValue = 39
  optional fluor QuantityValue = 40
  optional glucosidaseAct QuantityValue = 41
  optional lightIntensity QuantityValue = 42
  optional magnesium QuantityValue = 43
  optional meanFrictVel QuantityValue = 44
  optional meanPeakFrictVel QuantityValue = 45
  repeated miscParam String = 46
  repeated nAlkanes String = 47
  optional nitrate QuantityValue = 48
  optional nitrite QuantityValue = 49
  optional nitro QuantityValue = 50
  optional orgCarb QuantityValue = 51
  optional orgMatter QuantityValue = 52
  optional orgNitro QuantityValue = 53
  repeated organismCount OrganismCountEnum = 54
  optional oxyStatSamp OxyStatSampEnum = 55
  optional ph Double = 56
  optional partOrgCarb QuantityValue = 57
  optional partOrgNitro QuantityValue = 58
  repeated perturbation String = 59
  optional petroleumHydrocarb QuantityValue = 60
  repeated phaeopigments String = 61
  optional phosphate QuantityValue = 62
  repeated phosplipidFattAcid String = 63
  optional photonFlux QuantityValue = 64
  optional potassium QuantityValue = 65
  optional pressure QuantityValue = 66
  optional primaryProd QuantityValue = 67
  optional redoxPotential QuantityValue = 68
  optional salinity QuantityValue = 69
  optional sampStoreDur String = 70
  optional sampStoreLoc String = 71
  optional sampStoreTemp QuantityValue = 72
  optional silicate QuantityValue = 73
  optional sizeFracLow QuantityValue = 74
  optional sizeFracUp QuantityValue = 75
  optional sodium QuantityValue = 76
  optional solubleReactPhosp QuantityValue = 77
  optional sulfate QuantityValue = 78
  optional sulfide QuantityValue = 79
  optional suspendPartMatter QuantityValue = 80
  optional tidalStage TidalStageEnum = 81
  optional totDepthWaterCol QuantityValue = 82
  optional totDissNitro QuantityValue = 83
  optional totInorgNitro QuantityValue = 84
  optional totNitro QuantityValue = 85
  optional totPartCarb QuantityValue = 86
  optional totPhosp QuantityValue = 87
  optional turbidity QuantityValue = 88
  optional waterCurrent QuantityValue = 89
  sampName String = 90
  projectName String = 91
  optional sampVolWeDnaExt QuantityValue = 92
  sampTaxonId String = 93
  optional experimentalFactor String = 94
  optional negContType NegContTypeEnum = 95
  optional posContType String = 96
  optional subspecfGenLin String = 97
  numReplicons Integer = 98
  optional extrachromElements Integer = 99
  optional estimatedSize String = 100
  refBiomaterial String = 101
  optional sourceMatId String = 102
  optional pathogenicity String = 103
  optional bioticRelationship BioticRelationshipEnum = 104
  optional specificHost String = 105
  optional hostSpecRange Integer = 106
  optional hostDiseaseStat String = 107
  optional trophicLevel TrophicLevelEnum = 108
  optional encodedTraits String = 109
  optional relToOxygen RelToOxygenEnum = 110
  isolGrowthCondt String = 111
  optional sampCollecDevice String = 112
  optional sampCollecMethod String = 113
  optional sampMatProcess String = 114
  optional sampSize QuantityValue = 115
  optional nuclAcidExt String = 116
  optional nuclAcidAmp String = 117
  optional libSize Integer = 118
  optional libReadsSeqd Integer = 119
  optional libLayout LibLayoutEnum = 120
  optional libVector String = 121
  optional libScreen String = 122
  optional adapters String = 123
  seqMeth String = 124
  optional taxIdent TaxIdentEnum = 125
  assemblyQual AssemblyQualEnum = 126
  optional assemblyName String = 127
  assemblySoftware String = 128
  optional annot String = 129
  numberContig Integer = 130
  optional featPred String = 131
  optional refDb String = 132
  optional simSearchMeth String = 133
  optional taxClass String = 134
  optional complScore String = 135
  optional complSoftware String = 136
  optional associatedResource String = 137
  optional sop String = 138
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: eukaryote with environmental package water
message WaterMIGSEukaryote
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkalinityMethod String = 12
  optional alkylDiethers QuantityValue = 13
  optional aminopeptAct QuantityValue = 14
  optional ammonium QuantityValue = 15
  repeated atmosphericData String = 16
  optional bacteriaCarbProd QuantityValue = 17
  optional bacProd QuantityValue = 18
  optional bacResp QuantityValue = 19
  repeated biomass String = 20
  optional bishomohopanol QuantityValue = 21
  optional bromide QuantityValue = 22
  optional calcium QuantityValue = 23
  optional carbNitroRatio QuantityValue = 24
  repeated chemAdministration String = 25
  optional chloride QuantityValue = 26
  optional chlorophyll QuantityValue = 27
  optional conduc QuantityValue = 28
  optional density QuantityValue = 29
  repeated dietherLipids String = 30
  optional dissCarbDioxide QuantityValue = 31
  optional dissHydrogen QuantityValue = 32
  optional dissInorgCarb QuantityValue = 33
  optional dissInorgNitro QuantityValue = 34
  optional dissInorgPhosp QuantityValue = 35
  optional dissOrgCarb QuantityValue = 36
  optional dissOrgNitro QuantityValue = 37
  optional dissOxygen QuantityValue = 38
  optional downPar QuantityValue = 39
  optional fluor QuantityValue = 40
  optional glucosidaseAct QuantityValue = 41
  optional lightIntensity QuantityValue = 42
  optional magnesium QuantityValue = 43
  optional meanFrictVel QuantityValue = 44
  optional meanPeakFrictVel QuantityValue = 45
  repeated miscParam String = 46
  repeated nAlkanes String = 47
  optional nitrate QuantityValue = 48
  optional nitrite QuantityValue = 49
  optional nitro QuantityValue = 50
  optional orgCarb QuantityValue = 51
  optional orgMatter QuantityValue = 52
  optional orgNitro QuantityValue = 53
  repeated organismCount OrganismCountEnum = 54
  optional oxyStatSamp OxyStatSampEnum = 55
  optional ph Double = 56
  optional partOrgCarb QuantityValue = 57
  optional partOrgNitro QuantityValue = 58
  repeated perturbation String = 59
  optional petroleumHydrocarb QuantityValue = 60
  repeated phaeopigments String = 61
  optional phosphate QuantityValue = 62
  repeated phosplipidFattAcid String = 63
  optional photonFlux QuantityValue = 64
  optional potassium QuantityValue = 65
  optional pressure QuantityValue = 66
  optional primaryProd QuantityValue = 67
  optional redoxPotential QuantityValue = 68
  optional salinity QuantityValue = 69
  optional sampStoreDur String = 70
  optional sampStoreLoc String = 71
  optional sampStoreTemp QuantityValue = 72
  optional silicate QuantityValue = 73
  optional sizeFracLow QuantityValue = 74
  optional sizeFracUp QuantityValue = 75
  optional sodium QuantityValue = 76
  optional solubleReactPhosp QuantityValue = 77
  optional sulfate QuantityValue = 78
  optional sulfide QuantityValue = 79
  optional suspendPartMatter QuantityValue = 80
  optional tidalStage TidalStageEnum = 81
  optional totDepthWaterCol QuantityValue = 82
  optional totDissNitro QuantityValue = 83
  optional totInorgNitro QuantityValue = 84
  optional totNitro QuantityValue = 85
  optional totPartCarb QuantityValue = 86
  optional totPhosp QuantityValue = 87
  optional turbidity QuantityValue = 88
  optional waterCurrent QuantityValue = 89
  sampName String = 90
  projectName String = 91
  optional sampVolWeDnaExt QuantityValue = 92
  sampTaxonId String = 93
  optional experimentalFactor String = 94
  optional negContType NegContTypeEnum = 95
  optional posContType String = 96
  optional subspecfGenLin String = 97
  optional ploidy String = 98
  optional numReplicons Integer = 99
  optional extrachromElements Integer = 100
  optional estimatedSize String = 101
  optional refBiomaterial String = 102
  optional sourceMatId String = 103
  optional pathogenicity String = 104
  optional bioticRelationship BioticRelationshipEnum = 105
  optional specificHost String = 106
  optional hostSpecRange Integer = 107
  optional hostDiseaseStat String = 108
  optional trophicLevel TrophicLevelEnum = 109
  optional propagation String = 110
  isolGrowthCondt String = 111
  optional sampCollecDevice String = 112
  optional sampCollecMethod String = 113
  optional sampMatProcess String = 114
  optional sampSize QuantityValue = 115
  optional nuclAcidExt String = 116
  optional nuclAcidAmp String = 117
  optional libSize Integer = 118
  optional libReadsSeqd Integer = 119
  optional libLayout LibLayoutEnum = 120
  optional libVector String = 121
  optional libScreen String = 122
  optional adapters String = 123
  seqMeth String = 124
  optional taxIdent TaxIdentEnum = 125
  assemblyQual AssemblyQualEnum = 126
  optional assemblyName String = 127
  assemblySoftware String = 128
  optional annot String = 129
  numberContig Integer = 130
  optional featPred String = 131
  optional refDb String = 132
  optional simSearchMeth String = 133
  optional taxClass String = 134
  optional complScore String = 135
  optional complSoftware String = 136
  optional associatedResource String = 137
  optional sop String = 138
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: org with environmental package water
message WaterMIGSOrg
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkalinityMethod String = 12
  optional alkylDiethers QuantityValue = 13
  optional aminopeptAct QuantityValue = 14
  optional ammonium QuantityValue = 15
  repeated atmosphericData String = 16
  optional bacteriaCarbProd QuantityValue = 17
  optional bacProd QuantityValue = 18
  optional bacResp QuantityValue = 19
  repeated biomass String = 20
  optional bishomohopanol QuantityValue = 21
  optional bromide QuantityValue = 22
  optional calcium QuantityValue = 23
  optional carbNitroRatio QuantityValue = 24
  repeated chemAdministration String = 25
  optional chloride QuantityValue = 26
  optional chlorophyll QuantityValue = 27
  optional conduc QuantityValue = 28
  optional density QuantityValue = 29
  repeated dietherLipids String = 30
  optional dissCarbDioxide QuantityValue = 31
  optional dissHydrogen QuantityValue = 32
  optional dissInorgCarb QuantityValue = 33
  optional dissInorgNitro QuantityValue = 34
  optional dissInorgPhosp QuantityValue = 35
  optional dissOrgCarb QuantityValue = 36
  optional dissOrgNitro QuantityValue = 37
  optional dissOxygen QuantityValue = 38
  optional downPar QuantityValue = 39
  optional fluor QuantityValue = 40
  optional glucosidaseAct QuantityValue = 41
  optional lightIntensity QuantityValue = 42
  optional magnesium QuantityValue = 43
  optional meanFrictVel QuantityValue = 44
  optional meanPeakFrictVel QuantityValue = 45
  repeated miscParam String = 46
  repeated nAlkanes String = 47
  optional nitrate QuantityValue = 48
  optional nitrite QuantityValue = 49
  optional nitro QuantityValue = 50
  optional orgCarb QuantityValue = 51
  optional orgMatter QuantityValue = 52
  optional orgNitro QuantityValue = 53
  repeated organismCount OrganismCountEnum = 54
  optional oxyStatSamp OxyStatSampEnum = 55
  optional ph Double = 56
  optional partOrgCarb QuantityValue = 57
  optional partOrgNitro QuantityValue = 58
  repeated perturbation String = 59
  optional petroleumHydrocarb QuantityValue = 60
  repeated phaeopigments String = 61
  optional phosphate QuantityValue = 62
  repeated phosplipidFattAcid String = 63
  optional photonFlux QuantityValue = 64
  optional potassium QuantityValue = 65
  optional pressure QuantityValue = 66
  optional primaryProd QuantityValue = 67
  optional redoxPotential QuantityValue = 68
  optional salinity QuantityValue = 69
  optional sampStoreDur String = 70
  optional sampStoreLoc String = 71
  optional sampStoreTemp QuantityValue = 72
  optional silicate QuantityValue = 73
  optional sizeFracLow QuantityValue = 74
  optional sizeFracUp QuantityValue = 75
  optional sodium QuantityValue = 76
  optional solubleReactPhosp QuantityValue = 77
  optional sulfate QuantityValue = 78
  optional sulfide QuantityValue = 79
  optional suspendPartMatter QuantityValue = 80
  optional tidalStage TidalStageEnum = 81
  optional totDepthWaterCol QuantityValue = 82
  optional totDissNitro QuantityValue = 83
  optional totInorgNitro QuantityValue = 84
  optional totNitro QuantityValue = 85
  optional totPartCarb QuantityValue = 86
  optional totPhosp QuantityValue = 87
  optional turbidity QuantityValue = 88
  optional waterCurrent QuantityValue = 89
  sampName String = 90
  projectName String = 91
  optional sampVolWeDnaExt QuantityValue = 92
  sampTaxonId String = 93
  optional experimentalFactor String = 94
  optional negContType NegContTypeEnum = 95
  optional posContType String = 96
  optional subspecfGenLin String = 97
  optional extrachromElements Integer = 98
  optional estimatedSize String = 99
  optional refBiomaterial String = 100
  optional sourceMatId String = 101
  isolGrowthCondt String = 102
  optional sampCollecDevice String = 103
  optional sampCollecMethod String = 104
  optional sampMatProcess String = 105
  optional sampSize QuantityValue = 106
  optional nuclAcidExt String = 107
  optional nuclAcidAmp String = 108
  optional libSize Integer = 109
  optional libReadsSeqd Integer = 110
  optional libLayout LibLayoutEnum = 111
  optional libVector String = 112
  optional libScreen String = 113
  optional adapters String = 114
  seqMeth String = 115
  optional taxIdent TaxIdentEnum = 116
  optional assemblyQual AssemblyQualEnum = 117
  optional assemblyName String = 118
  assemblySoftware String = 119
  optional annot String = 120
  optional numberContig Integer = 121
  optional featPred String = 122
  optional refDb String = 123
  optional simSearchMeth String = 124
  optional taxClass String = 125
  optional complScore String = 126
  optional complSoftware String = 127
  optional associatedResource String = 128
  optional sop String = 129
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: plant with environmental package water
message WaterMIGSPlant
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkalinityMethod String = 12
  optional alkylDiethers QuantityValue = 13
  optional aminopeptAct QuantityValue = 14
  optional ammonium QuantityValue = 15
  repeated atmosphericData String = 16
  optional bacteriaCarbProd QuantityValue = 17
  optional bacProd QuantityValue = 18
  optional bacResp QuantityValue = 19
  repeated biomass String = 20
  optional bishomohopanol QuantityValue = 21
  optional bromide QuantityValue = 22
  optional calcium QuantityValue = 23
  optional carbNitroRatio QuantityValue = 24
  repeated chemAdministration String = 25
  optional chloride QuantityValue = 26
  optional chlorophyll QuantityValue = 27
  optional conduc QuantityValue = 28
  optional density QuantityValue = 29
  repeated dietherLipids String = 30
  optional dissCarbDioxide QuantityValue = 31
  optional dissHydrogen QuantityValue = 32
  optional dissInorgCarb QuantityValue = 33
  optional dissInorgNitro QuantityValue = 34
  optional dissInorgPhosp QuantityValue = 35
  optional dissOrgCarb QuantityValue = 36
  optional dissOrgNitro QuantityValue = 37
  optional dissOxygen QuantityValue = 38
  optional downPar QuantityValue = 39
  optional fluor QuantityValue = 40
  optional glucosidaseAct QuantityValue = 41
  optional lightIntensity QuantityValue = 42
  optional magnesium QuantityValue = 43
  optional meanFrictVel QuantityValue = 44
  optional meanPeakFrictVel QuantityValue = 45
  repeated miscParam String = 46
  repeated nAlkanes String = 47
  optional nitrate QuantityValue = 48
  optional nitrite QuantityValue = 49
  optional nitro QuantityValue = 50
  optional orgCarb QuantityValue = 51
  optional orgMatter QuantityValue = 52
  optional orgNitro QuantityValue = 53
  repeated organismCount OrganismCountEnum = 54
  optional oxyStatSamp OxyStatSampEnum = 55
  optional ph Double = 56
  optional partOrgCarb QuantityValue = 57
  optional partOrgNitro QuantityValue = 58
  repeated perturbation String = 59
  optional petroleumHydrocarb QuantityValue = 60
  repeated phaeopigments String = 61
  optional phosphate QuantityValue = 62
  repeated phosplipidFattAcid String = 63
  optional photonFlux QuantityValue = 64
  optional potassium QuantityValue = 65
  optional pressure QuantityValue = 66
  optional primaryProd QuantityValue = 67
  optional redoxPotential QuantityValue = 68
  optional salinity QuantityValue = 69
  optional sampStoreDur String = 70
  optional sampStoreLoc String = 71
  optional sampStoreTemp QuantityValue = 72
  optional silicate QuantityValue = 73
  optional sizeFracLow QuantityValue = 74
  optional sizeFracUp QuantityValue = 75
  optional sodium QuantityValue = 76
  optional solubleReactPhosp QuantityValue = 77
  optional sulfate QuantityValue = 78
  optional sulfide QuantityValue = 79
  optional suspendPartMatter QuantityValue = 80
  optional tidalStage TidalStageEnum = 81
  optional totDepthWaterCol QuantityValue = 82
  optional totDissNitro QuantityValue = 83
  optional totInorgNitro QuantityValue = 84
  optional totNitro QuantityValue = 85
  optional totPartCarb QuantityValue = 86
  optional totPhosp QuantityValue = 87
  optional turbidity QuantityValue = 88
  optional waterCurrent QuantityValue = 89
  sampName String = 90
  projectName String = 91
  optional sampVolWeDnaExt QuantityValue = 92
  sampTaxonId String = 93
  optional experimentalFactor String = 94
  optional negContType NegContTypeEnum = 95
  optional posContType String = 96
  optional subspecfGenLin String = 97
  optional estimatedSize String = 98
  optional refBiomaterial String = 99
  optional sourceMatId String = 100
  optional specificHost String = 101
  optional hostSpecRange Integer = 102
  propagation String = 103
  optional encodedTraits String = 104
  isolGrowthCondt String = 105
  optional sampCollecDevice String = 106
  optional sampCollecMethod String = 107
  optional sampMatProcess String = 108
  optional sampSize QuantityValue = 109
  optional nuclAcidExt String = 110
  optional nuclAcidAmp String = 111
  optional libSize Integer = 112
  optional libReadsSeqd Integer = 113
  optional libLayout LibLayoutEnum = 114
  optional libVector String = 115
  optional libScreen String = 116
  optional adapters String = 117
  seqMeth String = 118
  optional taxIdent TaxIdentEnum = 119
  optional assemblyQual AssemblyQualEnum = 120
  optional assemblyName String = 121
  assemblySoftware String = 122
  optional annot String = 123
  optional numberContig Integer = 124
  optional featPred String = 125
  optional refDb String = 126
  optional simSearchMeth String = 127
  optional taxClass String = 128
  optional complScore String = 129
  optional complSoftware String = 130
  optional associatedResource String = 131
  optional sop String = 132
 }
// Combinatorial checklist Minimal Information about a Genome Sequence: cultured bacteria/archaea with environmental package water
message WaterMIGSVirus
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkalinityMethod String = 12
  optional alkylDiethers QuantityValue = 13
  optional aminopeptAct QuantityValue = 14
  optional ammonium QuantityValue = 15
  repeated atmosphericData String = 16
  optional bacteriaCarbProd QuantityValue = 17
  optional bacProd QuantityValue = 18
  optional bacResp QuantityValue = 19
  repeated biomass String = 20
  optional bishomohopanol QuantityValue = 21
  optional bromide QuantityValue = 22
  optional calcium QuantityValue = 23
  optional carbNitroRatio QuantityValue = 24
  repeated chemAdministration String = 25
  optional chloride QuantityValue = 26
  optional chlorophyll QuantityValue = 27
  optional conduc QuantityValue = 28
  optional density QuantityValue = 29
  repeated dietherLipids String = 30
  optional dissCarbDioxide QuantityValue = 31
  optional dissHydrogen QuantityValue = 32
  optional dissInorgCarb QuantityValue = 33
  optional dissInorgNitro QuantityValue = 34
  optional dissInorgPhosp QuantityValue = 35
  optional dissOrgCarb QuantityValue = 36
  optional dissOrgNitro QuantityValue = 37
  optional dissOxygen QuantityValue = 38
  optional downPar QuantityValue = 39
  optional fluor QuantityValue = 40
  optional glucosidaseAct QuantityValue = 41
  optional lightIntensity QuantityValue = 42
  optional magnesium QuantityValue = 43
  optional meanFrictVel QuantityValue = 44
  optional meanPeakFrictVel QuantityValue = 45
  repeated miscParam String = 46
  repeated nAlkanes String = 47
  optional nitrate QuantityValue = 48
  optional nitrite QuantityValue = 49
  optional nitro QuantityValue = 50
  optional orgCarb QuantityValue = 51
  optional orgMatter QuantityValue = 52
  optional orgNitro QuantityValue = 53
  repeated organismCount OrganismCountEnum = 54
  optional oxyStatSamp OxyStatSampEnum = 55
  optional ph Double = 56
  optional partOrgCarb QuantityValue = 57
  optional partOrgNitro QuantityValue = 58
  repeated perturbation String = 59
  optional petroleumHydrocarb QuantityValue = 60
  repeated phaeopigments String = 61
  optional phosphate QuantityValue = 62
  repeated phosplipidFattAcid String = 63
  optional photonFlux QuantityValue = 64
  optional potassium QuantityValue = 65
  optional pressure QuantityValue = 66
  optional primaryProd QuantityValue = 67
  optional redoxPotential QuantityValue = 68
  optional salinity QuantityValue = 69
  optional sampStoreDur String = 70
  optional sampStoreLoc String = 71
  optional sampStoreTemp QuantityValue = 72
  optional silicate QuantityValue = 73
  optional sizeFracLow QuantityValue = 74
  optional sizeFracUp QuantityValue = 75
  optional sodium QuantityValue = 76
  optional solubleReactPhosp QuantityValue = 77
  optional sulfate QuantityValue = 78
  optional sulfide QuantityValue = 79
  optional suspendPartMatter QuantityValue = 80
  optional tidalStage TidalStageEnum = 81
  optional totDepthWaterCol QuantityValue = 82
  optional totDissNitro QuantityValue = 83
  optional totInorgNitro QuantityValue = 84
  optional totNitro QuantityValue = 85
  optional totPartCarb QuantityValue = 86
  optional totPhosp QuantityValue = 87
  optional turbidity QuantityValue = 88
  optional waterCurrent QuantityValue = 89
  sampName String = 90
  projectName String = 91
  optional sampVolWeDnaExt QuantityValue = 92
  sampTaxonId String = 93
  optional experimentalFactor String = 94
  optional negContType NegContTypeEnum = 95
  optional posContType String = 96
  optional subspecfGenLin String = 97
  optional numReplicons Integer = 98
  optional estimatedSize String = 99
  optional refBiomaterial String = 100
  optional sourceMatId String = 101
  optional pathogenicity String = 102
  optional bioticRelationship BioticRelationshipEnum = 103
  optional specificHost String = 104
  optional hostSpecRange Integer = 105
  optional hostDiseaseStat String = 106
  propagation String = 107
  optional encodedTraits String = 108
  isolGrowthCondt String = 109
  optional sampCollecDevice String = 110
  optional sampCollecMethod String = 111
  optional sampMatProcess String = 112
  optional sampSize QuantityValue = 113
  optional virusEnrichAppr VirusEnrichApprEnum = 114
  optional nuclAcidExt String = 115
  optional nuclAcidAmp String = 116
  optional libSize Integer = 117
  optional libReadsSeqd Integer = 118
  optional libLayout LibLayoutEnum = 119
  optional libVector String = 120
  optional libScreen String = 121
  optional adapters String = 122
  seqMeth String = 123
  optional taxIdent TaxIdentEnum = 124
  optional assemblyQual AssemblyQualEnum = 125
  optional assemblyName String = 126
  assemblySoftware String = 127
  optional annot String = 128
  optional numberContig Integer = 129
  optional featPred String = 130
  optional refDb String = 131
  optional simSearchMeth String = 132
  optional taxClass String = 133
  optional complScore String = 134
  optional complSoftware String = 135
  optional associatedResource String = 136
  optional sop String = 137
 }
// Combinatorial checklist Minimum Information About a Metagenome-Assembled Genome with environmental package water
message WaterMIMAG
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkalinityMethod String = 12
  optional alkylDiethers QuantityValue = 13
  optional aminopeptAct QuantityValue = 14
  optional ammonium QuantityValue = 15
  repeated atmosphericData String = 16
  optional bacteriaCarbProd QuantityValue = 17
  optional bacProd QuantityValue = 18
  optional bacResp QuantityValue = 19
  repeated biomass String = 20
  optional bishomohopanol QuantityValue = 21
  optional bromide QuantityValue = 22
  optional calcium QuantityValue = 23
  optional carbNitroRatio QuantityValue = 24
  repeated chemAdministration String = 25
  optional chloride QuantityValue = 26
  optional chlorophyll QuantityValue = 27
  optional conduc QuantityValue = 28
  optional density QuantityValue = 29
  repeated dietherLipids String = 30
  optional dissCarbDioxide QuantityValue = 31
  optional dissHydrogen QuantityValue = 32
  optional dissInorgCarb QuantityValue = 33
  optional dissInorgNitro QuantityValue = 34
  optional dissInorgPhosp QuantityValue = 35
  optional dissOrgCarb QuantityValue = 36
  optional dissOrgNitro QuantityValue = 37
  optional dissOxygen QuantityValue = 38
  optional downPar QuantityValue = 39
  optional fluor QuantityValue = 40
  optional glucosidaseAct QuantityValue = 41
  optional lightIntensity QuantityValue = 42
  optional magnesium QuantityValue = 43
  optional meanFrictVel QuantityValue = 44
  optional meanPeakFrictVel QuantityValue = 45
  repeated miscParam String = 46
  repeated nAlkanes String = 47
  optional nitrate QuantityValue = 48
  optional nitrite QuantityValue = 49
  optional nitro QuantityValue = 50
  optional orgCarb QuantityValue = 51
  optional orgMatter QuantityValue = 52
  optional orgNitro QuantityValue = 53
  repeated organismCount OrganismCountEnum = 54
  optional oxyStatSamp OxyStatSampEnum = 55
  optional ph Double = 56
  optional partOrgCarb QuantityValue = 57
  optional partOrgNitro QuantityValue = 58
  repeated perturbation String = 59
  optional petroleumHydrocarb QuantityValue = 60
  repeated phaeopigments String = 61
  optional phosphate QuantityValue = 62
  repeated phosplipidFattAcid String = 63
  optional photonFlux QuantityValue = 64
  optional potassium QuantityValue = 65
  optional pressure QuantityValue = 66
  optional primaryProd QuantityValue = 67
  optional redoxPotential QuantityValue = 68
  optional salinity QuantityValue = 69
  optional sampStoreDur String = 70
  optional sampStoreLoc String = 71
  optional sampStoreTemp QuantityValue = 72
  optional silicate QuantityValue = 73
  optional sizeFracLow QuantityValue = 74
  optional sizeFracUp QuantityValue = 75
  optional sodium QuantityValue = 76
  optional solubleReactPhosp QuantityValue = 77
  optional sulfate QuantityValue = 78
  optional sulfide QuantityValue = 79
  optional suspendPartMatter QuantityValue = 80
  optional tidalStage TidalStageEnum = 81
  optional totDepthWaterCol QuantityValue = 82
  optional totDissNitro QuantityValue = 83
  optional totInorgNitro QuantityValue = 84
  optional totNitro QuantityValue = 85
  optional totPartCarb QuantityValue = 86
  optional totPhosp QuantityValue = 87
  optional turbidity QuantityValue = 88
  optional waterCurrent QuantityValue = 89
  sampName String = 90
  projectName String = 91
  optional sampVolWeDnaExt QuantityValue = 92
  sampTaxonId String = 93
  optional experimentalFactor String = 94
  optional negContType NegContTypeEnum = 95
  optional posContType String = 96
  optional refBiomaterial String = 97
  optional sourceMatId String = 98
  optional relToOxygen RelToOxygenEnum = 99
  optional sampCollecDevice String = 100
  optional sampCollecMethod String = 101
  optional sampMatProcess String = 102
  optional sizeFrac String = 103
  optional sampSize QuantityValue = 104
  optional nuclAcidExt String = 105
  optional nuclAcidAmp String = 106
  optional libSize Integer = 107
  optional libReadsSeqd Integer = 108
  optional libLayout LibLayoutEnum = 109
  optional libVector String = 110
  optional libScreen String = 111
  optional mid String = 112
  optional adapters String = 113
  seqMeth String = 114
  taxIdent TaxIdentEnum = 115
  assemblyQual AssemblyQualEnum = 116
  optional assemblyName String = 117
  assemblySoftware String = 118
  optional annot String = 119
  optional numberContig Integer = 120
  optional featPred String = 121
  optional refDb String = 122
  optional simSearchMeth String = 123
  optional taxClass String = 124
  optional x16sRecover String = 125
  optional x16sRecoverSoftware String = 126
  optional trnas Integer = 127
  optional trnaExtSoftware String = 128
  complScore String = 129
  complSoftware String = 130
  optional complAppr ComplApprEnum = 131
  contamScore String = 132
  optional contamScreenInput String = 133
  optional contamScreenParam String = 134
  optional decontamSoftware DecontamSoftwareEnum = 135
  binParam BinParamEnum = 136
  binSoftware String = 137
  optional reassemblyBin String = 138
  optional magCovSoftware MagCovSoftwareEnum = 139
  optional associatedResource String = 140
  optional sop String = 141
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: specimen with environmental package water
message WaterMIMARKSSpecimen
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkalinityMethod String = 12
  optional alkylDiethers QuantityValue = 13
  optional aminopeptAct QuantityValue = 14
  optional ammonium QuantityValue = 15
  repeated atmosphericData String = 16
  optional bacteriaCarbProd QuantityValue = 17
  optional bacProd QuantityValue = 18
  optional bacResp QuantityValue = 19
  repeated biomass String = 20
  optional bishomohopanol QuantityValue = 21
  optional bromide QuantityValue = 22
  optional calcium QuantityValue = 23
  optional carbNitroRatio QuantityValue = 24
  repeated chemAdministration String = 25
  optional chloride QuantityValue = 26
  optional chlorophyll QuantityValue = 27
  optional conduc QuantityValue = 28
  optional density QuantityValue = 29
  repeated dietherLipids String = 30
  optional dissCarbDioxide QuantityValue = 31
  optional dissHydrogen QuantityValue = 32
  optional dissInorgCarb QuantityValue = 33
  optional dissInorgNitro QuantityValue = 34
  optional dissInorgPhosp QuantityValue = 35
  optional dissOrgCarb QuantityValue = 36
  optional dissOrgNitro QuantityValue = 37
  optional dissOxygen QuantityValue = 38
  optional downPar QuantityValue = 39
  optional fluor QuantityValue = 40
  optional glucosidaseAct QuantityValue = 41
  optional lightIntensity QuantityValue = 42
  optional magnesium QuantityValue = 43
  optional meanFrictVel QuantityValue = 44
  optional meanPeakFrictVel QuantityValue = 45
  repeated miscParam String = 46
  repeated nAlkanes String = 47
  optional nitrate QuantityValue = 48
  optional nitrite QuantityValue = 49
  optional nitro QuantityValue = 50
  optional orgCarb QuantityValue = 51
  optional orgMatter QuantityValue = 52
  optional orgNitro QuantityValue = 53
  repeated organismCount OrganismCountEnum = 54
  optional oxyStatSamp OxyStatSampEnum = 55
  optional ph Double = 56
  optional partOrgCarb QuantityValue = 57
  optional partOrgNitro QuantityValue = 58
  repeated perturbation String = 59
  optional petroleumHydrocarb QuantityValue = 60
  repeated phaeopigments String = 61
  optional phosphate QuantityValue = 62
  repeated phosplipidFattAcid String = 63
  optional photonFlux QuantityValue = 64
  optional potassium QuantityValue = 65
  optional pressure QuantityValue = 66
  optional primaryProd QuantityValue = 67
  optional redoxPotential QuantityValue = 68
  optional salinity QuantityValue = 69
  optional sampStoreDur String = 70
  optional sampStoreLoc String = 71
  optional sampStoreTemp QuantityValue = 72
  optional silicate QuantityValue = 73
  optional sizeFracLow QuantityValue = 74
  optional sizeFracUp QuantityValue = 75
  optional sodium QuantityValue = 76
  optional solubleReactPhosp QuantityValue = 77
  optional sulfate QuantityValue = 78
  optional sulfide QuantityValue = 79
  optional suspendPartMatter QuantityValue = 80
  optional tidalStage TidalStageEnum = 81
  optional totDepthWaterCol QuantityValue = 82
  optional totDissNitro QuantityValue = 83
  optional totInorgNitro QuantityValue = 84
  optional totNitro QuantityValue = 85
  optional totPartCarb QuantityValue = 86
  optional totPhosp QuantityValue = 87
  optional turbidity QuantityValue = 88
  optional waterCurrent QuantityValue = 89
  sampName String = 90
  projectName String = 91
  optional sampVolWeDnaExt QuantityValue = 92
  sampTaxonId String = 93
  optional experimentalFactor String = 94
  optional negContType NegContTypeEnum = 95
  optional posContType String = 96
  optional sourceMatId String = 97
  optional relToOxygen RelToOxygenEnum = 98
  optional sampCollecDevice String = 99
  optional sampCollecMethod String = 100
  optional sampMatProcess String = 101
  optional sizeFrac String = 102
  optional sampSize QuantityValue = 103
  optional nuclAcidExt String = 104
  optional nuclAcidAmp String = 105
  optional libSize Integer = 106
  optional libReadsSeqd Integer = 107
  optional libLayout LibLayoutEnum = 108
  optional libVector String = 109
  optional libScreen String = 110
  targetGene String = 111
  optional targetSubfragment String = 112
  optional pcrPrimers String = 113
  optional mid String = 114
  optional adapters String = 115
  optional pcrCond String = 116
  seqMeth String = 117
  optional seqQualityCheck String = 118
  optional chimeraCheck String = 119
  optional assemblySoftware String = 120
  optional associatedResource String = 121
  optional sop String = 122
 }
// Combinatorial checklist Minimal Information about a Marker Specimen: survey with environmental package water
message WaterMIMARKSSurvey
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkalinityMethod String = 12
  optional alkylDiethers QuantityValue = 13
  optional aminopeptAct QuantityValue = 14
  optional ammonium QuantityValue = 15
  repeated atmosphericData String = 16
  optional bacteriaCarbProd QuantityValue = 17
  optional bacProd QuantityValue = 18
  optional bacResp QuantityValue = 19
  repeated biomass String = 20
  optional bishomohopanol QuantityValue = 21
  optional bromide QuantityValue = 22
  optional calcium QuantityValue = 23
  optional carbNitroRatio QuantityValue = 24
  repeated chemAdministration String = 25
  optional chloride QuantityValue = 26
  optional chlorophyll QuantityValue = 27
  optional conduc QuantityValue = 28
  optional density QuantityValue = 29
  repeated dietherLipids String = 30
  optional dissCarbDioxide QuantityValue = 31
  optional dissHydrogen QuantityValue = 32
  optional dissInorgCarb QuantityValue = 33
  optional dissInorgNitro QuantityValue = 34
  optional dissInorgPhosp QuantityValue = 35
  optional dissOrgCarb QuantityValue = 36
  optional dissOrgNitro QuantityValue = 37
  optional dissOxygen QuantityValue = 38
  optional downPar QuantityValue = 39
  optional fluor QuantityValue = 40
  optional glucosidaseAct QuantityValue = 41
  optional lightIntensity QuantityValue = 42
  optional magnesium QuantityValue = 43
  optional meanFrictVel QuantityValue = 44
  optional meanPeakFrictVel QuantityValue = 45
  repeated miscParam String = 46
  repeated nAlkanes String = 47
  optional nitrate QuantityValue = 48
  optional nitrite QuantityValue = 49
  optional nitro QuantityValue = 50
  optional orgCarb QuantityValue = 51
  optional orgMatter QuantityValue = 52
  optional orgNitro QuantityValue = 53
  repeated organismCount OrganismCountEnum = 54
  optional oxyStatSamp OxyStatSampEnum = 55
  optional ph Double = 56
  optional partOrgCarb QuantityValue = 57
  optional partOrgNitro QuantityValue = 58
  repeated perturbation String = 59
  optional petroleumHydrocarb QuantityValue = 60
  repeated phaeopigments String = 61
  optional phosphate QuantityValue = 62
  repeated phosplipidFattAcid String = 63
  optional photonFlux QuantityValue = 64
  optional potassium QuantityValue = 65
  optional pressure QuantityValue = 66
  optional primaryProd QuantityValue = 67
  optional redoxPotential QuantityValue = 68
  optional salinity QuantityValue = 69
  optional sampStoreDur String = 70
  optional sampStoreLoc String = 71
  optional sampStoreTemp QuantityValue = 72
  optional silicate QuantityValue = 73
  optional sizeFracLow QuantityValue = 74
  optional sizeFracUp QuantityValue = 75
  optional sodium QuantityValue = 76
  optional solubleReactPhosp QuantityValue = 77
  optional sulfate QuantityValue = 78
  optional sulfide QuantityValue = 79
  optional suspendPartMatter QuantityValue = 80
  optional tidalStage TidalStageEnum = 81
  optional totDepthWaterCol QuantityValue = 82
  optional totDissNitro QuantityValue = 83
  optional totInorgNitro QuantityValue = 84
  optional totNitro QuantityValue = 85
  optional totPartCarb QuantityValue = 86
  optional totPhosp QuantityValue = 87
  optional turbidity QuantityValue = 88
  optional waterCurrent QuantityValue = 89
  sampName String = 90
  projectName String = 91
  optional sampVolWeDnaExt QuantityValue = 92
  sampTaxonId String = 93
  optional experimentalFactor String = 94
  optional negContType NegContTypeEnum = 95
  optional posContType String = 96
  optional subspecfGenLin String = 97
  optional extrachromElements Integer = 98
  optional sourceMatId String = 99
  optional bioticRelationship BioticRelationshipEnum = 100
  optional trophicLevel TrophicLevelEnum = 101
  optional relToOxygen RelToOxygenEnum = 102
  isolGrowthCondt String = 103
  optional sampCollecDevice String = 104
  optional sampCollecMethod String = 105
  optional sampMatProcess String = 106
  optional sampSize QuantityValue = 107
  optional nuclAcidExt String = 108
  optional nuclAcidAmp String = 109
  targetGene String = 110
  optional targetSubfragment String = 111
  optional pcrPrimers String = 112
  optional pcrCond String = 113
  seqMeth String = 114
  optional seqQualityCheck String = 115
  optional chimeraCheck String = 116
  optional associatedResource String = 117
  optional sop String = 118
 }
// Combinatorial checklist Metagenome or Environmental with environmental package water
message WaterMIMS
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkalinityMethod String = 12
  optional alkylDiethers QuantityValue = 13
  optional aminopeptAct QuantityValue = 14
  optional ammonium QuantityValue = 15
  repeated atmosphericData String = 16
  optional bacteriaCarbProd QuantityValue = 17
  optional bacProd QuantityValue = 18
  optional bacResp QuantityValue = 19
  repeated biomass String = 20
  optional bishomohopanol QuantityValue = 21
  optional bromide QuantityValue = 22
  optional calcium QuantityValue = 23
  optional carbNitroRatio QuantityValue = 24
  repeated chemAdministration String = 25
  optional chloride QuantityValue = 26
  optional chlorophyll QuantityValue = 27
  optional conduc QuantityValue = 28
  optional density QuantityValue = 29
  repeated dietherLipids String = 30
  optional dissCarbDioxide QuantityValue = 31
  optional dissHydrogen QuantityValue = 32
  optional dissInorgCarb QuantityValue = 33
  optional dissInorgNitro QuantityValue = 34
  optional dissInorgPhosp QuantityValue = 35
  optional dissOrgCarb QuantityValue = 36
  optional dissOrgNitro QuantityValue = 37
  optional dissOxygen QuantityValue = 38
  optional downPar QuantityValue = 39
  optional fluor QuantityValue = 40
  optional glucosidaseAct QuantityValue = 41
  optional lightIntensity QuantityValue = 42
  optional magnesium QuantityValue = 43
  optional meanFrictVel QuantityValue = 44
  optional meanPeakFrictVel QuantityValue = 45
  repeated miscParam String = 46
  repeated nAlkanes String = 47
  optional nitrate QuantityValue = 48
  optional nitrite QuantityValue = 49
  optional nitro QuantityValue = 50
  optional orgCarb QuantityValue = 51
  optional orgMatter QuantityValue = 52
  optional orgNitro QuantityValue = 53
  repeated organismCount OrganismCountEnum = 54
  optional oxyStatSamp OxyStatSampEnum = 55
  optional ph Double = 56
  optional partOrgCarb QuantityValue = 57
  optional partOrgNitro QuantityValue = 58
  repeated perturbation String = 59
  optional petroleumHydrocarb QuantityValue = 60
  repeated phaeopigments String = 61
  optional phosphate QuantityValue = 62
  repeated phosplipidFattAcid String = 63
  optional photonFlux QuantityValue = 64
  optional potassium QuantityValue = 65
  optional pressure QuantityValue = 66
  optional primaryProd QuantityValue = 67
  optional redoxPotential QuantityValue = 68
  optional salinity QuantityValue = 69
  optional sampStoreDur String = 70
  optional sampStoreLoc String = 71
  optional sampStoreTemp QuantityValue = 72
  optional silicate QuantityValue = 73
  optional sizeFracLow QuantityValue = 74
  optional sizeFracUp QuantityValue = 75
  optional sodium QuantityValue = 76
  optional solubleReactPhosp QuantityValue = 77
  optional sulfate QuantityValue = 78
  optional sulfide QuantityValue = 79
  optional suspendPartMatter QuantityValue = 80
  optional tidalStage TidalStageEnum = 81
  optional totDepthWaterCol QuantityValue = 82
  optional totDissNitro QuantityValue = 83
  optional totInorgNitro QuantityValue = 84
  optional totNitro QuantityValue = 85
  optional totPartCarb QuantityValue = 86
  optional totPhosp QuantityValue = 87
  optional turbidity QuantityValue = 88
  optional waterCurrent QuantityValue = 89
  sampName String = 90
  projectName String = 91
  optional sampVolWeDnaExt QuantityValue = 92
  sampTaxonId String = 93
  optional experimentalFactor String = 94
  optional negContType NegContTypeEnum = 95
  optional posContType String = 96
  optional refBiomaterial String = 97
  optional sourceMatId String = 98
  optional relToOxygen RelToOxygenEnum = 99
  optional sampCollecDevice String = 100
  optional sampCollecMethod String = 101
  optional sampMatProcess String = 102
  optional sizeFrac String = 103
  optional sampSize QuantityValue = 104
  optional nuclAcidExt String = 105
  optional nuclAcidAmp String = 106
  optional libSize Integer = 107
  optional libReadsSeqd Integer = 108
  optional libLayout LibLayoutEnum = 109
  optional libVector String = 110
  optional libScreen String = 111
  optional mid String = 112
  optional adapters String = 113
  seqMeth String = 114
  optional assemblyQual AssemblyQualEnum = 115
  optional assemblyName String = 116
  optional assemblySoftware String = 117
  optional annot String = 118
  optional numberContig Integer = 119
  optional featPred String = 120
  optional refDb String = 121
  optional simSearchMeth String = 122
  optional taxClass String = 123
  optional associatedResource String = 124
  optional sop String = 125
 }
// Combinatorial checklist Minimum Information About a Single Amplified Genome with environmental package water
message WaterMISAG
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkalinityMethod String = 12
  optional alkylDiethers QuantityValue = 13
  optional aminopeptAct QuantityValue = 14
  optional ammonium QuantityValue = 15
  repeated atmosphericData String = 16
  optional bacteriaCarbProd QuantityValue = 17
  optional bacProd QuantityValue = 18
  optional bacResp QuantityValue = 19
  repeated biomass String = 20
  optional bishomohopanol QuantityValue = 21
  optional bromide QuantityValue = 22
  optional calcium QuantityValue = 23
  optional carbNitroRatio QuantityValue = 24
  repeated chemAdministration String = 25
  optional chloride QuantityValue = 26
  optional chlorophyll QuantityValue = 27
  optional conduc QuantityValue = 28
  optional density QuantityValue = 29
  repeated dietherLipids String = 30
  optional dissCarbDioxide QuantityValue = 31
  optional dissHydrogen QuantityValue = 32
  optional dissInorgCarb QuantityValue = 33
  optional dissInorgNitro QuantityValue = 34
  optional dissInorgPhosp QuantityValue = 35
  optional dissOrgCarb QuantityValue = 36
  optional dissOrgNitro QuantityValue = 37
  optional dissOxygen QuantityValue = 38
  optional downPar QuantityValue = 39
  optional fluor QuantityValue = 40
  optional glucosidaseAct QuantityValue = 41
  optional lightIntensity QuantityValue = 42
  optional magnesium QuantityValue = 43
  optional meanFrictVel QuantityValue = 44
  optional meanPeakFrictVel QuantityValue = 45
  repeated miscParam String = 46
  repeated nAlkanes String = 47
  optional nitrate QuantityValue = 48
  optional nitrite QuantityValue = 49
  optional nitro QuantityValue = 50
  optional orgCarb QuantityValue = 51
  optional orgMatter QuantityValue = 52
  optional orgNitro QuantityValue = 53
  repeated organismCount OrganismCountEnum = 54
  optional oxyStatSamp OxyStatSampEnum = 55
  optional ph Double = 56
  optional partOrgCarb QuantityValue = 57
  optional partOrgNitro QuantityValue = 58
  repeated perturbation String = 59
  optional petroleumHydrocarb QuantityValue = 60
  repeated phaeopigments String = 61
  optional phosphate QuantityValue = 62
  repeated phosplipidFattAcid String = 63
  optional photonFlux QuantityValue = 64
  optional potassium QuantityValue = 65
  optional pressure QuantityValue = 66
  optional primaryProd QuantityValue = 67
  optional redoxPotential QuantityValue = 68
  optional salinity QuantityValue = 69
  optional sampStoreDur String = 70
  optional sampStoreLoc String = 71
  optional sampStoreTemp QuantityValue = 72
  optional silicate QuantityValue = 73
  optional sizeFracLow QuantityValue = 74
  optional sizeFracUp QuantityValue = 75
  optional sodium QuantityValue = 76
  optional solubleReactPhosp QuantityValue = 77
  optional sulfate QuantityValue = 78
  optional sulfide QuantityValue = 79
  optional suspendPartMatter QuantityValue = 80
  optional tidalStage TidalStageEnum = 81
  optional totDepthWaterCol QuantityValue = 82
  optional totDissNitro QuantityValue = 83
  optional totInorgNitro QuantityValue = 84
  optional totNitro QuantityValue = 85
  optional totPartCarb QuantityValue = 86
  optional totPhosp QuantityValue = 87
  optional turbidity QuantityValue = 88
  optional waterCurrent QuantityValue = 89
  sampName String = 90
  projectName String = 91
  optional sampVolWeDnaExt QuantityValue = 92
  sampTaxonId String = 93
  optional experimentalFactor String = 94
  optional negContType NegContTypeEnum = 95
  optional posContType String = 96
  optional refBiomaterial String = 97
  optional sourceMatId String = 98
  optional relToOxygen RelToOxygenEnum = 99
  optional sampCollecDevice String = 100
  optional sampCollecMethod String = 101
  optional sampMatProcess String = 102
  optional sizeFrac String = 103
  optional sampSize QuantityValue = 104
  optional nuclAcidExt String = 105
  optional nuclAcidAmp String = 106
  optional libSize Integer = 107
  optional libReadsSeqd Integer = 108
  optional libLayout LibLayoutEnum = 109
  optional libVector String = 110
  optional libScreen String = 111
  optional mid String = 112
  optional adapters String = 113
  seqMeth String = 114
  taxIdent TaxIdentEnum = 115
  assemblyQual AssemblyQualEnum = 116
  optional assemblyName String = 117
  assemblySoftware String = 118
  optional annot String = 119
  optional numberContig Integer = 120
  optional featPred String = 121
  optional refDb String = 122
  optional simSearchMeth String = 123
  optional taxClass String = 124
  optional x16sRecover String = 125
  optional x16sRecoverSoftware String = 126
  optional trnas Integer = 127
  optional trnaExtSoftware String = 128
  complScore String = 129
  complSoftware String = 130
  optional complAppr ComplApprEnum = 131
  contamScore String = 132
  optional contamScreenInput String = 133
  optional contamScreenParam String = 134
  optional decontamSoftware DecontamSoftwareEnum = 135
  sortTech SortTechEnum = 136
  singleCellLysisAppr SingleCellLysisApprEnum = 137
  optional singleCellLysisProt String = 138
  wgaAmpAppr String = 139
  optional wgaAmpKit String = 140
  optional associatedResource String = 141
  optional sop String = 142
 }
// Combinatorial checklist Minimum Information About an Uncultivated Virus Genome with environmental package water
message WaterMIUVIG
 {
  optional latLon String = 1
  depth QuantityValue = 2
  optional alt QuantityValue = 3
  optional elev QuantityValue = 4
  optional temp QuantityValue = 5
  optional geoLocName String = 6
  optional collectionDate Date = 7
  optional envBroadScale String = 8
  optional envLocalScale String = 9
  optional envMedium String = 10
  optional alkalinity QuantityValue = 11
  optional alkalinityMethod String = 12
  optional alkylDiethers QuantityValue = 13
  optional aminopeptAct QuantityValue = 14
  optional ammonium QuantityValue = 15
  repeated atmosphericData String = 16
  optional bacteriaCarbProd QuantityValue = 17
  optional bacProd QuantityValue = 18
  optional bacResp QuantityValue = 19
  repeated biomass String = 20
  optional bishomohopanol QuantityValue = 21
  optional bromide QuantityValue = 22
  optional calcium QuantityValue = 23
  optional carbNitroRatio QuantityValue = 24
  repeated chemAdministration String = 25
  optional chloride QuantityValue = 26
  optional chlorophyll QuantityValue = 27
  optional conduc QuantityValue = 28
  optional density QuantityValue = 29
  repeated dietherLipids String = 30
  optional dissCarbDioxide QuantityValue = 31
  optional dissHydrogen QuantityValue = 32
  optional dissInorgCarb QuantityValue = 33
  optional dissInorgNitro QuantityValue = 34
  optional dissInorgPhosp QuantityValue = 35
  optional dissOrgCarb QuantityValue = 36
  optional dissOrgNitro QuantityValue = 37
  optional dissOxygen QuantityValue = 38
  optional downPar QuantityValue = 39
  optional fluor QuantityValue = 40
  optional glucosidaseAct QuantityValue = 41
  optional lightIntensity QuantityValue = 42
  optional magnesium QuantityValue = 43
  optional meanFrictVel QuantityValue = 44
  optional meanPeakFrictVel QuantityValue = 45
  repeated miscParam String = 46
  repeated nAlkanes String = 47
  optional nitrate QuantityValue = 48
  optional nitrite QuantityValue = 49
  optional nitro QuantityValue = 50
  optional orgCarb QuantityValue = 51
  optional orgMatter QuantityValue = 52
  optional orgNitro QuantityValue = 53
  repeated organismCount OrganismCountEnum = 54
  optional oxyStatSamp OxyStatSampEnum = 55
  optional ph Double = 56
  optional partOrgCarb QuantityValue = 57
  optional partOrgNitro QuantityValue = 58
  repeated perturbation String = 59
  optional petroleumHydrocarb QuantityValue = 60
  repeated phaeopigments String = 61
  optional phosphate QuantityValue = 62
  repeated phosplipidFattAcid String = 63
  optional photonFlux QuantityValue = 64
  optional potassium QuantityValue = 65
  optional pressure QuantityValue = 66
  optional primaryProd QuantityValue = 67
  optional redoxPotential QuantityValue = 68
  optional salinity QuantityValue = 69
  optional sampStoreDur String = 70
  optional sampStoreLoc String = 71
  optional sampStoreTemp QuantityValue = 72
  optional silicate QuantityValue = 73
  optional sizeFracLow QuantityValue = 74
  optional sizeFracUp QuantityValue = 75
  optional sodium QuantityValue = 76
  optional solubleReactPhosp QuantityValue = 77
  optional sulfate QuantityValue = 78
  optional sulfide QuantityValue = 79
  optional suspendPartMatter QuantityValue = 80
  optional tidalStage TidalStageEnum = 81
  optional totDepthWaterCol QuantityValue = 82
  optional totDissNitro QuantityValue = 83
  optional totInorgNitro QuantityValue = 84
  optional totNitro QuantityValue = 85
  optional totPartCarb QuantityValue = 86
  optional totPhosp QuantityValue = 87
  optional turbidity QuantityValue = 88
  optional waterCurrent QuantityValue = 89
  sampName String = 90
  projectName String = 91
  optional sampVolWeDnaExt QuantityValue = 92
  sampTaxonId String = 93
  optional experimentalFactor String = 94
  optional negContType NegContTypeEnum = 95
  optional posContType String = 96
  optional estimatedSize String = 97
  optional refBiomaterial String = 98
  optional sourceMatId String = 99
  optional pathogenicity String = 100
  optional bioticRelationship BioticRelationshipEnum = 101
  optional specificHost String = 102
  optional hostSpecRange Integer = 103
  optional hostDiseaseStat String = 104
  optional sampCollecDevice String = 105
  optional sampCollecMethod String = 106
  optional sampMatProcess String = 107
  optional sizeFrac String = 108
  optional sampSize QuantityValue = 109
  sourceUvig SourceUvigEnum = 110
  virusEnrichAppr VirusEnrichApprEnum = 111
  optional nuclAcidExt String = 112
  optional nuclAcidAmp String = 113
  optional libSize Integer = 114
  optional libReadsSeqd Integer = 115
  optional libLayout LibLayoutEnum = 116
  optional libVector String = 117
  optional libScreen String = 118
  optional mid String = 119
  optional adapters String = 120
  seqMeth String = 121
  optional taxIdent TaxIdentEnum = 122
  assemblyQual AssemblyQualEnum = 123
  optional assemblyName String = 124
  assemblySoftware String = 125
  optional annot String = 126
  numberContig Integer = 127
  optional featPred String = 128
  optional refDb String = 129
  optional simSearchMeth String = 130
  optional taxClass String = 131
  optional trnas Integer = 132
  optional trnaExtSoftware String = 133
  optional complScore String = 134
  optional complSoftware String = 135
  optional complAppr ComplApprEnum = 136
  optional sortTech SortTechEnum = 137
  optional singleCellLysisAppr SingleCellLysisApprEnum = 138
  optional singleCellLysisProt String = 139
  optional wgaAmpAppr String = 140
  optional wgaAmpKit String = 141
  optional binParam BinParamEnum = 142
  optional binSoftware String = 143
  optional reassemblyBin String = 144
  optional magCovSoftware MagCovSoftwareEnum = 145
  virIdentSoftware String = 146
  predGenomeType PredGenomeTypeEnum = 147
  predGenomeStruc PredGenomeStrucEnum = 148
  detecType String = 149
  optional otuClassAppr String = 150
  optional otuSeqCompAppr String = 151
  optional otuDb String = 152
  optional hostPredAppr HostPredApprEnum = 153
  optional hostPredEstAcc String = 154
  optional associatedResource String = 155
  optional sop String = 156
 }
