type Agriculture
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue!
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    plantGrowthMed: PlantGrowthMedEnum
    soilHorizon: SoilHorizonEnum
    photosyntActiv: [QuantityValue]
    photosyntActivMeth: [String]
    sampCollectMethod: String
    enrichmentProtocol: String
    libraryPrepKit: String
    sequencingLocation: String
    soilPH: Double
    soilConductivity: QuantityValue
    relLocation: String
    soilCover: String
    porosity: String
    texture: QuantityValue
    textureMeth: String
    hostSymbiont: [String]
    presAnimalInsect: String
    plantWaterMethod: String
    animWaterMethod: [String]
    farmWaterSource: [FarmWaterSourceEnum]
    waterSourceShared: [WaterSourceSharedEnum]
    waterPH: Double
    season: String
    solarIrradiance: QuantityValue
    cropYield: String
    seasonHumidity: QuantityValue
    humidity: QuantityValue
    adjacentEnvironment: [String]
    chemAdministration: [String]!
    foodProd: [String]
    lotNumber: [String]
    fertilizerAdmin: String
    sampStorTemp: QuantityValue
    foodTravMode: [String]
    foodTravVehic: [String]
    farmEquipSan: [String]
    farmEquip: [String]
    farmEquipShared: [String]
    foodHarvestProc: [String]
    plantStruc: String
    hostDryMass: QuantityValue
    ancesData: String
    geneticMod: String
    foodProductType: String
    foodSource: String!
    spikeinStrain: [String]
    organismCount: [OrganismCountEnum]
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    cultIsolDate: Date
    sampPooling: [String]
    rootMedMacronutr: String
    rootMedCarbon: String
    rootMedPh: Double
    waterTempRegm: [String]
    wateringRegm: [String]
    standingWaterRegm: [String]
    gaseousEnvironment: [String]
    fungicideRegm: [String]
    climateEnvironment: [String]
    herbicideRegm: [String]
    nonMineralNutrRegm: [String]
    pesticideRegm: [String]
    phRegm: [String]
    saltRegm: [String]
    seasonEnvironment: [String]
    perturbation: [String]
    sampStoreDur: String!
    sampStoreLoc: String!
    sampCollectDevice: String!
    hostAge: QuantityValue!
    hostCommonName: String!
    hostGenotype: String!
    hostHeight: QuantityValue!
    hostSubspecfGenlin: [String]
    hostLength: QuantityValue!
    hostLifeStage: String!
    hostPhenotype: String!
    hostTaxid: String!
    hostTotMass: QuantityValue!
    plantProduct: String
    oxyStatSamp: OxyStatSampEnum
    assemblyQuality: String
    url: [String]
    faoClass: FaoClassEnum
    localClass: String
    localClassMeth: String
    soilType: String!
    soilTypeMeth: String!
    horizon: HorizonEnum
    horizonMeth: String
    linkClassInfo: String
    previousLandUse: String
    previousLandUseMeth: String
    cropRotation: String
    agrochemAddition: [String]
    tillage: [TillageEnum]
    fire: Date
    flooding: Date
    extremeEvent: Date
    linkClimateInfo: String
    annualTemp: QuantityValue
    seasonTemp: QuantityValue
    annualPrecpt: QuantityValue
    seasonPrecpt: QuantityValue
    curLandUse: CurLandUseEnum
    slopeGradient: QuantityValue
    slopeAspect: QuantityValue
    profilePosition: ProfilePositionEnum
    drainageClass: DrainageClassEnum
    storeCond: String!
    phMeth: String
    curVegetation: String
    curVegetationMeth: String
    totOrgCarb: QuantityValue
    totOrgCMeth: String
    totNitro: QuantityValue
    totNMeth: String
    microbialBiomass: QuantityValue!
    microbialBiomassMeth: String!
    heavyMetalsMeth: String
    totCar: QuantityValue
    totPhos: QuantityValue
    sieving: String!
    poolDnaExtracts: String!
    miscParam: [String]
    hostDiseaseStat: String
    specificHost: String!
    pathogenicity: String!
    bioticRelationship: BioticRelationshipEnum
    isolGrowthCondt: String
    sampMatProcess: String!
    hostSpecRange: Integer!
    trophicLevel: TrophicLevelEnum
    sampSize: QuantityValue!
    seqMeth: String!
    sampVolWeDnaExt: QuantityValue!
    pcrPrimers: String!
    nuclAcidExt: String!
    nuclAcidAmp: String!
    libSize: Integer
    libReadsSeqd: Integer!
    libLayout: LibLayoutEnum
    libVector: String!
    libScreen: String!
    targetGene: String!
    targetSubfragment: String!
    mid: String!
    adapters: String!
    pcrCond: String!
    seqQualityCheck: String
    chimeraCheck: String!
    assemblyName: String!
    assemblySoftware: String
    annot: String
    sop: String
    sourceMatId: String
  }

type AgricultureMIGSBacteria implements MIGSBacteria
  {
    latLon: String
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    plantGrowthMed: PlantGrowthMedEnum
    soilHorizon: SoilHorizonEnum
    photosyntActiv: [QuantityValue]
    photosyntActivMeth: [String]
    sampCollectMethod: String
    enrichmentProtocol: String
    libraryPrepKit: String
    sequencingLocation: String
    temp: QuantityValue
    soilPH: Double
    soilConductivity: QuantityValue
    relLocation: String
    soilCover: String
    porosity: String
    texture: QuantityValue
    textureMeth: String
    hostSymbiont: [String]
    presAnimalInsect: String
    plantWaterMethod: String
    animWaterMethod: [String]
    farmWaterSource: [FarmWaterSourceEnum]
    waterSourceShared: [WaterSourceSharedEnum]
    waterPH: Double
    season: String
    solarIrradiance: QuantityValue
    cropYield: String
    seasonHumidity: QuantityValue
    humidity: QuantityValue
    adjacentEnvironment: [String]
    chemAdministration: [String]!
    foodProd: [String]
    lotNumber: [String]
    fertilizerAdmin: String
    sampStorTemp: QuantityValue
    foodTravMode: [String]
    foodTravVehic: [String]
    farmEquipSan: [String]
    farmEquip: [String]
    farmEquipShared: [String]
    foodHarvestProc: [String]
    plantStruc: String
    hostDryMass: QuantityValue
    ancesData: String
    geneticMod: String
    foodProductType: String
    foodSource: String!
    spikeinStrain: [String]
    organismCount: [OrganismCountEnum]
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    cultIsolDate: Date
    sampPooling: [String]
    rootMedMacronutr: String
    rootMedCarbon: String
    rootMedPh: Double
    depth: QuantityValue!
    waterTempRegm: [String]
    wateringRegm: [String]
    standingWaterRegm: [String]
    gaseousEnvironment: [String]
    fungicideRegm: [String]
    climateEnvironment: [String]
    herbicideRegm: [String]
    nonMineralNutrRegm: [String]
    pesticideRegm: [String]
    phRegm: [String]
    saltRegm: [String]
    seasonEnvironment: [String]
    perturbation: [String]
    sampStoreDur: String!
    sampStoreLoc: String!
    sampCollectDevice: String!
    hostAge: QuantityValue!
    hostCommonName: String!
    hostGenotype: String!
    hostHeight: QuantityValue!
    hostSubspecfGenlin: [String]
    hostLength: QuantityValue!
    hostLifeStage: String!
    hostPhenotype: String!
    hostTaxid: String!
    hostTotMass: QuantityValue!
    plantProduct: String
    oxyStatSamp: OxyStatSampEnum
    assemblyQuality: String
    url: [String]
    faoClass: FaoClassEnum
    localClass: String
    localClassMeth: String
    soilType: String!
    soilTypeMeth: String!
    horizon: HorizonEnum
    horizonMeth: String
    linkClassInfo: String
    previousLandUse: String
    previousLandUseMeth: String
    cropRotation: String
    agrochemAddition: [String]
    tillage: [TillageEnum]
    fire: Date
    flooding: Date
    extremeEvent: Date
    linkClimateInfo: String
    annualTemp: QuantityValue
    seasonTemp: QuantityValue
    annualPrecpt: QuantityValue
    seasonPrecpt: QuantityValue
    curLandUse: CurLandUseEnum
    slopeGradient: QuantityValue
    slopeAspect: QuantityValue
    profilePosition: ProfilePositionEnum
    drainageClass: DrainageClassEnum
    storeCond: String!
    phMeth: String
    curVegetation: String
    curVegetationMeth: String
    totOrgCarb: QuantityValue
    totOrgCMeth: String
    totNitro: QuantityValue
    totNMeth: String
    microbialBiomass: QuantityValue!
    microbialBiomassMeth: String!
    heavyMetalsMeth: String
    totCar: QuantityValue
    totPhos: QuantityValue
    sieving: String!
    poolDnaExtracts: String!
    miscParam: [String]
    hostDiseaseStat: String
    specificHost: String!
    pathogenicity: String!
    bioticRelationship: BioticRelationshipEnum
    isolGrowthCondt: String
    sampMatProcess: String!
    hostSpecRange: Integer!
    trophicLevel: TrophicLevelEnum
    sampSize: QuantityValue!
    seqMeth: String!
    sampVolWeDnaExt: QuantityValue!
    pcrPrimers: String!
    nuclAcidExt: String!
    nuclAcidAmp: String!
    libSize: Integer
    libReadsSeqd: Integer!
    libLayout: LibLayoutEnum
    libVector: String!
    libScreen: String!
    targetGene: String!
    targetSubfragment: String!
    mid: String!
    adapters: String!
    pcrCond: String!
    seqQualityCheck: String
    chimeraCheck: String!
    assemblyName: String!
    assemblySoftware: String
    annot: String
    sop: String
    sourceMatId: String
    sampName: String!
    sampTaxonId: String!
    projectName: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer!
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String!
    encodedTraits: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
  }

type AgricultureMIGSEukaryote implements MIGSEukaryote
  {
    latLon: String
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    plantGrowthMed: PlantGrowthMedEnum
    soilHorizon: SoilHorizonEnum
    photosyntActiv: [QuantityValue]
    photosyntActivMeth: [String]
    sampCollectMethod: String
    enrichmentProtocol: String
    libraryPrepKit: String
    sequencingLocation: String
    temp: QuantityValue
    soilPH: Double
    soilConductivity: QuantityValue
    relLocation: String
    soilCover: String
    porosity: String
    texture: QuantityValue
    textureMeth: String
    hostSymbiont: [String]
    presAnimalInsect: String
    plantWaterMethod: String
    animWaterMethod: [String]
    farmWaterSource: [FarmWaterSourceEnum]
    waterSourceShared: [WaterSourceSharedEnum]
    waterPH: Double
    season: String
    solarIrradiance: QuantityValue
    cropYield: String
    seasonHumidity: QuantityValue
    humidity: QuantityValue
    adjacentEnvironment: [String]
    chemAdministration: [String]!
    foodProd: [String]
    lotNumber: [String]
    fertilizerAdmin: String
    sampStorTemp: QuantityValue
    foodTravMode: [String]
    foodTravVehic: [String]
    farmEquipSan: [String]
    farmEquip: [String]
    farmEquipShared: [String]
    foodHarvestProc: [String]
    plantStruc: String
    hostDryMass: QuantityValue
    ancesData: String
    geneticMod: String
    foodProductType: String
    foodSource: String!
    spikeinStrain: [String]
    organismCount: [OrganismCountEnum]
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    cultIsolDate: Date
    sampPooling: [String]
    rootMedMacronutr: String
    rootMedCarbon: String
    rootMedPh: Double
    depth: QuantityValue!
    waterTempRegm: [String]
    wateringRegm: [String]
    standingWaterRegm: [String]
    gaseousEnvironment: [String]
    fungicideRegm: [String]
    climateEnvironment: [String]
    herbicideRegm: [String]
    nonMineralNutrRegm: [String]
    pesticideRegm: [String]
    phRegm: [String]
    saltRegm: [String]
    seasonEnvironment: [String]
    perturbation: [String]
    sampStoreDur: String!
    sampStoreLoc: String!
    sampCollectDevice: String!
    hostAge: QuantityValue!
    hostCommonName: String!
    hostGenotype: String!
    hostHeight: QuantityValue!
    hostSubspecfGenlin: [String]
    hostLength: QuantityValue!
    hostLifeStage: String!
    hostPhenotype: String!
    hostTaxid: String!
    hostTotMass: QuantityValue!
    plantProduct: String
    oxyStatSamp: OxyStatSampEnum
    assemblyQuality: String
    url: [String]
    faoClass: FaoClassEnum
    localClass: String
    localClassMeth: String
    soilType: String!
    soilTypeMeth: String!
    horizon: HorizonEnum
    horizonMeth: String
    linkClassInfo: String
    previousLandUse: String
    previousLandUseMeth: String
    cropRotation: String
    agrochemAddition: [String]
    tillage: [TillageEnum]
    fire: Date
    flooding: Date
    extremeEvent: Date
    linkClimateInfo: String
    annualTemp: QuantityValue
    seasonTemp: QuantityValue
    annualPrecpt: QuantityValue
    seasonPrecpt: QuantityValue
    curLandUse: CurLandUseEnum
    slopeGradient: QuantityValue
    slopeAspect: QuantityValue
    profilePosition: ProfilePositionEnum
    drainageClass: DrainageClassEnum
    storeCond: String!
    phMeth: String
    curVegetation: String
    curVegetationMeth: String
    totOrgCarb: QuantityValue
    totOrgCMeth: String
    totNitro: QuantityValue
    totNMeth: String
    microbialBiomass: QuantityValue!
    microbialBiomassMeth: String!
    heavyMetalsMeth: String
    totCar: QuantityValue
    totPhos: QuantityValue
    sieving: String!
    poolDnaExtracts: String!
    miscParam: [String]
    hostDiseaseStat: String
    specificHost: String!
    pathogenicity: String!
    bioticRelationship: BioticRelationshipEnum
    isolGrowthCondt: String
    sampMatProcess: String!
    hostSpecRange: Integer!
    trophicLevel: TrophicLevelEnum
    sampSize: QuantityValue!
    seqMeth: String!
    sampVolWeDnaExt: QuantityValue!
    pcrPrimers: String!
    nuclAcidExt: String!
    nuclAcidAmp: String!
    libSize: Integer
    libReadsSeqd: Integer!
    libLayout: LibLayoutEnum
    libVector: String!
    libScreen: String!
    targetGene: String!
    targetSubfragment: String!
    mid: String!
    adapters: String!
    pcrCond: String!
    seqQualityCheck: String
    chimeraCheck: String!
    assemblyName: String!
    assemblySoftware: String
    annot: String
    sop: String
    sourceMatId: String
    sampName: String!
    sampTaxonId: String!
    projectName: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    ploidy: String
    numReplicons: Integer
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    propagation: String
    sampCollecDevice: String
    sampCollecMethod: String
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
  }

type AgricultureMIGSOrg implements MIGSOrg
  {
    latLon: String
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    plantGrowthMed: PlantGrowthMedEnum
    soilHorizon: SoilHorizonEnum
    photosyntActiv: [QuantityValue]
    photosyntActivMeth: [String]
    sampCollectMethod: String
    enrichmentProtocol: String
    libraryPrepKit: String
    sequencingLocation: String
    temp: QuantityValue
    soilPH: Double
    soilConductivity: QuantityValue
    relLocation: String
    soilCover: String
    porosity: String
    texture: QuantityValue
    textureMeth: String
    hostSymbiont: [String]
    presAnimalInsect: String
    plantWaterMethod: String
    animWaterMethod: [String]
    farmWaterSource: [FarmWaterSourceEnum]
    waterSourceShared: [WaterSourceSharedEnum]
    waterPH: Double
    season: String
    solarIrradiance: QuantityValue
    cropYield: String
    seasonHumidity: QuantityValue
    humidity: QuantityValue
    adjacentEnvironment: [String]
    chemAdministration: [String]!
    foodProd: [String]
    lotNumber: [String]
    fertilizerAdmin: String
    sampStorTemp: QuantityValue
    foodTravMode: [String]
    foodTravVehic: [String]
    farmEquipSan: [String]
    farmEquip: [String]
    farmEquipShared: [String]
    foodHarvestProc: [String]
    plantStruc: String
    hostDryMass: QuantityValue
    ancesData: String
    geneticMod: String
    foodProductType: String
    foodSource: String!
    spikeinStrain: [String]
    organismCount: [OrganismCountEnum]
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    cultIsolDate: Date
    sampPooling: [String]
    rootMedMacronutr: String
    rootMedCarbon: String
    rootMedPh: Double
    depth: QuantityValue!
    waterTempRegm: [String]
    wateringRegm: [String]
    standingWaterRegm: [String]
    gaseousEnvironment: [String]
    fungicideRegm: [String]
    climateEnvironment: [String]
    herbicideRegm: [String]
    nonMineralNutrRegm: [String]
    pesticideRegm: [String]
    phRegm: [String]
    saltRegm: [String]
    seasonEnvironment: [String]
    perturbation: [String]
    sampStoreDur: String!
    sampStoreLoc: String!
    sampCollectDevice: String!
    hostAge: QuantityValue!
    hostCommonName: String!
    hostGenotype: String!
    hostHeight: QuantityValue!
    hostSubspecfGenlin: [String]
    hostLength: QuantityValue!
    hostLifeStage: String!
    hostPhenotype: String!
    hostTaxid: String!
    hostTotMass: QuantityValue!
    plantProduct: String
    oxyStatSamp: OxyStatSampEnum
    assemblyQuality: String
    url: [String]
    faoClass: FaoClassEnum
    localClass: String
    localClassMeth: String
    soilType: String!
    soilTypeMeth: String!
    horizon: HorizonEnum
    horizonMeth: String
    linkClassInfo: String
    previousLandUse: String
    previousLandUseMeth: String
    cropRotation: String
    agrochemAddition: [String]
    tillage: [TillageEnum]
    fire: Date
    flooding: Date
    extremeEvent: Date
    linkClimateInfo: String
    annualTemp: QuantityValue
    seasonTemp: QuantityValue
    annualPrecpt: QuantityValue
    seasonPrecpt: QuantityValue
    curLandUse: CurLandUseEnum
    slopeGradient: QuantityValue
    slopeAspect: QuantityValue
    profilePosition: ProfilePositionEnum
    drainageClass: DrainageClassEnum
    storeCond: String!
    phMeth: String
    curVegetation: String
    curVegetationMeth: String
    totOrgCarb: QuantityValue
    totOrgCMeth: String
    totNitro: QuantityValue
    totNMeth: String
    microbialBiomass: QuantityValue!
    microbialBiomassMeth: String!
    heavyMetalsMeth: String
    totCar: QuantityValue
    totPhos: QuantityValue
    sieving: String!
    poolDnaExtracts: String!
    miscParam: [String]
    hostDiseaseStat: String
    specificHost: String!
    pathogenicity: String!
    bioticRelationship: BioticRelationshipEnum
    isolGrowthCondt: String
    sampMatProcess: String!
    hostSpecRange: Integer!
    trophicLevel: TrophicLevelEnum
    sampSize: QuantityValue!
    seqMeth: String!
    sampVolWeDnaExt: QuantityValue!
    pcrPrimers: String!
    nuclAcidExt: String!
    nuclAcidAmp: String!
    libSize: Integer
    libReadsSeqd: Integer!
    libLayout: LibLayoutEnum
    libVector: String!
    libScreen: String!
    targetGene: String!
    targetSubfragment: String!
    mid: String!
    adapters: String!
    pcrCond: String!
    seqQualityCheck: String
    chimeraCheck: String!
    assemblyName: String!
    assemblySoftware: String
    annot: String
    sop: String
    sourceMatId: String
    sampName: String!
    sampTaxonId: String!
    projectName: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sampCollecDevice: String
    sampCollecMethod: String
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
  }

type AgricultureMIGSPlant implements MIGSPlant
  {
    latLon: String
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    plantGrowthMed: PlantGrowthMedEnum
    soilHorizon: SoilHorizonEnum
    photosyntActiv: [QuantityValue]
    photosyntActivMeth: [String]
    sampCollectMethod: String
    enrichmentProtocol: String
    libraryPrepKit: String
    sequencingLocation: String
    temp: QuantityValue
    soilPH: Double
    soilConductivity: QuantityValue
    relLocation: String
    soilCover: String
    porosity: String
    texture: QuantityValue
    textureMeth: String
    hostSymbiont: [String]
    presAnimalInsect: String
    plantWaterMethod: String
    animWaterMethod: [String]
    farmWaterSource: [FarmWaterSourceEnum]
    waterSourceShared: [WaterSourceSharedEnum]
    waterPH: Double
    season: String
    solarIrradiance: QuantityValue
    cropYield: String
    seasonHumidity: QuantityValue
    humidity: QuantityValue
    adjacentEnvironment: [String]
    chemAdministration: [String]!
    foodProd: [String]
    lotNumber: [String]
    fertilizerAdmin: String
    sampStorTemp: QuantityValue
    foodTravMode: [String]
    foodTravVehic: [String]
    farmEquipSan: [String]
    farmEquip: [String]
    farmEquipShared: [String]
    foodHarvestProc: [String]
    plantStruc: String
    hostDryMass: QuantityValue
    ancesData: String
    geneticMod: String
    foodProductType: String
    foodSource: String!
    spikeinStrain: [String]
    organismCount: [OrganismCountEnum]
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    cultIsolDate: Date
    sampPooling: [String]
    rootMedMacronutr: String
    rootMedCarbon: String
    rootMedPh: Double
    depth: QuantityValue!
    waterTempRegm: [String]
    wateringRegm: [String]
    standingWaterRegm: [String]
    gaseousEnvironment: [String]
    fungicideRegm: [String]
    climateEnvironment: [String]
    herbicideRegm: [String]
    nonMineralNutrRegm: [String]
    pesticideRegm: [String]
    phRegm: [String]
    saltRegm: [String]
    seasonEnvironment: [String]
    perturbation: [String]
    sampStoreDur: String!
    sampStoreLoc: String!
    sampCollectDevice: String!
    hostAge: QuantityValue!
    hostCommonName: String!
    hostGenotype: String!
    hostHeight: QuantityValue!
    hostSubspecfGenlin: [String]
    hostLength: QuantityValue!
    hostLifeStage: String!
    hostPhenotype: String!
    hostTaxid: String!
    hostTotMass: QuantityValue!
    plantProduct: String
    oxyStatSamp: OxyStatSampEnum
    assemblyQuality: String
    url: [String]
    faoClass: FaoClassEnum
    localClass: String
    localClassMeth: String
    soilType: String!
    soilTypeMeth: String!
    horizon: HorizonEnum
    horizonMeth: String
    linkClassInfo: String
    previousLandUse: String
    previousLandUseMeth: String
    cropRotation: String
    agrochemAddition: [String]
    tillage: [TillageEnum]
    fire: Date
    flooding: Date
    extremeEvent: Date
    linkClimateInfo: String
    annualTemp: QuantityValue
    seasonTemp: QuantityValue
    annualPrecpt: QuantityValue
    seasonPrecpt: QuantityValue
    curLandUse: CurLandUseEnum
    slopeGradient: QuantityValue
    slopeAspect: QuantityValue
    profilePosition: ProfilePositionEnum
    drainageClass: DrainageClassEnum
    storeCond: String!
    phMeth: String
    curVegetation: String
    curVegetationMeth: String
    totOrgCarb: QuantityValue
    totOrgCMeth: String
    totNitro: QuantityValue
    totNMeth: String
    microbialBiomass: QuantityValue!
    microbialBiomassMeth: String!
    heavyMetalsMeth: String
    totCar: QuantityValue
    totPhos: QuantityValue
    sieving: String!
    poolDnaExtracts: String!
    miscParam: [String]
    hostDiseaseStat: String
    specificHost: String!
    pathogenicity: String!
    bioticRelationship: BioticRelationshipEnum
    isolGrowthCondt: String
    sampMatProcess: String!
    hostSpecRange: Integer!
    trophicLevel: TrophicLevelEnum
    sampSize: QuantityValue!
    seqMeth: String!
    sampVolWeDnaExt: QuantityValue!
    pcrPrimers: String!
    nuclAcidExt: String!
    nuclAcidAmp: String!
    libSize: Integer
    libReadsSeqd: Integer!
    libLayout: LibLayoutEnum
    libVector: String!
    libScreen: String!
    targetGene: String!
    targetSubfragment: String!
    mid: String!
    adapters: String!
    pcrCond: String!
    seqQualityCheck: String
    chimeraCheck: String!
    assemblyName: String!
    assemblySoftware: String
    annot: String
    sop: String
    sourceMatId: String
    sampName: String!
    sampTaxonId: String!
    projectName: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    estimatedSize: String
    refBiomaterial: String
    propagation: String!
    encodedTraits: String
    sampCollecDevice: String
    sampCollecMethod: String
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
  }

type AgricultureMIGSVirus implements MIGSVirus
  {
    latLon: String
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    plantGrowthMed: PlantGrowthMedEnum
    soilHorizon: SoilHorizonEnum
    photosyntActiv: [QuantityValue]
    photosyntActivMeth: [String]
    sampCollectMethod: String
    enrichmentProtocol: String
    libraryPrepKit: String
    sequencingLocation: String
    temp: QuantityValue
    soilPH: Double
    soilConductivity: QuantityValue
    relLocation: String
    soilCover: String
    porosity: String
    texture: QuantityValue
    textureMeth: String
    hostSymbiont: [String]
    presAnimalInsect: String
    plantWaterMethod: String
    animWaterMethod: [String]
    farmWaterSource: [FarmWaterSourceEnum]
    waterSourceShared: [WaterSourceSharedEnum]
    waterPH: Double
    season: String
    solarIrradiance: QuantityValue
    cropYield: String
    seasonHumidity: QuantityValue
    humidity: QuantityValue
    adjacentEnvironment: [String]
    chemAdministration: [String]!
    foodProd: [String]
    lotNumber: [String]
    fertilizerAdmin: String
    sampStorTemp: QuantityValue
    foodTravMode: [String]
    foodTravVehic: [String]
    farmEquipSan: [String]
    farmEquip: [String]
    farmEquipShared: [String]
    foodHarvestProc: [String]
    plantStruc: String
    hostDryMass: QuantityValue
    ancesData: String
    geneticMod: String
    foodProductType: String
    foodSource: String!
    spikeinStrain: [String]
    organismCount: [OrganismCountEnum]
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    cultIsolDate: Date
    sampPooling: [String]
    rootMedMacronutr: String
    rootMedCarbon: String
    rootMedPh: Double
    depth: QuantityValue!
    waterTempRegm: [String]
    wateringRegm: [String]
    standingWaterRegm: [String]
    gaseousEnvironment: [String]
    fungicideRegm: [String]
    climateEnvironment: [String]
    herbicideRegm: [String]
    nonMineralNutrRegm: [String]
    pesticideRegm: [String]
    phRegm: [String]
    saltRegm: [String]
    seasonEnvironment: [String]
    perturbation: [String]
    sampStoreDur: String!
    sampStoreLoc: String!
    sampCollectDevice: String!
    hostAge: QuantityValue!
    hostCommonName: String!
    hostGenotype: String!
    hostHeight: QuantityValue!
    hostSubspecfGenlin: [String]
    hostLength: QuantityValue!
    hostLifeStage: String!
    hostPhenotype: String!
    hostTaxid: String!
    hostTotMass: QuantityValue!
    plantProduct: String
    oxyStatSamp: OxyStatSampEnum
    assemblyQuality: String
    url: [String]
    faoClass: FaoClassEnum
    localClass: String
    localClassMeth: String
    soilType: String!
    soilTypeMeth: String!
    horizon: HorizonEnum
    horizonMeth: String
    linkClassInfo: String
    previousLandUse: String
    previousLandUseMeth: String
    cropRotation: String
    agrochemAddition: [String]
    tillage: [TillageEnum]
    fire: Date
    flooding: Date
    extremeEvent: Date
    linkClimateInfo: String
    annualTemp: QuantityValue
    seasonTemp: QuantityValue
    annualPrecpt: QuantityValue
    seasonPrecpt: QuantityValue
    curLandUse: CurLandUseEnum
    slopeGradient: QuantityValue
    slopeAspect: QuantityValue
    profilePosition: ProfilePositionEnum
    drainageClass: DrainageClassEnum
    storeCond: String!
    phMeth: String
    curVegetation: String
    curVegetationMeth: String
    totOrgCarb: QuantityValue
    totOrgCMeth: String
    totNitro: QuantityValue
    totNMeth: String
    microbialBiomass: QuantityValue!
    microbialBiomassMeth: String!
    heavyMetalsMeth: String
    totCar: QuantityValue
    totPhos: QuantityValue
    sieving: String!
    poolDnaExtracts: String!
    miscParam: [String]
    hostDiseaseStat: String
    specificHost: String!
    pathogenicity: String!
    bioticRelationship: BioticRelationshipEnum
    isolGrowthCondt: String
    sampMatProcess: String!
    hostSpecRange: Integer!
    trophicLevel: TrophicLevelEnum
    sampSize: QuantityValue!
    seqMeth: String!
    sampVolWeDnaExt: QuantityValue!
    pcrPrimers: String!
    nuclAcidExt: String!
    nuclAcidAmp: String!
    libSize: Integer
    libReadsSeqd: Integer!
    libLayout: LibLayoutEnum
    libVector: String!
    libScreen: String!
    targetGene: String!
    targetSubfragment: String!
    mid: String!
    adapters: String!
    pcrCond: String!
    seqQualityCheck: String
    chimeraCheck: String!
    assemblyName: String!
    assemblySoftware: String
    annot: String
    sop: String
    sourceMatId: String
    sampName: String!
    sampTaxonId: String!
    projectName: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer
    estimatedSize: String
    refBiomaterial: String
    propagation: String!
    encodedTraits: String
    sampCollecDevice: String
    sampCollecMethod: String
    virusEnrichAppr: VirusEnrichApprEnum
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
  }

type AgricultureMIMAG implements MIMAG
  {
    latLon: String
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    plantGrowthMed: PlantGrowthMedEnum
    soilHorizon: SoilHorizonEnum
    photosyntActiv: [QuantityValue]
    photosyntActivMeth: [String]
    sampCollectMethod: String
    enrichmentProtocol: String
    libraryPrepKit: String
    sequencingLocation: String
    temp: QuantityValue
    soilPH: Double
    soilConductivity: QuantityValue
    relLocation: String
    soilCover: String
    porosity: String
    texture: QuantityValue
    textureMeth: String
    hostSymbiont: [String]
    presAnimalInsect: String
    plantWaterMethod: String
    animWaterMethod: [String]
    farmWaterSource: [FarmWaterSourceEnum]
    waterSourceShared: [WaterSourceSharedEnum]
    waterPH: Double
    season: String
    solarIrradiance: QuantityValue
    cropYield: String
    seasonHumidity: QuantityValue
    humidity: QuantityValue
    adjacentEnvironment: [String]
    chemAdministration: [String]!
    foodProd: [String]
    lotNumber: [String]
    fertilizerAdmin: String
    sampStorTemp: QuantityValue
    foodTravMode: [String]
    foodTravVehic: [String]
    farmEquipSan: [String]
    farmEquip: [String]
    farmEquipShared: [String]
    foodHarvestProc: [String]
    plantStruc: String
    hostDryMass: QuantityValue
    ancesData: String
    geneticMod: String
    foodProductType: String
    foodSource: String!
    spikeinStrain: [String]
    organismCount: [OrganismCountEnum]
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    cultIsolDate: Date
    sampPooling: [String]
    rootMedMacronutr: String
    rootMedCarbon: String
    rootMedPh: Double
    depth: QuantityValue!
    waterTempRegm: [String]
    wateringRegm: [String]
    standingWaterRegm: [String]
    gaseousEnvironment: [String]
    fungicideRegm: [String]
    climateEnvironment: [String]
    herbicideRegm: [String]
    nonMineralNutrRegm: [String]
    pesticideRegm: [String]
    phRegm: [String]
    saltRegm: [String]
    seasonEnvironment: [String]
    perturbation: [String]
    sampStoreDur: String!
    sampStoreLoc: String!
    sampCollectDevice: String!
    hostAge: QuantityValue!
    hostCommonName: String!
    hostGenotype: String!
    hostHeight: QuantityValue!
    hostSubspecfGenlin: [String]
    hostLength: QuantityValue!
    hostLifeStage: String!
    hostPhenotype: String!
    hostTaxid: String!
    hostTotMass: QuantityValue!
    plantProduct: String
    oxyStatSamp: OxyStatSampEnum
    assemblyQuality: String
    url: [String]
    faoClass: FaoClassEnum
    localClass: String
    localClassMeth: String
    soilType: String!
    soilTypeMeth: String!
    horizon: HorizonEnum
    horizonMeth: String
    linkClassInfo: String
    previousLandUse: String
    previousLandUseMeth: String
    cropRotation: String
    agrochemAddition: [String]
    tillage: [TillageEnum]
    fire: Date
    flooding: Date
    extremeEvent: Date
    linkClimateInfo: String
    annualTemp: QuantityValue
    seasonTemp: QuantityValue
    annualPrecpt: QuantityValue
    seasonPrecpt: QuantityValue
    curLandUse: CurLandUseEnum
    slopeGradient: QuantityValue
    slopeAspect: QuantityValue
    profilePosition: ProfilePositionEnum
    drainageClass: DrainageClassEnum
    storeCond: String!
    phMeth: String
    curVegetation: String
    curVegetationMeth: String
    totOrgCarb: QuantityValue
    totOrgCMeth: String
    totNitro: QuantityValue
    totNMeth: String
    microbialBiomass: QuantityValue!
    microbialBiomassMeth: String!
    heavyMetalsMeth: String
    totCar: QuantityValue
    totPhos: QuantityValue
    sieving: String!
    poolDnaExtracts: String!
    miscParam: [String]
    hostDiseaseStat: String
    specificHost: String!
    pathogenicity: String!
    bioticRelationship: BioticRelationshipEnum
    isolGrowthCondt: String
    sampMatProcess: String!
    hostSpecRange: Integer!
    trophicLevel: TrophicLevelEnum
    sampSize: QuantityValue!
    seqMeth: String!
    sampVolWeDnaExt: QuantityValue!
    pcrPrimers: String!
    nuclAcidExt: String!
    nuclAcidAmp: String!
    libSize: Integer
    libReadsSeqd: Integer!
    libLayout: LibLayoutEnum
    libVector: String!
    libScreen: String!
    targetGene: String!
    targetSubfragment: String!
    mid: String!
    adapters: String!
    pcrCond: String!
    seqQualityCheck: String
    chimeraCheck: String!
    assemblyName: String!
    assemblySoftware: String
    annot: String
    sop: String
    sourceMatId: String
    sampName: String!
    sampTaxonId: String!
    projectName: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sizeFrac: String
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    binParam: BinParamEnum!
    binSoftware: String!
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    associatedResource: String
  }

type AgricultureMIMARKSSpecimen implements MIMARKSSpecimen
  {
    latLon: String
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    plantGrowthMed: PlantGrowthMedEnum
    soilHorizon: SoilHorizonEnum
    photosyntActiv: [QuantityValue]
    photosyntActivMeth: [String]
    sampCollectMethod: String
    enrichmentProtocol: String
    libraryPrepKit: String
    sequencingLocation: String
    temp: QuantityValue
    soilPH: Double
    soilConductivity: QuantityValue
    relLocation: String
    soilCover: String
    porosity: String
    texture: QuantityValue
    textureMeth: String
    hostSymbiont: [String]
    presAnimalInsect: String
    plantWaterMethod: String
    animWaterMethod: [String]
    farmWaterSource: [FarmWaterSourceEnum]
    waterSourceShared: [WaterSourceSharedEnum]
    waterPH: Double
    season: String
    solarIrradiance: QuantityValue
    cropYield: String
    seasonHumidity: QuantityValue
    humidity: QuantityValue
    adjacentEnvironment: [String]
    chemAdministration: [String]!
    foodProd: [String]
    lotNumber: [String]
    fertilizerAdmin: String
    sampStorTemp: QuantityValue
    foodTravMode: [String]
    foodTravVehic: [String]
    farmEquipSan: [String]
    farmEquip: [String]
    farmEquipShared: [String]
    foodHarvestProc: [String]
    plantStruc: String
    hostDryMass: QuantityValue
    ancesData: String
    geneticMod: String
    foodProductType: String
    foodSource: String!
    spikeinStrain: [String]
    organismCount: [OrganismCountEnum]
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    cultIsolDate: Date
    sampPooling: [String]
    rootMedMacronutr: String
    rootMedCarbon: String
    rootMedPh: Double
    depth: QuantityValue!
    waterTempRegm: [String]
    wateringRegm: [String]
    standingWaterRegm: [String]
    gaseousEnvironment: [String]
    fungicideRegm: [String]
    climateEnvironment: [String]
    herbicideRegm: [String]
    nonMineralNutrRegm: [String]
    pesticideRegm: [String]
    phRegm: [String]
    saltRegm: [String]
    seasonEnvironment: [String]
    perturbation: [String]
    sampStoreDur: String!
    sampStoreLoc: String!
    sampCollectDevice: String!
    hostAge: QuantityValue!
    hostCommonName: String!
    hostGenotype: String!
    hostHeight: QuantityValue!
    hostSubspecfGenlin: [String]
    hostLength: QuantityValue!
    hostLifeStage: String!
    hostPhenotype: String!
    hostTaxid: String!
    hostTotMass: QuantityValue!
    plantProduct: String
    oxyStatSamp: OxyStatSampEnum
    assemblyQuality: String
    url: [String]
    faoClass: FaoClassEnum
    localClass: String
    localClassMeth: String
    soilType: String!
    soilTypeMeth: String!
    horizon: HorizonEnum
    horizonMeth: String
    linkClassInfo: String
    previousLandUse: String
    previousLandUseMeth: String
    cropRotation: String
    agrochemAddition: [String]
    tillage: [TillageEnum]
    fire: Date
    flooding: Date
    extremeEvent: Date
    linkClimateInfo: String
    annualTemp: QuantityValue
    seasonTemp: QuantityValue
    annualPrecpt: QuantityValue
    seasonPrecpt: QuantityValue
    curLandUse: CurLandUseEnum
    slopeGradient: QuantityValue
    slopeAspect: QuantityValue
    profilePosition: ProfilePositionEnum
    drainageClass: DrainageClassEnum
    storeCond: String!
    phMeth: String
    curVegetation: String
    curVegetationMeth: String
    totOrgCarb: QuantityValue
    totOrgCMeth: String
    totNitro: QuantityValue
    totNMeth: String
    microbialBiomass: QuantityValue!
    microbialBiomassMeth: String!
    heavyMetalsMeth: String
    totCar: QuantityValue
    totPhos: QuantityValue
    sieving: String!
    poolDnaExtracts: String!
    miscParam: [String]
    hostDiseaseStat: String
    specificHost: String!
    pathogenicity: String!
    bioticRelationship: BioticRelationshipEnum
    isolGrowthCondt: String
    sampMatProcess: String!
    hostSpecRange: Integer!
    trophicLevel: TrophicLevelEnum
    sampSize: QuantityValue!
    seqMeth: String!
    sampVolWeDnaExt: QuantityValue!
    pcrPrimers: String!
    nuclAcidExt: String!
    nuclAcidAmp: String!
    libSize: Integer
    libReadsSeqd: Integer!
    libLayout: LibLayoutEnum
    libVector: String!
    libScreen: String!
    targetGene: String!
    targetSubfragment: String!
    mid: String!
    adapters: String!
    pcrCond: String!
    seqQualityCheck: String
    chimeraCheck: String!
    assemblyName: String!
    assemblySoftware: String
    annot: String
    sop: String
    sourceMatId: String
    sampName: String!
    sampTaxonId: String!
    projectName: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sizeFrac: String
    associatedResource: String
  }

type AgricultureMIMARKSSurvey implements MIMARKSSurvey
  {
    latLon: String
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    plantGrowthMed: PlantGrowthMedEnum
    soilHorizon: SoilHorizonEnum
    photosyntActiv: [QuantityValue]
    photosyntActivMeth: [String]
    sampCollectMethod: String
    enrichmentProtocol: String
    libraryPrepKit: String
    sequencingLocation: String
    temp: QuantityValue
    soilPH: Double
    soilConductivity: QuantityValue
    relLocation: String
    soilCover: String
    porosity: String
    texture: QuantityValue
    textureMeth: String
    hostSymbiont: [String]
    presAnimalInsect: String
    plantWaterMethod: String
    animWaterMethod: [String]
    farmWaterSource: [FarmWaterSourceEnum]
    waterSourceShared: [WaterSourceSharedEnum]
    waterPH: Double
    season: String
    solarIrradiance: QuantityValue
    cropYield: String
    seasonHumidity: QuantityValue
    humidity: QuantityValue
    adjacentEnvironment: [String]
    chemAdministration: [String]!
    foodProd: [String]
    lotNumber: [String]
    fertilizerAdmin: String
    sampStorTemp: QuantityValue
    foodTravMode: [String]
    foodTravVehic: [String]
    farmEquipSan: [String]
    farmEquip: [String]
    farmEquipShared: [String]
    foodHarvestProc: [String]
    plantStruc: String
    hostDryMass: QuantityValue
    ancesData: String
    geneticMod: String
    foodProductType: String
    foodSource: String!
    spikeinStrain: [String]
    organismCount: [OrganismCountEnum]
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    cultIsolDate: Date
    sampPooling: [String]
    rootMedMacronutr: String
    rootMedCarbon: String
    rootMedPh: Double
    depth: QuantityValue!
    waterTempRegm: [String]
    wateringRegm: [String]
    standingWaterRegm: [String]
    gaseousEnvironment: [String]
    fungicideRegm: [String]
    climateEnvironment: [String]
    herbicideRegm: [String]
    nonMineralNutrRegm: [String]
    pesticideRegm: [String]
    phRegm: [String]
    saltRegm: [String]
    seasonEnvironment: [String]
    perturbation: [String]
    sampStoreDur: String!
    sampStoreLoc: String!
    sampCollectDevice: String!
    hostAge: QuantityValue!
    hostCommonName: String!
    hostGenotype: String!
    hostHeight: QuantityValue!
    hostSubspecfGenlin: [String]
    hostLength: QuantityValue!
    hostLifeStage: String!
    hostPhenotype: String!
    hostTaxid: String!
    hostTotMass: QuantityValue!
    plantProduct: String
    oxyStatSamp: OxyStatSampEnum
    assemblyQuality: String
    url: [String]
    faoClass: FaoClassEnum
    localClass: String
    localClassMeth: String
    soilType: String!
    soilTypeMeth: String!
    horizon: HorizonEnum
    horizonMeth: String
    linkClassInfo: String
    previousLandUse: String
    previousLandUseMeth: String
    cropRotation: String
    agrochemAddition: [String]
    tillage: [TillageEnum]
    fire: Date
    flooding: Date
    extremeEvent: Date
    linkClimateInfo: String
    annualTemp: QuantityValue
    seasonTemp: QuantityValue
    annualPrecpt: QuantityValue
    seasonPrecpt: QuantityValue
    curLandUse: CurLandUseEnum
    slopeGradient: QuantityValue
    slopeAspect: QuantityValue
    profilePosition: ProfilePositionEnum
    drainageClass: DrainageClassEnum
    storeCond: String!
    phMeth: String
    curVegetation: String
    curVegetationMeth: String
    totOrgCarb: QuantityValue
    totOrgCMeth: String
    totNitro: QuantityValue
    totNMeth: String
    microbialBiomass: QuantityValue!
    microbialBiomassMeth: String!
    heavyMetalsMeth: String
    totCar: QuantityValue
    totPhos: QuantityValue
    sieving: String!
    poolDnaExtracts: String!
    miscParam: [String]
    hostDiseaseStat: String
    specificHost: String!
    pathogenicity: String!
    bioticRelationship: BioticRelationshipEnum
    isolGrowthCondt: String
    sampMatProcess: String!
    hostSpecRange: Integer!
    trophicLevel: TrophicLevelEnum
    sampSize: QuantityValue!
    seqMeth: String!
    sampVolWeDnaExt: QuantityValue!
    pcrPrimers: String!
    nuclAcidExt: String!
    nuclAcidAmp: String!
    libSize: Integer
    libReadsSeqd: Integer!
    libLayout: LibLayoutEnum
    libVector: String!
    libScreen: String!
    targetGene: String!
    targetSubfragment: String!
    mid: String!
    adapters: String!
    pcrCond: String!
    seqQualityCheck: String
    chimeraCheck: String!
    assemblyName: String!
    assemblySoftware: String
    annot: String
    sop: String
    sourceMatId: String
    sampName: String!
    sampTaxonId: String!
    projectName: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    associatedResource: String
  }

type AgricultureMIMS implements MIMS
  {
    latLon: String
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    plantGrowthMed: PlantGrowthMedEnum
    soilHorizon: SoilHorizonEnum
    photosyntActiv: [QuantityValue]
    photosyntActivMeth: [String]
    sampCollectMethod: String
    enrichmentProtocol: String
    libraryPrepKit: String
    sequencingLocation: String
    temp: QuantityValue
    soilPH: Double
    soilConductivity: QuantityValue
    relLocation: String
    soilCover: String
    porosity: String
    texture: QuantityValue
    textureMeth: String
    hostSymbiont: [String]
    presAnimalInsect: String
    plantWaterMethod: String
    animWaterMethod: [String]
    farmWaterSource: [FarmWaterSourceEnum]
    waterSourceShared: [WaterSourceSharedEnum]
    waterPH: Double
    season: String
    solarIrradiance: QuantityValue
    cropYield: String
    seasonHumidity: QuantityValue
    humidity: QuantityValue
    adjacentEnvironment: [String]
    chemAdministration: [String]!
    foodProd: [String]
    lotNumber: [String]
    fertilizerAdmin: String
    sampStorTemp: QuantityValue
    foodTravMode: [String]
    foodTravVehic: [String]
    farmEquipSan: [String]
    farmEquip: [String]
    farmEquipShared: [String]
    foodHarvestProc: [String]
    plantStruc: String
    hostDryMass: QuantityValue
    ancesData: String
    geneticMod: String
    foodProductType: String
    foodSource: String!
    spikeinStrain: [String]
    organismCount: [OrganismCountEnum]
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    cultIsolDate: Date
    sampPooling: [String]
    rootMedMacronutr: String
    rootMedCarbon: String
    rootMedPh: Double
    depth: QuantityValue!
    waterTempRegm: [String]
    wateringRegm: [String]
    standingWaterRegm: [String]
    gaseousEnvironment: [String]
    fungicideRegm: [String]
    climateEnvironment: [String]
    herbicideRegm: [String]
    nonMineralNutrRegm: [String]
    pesticideRegm: [String]
    phRegm: [String]
    saltRegm: [String]
    seasonEnvironment: [String]
    perturbation: [String]
    sampStoreDur: String!
    sampStoreLoc: String!
    sampCollectDevice: String!
    hostAge: QuantityValue!
    hostCommonName: String!
    hostGenotype: String!
    hostHeight: QuantityValue!
    hostSubspecfGenlin: [String]
    hostLength: QuantityValue!
    hostLifeStage: String!
    hostPhenotype: String!
    hostTaxid: String!
    hostTotMass: QuantityValue!
    plantProduct: String
    oxyStatSamp: OxyStatSampEnum
    assemblyQuality: String
    url: [String]
    faoClass: FaoClassEnum
    localClass: String
    localClassMeth: String
    soilType: String!
    soilTypeMeth: String!
    horizon: HorizonEnum
    horizonMeth: String
    linkClassInfo: String
    previousLandUse: String
    previousLandUseMeth: String
    cropRotation: String
    agrochemAddition: [String]
    tillage: [TillageEnum]
    fire: Date
    flooding: Date
    extremeEvent: Date
    linkClimateInfo: String
    annualTemp: QuantityValue
    seasonTemp: QuantityValue
    annualPrecpt: QuantityValue
    seasonPrecpt: QuantityValue
    curLandUse: CurLandUseEnum
    slopeGradient: QuantityValue
    slopeAspect: QuantityValue
    profilePosition: ProfilePositionEnum
    drainageClass: DrainageClassEnum
    storeCond: String!
    phMeth: String
    curVegetation: String
    curVegetationMeth: String
    totOrgCarb: QuantityValue
    totOrgCMeth: String
    totNitro: QuantityValue
    totNMeth: String
    microbialBiomass: QuantityValue!
    microbialBiomassMeth: String!
    heavyMetalsMeth: String
    totCar: QuantityValue
    totPhos: QuantityValue
    sieving: String!
    poolDnaExtracts: String!
    miscParam: [String]
    hostDiseaseStat: String
    specificHost: String!
    pathogenicity: String!
    bioticRelationship: BioticRelationshipEnum
    isolGrowthCondt: String
    sampMatProcess: String!
    hostSpecRange: Integer!
    trophicLevel: TrophicLevelEnum
    sampSize: QuantityValue!
    seqMeth: String!
    sampVolWeDnaExt: QuantityValue!
    pcrPrimers: String!
    nuclAcidExt: String!
    nuclAcidAmp: String!
    libSize: Integer
    libReadsSeqd: Integer!
    libLayout: LibLayoutEnum
    libVector: String!
    libScreen: String!
    targetGene: String!
    targetSubfragment: String!
    mid: String!
    adapters: String!
    pcrCond: String!
    seqQualityCheck: String
    chimeraCheck: String!
    assemblyName: String!
    assemblySoftware: String
    annot: String
    sop: String
    sourceMatId: String
    sampName: String!
    sampTaxonId: String!
    projectName: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sizeFrac: String
    assemblyQual: AssemblyQualEnum
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    associatedResource: String
  }

type AgricultureMISAG implements MISAG
  {
    latLon: String
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    plantGrowthMed: PlantGrowthMedEnum
    soilHorizon: SoilHorizonEnum
    photosyntActiv: [QuantityValue]
    photosyntActivMeth: [String]
    sampCollectMethod: String
    enrichmentProtocol: String
    libraryPrepKit: String
    sequencingLocation: String
    temp: QuantityValue
    soilPH: Double
    soilConductivity: QuantityValue
    relLocation: String
    soilCover: String
    porosity: String
    texture: QuantityValue
    textureMeth: String
    hostSymbiont: [String]
    presAnimalInsect: String
    plantWaterMethod: String
    animWaterMethod: [String]
    farmWaterSource: [FarmWaterSourceEnum]
    waterSourceShared: [WaterSourceSharedEnum]
    waterPH: Double
    season: String
    solarIrradiance: QuantityValue
    cropYield: String
    seasonHumidity: QuantityValue
    humidity: QuantityValue
    adjacentEnvironment: [String]
    chemAdministration: [String]!
    foodProd: [String]
    lotNumber: [String]
    fertilizerAdmin: String
    sampStorTemp: QuantityValue
    foodTravMode: [String]
    foodTravVehic: [String]
    farmEquipSan: [String]
    farmEquip: [String]
    farmEquipShared: [String]
    foodHarvestProc: [String]
    plantStruc: String
    hostDryMass: QuantityValue
    ancesData: String
    geneticMod: String
    foodProductType: String
    foodSource: String!
    spikeinStrain: [String]
    organismCount: [OrganismCountEnum]
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    cultIsolDate: Date
    sampPooling: [String]
    rootMedMacronutr: String
    rootMedCarbon: String
    rootMedPh: Double
    depth: QuantityValue!
    waterTempRegm: [String]
    wateringRegm: [String]
    standingWaterRegm: [String]
    gaseousEnvironment: [String]
    fungicideRegm: [String]
    climateEnvironment: [String]
    herbicideRegm: [String]
    nonMineralNutrRegm: [String]
    pesticideRegm: [String]
    phRegm: [String]
    saltRegm: [String]
    seasonEnvironment: [String]
    perturbation: [String]
    sampStoreDur: String!
    sampStoreLoc: String!
    sampCollectDevice: String!
    hostAge: QuantityValue!
    hostCommonName: String!
    hostGenotype: String!
    hostHeight: QuantityValue!
    hostSubspecfGenlin: [String]
    hostLength: QuantityValue!
    hostLifeStage: String!
    hostPhenotype: String!
    hostTaxid: String!
    hostTotMass: QuantityValue!
    plantProduct: String
    oxyStatSamp: OxyStatSampEnum
    assemblyQuality: String
    url: [String]
    faoClass: FaoClassEnum
    localClass: String
    localClassMeth: String
    soilType: String!
    soilTypeMeth: String!
    horizon: HorizonEnum
    horizonMeth: String
    linkClassInfo: String
    previousLandUse: String
    previousLandUseMeth: String
    cropRotation: String
    agrochemAddition: [String]
    tillage: [TillageEnum]
    fire: Date
    flooding: Date
    extremeEvent: Date
    linkClimateInfo: String
    annualTemp: QuantityValue
    seasonTemp: QuantityValue
    annualPrecpt: QuantityValue
    seasonPrecpt: QuantityValue
    curLandUse: CurLandUseEnum
    slopeGradient: QuantityValue
    slopeAspect: QuantityValue
    profilePosition: ProfilePositionEnum
    drainageClass: DrainageClassEnum
    storeCond: String!
    phMeth: String
    curVegetation: String
    curVegetationMeth: String
    totOrgCarb: QuantityValue
    totOrgCMeth: String
    totNitro: QuantityValue
    totNMeth: String
    microbialBiomass: QuantityValue!
    microbialBiomassMeth: String!
    heavyMetalsMeth: String
    totCar: QuantityValue
    totPhos: QuantityValue
    sieving: String!
    poolDnaExtracts: String!
    miscParam: [String]
    hostDiseaseStat: String
    specificHost: String!
    pathogenicity: String!
    bioticRelationship: BioticRelationshipEnum
    isolGrowthCondt: String
    sampMatProcess: String!
    hostSpecRange: Integer!
    trophicLevel: TrophicLevelEnum
    sampSize: QuantityValue!
    seqMeth: String!
    sampVolWeDnaExt: QuantityValue!
    pcrPrimers: String!
    nuclAcidExt: String!
    nuclAcidAmp: String!
    libSize: Integer
    libReadsSeqd: Integer!
    libLayout: LibLayoutEnum
    libVector: String!
    libScreen: String!
    targetGene: String!
    targetSubfragment: String!
    mid: String!
    adapters: String!
    pcrCond: String!
    seqQualityCheck: String
    chimeraCheck: String!
    assemblyName: String!
    assemblySoftware: String
    annot: String
    sop: String
    sourceMatId: String
    sampName: String!
    sampTaxonId: String!
    projectName: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sizeFrac: String
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    sortTech: SortTechEnum!
    singleCellLysisAppr: SingleCellLysisApprEnum!
    singleCellLysisProt: String
    wgaAmpAppr: String!
    wgaAmpKit: String
    associatedResource: String
  }

type AgricultureMIUVIG implements MIUVIG
  {
    latLon: String
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    plantGrowthMed: PlantGrowthMedEnum
    soilHorizon: SoilHorizonEnum
    photosyntActiv: [QuantityValue]
    photosyntActivMeth: [String]
    sampCollectMethod: String
    enrichmentProtocol: String
    libraryPrepKit: String
    sequencingLocation: String
    temp: QuantityValue
    soilPH: Double
    soilConductivity: QuantityValue
    relLocation: String
    soilCover: String
    porosity: String
    texture: QuantityValue
    textureMeth: String
    hostSymbiont: [String]
    presAnimalInsect: String
    plantWaterMethod: String
    animWaterMethod: [String]
    farmWaterSource: [FarmWaterSourceEnum]
    waterSourceShared: [WaterSourceSharedEnum]
    waterPH: Double
    season: String
    solarIrradiance: QuantityValue
    cropYield: String
    seasonHumidity: QuantityValue
    humidity: QuantityValue
    adjacentEnvironment: [String]
    chemAdministration: [String]!
    foodProd: [String]
    lotNumber: [String]
    fertilizerAdmin: String
    sampStorTemp: QuantityValue
    foodTravMode: [String]
    foodTravVehic: [String]
    farmEquipSan: [String]
    farmEquip: [String]
    farmEquipShared: [String]
    foodHarvestProc: [String]
    plantStruc: String
    hostDryMass: QuantityValue
    ancesData: String
    geneticMod: String
    foodProductType: String
    foodSource: String!
    spikeinStrain: [String]
    organismCount: [OrganismCountEnum]
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    cultIsolDate: Date
    sampPooling: [String]
    rootMedMacronutr: String
    rootMedCarbon: String
    rootMedPh: Double
    depth: QuantityValue!
    waterTempRegm: [String]
    wateringRegm: [String]
    standingWaterRegm: [String]
    gaseousEnvironment: [String]
    fungicideRegm: [String]
    climateEnvironment: [String]
    herbicideRegm: [String]
    nonMineralNutrRegm: [String]
    pesticideRegm: [String]
    phRegm: [String]
    saltRegm: [String]
    seasonEnvironment: [String]
    perturbation: [String]
    sampStoreDur: String!
    sampStoreLoc: String!
    sampCollectDevice: String!
    hostAge: QuantityValue!
    hostCommonName: String!
    hostGenotype: String!
    hostHeight: QuantityValue!
    hostSubspecfGenlin: [String]
    hostLength: QuantityValue!
    hostLifeStage: String!
    hostPhenotype: String!
    hostTaxid: String!
    hostTotMass: QuantityValue!
    plantProduct: String
    oxyStatSamp: OxyStatSampEnum
    assemblyQuality: String
    url: [String]
    faoClass: FaoClassEnum
    localClass: String
    localClassMeth: String
    soilType: String!
    soilTypeMeth: String!
    horizon: HorizonEnum
    horizonMeth: String
    linkClassInfo: String
    previousLandUse: String
    previousLandUseMeth: String
    cropRotation: String
    agrochemAddition: [String]
    tillage: [TillageEnum]
    fire: Date
    flooding: Date
    extremeEvent: Date
    linkClimateInfo: String
    annualTemp: QuantityValue
    seasonTemp: QuantityValue
    annualPrecpt: QuantityValue
    seasonPrecpt: QuantityValue
    curLandUse: CurLandUseEnum
    slopeGradient: QuantityValue
    slopeAspect: QuantityValue
    profilePosition: ProfilePositionEnum
    drainageClass: DrainageClassEnum
    storeCond: String!
    phMeth: String
    curVegetation: String
    curVegetationMeth: String
    totOrgCarb: QuantityValue
    totOrgCMeth: String
    totNitro: QuantityValue
    totNMeth: String
    microbialBiomass: QuantityValue!
    microbialBiomassMeth: String!
    heavyMetalsMeth: String
    totCar: QuantityValue
    totPhos: QuantityValue
    sieving: String!
    poolDnaExtracts: String!
    miscParam: [String]
    hostDiseaseStat: String
    specificHost: String!
    pathogenicity: String!
    bioticRelationship: BioticRelationshipEnum
    isolGrowthCondt: String
    sampMatProcess: String!
    hostSpecRange: Integer!
    trophicLevel: TrophicLevelEnum
    sampSize: QuantityValue!
    seqMeth: String!
    sampVolWeDnaExt: QuantityValue!
    pcrPrimers: String!
    nuclAcidExt: String!
    nuclAcidAmp: String!
    libSize: Integer
    libReadsSeqd: Integer!
    libLayout: LibLayoutEnum
    libVector: String!
    libScreen: String!
    targetGene: String!
    targetSubfragment: String!
    mid: String!
    adapters: String!
    pcrCond: String!
    seqQualityCheck: String
    chimeraCheck: String!
    assemblyName: String!
    assemblySoftware: String
    annot: String
    sop: String
    sourceMatId: String
    sampName: String!
    sampTaxonId: String!
    projectName: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    estimatedSize: String
    refBiomaterial: String
    sampCollecDevice: String
    sampCollecMethod: String
    sizeFrac: String
    sourceUvig: SourceUvigEnum!
    virusEnrichAppr: VirusEnrichApprEnum!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String
    complSoftware: String
    complAppr: ComplApprEnum
    sortTech: SortTechEnum
    singleCellLysisAppr: SingleCellLysisApprEnum
    singleCellLysisProt: String
    wgaAmpAppr: String
    wgaAmpKit: String
    binParam: BinParamEnum
    binSoftware: String
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    virIdentSoftware: String!
    predGenomeType: PredGenomeTypeEnum!
    predGenomeStruc: PredGenomeStrucEnum!
    detecType: String!
    otuClassAppr: String
    otuSeqCompAppr: String
    otuDb: String
    hostPredAppr: HostPredApprEnum
    hostPredEstAcc: String
    associatedResource: String
  }

type Air
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue!
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    barometricPress: QuantityValue
    carbDioxide: QuantityValue
    carbMonoxide: QuantityValue
    chemAdministration: [String]
    humidity: QuantityValue
    methane: QuantityValue
    organismCount: [OrganismCountEnum]
    oxygen: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    perturbation: [String]
    pollutants: [String]
    airParticulateMatterConcentration: [String]
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    solarIrradiance: QuantityValue
    ventilationRate: QuantityValue
    ventilationType: String
    volatileOrgComp: [String]
    windDirection: String
    windSpeed: QuantityValue
    miscParam: [String]
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
  }

type AirMIGSBacteria implements MIGSBacteria
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue!
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    barometricPress: QuantityValue
    carbDioxide: QuantityValue
    carbMonoxide: QuantityValue
    chemAdministration: [String]
    humidity: QuantityValue
    methane: QuantityValue
    organismCount: [OrganismCountEnum]
    oxygen: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    perturbation: [String]
    pollutants: [String]
    airParticulateMatterConcentration: [String]
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    solarIrradiance: QuantityValue
    ventilationRate: QuantityValue
    ventilationType: String
    volatileOrgComp: [String]
    windDirection: String
    windSpeed: QuantityValue
    miscParam: [String]
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer!
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String!
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    trophicLevel: TrophicLevelEnum
    encodedTraits: String
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type AirMIGSEukaryote implements MIGSEukaryote
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue!
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    barometricPress: QuantityValue
    carbDioxide: QuantityValue
    carbMonoxide: QuantityValue
    chemAdministration: [String]
    humidity: QuantityValue
    methane: QuantityValue
    organismCount: [OrganismCountEnum]
    oxygen: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    perturbation: [String]
    pollutants: [String]
    airParticulateMatterConcentration: [String]
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    solarIrradiance: QuantityValue
    ventilationRate: QuantityValue
    ventilationType: String
    volatileOrgComp: [String]
    windDirection: String
    windSpeed: QuantityValue
    miscParam: [String]
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    ploidy: String
    numReplicons: Integer
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    trophicLevel: TrophicLevelEnum
    propagation: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type AirMIGSOrg implements MIGSOrg
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue!
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    barometricPress: QuantityValue
    carbDioxide: QuantityValue
    carbMonoxide: QuantityValue
    chemAdministration: [String]
    humidity: QuantityValue
    methane: QuantityValue
    organismCount: [OrganismCountEnum]
    oxygen: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    perturbation: [String]
    pollutants: [String]
    airParticulateMatterConcentration: [String]
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    solarIrradiance: QuantityValue
    ventilationRate: QuantityValue
    ventilationType: String
    volatileOrgComp: [String]
    windDirection: String
    windSpeed: QuantityValue
    miscParam: [String]
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type AirMIGSPlant implements MIGSPlant
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue!
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    barometricPress: QuantityValue
    carbDioxide: QuantityValue
    carbMonoxide: QuantityValue
    chemAdministration: [String]
    humidity: QuantityValue
    methane: QuantityValue
    organismCount: [OrganismCountEnum]
    oxygen: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    perturbation: [String]
    pollutants: [String]
    airParticulateMatterConcentration: [String]
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    solarIrradiance: QuantityValue
    ventilationRate: QuantityValue
    ventilationType: String
    volatileOrgComp: [String]
    windDirection: String
    windSpeed: QuantityValue
    miscParam: [String]
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    specificHost: String
    hostSpecRange: Integer
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type AirMIGSVirus implements MIGSVirus
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue!
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    barometricPress: QuantityValue
    carbDioxide: QuantityValue
    carbMonoxide: QuantityValue
    chemAdministration: [String]
    humidity: QuantityValue
    methane: QuantityValue
    organismCount: [OrganismCountEnum]
    oxygen: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    perturbation: [String]
    pollutants: [String]
    airParticulateMatterConcentration: [String]
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    solarIrradiance: QuantityValue
    ventilationRate: QuantityValue
    ventilationType: String
    volatileOrgComp: [String]
    windDirection: String
    windSpeed: QuantityValue
    miscParam: [String]
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    virusEnrichAppr: VirusEnrichApprEnum
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type AirMIMAG implements MIMAG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue!
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    barometricPress: QuantityValue
    carbDioxide: QuantityValue
    carbMonoxide: QuantityValue
    chemAdministration: [String]
    humidity: QuantityValue
    methane: QuantityValue
    organismCount: [OrganismCountEnum]
    oxygen: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    perturbation: [String]
    pollutants: [String]
    airParticulateMatterConcentration: [String]
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    solarIrradiance: QuantityValue
    ventilationRate: QuantityValue
    ventilationType: String
    volatileOrgComp: [String]
    windDirection: String
    windSpeed: QuantityValue
    miscParam: [String]
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    binParam: BinParamEnum!
    binSoftware: String!
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    associatedResource: String
    sop: String
  }

type AirMIMARKSSpecimen implements MIMARKSSpecimen
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue!
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    barometricPress: QuantityValue
    carbDioxide: QuantityValue
    carbMonoxide: QuantityValue
    chemAdministration: [String]
    humidity: QuantityValue
    methane: QuantityValue
    organismCount: [OrganismCountEnum]
    oxygen: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    perturbation: [String]
    pollutants: [String]
    airParticulateMatterConcentration: [String]
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    solarIrradiance: QuantityValue
    ventilationRate: QuantityValue
    ventilationType: String
    volatileOrgComp: [String]
    windDirection: String
    windSpeed: QuantityValue
    miscParam: [String]
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    mid: String
    adapters: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    assemblySoftware: String
    associatedResource: String
    sop: String
  }

type AirMIMARKSSurvey implements MIMARKSSurvey
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue!
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    barometricPress: QuantityValue
    carbDioxide: QuantityValue
    carbMonoxide: QuantityValue
    chemAdministration: [String]
    humidity: QuantityValue
    methane: QuantityValue
    organismCount: [OrganismCountEnum]
    oxygen: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    perturbation: [String]
    pollutants: [String]
    airParticulateMatterConcentration: [String]
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    solarIrradiance: QuantityValue
    ventilationRate: QuantityValue
    ventilationType: String
    volatileOrgComp: [String]
    windDirection: String
    windSpeed: QuantityValue
    miscParam: [String]
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    sourceMatId: String
    bioticRelationship: BioticRelationshipEnum
    trophicLevel: TrophicLevelEnum
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    associatedResource: String
    sop: String
  }

type AirMIMS implements MIMS
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue!
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    barometricPress: QuantityValue
    carbDioxide: QuantityValue
    carbMonoxide: QuantityValue
    chemAdministration: [String]
    humidity: QuantityValue
    methane: QuantityValue
    organismCount: [OrganismCountEnum]
    oxygen: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    perturbation: [String]
    pollutants: [String]
    airParticulateMatterConcentration: [String]
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    solarIrradiance: QuantityValue
    ventilationRate: QuantityValue
    ventilationType: String
    volatileOrgComp: [String]
    windDirection: String
    windSpeed: QuantityValue
    miscParam: [String]
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    associatedResource: String
    sop: String
  }

type AirMISAG implements MISAG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue!
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    barometricPress: QuantityValue
    carbDioxide: QuantityValue
    carbMonoxide: QuantityValue
    chemAdministration: [String]
    humidity: QuantityValue
    methane: QuantityValue
    organismCount: [OrganismCountEnum]
    oxygen: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    perturbation: [String]
    pollutants: [String]
    airParticulateMatterConcentration: [String]
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    solarIrradiance: QuantityValue
    ventilationRate: QuantityValue
    ventilationType: String
    volatileOrgComp: [String]
    windDirection: String
    windSpeed: QuantityValue
    miscParam: [String]
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    sortTech: SortTechEnum!
    singleCellLysisAppr: SingleCellLysisApprEnum!
    singleCellLysisProt: String
    wgaAmpAppr: String!
    wgaAmpKit: String
    associatedResource: String
    sop: String
  }

type AirMIUVIG implements MIUVIG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue!
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    barometricPress: QuantityValue
    carbDioxide: QuantityValue
    carbMonoxide: QuantityValue
    chemAdministration: [String]
    humidity: QuantityValue
    methane: QuantityValue
    organismCount: [OrganismCountEnum]
    oxygen: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    perturbation: [String]
    pollutants: [String]
    airParticulateMatterConcentration: [String]
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    solarIrradiance: QuantityValue
    ventilationRate: QuantityValue
    ventilationType: String
    volatileOrgComp: [String]
    windDirection: String
    windSpeed: QuantityValue
    miscParam: [String]
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    sourceUvig: SourceUvigEnum!
    virusEnrichAppr: VirusEnrichApprEnum!
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String
    complSoftware: String
    complAppr: ComplApprEnum
    sortTech: SortTechEnum
    singleCellLysisAppr: SingleCellLysisApprEnum
    singleCellLysisProt: String
    wgaAmpAppr: String
    wgaAmpKit: String
    binParam: BinParamEnum
    binSoftware: String
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    virIdentSoftware: String!
    predGenomeType: PredGenomeTypeEnum!
    predGenomeStruc: PredGenomeStrucEnum!
    detecType: String!
    otuClassAppr: String
    otuSeqCompAppr: String
    otuDb: String
    hostPredAppr: HostPredApprEnum
    hostPredEstAcc: String
    associatedResource: String
    sop: String
  }

type BuiltEnvironment
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    surfMaterial: SurfMaterialEnum
    surfAirCont: [SurfAirContEnum]
    relAirHumidity: QuantityValue!
    absAirHumidity: QuantityValue!
    surfHumidity: QuantityValue
    surfTemp: QuantityValue
    surfMoisturePh: Double
    buildOccupType: [BuildOccupTypeEnum]!
    surfMoisture: QuantityValue
    dewPoint: QuantityValue
    carbDioxide: QuantityValue!
    ventilationType: String!
    organismCount: [OrganismCountEnum]!
    indoorSpace: IndoorSpaceEnum!
    indoorSurf: IndoorSurfEnum
    filterType: [FilterTypeEnum]!
    heatCoolType: [HeatCoolTypeEnum]!
    substructureType: [SubstructureTypeEnum]
    buildingSetting: BuildingSettingEnum!
    lightType: [LightTypeEnum]!
    sampSortMeth: [String]
    spaceTypState: String!
    typOccupDensity: Double!
    occupSamp: Integer!
    occupDensitySamp: Double!
    address: String
    adjRoom: String
    aeroStruc: String
    amountLight: QuantityValue
    archStruc: ArchStrucEnum
    avgOccup: Double
    avgDewPoint: QuantityValue
    avgTemp: QuantityValue
    bathroomCount: Integer
    bedroomCount: Integer
    builtStrucAge: QuantityValue
    builtStrucSet: String
    builtStrucType: String
    ceilArea: QuantityValue
    ceilCond: CeilCondEnum
    ceilFinishMat: CeilFinishMatEnum
    ceilWaterMold: String
    ceilStruc: String
    ceilTexture: CeilTextureEnum
    ceilThermalMass: QuantityValue
    ceilType: CeilTypeEnum
    coolSystId: Integer
    dateLastRain: Date
    buildDocs: BuildDocsEnum
    doorSize: QuantityValue
    doorCond: DoorCondEnum
    doorDirect: DoorDirectEnum
    doorLoc: DoorLocEnum
    doorMat: DoorMatEnum
    doorMove: DoorMoveEnum
    doorWaterMold: String
    doorType: DoorTypeEnum
    doorCompType: DoorCompTypeEnum
    doorTypeMetal: DoorTypeMetalEnum
    doorTypeWood: DoorTypeWoodEnum
    drawings: DrawingsEnum
    elevator: Integer
    escalator: Integer
    expDuct: QuantityValue
    expPipe: Integer
    extDoor: Integer
    fireplaceType: String
    floorAge: QuantityValue
    floorArea: QuantityValue
    floorCond: FloorCondEnum
    floorCount: Integer
    floorFinishMat: FloorFinishMatEnum
    floorWaterMold: FloorWaterMoldEnum
    floorStruc: FloorStrucEnum
    floorThermalMass: QuantityValue
    freqClean: FreqCleanEnum
    freqCook: Integer
    furniture: FurnitureEnum
    genderRestroom: GenderRestroomEnum
    hallCount: Integer
    handidness: HandidnessEnum
    heatDelivLoc: HeatDelivLocEnum
    heatSysDelivMeth: String
    heatSystemId: Integer
    heightCarperFiber: QuantityValue
    insideLux: QuantityValue
    intWallCond: IntWallCondEnum
    lastClean: Date
    maxOccup: Integer
    mechStruc: MechStrucEnum
    numberPlants: Integer
    numberPets: Integer
    numberResident: Integer
    occupDocument: OccupDocumentEnum
    extWallOrient: ExtWallOrientEnum
    extWindowOrient: ExtWindowOrientEnum
    relHumidityOut: QuantityValue
    presAnimalInsect: String
    quadPos: QuadPosEnum
    relSampLoc: RelSampLocEnum
    roomAirExchRate: QuantityValue
    roomArchitecElem: String
    roomCondt: RoomCondtEnum
    roomCount: Integer
    roomDim: String
    roomDoorDist: String
    roomLoc: RoomLocEnum
    roomMoistDamHist: Integer
    roomNetArea: String
    roomOccup: Integer
    roomSampPos: RoomSampPosEnum
    roomType: RoomTypeEnum
    roomVol: String
    roomWindowCount: Integer
    roomConnected: RoomConnectedEnum
    roomHallway: String
    roomDoorShare: String
    roomWallShare: String
    sampWeather: SampWeatherEnum
    sampFloor: SampFloorEnum
    sampRoomId: Integer
    sampTimeOut: Double
    season: String
    seasonUse: SeasonUseEnum
    shadingDeviceCond: ShadingDeviceCondEnum
    shadingDeviceLoc: String
    shadingDeviceMat: String
    shadDevWaterMold: String
    shadingDeviceType: ShadingDeviceTypeEnum
    specificHumidity: QuantityValue
    specific: SpecificEnum
    tempOut: QuantityValue
    trainLine: TrainLineEnum
    trainStatLoc: TrainStatLocEnum
    trainStopLoc: TrainStopLocEnum
    visMedia: VisMediaEnum
    wallArea: QuantityValue
    wallConstType: WallConstTypeEnum
    wallFinishMat: WallFinishMatEnum
    wallHeight: QuantityValue
    wallLoc: WallLocEnum
    wallWaterMold: String
    wallSurfTreatment: WallSurfTreatmentEnum
    wallTexture: WallTextureEnum
    wallThermalMass: QuantityValue
    waterFeatSize: QuantityValue
    waterFeatType: WaterFeatTypeEnum
    weekday: WeekdayEnum
    windowSize: String
    windowCond: WindowCondEnum
    windowCover: WindowCoverEnum
    windowHorizPos: WindowHorizPosEnum
    windowLoc: WindowLocEnum
    windowMat: WindowMatEnum
    windowOpenFreq: Integer
    windowWaterMold: String
    windowStatus: String
    windowType: WindowTypeEnum
    windowVertPos: WindowVertPosEnum
    sampName: String!
    projectName: String!
  }

type BuiltEnvironmentMIGSBacteria implements MIGSBacteria
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    surfMaterial: SurfMaterialEnum
    surfAirCont: [SurfAirContEnum]
    relAirHumidity: QuantityValue!
    absAirHumidity: QuantityValue!
    surfHumidity: QuantityValue
    temp: QuantityValue!
    surfTemp: QuantityValue
    surfMoisturePh: Double
    buildOccupType: [BuildOccupTypeEnum]!
    surfMoisture: QuantityValue
    dewPoint: QuantityValue
    carbDioxide: QuantityValue!
    ventilationType: String!
    organismCount: [OrganismCountEnum]!
    indoorSpace: IndoorSpaceEnum!
    indoorSurf: IndoorSurfEnum
    filterType: [FilterTypeEnum]!
    heatCoolType: [HeatCoolTypeEnum]!
    substructureType: [SubstructureTypeEnum]
    buildingSetting: BuildingSettingEnum!
    lightType: [LightTypeEnum]!
    sampSortMeth: [String]
    spaceTypState: String!
    typOccupDensity: Double!
    occupSamp: Integer!
    occupDensitySamp: Double!
    address: String
    adjRoom: String
    aeroStruc: String
    amountLight: QuantityValue
    archStruc: ArchStrucEnum
    avgOccup: Double
    avgDewPoint: QuantityValue
    avgTemp: QuantityValue
    bathroomCount: Integer
    bedroomCount: Integer
    builtStrucAge: QuantityValue
    builtStrucSet: String
    builtStrucType: String
    ceilArea: QuantityValue
    ceilCond: CeilCondEnum
    ceilFinishMat: CeilFinishMatEnum
    ceilWaterMold: String
    ceilStruc: String
    ceilTexture: CeilTextureEnum
    ceilThermalMass: QuantityValue
    ceilType: CeilTypeEnum
    coolSystId: Integer
    dateLastRain: Date
    buildDocs: BuildDocsEnum
    doorSize: QuantityValue
    doorCond: DoorCondEnum
    doorDirect: DoorDirectEnum
    doorLoc: DoorLocEnum
    doorMat: DoorMatEnum
    doorMove: DoorMoveEnum
    doorWaterMold: String
    doorType: DoorTypeEnum
    doorCompType: DoorCompTypeEnum
    doorTypeMetal: DoorTypeMetalEnum
    doorTypeWood: DoorTypeWoodEnum
    drawings: DrawingsEnum
    elevator: Integer
    escalator: Integer
    expDuct: QuantityValue
    expPipe: Integer
    extDoor: Integer
    fireplaceType: String
    floorAge: QuantityValue
    floorArea: QuantityValue
    floorCond: FloorCondEnum
    floorCount: Integer
    floorFinishMat: FloorFinishMatEnum
    floorWaterMold: FloorWaterMoldEnum
    floorStruc: FloorStrucEnum
    floorThermalMass: QuantityValue
    freqClean: FreqCleanEnum
    freqCook: Integer
    furniture: FurnitureEnum
    genderRestroom: GenderRestroomEnum
    hallCount: Integer
    handidness: HandidnessEnum
    heatDelivLoc: HeatDelivLocEnum
    heatSysDelivMeth: String
    heatSystemId: Integer
    heightCarperFiber: QuantityValue
    insideLux: QuantityValue
    intWallCond: IntWallCondEnum
    lastClean: Date
    maxOccup: Integer
    mechStruc: MechStrucEnum
    numberPlants: Integer
    numberPets: Integer
    numberResident: Integer
    occupDocument: OccupDocumentEnum
    extWallOrient: ExtWallOrientEnum
    extWindowOrient: ExtWindowOrientEnum
    relHumidityOut: QuantityValue
    presAnimalInsect: String
    quadPos: QuadPosEnum
    relSampLoc: RelSampLocEnum
    roomAirExchRate: QuantityValue
    roomArchitecElem: String
    roomCondt: RoomCondtEnum
    roomCount: Integer
    roomDim: String
    roomDoorDist: String
    roomLoc: RoomLocEnum
    roomMoistDamHist: Integer
    roomNetArea: String
    roomOccup: Integer
    roomSampPos: RoomSampPosEnum
    roomType: RoomTypeEnum
    roomVol: String
    roomWindowCount: Integer
    roomConnected: RoomConnectedEnum
    roomHallway: String
    roomDoorShare: String
    roomWallShare: String
    sampWeather: SampWeatherEnum
    sampFloor: SampFloorEnum
    sampRoomId: Integer
    sampTimeOut: Double
    season: String
    seasonUse: SeasonUseEnum
    shadingDeviceCond: ShadingDeviceCondEnum
    shadingDeviceLoc: String
    shadingDeviceMat: String
    shadDevWaterMold: String
    shadingDeviceType: ShadingDeviceTypeEnum
    specificHumidity: QuantityValue
    specific: SpecificEnum
    tempOut: QuantityValue
    trainLine: TrainLineEnum
    trainStatLoc: TrainStatLocEnum
    trainStopLoc: TrainStopLocEnum
    visMedia: VisMediaEnum
    wallArea: QuantityValue
    wallConstType: WallConstTypeEnum
    wallFinishMat: WallFinishMatEnum
    wallHeight: QuantityValue
    wallLoc: WallLocEnum
    wallWaterMold: String
    wallSurfTreatment: WallSurfTreatmentEnum
    wallTexture: WallTextureEnum
    wallThermalMass: QuantityValue
    waterFeatSize: QuantityValue
    waterFeatType: WaterFeatTypeEnum
    weekday: WeekdayEnum
    windowSize: String
    windowCond: WindowCondEnum
    windowCover: WindowCoverEnum
    windowHorizPos: WindowHorizPosEnum
    windowLoc: WindowLocEnum
    windowMat: WindowMatEnum
    windowOpenFreq: Integer
    windowWaterMold: String
    windowStatus: String
    windowType: WindowTypeEnum
    windowVertPos: WindowVertPosEnum
    sampName: String!
    projectName: String!
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer!
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String!
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    trophicLevel: TrophicLevelEnum
    encodedTraits: String
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    sampVolWeDnaExt: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type BuiltEnvironmentMIGSEukaryote implements MIGSEukaryote
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    surfMaterial: SurfMaterialEnum
    surfAirCont: [SurfAirContEnum]
    relAirHumidity: QuantityValue!
    absAirHumidity: QuantityValue!
    surfHumidity: QuantityValue
    temp: QuantityValue!
    surfTemp: QuantityValue
    surfMoisturePh: Double
    buildOccupType: [BuildOccupTypeEnum]!
    surfMoisture: QuantityValue
    dewPoint: QuantityValue
    carbDioxide: QuantityValue!
    ventilationType: String!
    organismCount: [OrganismCountEnum]!
    indoorSpace: IndoorSpaceEnum!
    indoorSurf: IndoorSurfEnum
    filterType: [FilterTypeEnum]!
    heatCoolType: [HeatCoolTypeEnum]!
    substructureType: [SubstructureTypeEnum]
    buildingSetting: BuildingSettingEnum!
    lightType: [LightTypeEnum]!
    sampSortMeth: [String]
    spaceTypState: String!
    typOccupDensity: Double!
    occupSamp: Integer!
    occupDensitySamp: Double!
    address: String
    adjRoom: String
    aeroStruc: String
    amountLight: QuantityValue
    archStruc: ArchStrucEnum
    avgOccup: Double
    avgDewPoint: QuantityValue
    avgTemp: QuantityValue
    bathroomCount: Integer
    bedroomCount: Integer
    builtStrucAge: QuantityValue
    builtStrucSet: String
    builtStrucType: String
    ceilArea: QuantityValue
    ceilCond: CeilCondEnum
    ceilFinishMat: CeilFinishMatEnum
    ceilWaterMold: String
    ceilStruc: String
    ceilTexture: CeilTextureEnum
    ceilThermalMass: QuantityValue
    ceilType: CeilTypeEnum
    coolSystId: Integer
    dateLastRain: Date
    buildDocs: BuildDocsEnum
    doorSize: QuantityValue
    doorCond: DoorCondEnum
    doorDirect: DoorDirectEnum
    doorLoc: DoorLocEnum
    doorMat: DoorMatEnum
    doorMove: DoorMoveEnum
    doorWaterMold: String
    doorType: DoorTypeEnum
    doorCompType: DoorCompTypeEnum
    doorTypeMetal: DoorTypeMetalEnum
    doorTypeWood: DoorTypeWoodEnum
    drawings: DrawingsEnum
    elevator: Integer
    escalator: Integer
    expDuct: QuantityValue
    expPipe: Integer
    extDoor: Integer
    fireplaceType: String
    floorAge: QuantityValue
    floorArea: QuantityValue
    floorCond: FloorCondEnum
    floorCount: Integer
    floorFinishMat: FloorFinishMatEnum
    floorWaterMold: FloorWaterMoldEnum
    floorStruc: FloorStrucEnum
    floorThermalMass: QuantityValue
    freqClean: FreqCleanEnum
    freqCook: Integer
    furniture: FurnitureEnum
    genderRestroom: GenderRestroomEnum
    hallCount: Integer
    handidness: HandidnessEnum
    heatDelivLoc: HeatDelivLocEnum
    heatSysDelivMeth: String
    heatSystemId: Integer
    heightCarperFiber: QuantityValue
    insideLux: QuantityValue
    intWallCond: IntWallCondEnum
    lastClean: Date
    maxOccup: Integer
    mechStruc: MechStrucEnum
    numberPlants: Integer
    numberPets: Integer
    numberResident: Integer
    occupDocument: OccupDocumentEnum
    extWallOrient: ExtWallOrientEnum
    extWindowOrient: ExtWindowOrientEnum
    relHumidityOut: QuantityValue
    presAnimalInsect: String
    quadPos: QuadPosEnum
    relSampLoc: RelSampLocEnum
    roomAirExchRate: QuantityValue
    roomArchitecElem: String
    roomCondt: RoomCondtEnum
    roomCount: Integer
    roomDim: String
    roomDoorDist: String
    roomLoc: RoomLocEnum
    roomMoistDamHist: Integer
    roomNetArea: String
    roomOccup: Integer
    roomSampPos: RoomSampPosEnum
    roomType: RoomTypeEnum
    roomVol: String
    roomWindowCount: Integer
    roomConnected: RoomConnectedEnum
    roomHallway: String
    roomDoorShare: String
    roomWallShare: String
    sampWeather: SampWeatherEnum
    sampFloor: SampFloorEnum
    sampRoomId: Integer
    sampTimeOut: Double
    season: String
    seasonUse: SeasonUseEnum
    shadingDeviceCond: ShadingDeviceCondEnum
    shadingDeviceLoc: String
    shadingDeviceMat: String
    shadDevWaterMold: String
    shadingDeviceType: ShadingDeviceTypeEnum
    specificHumidity: QuantityValue
    specific: SpecificEnum
    tempOut: QuantityValue
    trainLine: TrainLineEnum
    trainStatLoc: TrainStatLocEnum
    trainStopLoc: TrainStopLocEnum
    visMedia: VisMediaEnum
    wallArea: QuantityValue
    wallConstType: WallConstTypeEnum
    wallFinishMat: WallFinishMatEnum
    wallHeight: QuantityValue
    wallLoc: WallLocEnum
    wallWaterMold: String
    wallSurfTreatment: WallSurfTreatmentEnum
    wallTexture: WallTextureEnum
    wallThermalMass: QuantityValue
    waterFeatSize: QuantityValue
    waterFeatType: WaterFeatTypeEnum
    weekday: WeekdayEnum
    windowSize: String
    windowCond: WindowCondEnum
    windowCover: WindowCoverEnum
    windowHorizPos: WindowHorizPosEnum
    windowLoc: WindowLocEnum
    windowMat: WindowMatEnum
    windowOpenFreq: Integer
    windowWaterMold: String
    windowStatus: String
    windowType: WindowTypeEnum
    windowVertPos: WindowVertPosEnum
    sampName: String!
    projectName: String!
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    ploidy: String
    numReplicons: Integer
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    trophicLevel: TrophicLevelEnum
    propagation: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    sampVolWeDnaExt: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type BuiltEnvironmentMIGSOrg implements MIGSOrg
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    surfMaterial: SurfMaterialEnum
    surfAirCont: [SurfAirContEnum]
    relAirHumidity: QuantityValue!
    absAirHumidity: QuantityValue!
    surfHumidity: QuantityValue
    temp: QuantityValue!
    surfTemp: QuantityValue
    surfMoisturePh: Double
    buildOccupType: [BuildOccupTypeEnum]!
    surfMoisture: QuantityValue
    dewPoint: QuantityValue
    carbDioxide: QuantityValue!
    ventilationType: String!
    organismCount: [OrganismCountEnum]!
    indoorSpace: IndoorSpaceEnum!
    indoorSurf: IndoorSurfEnum
    filterType: [FilterTypeEnum]!
    heatCoolType: [HeatCoolTypeEnum]!
    substructureType: [SubstructureTypeEnum]
    buildingSetting: BuildingSettingEnum!
    lightType: [LightTypeEnum]!
    sampSortMeth: [String]
    spaceTypState: String!
    typOccupDensity: Double!
    occupSamp: Integer!
    occupDensitySamp: Double!
    address: String
    adjRoom: String
    aeroStruc: String
    amountLight: QuantityValue
    archStruc: ArchStrucEnum
    avgOccup: Double
    avgDewPoint: QuantityValue
    avgTemp: QuantityValue
    bathroomCount: Integer
    bedroomCount: Integer
    builtStrucAge: QuantityValue
    builtStrucSet: String
    builtStrucType: String
    ceilArea: QuantityValue
    ceilCond: CeilCondEnum
    ceilFinishMat: CeilFinishMatEnum
    ceilWaterMold: String
    ceilStruc: String
    ceilTexture: CeilTextureEnum
    ceilThermalMass: QuantityValue
    ceilType: CeilTypeEnum
    coolSystId: Integer
    dateLastRain: Date
    buildDocs: BuildDocsEnum
    doorSize: QuantityValue
    doorCond: DoorCondEnum
    doorDirect: DoorDirectEnum
    doorLoc: DoorLocEnum
    doorMat: DoorMatEnum
    doorMove: DoorMoveEnum
    doorWaterMold: String
    doorType: DoorTypeEnum
    doorCompType: DoorCompTypeEnum
    doorTypeMetal: DoorTypeMetalEnum
    doorTypeWood: DoorTypeWoodEnum
    drawings: DrawingsEnum
    elevator: Integer
    escalator: Integer
    expDuct: QuantityValue
    expPipe: Integer
    extDoor: Integer
    fireplaceType: String
    floorAge: QuantityValue
    floorArea: QuantityValue
    floorCond: FloorCondEnum
    floorCount: Integer
    floorFinishMat: FloorFinishMatEnum
    floorWaterMold: FloorWaterMoldEnum
    floorStruc: FloorStrucEnum
    floorThermalMass: QuantityValue
    freqClean: FreqCleanEnum
    freqCook: Integer
    furniture: FurnitureEnum
    genderRestroom: GenderRestroomEnum
    hallCount: Integer
    handidness: HandidnessEnum
    heatDelivLoc: HeatDelivLocEnum
    heatSysDelivMeth: String
    heatSystemId: Integer
    heightCarperFiber: QuantityValue
    insideLux: QuantityValue
    intWallCond: IntWallCondEnum
    lastClean: Date
    maxOccup: Integer
    mechStruc: MechStrucEnum
    numberPlants: Integer
    numberPets: Integer
    numberResident: Integer
    occupDocument: OccupDocumentEnum
    extWallOrient: ExtWallOrientEnum
    extWindowOrient: ExtWindowOrientEnum
    relHumidityOut: QuantityValue
    presAnimalInsect: String
    quadPos: QuadPosEnum
    relSampLoc: RelSampLocEnum
    roomAirExchRate: QuantityValue
    roomArchitecElem: String
    roomCondt: RoomCondtEnum
    roomCount: Integer
    roomDim: String
    roomDoorDist: String
    roomLoc: RoomLocEnum
    roomMoistDamHist: Integer
    roomNetArea: String
    roomOccup: Integer
    roomSampPos: RoomSampPosEnum
    roomType: RoomTypeEnum
    roomVol: String
    roomWindowCount: Integer
    roomConnected: RoomConnectedEnum
    roomHallway: String
    roomDoorShare: String
    roomWallShare: String
    sampWeather: SampWeatherEnum
    sampFloor: SampFloorEnum
    sampRoomId: Integer
    sampTimeOut: Double
    season: String
    seasonUse: SeasonUseEnum
    shadingDeviceCond: ShadingDeviceCondEnum
    shadingDeviceLoc: String
    shadingDeviceMat: String
    shadDevWaterMold: String
    shadingDeviceType: ShadingDeviceTypeEnum
    specificHumidity: QuantityValue
    specific: SpecificEnum
    tempOut: QuantityValue
    trainLine: TrainLineEnum
    trainStatLoc: TrainStatLocEnum
    trainStopLoc: TrainStopLocEnum
    visMedia: VisMediaEnum
    wallArea: QuantityValue
    wallConstType: WallConstTypeEnum
    wallFinishMat: WallFinishMatEnum
    wallHeight: QuantityValue
    wallLoc: WallLocEnum
    wallWaterMold: String
    wallSurfTreatment: WallSurfTreatmentEnum
    wallTexture: WallTextureEnum
    wallThermalMass: QuantityValue
    waterFeatSize: QuantityValue
    waterFeatType: WaterFeatTypeEnum
    weekday: WeekdayEnum
    windowSize: String
    windowCond: WindowCondEnum
    windowCover: WindowCoverEnum
    windowHorizPos: WindowHorizPosEnum
    windowLoc: WindowLocEnum
    windowMat: WindowMatEnum
    windowOpenFreq: Integer
    windowWaterMold: String
    windowStatus: String
    windowType: WindowTypeEnum
    windowVertPos: WindowVertPosEnum
    sampName: String!
    projectName: String!
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    sampVolWeDnaExt: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type BuiltEnvironmentMIGSPlant implements MIGSPlant
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    surfMaterial: SurfMaterialEnum
    surfAirCont: [SurfAirContEnum]
    relAirHumidity: QuantityValue!
    absAirHumidity: QuantityValue!
    surfHumidity: QuantityValue
    temp: QuantityValue!
    surfTemp: QuantityValue
    surfMoisturePh: Double
    buildOccupType: [BuildOccupTypeEnum]!
    surfMoisture: QuantityValue
    dewPoint: QuantityValue
    carbDioxide: QuantityValue!
    ventilationType: String!
    organismCount: [OrganismCountEnum]!
    indoorSpace: IndoorSpaceEnum!
    indoorSurf: IndoorSurfEnum
    filterType: [FilterTypeEnum]!
    heatCoolType: [HeatCoolTypeEnum]!
    substructureType: [SubstructureTypeEnum]
    buildingSetting: BuildingSettingEnum!
    lightType: [LightTypeEnum]!
    sampSortMeth: [String]
    spaceTypState: String!
    typOccupDensity: Double!
    occupSamp: Integer!
    occupDensitySamp: Double!
    address: String
    adjRoom: String
    aeroStruc: String
    amountLight: QuantityValue
    archStruc: ArchStrucEnum
    avgOccup: Double
    avgDewPoint: QuantityValue
    avgTemp: QuantityValue
    bathroomCount: Integer
    bedroomCount: Integer
    builtStrucAge: QuantityValue
    builtStrucSet: String
    builtStrucType: String
    ceilArea: QuantityValue
    ceilCond: CeilCondEnum
    ceilFinishMat: CeilFinishMatEnum
    ceilWaterMold: String
    ceilStruc: String
    ceilTexture: CeilTextureEnum
    ceilThermalMass: QuantityValue
    ceilType: CeilTypeEnum
    coolSystId: Integer
    dateLastRain: Date
    buildDocs: BuildDocsEnum
    doorSize: QuantityValue
    doorCond: DoorCondEnum
    doorDirect: DoorDirectEnum
    doorLoc: DoorLocEnum
    doorMat: DoorMatEnum
    doorMove: DoorMoveEnum
    doorWaterMold: String
    doorType: DoorTypeEnum
    doorCompType: DoorCompTypeEnum
    doorTypeMetal: DoorTypeMetalEnum
    doorTypeWood: DoorTypeWoodEnum
    drawings: DrawingsEnum
    elevator: Integer
    escalator: Integer
    expDuct: QuantityValue
    expPipe: Integer
    extDoor: Integer
    fireplaceType: String
    floorAge: QuantityValue
    floorArea: QuantityValue
    floorCond: FloorCondEnum
    floorCount: Integer
    floorFinishMat: FloorFinishMatEnum
    floorWaterMold: FloorWaterMoldEnum
    floorStruc: FloorStrucEnum
    floorThermalMass: QuantityValue
    freqClean: FreqCleanEnum
    freqCook: Integer
    furniture: FurnitureEnum
    genderRestroom: GenderRestroomEnum
    hallCount: Integer
    handidness: HandidnessEnum
    heatDelivLoc: HeatDelivLocEnum
    heatSysDelivMeth: String
    heatSystemId: Integer
    heightCarperFiber: QuantityValue
    insideLux: QuantityValue
    intWallCond: IntWallCondEnum
    lastClean: Date
    maxOccup: Integer
    mechStruc: MechStrucEnum
    numberPlants: Integer
    numberPets: Integer
    numberResident: Integer
    occupDocument: OccupDocumentEnum
    extWallOrient: ExtWallOrientEnum
    extWindowOrient: ExtWindowOrientEnum
    relHumidityOut: QuantityValue
    presAnimalInsect: String
    quadPos: QuadPosEnum
    relSampLoc: RelSampLocEnum
    roomAirExchRate: QuantityValue
    roomArchitecElem: String
    roomCondt: RoomCondtEnum
    roomCount: Integer
    roomDim: String
    roomDoorDist: String
    roomLoc: RoomLocEnum
    roomMoistDamHist: Integer
    roomNetArea: String
    roomOccup: Integer
    roomSampPos: RoomSampPosEnum
    roomType: RoomTypeEnum
    roomVol: String
    roomWindowCount: Integer
    roomConnected: RoomConnectedEnum
    roomHallway: String
    roomDoorShare: String
    roomWallShare: String
    sampWeather: SampWeatherEnum
    sampFloor: SampFloorEnum
    sampRoomId: Integer
    sampTimeOut: Double
    season: String
    seasonUse: SeasonUseEnum
    shadingDeviceCond: ShadingDeviceCondEnum
    shadingDeviceLoc: String
    shadingDeviceMat: String
    shadDevWaterMold: String
    shadingDeviceType: ShadingDeviceTypeEnum
    specificHumidity: QuantityValue
    specific: SpecificEnum
    tempOut: QuantityValue
    trainLine: TrainLineEnum
    trainStatLoc: TrainStatLocEnum
    trainStopLoc: TrainStopLocEnum
    visMedia: VisMediaEnum
    wallArea: QuantityValue
    wallConstType: WallConstTypeEnum
    wallFinishMat: WallFinishMatEnum
    wallHeight: QuantityValue
    wallLoc: WallLocEnum
    wallWaterMold: String
    wallSurfTreatment: WallSurfTreatmentEnum
    wallTexture: WallTextureEnum
    wallThermalMass: QuantityValue
    waterFeatSize: QuantityValue
    waterFeatType: WaterFeatTypeEnum
    weekday: WeekdayEnum
    windowSize: String
    windowCond: WindowCondEnum
    windowCover: WindowCoverEnum
    windowHorizPos: WindowHorizPosEnum
    windowLoc: WindowLocEnum
    windowMat: WindowMatEnum
    windowOpenFreq: Integer
    windowWaterMold: String
    windowStatus: String
    windowType: WindowTypeEnum
    windowVertPos: WindowVertPosEnum
    sampName: String!
    projectName: String!
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    specificHost: String
    hostSpecRange: Integer
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    sampVolWeDnaExt: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type BuiltEnvironmentMIGSVirus implements MIGSVirus
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    surfMaterial: SurfMaterialEnum
    surfAirCont: [SurfAirContEnum]
    relAirHumidity: QuantityValue!
    absAirHumidity: QuantityValue!
    surfHumidity: QuantityValue
    temp: QuantityValue!
    surfTemp: QuantityValue
    surfMoisturePh: Double
    buildOccupType: [BuildOccupTypeEnum]!
    surfMoisture: QuantityValue
    dewPoint: QuantityValue
    carbDioxide: QuantityValue!
    ventilationType: String!
    organismCount: [OrganismCountEnum]!
    indoorSpace: IndoorSpaceEnum!
    indoorSurf: IndoorSurfEnum
    filterType: [FilterTypeEnum]!
    heatCoolType: [HeatCoolTypeEnum]!
    substructureType: [SubstructureTypeEnum]
    buildingSetting: BuildingSettingEnum!
    lightType: [LightTypeEnum]!
    sampSortMeth: [String]
    spaceTypState: String!
    typOccupDensity: Double!
    occupSamp: Integer!
    occupDensitySamp: Double!
    address: String
    adjRoom: String
    aeroStruc: String
    amountLight: QuantityValue
    archStruc: ArchStrucEnum
    avgOccup: Double
    avgDewPoint: QuantityValue
    avgTemp: QuantityValue
    bathroomCount: Integer
    bedroomCount: Integer
    builtStrucAge: QuantityValue
    builtStrucSet: String
    builtStrucType: String
    ceilArea: QuantityValue
    ceilCond: CeilCondEnum
    ceilFinishMat: CeilFinishMatEnum
    ceilWaterMold: String
    ceilStruc: String
    ceilTexture: CeilTextureEnum
    ceilThermalMass: QuantityValue
    ceilType: CeilTypeEnum
    coolSystId: Integer
    dateLastRain: Date
    buildDocs: BuildDocsEnum
    doorSize: QuantityValue
    doorCond: DoorCondEnum
    doorDirect: DoorDirectEnum
    doorLoc: DoorLocEnum
    doorMat: DoorMatEnum
    doorMove: DoorMoveEnum
    doorWaterMold: String
    doorType: DoorTypeEnum
    doorCompType: DoorCompTypeEnum
    doorTypeMetal: DoorTypeMetalEnum
    doorTypeWood: DoorTypeWoodEnum
    drawings: DrawingsEnum
    elevator: Integer
    escalator: Integer
    expDuct: QuantityValue
    expPipe: Integer
    extDoor: Integer
    fireplaceType: String
    floorAge: QuantityValue
    floorArea: QuantityValue
    floorCond: FloorCondEnum
    floorCount: Integer
    floorFinishMat: FloorFinishMatEnum
    floorWaterMold: FloorWaterMoldEnum
    floorStruc: FloorStrucEnum
    floorThermalMass: QuantityValue
    freqClean: FreqCleanEnum
    freqCook: Integer
    furniture: FurnitureEnum
    genderRestroom: GenderRestroomEnum
    hallCount: Integer
    handidness: HandidnessEnum
    heatDelivLoc: HeatDelivLocEnum
    heatSysDelivMeth: String
    heatSystemId: Integer
    heightCarperFiber: QuantityValue
    insideLux: QuantityValue
    intWallCond: IntWallCondEnum
    lastClean: Date
    maxOccup: Integer
    mechStruc: MechStrucEnum
    numberPlants: Integer
    numberPets: Integer
    numberResident: Integer
    occupDocument: OccupDocumentEnum
    extWallOrient: ExtWallOrientEnum
    extWindowOrient: ExtWindowOrientEnum
    relHumidityOut: QuantityValue
    presAnimalInsect: String
    quadPos: QuadPosEnum
    relSampLoc: RelSampLocEnum
    roomAirExchRate: QuantityValue
    roomArchitecElem: String
    roomCondt: RoomCondtEnum
    roomCount: Integer
    roomDim: String
    roomDoorDist: String
    roomLoc: RoomLocEnum
    roomMoistDamHist: Integer
    roomNetArea: String
    roomOccup: Integer
    roomSampPos: RoomSampPosEnum
    roomType: RoomTypeEnum
    roomVol: String
    roomWindowCount: Integer
    roomConnected: RoomConnectedEnum
    roomHallway: String
    roomDoorShare: String
    roomWallShare: String
    sampWeather: SampWeatherEnum
    sampFloor: SampFloorEnum
    sampRoomId: Integer
    sampTimeOut: Double
    season: String
    seasonUse: SeasonUseEnum
    shadingDeviceCond: ShadingDeviceCondEnum
    shadingDeviceLoc: String
    shadingDeviceMat: String
    shadDevWaterMold: String
    shadingDeviceType: ShadingDeviceTypeEnum
    specificHumidity: QuantityValue
    specific: SpecificEnum
    tempOut: QuantityValue
    trainLine: TrainLineEnum
    trainStatLoc: TrainStatLocEnum
    trainStopLoc: TrainStopLocEnum
    visMedia: VisMediaEnum
    wallArea: QuantityValue
    wallConstType: WallConstTypeEnum
    wallFinishMat: WallFinishMatEnum
    wallHeight: QuantityValue
    wallLoc: WallLocEnum
    wallWaterMold: String
    wallSurfTreatment: WallSurfTreatmentEnum
    wallTexture: WallTextureEnum
    wallThermalMass: QuantityValue
    waterFeatSize: QuantityValue
    waterFeatType: WaterFeatTypeEnum
    weekday: WeekdayEnum
    windowSize: String
    windowCond: WindowCondEnum
    windowCover: WindowCoverEnum
    windowHorizPos: WindowHorizPosEnum
    windowLoc: WindowLocEnum
    windowMat: WindowMatEnum
    windowOpenFreq: Integer
    windowWaterMold: String
    windowStatus: String
    windowType: WindowTypeEnum
    windowVertPos: WindowVertPosEnum
    sampName: String!
    projectName: String!
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    sampVolWeDnaExt: QuantityValue
    virusEnrichAppr: VirusEnrichApprEnum
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type BuiltEnvironmentMIMAG implements MIMAG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    surfMaterial: SurfMaterialEnum
    surfAirCont: [SurfAirContEnum]
    relAirHumidity: QuantityValue!
    absAirHumidity: QuantityValue!
    surfHumidity: QuantityValue
    temp: QuantityValue!
    surfTemp: QuantityValue
    surfMoisturePh: Double
    buildOccupType: [BuildOccupTypeEnum]!
    surfMoisture: QuantityValue
    dewPoint: QuantityValue
    carbDioxide: QuantityValue!
    ventilationType: String!
    organismCount: [OrganismCountEnum]!
    indoorSpace: IndoorSpaceEnum!
    indoorSurf: IndoorSurfEnum
    filterType: [FilterTypeEnum]!
    heatCoolType: [HeatCoolTypeEnum]!
    substructureType: [SubstructureTypeEnum]
    buildingSetting: BuildingSettingEnum!
    lightType: [LightTypeEnum]!
    sampSortMeth: [String]
    spaceTypState: String!
    typOccupDensity: Double!
    occupSamp: Integer!
    occupDensitySamp: Double!
    address: String
    adjRoom: String
    aeroStruc: String
    amountLight: QuantityValue
    archStruc: ArchStrucEnum
    avgOccup: Double
    avgDewPoint: QuantityValue
    avgTemp: QuantityValue
    bathroomCount: Integer
    bedroomCount: Integer
    builtStrucAge: QuantityValue
    builtStrucSet: String
    builtStrucType: String
    ceilArea: QuantityValue
    ceilCond: CeilCondEnum
    ceilFinishMat: CeilFinishMatEnum
    ceilWaterMold: String
    ceilStruc: String
    ceilTexture: CeilTextureEnum
    ceilThermalMass: QuantityValue
    ceilType: CeilTypeEnum
    coolSystId: Integer
    dateLastRain: Date
    buildDocs: BuildDocsEnum
    doorSize: QuantityValue
    doorCond: DoorCondEnum
    doorDirect: DoorDirectEnum
    doorLoc: DoorLocEnum
    doorMat: DoorMatEnum
    doorMove: DoorMoveEnum
    doorWaterMold: String
    doorType: DoorTypeEnum
    doorCompType: DoorCompTypeEnum
    doorTypeMetal: DoorTypeMetalEnum
    doorTypeWood: DoorTypeWoodEnum
    drawings: DrawingsEnum
    elevator: Integer
    escalator: Integer
    expDuct: QuantityValue
    expPipe: Integer
    extDoor: Integer
    fireplaceType: String
    floorAge: QuantityValue
    floorArea: QuantityValue
    floorCond: FloorCondEnum
    floorCount: Integer
    floorFinishMat: FloorFinishMatEnum
    floorWaterMold: FloorWaterMoldEnum
    floorStruc: FloorStrucEnum
    floorThermalMass: QuantityValue
    freqClean: FreqCleanEnum
    freqCook: Integer
    furniture: FurnitureEnum
    genderRestroom: GenderRestroomEnum
    hallCount: Integer
    handidness: HandidnessEnum
    heatDelivLoc: HeatDelivLocEnum
    heatSysDelivMeth: String
    heatSystemId: Integer
    heightCarperFiber: QuantityValue
    insideLux: QuantityValue
    intWallCond: IntWallCondEnum
    lastClean: Date
    maxOccup: Integer
    mechStruc: MechStrucEnum
    numberPlants: Integer
    numberPets: Integer
    numberResident: Integer
    occupDocument: OccupDocumentEnum
    extWallOrient: ExtWallOrientEnum
    extWindowOrient: ExtWindowOrientEnum
    relHumidityOut: QuantityValue
    presAnimalInsect: String
    quadPos: QuadPosEnum
    relSampLoc: RelSampLocEnum
    roomAirExchRate: QuantityValue
    roomArchitecElem: String
    roomCondt: RoomCondtEnum
    roomCount: Integer
    roomDim: String
    roomDoorDist: String
    roomLoc: RoomLocEnum
    roomMoistDamHist: Integer
    roomNetArea: String
    roomOccup: Integer
    roomSampPos: RoomSampPosEnum
    roomType: RoomTypeEnum
    roomVol: String
    roomWindowCount: Integer
    roomConnected: RoomConnectedEnum
    roomHallway: String
    roomDoorShare: String
    roomWallShare: String
    sampWeather: SampWeatherEnum
    sampFloor: SampFloorEnum
    sampRoomId: Integer
    sampTimeOut: Double
    season: String
    seasonUse: SeasonUseEnum
    shadingDeviceCond: ShadingDeviceCondEnum
    shadingDeviceLoc: String
    shadingDeviceMat: String
    shadDevWaterMold: String
    shadingDeviceType: ShadingDeviceTypeEnum
    specificHumidity: QuantityValue
    specific: SpecificEnum
    tempOut: QuantityValue
    trainLine: TrainLineEnum
    trainStatLoc: TrainStatLocEnum
    trainStopLoc: TrainStopLocEnum
    visMedia: VisMediaEnum
    wallArea: QuantityValue
    wallConstType: WallConstTypeEnum
    wallFinishMat: WallFinishMatEnum
    wallHeight: QuantityValue
    wallLoc: WallLocEnum
    wallWaterMold: String
    wallSurfTreatment: WallSurfTreatmentEnum
    wallTexture: WallTextureEnum
    wallThermalMass: QuantityValue
    waterFeatSize: QuantityValue
    waterFeatType: WaterFeatTypeEnum
    weekday: WeekdayEnum
    windowSize: String
    windowCond: WindowCondEnum
    windowCover: WindowCoverEnum
    windowHorizPos: WindowHorizPosEnum
    windowLoc: WindowLocEnum
    windowMat: WindowMatEnum
    windowOpenFreq: Integer
    windowWaterMold: String
    windowStatus: String
    windowType: WindowTypeEnum
    windowVertPos: WindowVertPosEnum
    sampName: String!
    projectName: String!
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    sampVolWeDnaExt: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    binParam: BinParamEnum!
    binSoftware: String!
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    associatedResource: String
    sop: String
  }

type BuiltEnvironmentMIMARKSSpecimen implements MIMARKSSpecimen
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    surfMaterial: SurfMaterialEnum
    surfAirCont: [SurfAirContEnum]
    relAirHumidity: QuantityValue!
    absAirHumidity: QuantityValue!
    surfHumidity: QuantityValue
    temp: QuantityValue!
    surfTemp: QuantityValue
    surfMoisturePh: Double
    buildOccupType: [BuildOccupTypeEnum]!
    surfMoisture: QuantityValue
    dewPoint: QuantityValue
    carbDioxide: QuantityValue!
    ventilationType: String!
    organismCount: [OrganismCountEnum]!
    indoorSpace: IndoorSpaceEnum!
    indoorSurf: IndoorSurfEnum
    filterType: [FilterTypeEnum]!
    heatCoolType: [HeatCoolTypeEnum]!
    substructureType: [SubstructureTypeEnum]
    buildingSetting: BuildingSettingEnum!
    lightType: [LightTypeEnum]!
    sampSortMeth: [String]
    spaceTypState: String!
    typOccupDensity: Double!
    occupSamp: Integer!
    occupDensitySamp: Double!
    address: String
    adjRoom: String
    aeroStruc: String
    amountLight: QuantityValue
    archStruc: ArchStrucEnum
    avgOccup: Double
    avgDewPoint: QuantityValue
    avgTemp: QuantityValue
    bathroomCount: Integer
    bedroomCount: Integer
    builtStrucAge: QuantityValue
    builtStrucSet: String
    builtStrucType: String
    ceilArea: QuantityValue
    ceilCond: CeilCondEnum
    ceilFinishMat: CeilFinishMatEnum
    ceilWaterMold: String
    ceilStruc: String
    ceilTexture: CeilTextureEnum
    ceilThermalMass: QuantityValue
    ceilType: CeilTypeEnum
    coolSystId: Integer
    dateLastRain: Date
    buildDocs: BuildDocsEnum
    doorSize: QuantityValue
    doorCond: DoorCondEnum
    doorDirect: DoorDirectEnum
    doorLoc: DoorLocEnum
    doorMat: DoorMatEnum
    doorMove: DoorMoveEnum
    doorWaterMold: String
    doorType: DoorTypeEnum
    doorCompType: DoorCompTypeEnum
    doorTypeMetal: DoorTypeMetalEnum
    doorTypeWood: DoorTypeWoodEnum
    drawings: DrawingsEnum
    elevator: Integer
    escalator: Integer
    expDuct: QuantityValue
    expPipe: Integer
    extDoor: Integer
    fireplaceType: String
    floorAge: QuantityValue
    floorArea: QuantityValue
    floorCond: FloorCondEnum
    floorCount: Integer
    floorFinishMat: FloorFinishMatEnum
    floorWaterMold: FloorWaterMoldEnum
    floorStruc: FloorStrucEnum
    floorThermalMass: QuantityValue
    freqClean: FreqCleanEnum
    freqCook: Integer
    furniture: FurnitureEnum
    genderRestroom: GenderRestroomEnum
    hallCount: Integer
    handidness: HandidnessEnum
    heatDelivLoc: HeatDelivLocEnum
    heatSysDelivMeth: String
    heatSystemId: Integer
    heightCarperFiber: QuantityValue
    insideLux: QuantityValue
    intWallCond: IntWallCondEnum
    lastClean: Date
    maxOccup: Integer
    mechStruc: MechStrucEnum
    numberPlants: Integer
    numberPets: Integer
    numberResident: Integer
    occupDocument: OccupDocumentEnum
    extWallOrient: ExtWallOrientEnum
    extWindowOrient: ExtWindowOrientEnum
    relHumidityOut: QuantityValue
    presAnimalInsect: String
    quadPos: QuadPosEnum
    relSampLoc: RelSampLocEnum
    roomAirExchRate: QuantityValue
    roomArchitecElem: String
    roomCondt: RoomCondtEnum
    roomCount: Integer
    roomDim: String
    roomDoorDist: String
    roomLoc: RoomLocEnum
    roomMoistDamHist: Integer
    roomNetArea: String
    roomOccup: Integer
    roomSampPos: RoomSampPosEnum
    roomType: RoomTypeEnum
    roomVol: String
    roomWindowCount: Integer
    roomConnected: RoomConnectedEnum
    roomHallway: String
    roomDoorShare: String
    roomWallShare: String
    sampWeather: SampWeatherEnum
    sampFloor: SampFloorEnum
    sampRoomId: Integer
    sampTimeOut: Double
    season: String
    seasonUse: SeasonUseEnum
    shadingDeviceCond: ShadingDeviceCondEnum
    shadingDeviceLoc: String
    shadingDeviceMat: String
    shadDevWaterMold: String
    shadingDeviceType: ShadingDeviceTypeEnum
    specificHumidity: QuantityValue
    specific: SpecificEnum
    tempOut: QuantityValue
    trainLine: TrainLineEnum
    trainStatLoc: TrainStatLocEnum
    trainStopLoc: TrainStopLocEnum
    visMedia: VisMediaEnum
    wallArea: QuantityValue
    wallConstType: WallConstTypeEnum
    wallFinishMat: WallFinishMatEnum
    wallHeight: QuantityValue
    wallLoc: WallLocEnum
    wallWaterMold: String
    wallSurfTreatment: WallSurfTreatmentEnum
    wallTexture: WallTextureEnum
    wallThermalMass: QuantityValue
    waterFeatSize: QuantityValue
    waterFeatType: WaterFeatTypeEnum
    weekday: WeekdayEnum
    windowSize: String
    windowCond: WindowCondEnum
    windowCover: WindowCoverEnum
    windowHorizPos: WindowHorizPosEnum
    windowLoc: WindowLocEnum
    windowMat: WindowMatEnum
    windowOpenFreq: Integer
    windowWaterMold: String
    windowStatus: String
    windowType: WindowTypeEnum
    windowVertPos: WindowVertPosEnum
    sampName: String!
    projectName: String!
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    sampVolWeDnaExt: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    mid: String
    adapters: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    assemblySoftware: String
    associatedResource: String
    sop: String
  }

type BuiltEnvironmentMIMARKSSurvey implements MIMARKSSurvey
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    surfMaterial: SurfMaterialEnum
    surfAirCont: [SurfAirContEnum]
    relAirHumidity: QuantityValue!
    absAirHumidity: QuantityValue!
    surfHumidity: QuantityValue
    temp: QuantityValue!
    surfTemp: QuantityValue
    surfMoisturePh: Double
    buildOccupType: [BuildOccupTypeEnum]!
    surfMoisture: QuantityValue
    dewPoint: QuantityValue
    carbDioxide: QuantityValue!
    ventilationType: String!
    organismCount: [OrganismCountEnum]!
    indoorSpace: IndoorSpaceEnum!
    indoorSurf: IndoorSurfEnum
    filterType: [FilterTypeEnum]!
    heatCoolType: [HeatCoolTypeEnum]!
    substructureType: [SubstructureTypeEnum]
    buildingSetting: BuildingSettingEnum!
    lightType: [LightTypeEnum]!
    sampSortMeth: [String]
    spaceTypState: String!
    typOccupDensity: Double!
    occupSamp: Integer!
    occupDensitySamp: Double!
    address: String
    adjRoom: String
    aeroStruc: String
    amountLight: QuantityValue
    archStruc: ArchStrucEnum
    avgOccup: Double
    avgDewPoint: QuantityValue
    avgTemp: QuantityValue
    bathroomCount: Integer
    bedroomCount: Integer
    builtStrucAge: QuantityValue
    builtStrucSet: String
    builtStrucType: String
    ceilArea: QuantityValue
    ceilCond: CeilCondEnum
    ceilFinishMat: CeilFinishMatEnum
    ceilWaterMold: String
    ceilStruc: String
    ceilTexture: CeilTextureEnum
    ceilThermalMass: QuantityValue
    ceilType: CeilTypeEnum
    coolSystId: Integer
    dateLastRain: Date
    buildDocs: BuildDocsEnum
    doorSize: QuantityValue
    doorCond: DoorCondEnum
    doorDirect: DoorDirectEnum
    doorLoc: DoorLocEnum
    doorMat: DoorMatEnum
    doorMove: DoorMoveEnum
    doorWaterMold: String
    doorType: DoorTypeEnum
    doorCompType: DoorCompTypeEnum
    doorTypeMetal: DoorTypeMetalEnum
    doorTypeWood: DoorTypeWoodEnum
    drawings: DrawingsEnum
    elevator: Integer
    escalator: Integer
    expDuct: QuantityValue
    expPipe: Integer
    extDoor: Integer
    fireplaceType: String
    floorAge: QuantityValue
    floorArea: QuantityValue
    floorCond: FloorCondEnum
    floorCount: Integer
    floorFinishMat: FloorFinishMatEnum
    floorWaterMold: FloorWaterMoldEnum
    floorStruc: FloorStrucEnum
    floorThermalMass: QuantityValue
    freqClean: FreqCleanEnum
    freqCook: Integer
    furniture: FurnitureEnum
    genderRestroom: GenderRestroomEnum
    hallCount: Integer
    handidness: HandidnessEnum
    heatDelivLoc: HeatDelivLocEnum
    heatSysDelivMeth: String
    heatSystemId: Integer
    heightCarperFiber: QuantityValue
    insideLux: QuantityValue
    intWallCond: IntWallCondEnum
    lastClean: Date
    maxOccup: Integer
    mechStruc: MechStrucEnum
    numberPlants: Integer
    numberPets: Integer
    numberResident: Integer
    occupDocument: OccupDocumentEnum
    extWallOrient: ExtWallOrientEnum
    extWindowOrient: ExtWindowOrientEnum
    relHumidityOut: QuantityValue
    presAnimalInsect: String
    quadPos: QuadPosEnum
    relSampLoc: RelSampLocEnum
    roomAirExchRate: QuantityValue
    roomArchitecElem: String
    roomCondt: RoomCondtEnum
    roomCount: Integer
    roomDim: String
    roomDoorDist: String
    roomLoc: RoomLocEnum
    roomMoistDamHist: Integer
    roomNetArea: String
    roomOccup: Integer
    roomSampPos: RoomSampPosEnum
    roomType: RoomTypeEnum
    roomVol: String
    roomWindowCount: Integer
    roomConnected: RoomConnectedEnum
    roomHallway: String
    roomDoorShare: String
    roomWallShare: String
    sampWeather: SampWeatherEnum
    sampFloor: SampFloorEnum
    sampRoomId: Integer
    sampTimeOut: Double
    season: String
    seasonUse: SeasonUseEnum
    shadingDeviceCond: ShadingDeviceCondEnum
    shadingDeviceLoc: String
    shadingDeviceMat: String
    shadDevWaterMold: String
    shadingDeviceType: ShadingDeviceTypeEnum
    specificHumidity: QuantityValue
    specific: SpecificEnum
    tempOut: QuantityValue
    trainLine: TrainLineEnum
    trainStatLoc: TrainStatLocEnum
    trainStopLoc: TrainStopLocEnum
    visMedia: VisMediaEnum
    wallArea: QuantityValue
    wallConstType: WallConstTypeEnum
    wallFinishMat: WallFinishMatEnum
    wallHeight: QuantityValue
    wallLoc: WallLocEnum
    wallWaterMold: String
    wallSurfTreatment: WallSurfTreatmentEnum
    wallTexture: WallTextureEnum
    wallThermalMass: QuantityValue
    waterFeatSize: QuantityValue
    waterFeatType: WaterFeatTypeEnum
    weekday: WeekdayEnum
    windowSize: String
    windowCond: WindowCondEnum
    windowCover: WindowCoverEnum
    windowHorizPos: WindowHorizPosEnum
    windowLoc: WindowLocEnum
    windowMat: WindowMatEnum
    windowOpenFreq: Integer
    windowWaterMold: String
    windowStatus: String
    windowType: WindowTypeEnum
    windowVertPos: WindowVertPosEnum
    sampName: String!
    projectName: String!
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    sourceMatId: String
    bioticRelationship: BioticRelationshipEnum
    trophicLevel: TrophicLevelEnum
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    sampVolWeDnaExt: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    associatedResource: String
    sop: String
  }

type BuiltEnvironmentMIMS implements MIMS
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    surfMaterial: SurfMaterialEnum
    surfAirCont: [SurfAirContEnum]
    relAirHumidity: QuantityValue!
    absAirHumidity: QuantityValue!
    surfHumidity: QuantityValue
    temp: QuantityValue!
    surfTemp: QuantityValue
    surfMoisturePh: Double
    buildOccupType: [BuildOccupTypeEnum]!
    surfMoisture: QuantityValue
    dewPoint: QuantityValue
    carbDioxide: QuantityValue!
    ventilationType: String!
    organismCount: [OrganismCountEnum]!
    indoorSpace: IndoorSpaceEnum!
    indoorSurf: IndoorSurfEnum
    filterType: [FilterTypeEnum]!
    heatCoolType: [HeatCoolTypeEnum]!
    substructureType: [SubstructureTypeEnum]
    buildingSetting: BuildingSettingEnum!
    lightType: [LightTypeEnum]!
    sampSortMeth: [String]
    spaceTypState: String!
    typOccupDensity: Double!
    occupSamp: Integer!
    occupDensitySamp: Double!
    address: String
    adjRoom: String
    aeroStruc: String
    amountLight: QuantityValue
    archStruc: ArchStrucEnum
    avgOccup: Double
    avgDewPoint: QuantityValue
    avgTemp: QuantityValue
    bathroomCount: Integer
    bedroomCount: Integer
    builtStrucAge: QuantityValue
    builtStrucSet: String
    builtStrucType: String
    ceilArea: QuantityValue
    ceilCond: CeilCondEnum
    ceilFinishMat: CeilFinishMatEnum
    ceilWaterMold: String
    ceilStruc: String
    ceilTexture: CeilTextureEnum
    ceilThermalMass: QuantityValue
    ceilType: CeilTypeEnum
    coolSystId: Integer
    dateLastRain: Date
    buildDocs: BuildDocsEnum
    doorSize: QuantityValue
    doorCond: DoorCondEnum
    doorDirect: DoorDirectEnum
    doorLoc: DoorLocEnum
    doorMat: DoorMatEnum
    doorMove: DoorMoveEnum
    doorWaterMold: String
    doorType: DoorTypeEnum
    doorCompType: DoorCompTypeEnum
    doorTypeMetal: DoorTypeMetalEnum
    doorTypeWood: DoorTypeWoodEnum
    drawings: DrawingsEnum
    elevator: Integer
    escalator: Integer
    expDuct: QuantityValue
    expPipe: Integer
    extDoor: Integer
    fireplaceType: String
    floorAge: QuantityValue
    floorArea: QuantityValue
    floorCond: FloorCondEnum
    floorCount: Integer
    floorFinishMat: FloorFinishMatEnum
    floorWaterMold: FloorWaterMoldEnum
    floorStruc: FloorStrucEnum
    floorThermalMass: QuantityValue
    freqClean: FreqCleanEnum
    freqCook: Integer
    furniture: FurnitureEnum
    genderRestroom: GenderRestroomEnum
    hallCount: Integer
    handidness: HandidnessEnum
    heatDelivLoc: HeatDelivLocEnum
    heatSysDelivMeth: String
    heatSystemId: Integer
    heightCarperFiber: QuantityValue
    insideLux: QuantityValue
    intWallCond: IntWallCondEnum
    lastClean: Date
    maxOccup: Integer
    mechStruc: MechStrucEnum
    numberPlants: Integer
    numberPets: Integer
    numberResident: Integer
    occupDocument: OccupDocumentEnum
    extWallOrient: ExtWallOrientEnum
    extWindowOrient: ExtWindowOrientEnum
    relHumidityOut: QuantityValue
    presAnimalInsect: String
    quadPos: QuadPosEnum
    relSampLoc: RelSampLocEnum
    roomAirExchRate: QuantityValue
    roomArchitecElem: String
    roomCondt: RoomCondtEnum
    roomCount: Integer
    roomDim: String
    roomDoorDist: String
    roomLoc: RoomLocEnum
    roomMoistDamHist: Integer
    roomNetArea: String
    roomOccup: Integer
    roomSampPos: RoomSampPosEnum
    roomType: RoomTypeEnum
    roomVol: String
    roomWindowCount: Integer
    roomConnected: RoomConnectedEnum
    roomHallway: String
    roomDoorShare: String
    roomWallShare: String
    sampWeather: SampWeatherEnum
    sampFloor: SampFloorEnum
    sampRoomId: Integer
    sampTimeOut: Double
    season: String
    seasonUse: SeasonUseEnum
    shadingDeviceCond: ShadingDeviceCondEnum
    shadingDeviceLoc: String
    shadingDeviceMat: String
    shadDevWaterMold: String
    shadingDeviceType: ShadingDeviceTypeEnum
    specificHumidity: QuantityValue
    specific: SpecificEnum
    tempOut: QuantityValue
    trainLine: TrainLineEnum
    trainStatLoc: TrainStatLocEnum
    trainStopLoc: TrainStopLocEnum
    visMedia: VisMediaEnum
    wallArea: QuantityValue
    wallConstType: WallConstTypeEnum
    wallFinishMat: WallFinishMatEnum
    wallHeight: QuantityValue
    wallLoc: WallLocEnum
    wallWaterMold: String
    wallSurfTreatment: WallSurfTreatmentEnum
    wallTexture: WallTextureEnum
    wallThermalMass: QuantityValue
    waterFeatSize: QuantityValue
    waterFeatType: WaterFeatTypeEnum
    weekday: WeekdayEnum
    windowSize: String
    windowCond: WindowCondEnum
    windowCover: WindowCoverEnum
    windowHorizPos: WindowHorizPosEnum
    windowLoc: WindowLocEnum
    windowMat: WindowMatEnum
    windowOpenFreq: Integer
    windowWaterMold: String
    windowStatus: String
    windowType: WindowTypeEnum
    windowVertPos: WindowVertPosEnum
    sampName: String!
    projectName: String!
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    sampVolWeDnaExt: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    associatedResource: String
    sop: String
  }

type BuiltEnvironmentMISAG implements MISAG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    surfMaterial: SurfMaterialEnum
    surfAirCont: [SurfAirContEnum]
    relAirHumidity: QuantityValue!
    absAirHumidity: QuantityValue!
    surfHumidity: QuantityValue
    temp: QuantityValue!
    surfTemp: QuantityValue
    surfMoisturePh: Double
    buildOccupType: [BuildOccupTypeEnum]!
    surfMoisture: QuantityValue
    dewPoint: QuantityValue
    carbDioxide: QuantityValue!
    ventilationType: String!
    organismCount: [OrganismCountEnum]!
    indoorSpace: IndoorSpaceEnum!
    indoorSurf: IndoorSurfEnum
    filterType: [FilterTypeEnum]!
    heatCoolType: [HeatCoolTypeEnum]!
    substructureType: [SubstructureTypeEnum]
    buildingSetting: BuildingSettingEnum!
    lightType: [LightTypeEnum]!
    sampSortMeth: [String]
    spaceTypState: String!
    typOccupDensity: Double!
    occupSamp: Integer!
    occupDensitySamp: Double!
    address: String
    adjRoom: String
    aeroStruc: String
    amountLight: QuantityValue
    archStruc: ArchStrucEnum
    avgOccup: Double
    avgDewPoint: QuantityValue
    avgTemp: QuantityValue
    bathroomCount: Integer
    bedroomCount: Integer
    builtStrucAge: QuantityValue
    builtStrucSet: String
    builtStrucType: String
    ceilArea: QuantityValue
    ceilCond: CeilCondEnum
    ceilFinishMat: CeilFinishMatEnum
    ceilWaterMold: String
    ceilStruc: String
    ceilTexture: CeilTextureEnum
    ceilThermalMass: QuantityValue
    ceilType: CeilTypeEnum
    coolSystId: Integer
    dateLastRain: Date
    buildDocs: BuildDocsEnum
    doorSize: QuantityValue
    doorCond: DoorCondEnum
    doorDirect: DoorDirectEnum
    doorLoc: DoorLocEnum
    doorMat: DoorMatEnum
    doorMove: DoorMoveEnum
    doorWaterMold: String
    doorType: DoorTypeEnum
    doorCompType: DoorCompTypeEnum
    doorTypeMetal: DoorTypeMetalEnum
    doorTypeWood: DoorTypeWoodEnum
    drawings: DrawingsEnum
    elevator: Integer
    escalator: Integer
    expDuct: QuantityValue
    expPipe: Integer
    extDoor: Integer
    fireplaceType: String
    floorAge: QuantityValue
    floorArea: QuantityValue
    floorCond: FloorCondEnum
    floorCount: Integer
    floorFinishMat: FloorFinishMatEnum
    floorWaterMold: FloorWaterMoldEnum
    floorStruc: FloorStrucEnum
    floorThermalMass: QuantityValue
    freqClean: FreqCleanEnum
    freqCook: Integer
    furniture: FurnitureEnum
    genderRestroom: GenderRestroomEnum
    hallCount: Integer
    handidness: HandidnessEnum
    heatDelivLoc: HeatDelivLocEnum
    heatSysDelivMeth: String
    heatSystemId: Integer
    heightCarperFiber: QuantityValue
    insideLux: QuantityValue
    intWallCond: IntWallCondEnum
    lastClean: Date
    maxOccup: Integer
    mechStruc: MechStrucEnum
    numberPlants: Integer
    numberPets: Integer
    numberResident: Integer
    occupDocument: OccupDocumentEnum
    extWallOrient: ExtWallOrientEnum
    extWindowOrient: ExtWindowOrientEnum
    relHumidityOut: QuantityValue
    presAnimalInsect: String
    quadPos: QuadPosEnum
    relSampLoc: RelSampLocEnum
    roomAirExchRate: QuantityValue
    roomArchitecElem: String
    roomCondt: RoomCondtEnum
    roomCount: Integer
    roomDim: String
    roomDoorDist: String
    roomLoc: RoomLocEnum
    roomMoistDamHist: Integer
    roomNetArea: String
    roomOccup: Integer
    roomSampPos: RoomSampPosEnum
    roomType: RoomTypeEnum
    roomVol: String
    roomWindowCount: Integer
    roomConnected: RoomConnectedEnum
    roomHallway: String
    roomDoorShare: String
    roomWallShare: String
    sampWeather: SampWeatherEnum
    sampFloor: SampFloorEnum
    sampRoomId: Integer
    sampTimeOut: Double
    season: String
    seasonUse: SeasonUseEnum
    shadingDeviceCond: ShadingDeviceCondEnum
    shadingDeviceLoc: String
    shadingDeviceMat: String
    shadDevWaterMold: String
    shadingDeviceType: ShadingDeviceTypeEnum
    specificHumidity: QuantityValue
    specific: SpecificEnum
    tempOut: QuantityValue
    trainLine: TrainLineEnum
    trainStatLoc: TrainStatLocEnum
    trainStopLoc: TrainStopLocEnum
    visMedia: VisMediaEnum
    wallArea: QuantityValue
    wallConstType: WallConstTypeEnum
    wallFinishMat: WallFinishMatEnum
    wallHeight: QuantityValue
    wallLoc: WallLocEnum
    wallWaterMold: String
    wallSurfTreatment: WallSurfTreatmentEnum
    wallTexture: WallTextureEnum
    wallThermalMass: QuantityValue
    waterFeatSize: QuantityValue
    waterFeatType: WaterFeatTypeEnum
    weekday: WeekdayEnum
    windowSize: String
    windowCond: WindowCondEnum
    windowCover: WindowCoverEnum
    windowHorizPos: WindowHorizPosEnum
    windowLoc: WindowLocEnum
    windowMat: WindowMatEnum
    windowOpenFreq: Integer
    windowWaterMold: String
    windowStatus: String
    windowType: WindowTypeEnum
    windowVertPos: WindowVertPosEnum
    sampName: String!
    projectName: String!
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    sampVolWeDnaExt: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    sortTech: SortTechEnum!
    singleCellLysisAppr: SingleCellLysisApprEnum!
    singleCellLysisProt: String
    wgaAmpAppr: String!
    wgaAmpKit: String
    associatedResource: String
    sop: String
  }

type BuiltEnvironmentMIUVIG implements MIUVIG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    surfMaterial: SurfMaterialEnum
    surfAirCont: [SurfAirContEnum]
    relAirHumidity: QuantityValue!
    absAirHumidity: QuantityValue!
    surfHumidity: QuantityValue
    temp: QuantityValue!
    surfTemp: QuantityValue
    surfMoisturePh: Double
    buildOccupType: [BuildOccupTypeEnum]!
    surfMoisture: QuantityValue
    dewPoint: QuantityValue
    carbDioxide: QuantityValue!
    ventilationType: String!
    organismCount: [OrganismCountEnum]!
    indoorSpace: IndoorSpaceEnum!
    indoorSurf: IndoorSurfEnum
    filterType: [FilterTypeEnum]!
    heatCoolType: [HeatCoolTypeEnum]!
    substructureType: [SubstructureTypeEnum]
    buildingSetting: BuildingSettingEnum!
    lightType: [LightTypeEnum]!
    sampSortMeth: [String]
    spaceTypState: String!
    typOccupDensity: Double!
    occupSamp: Integer!
    occupDensitySamp: Double!
    address: String
    adjRoom: String
    aeroStruc: String
    amountLight: QuantityValue
    archStruc: ArchStrucEnum
    avgOccup: Double
    avgDewPoint: QuantityValue
    avgTemp: QuantityValue
    bathroomCount: Integer
    bedroomCount: Integer
    builtStrucAge: QuantityValue
    builtStrucSet: String
    builtStrucType: String
    ceilArea: QuantityValue
    ceilCond: CeilCondEnum
    ceilFinishMat: CeilFinishMatEnum
    ceilWaterMold: String
    ceilStruc: String
    ceilTexture: CeilTextureEnum
    ceilThermalMass: QuantityValue
    ceilType: CeilTypeEnum
    coolSystId: Integer
    dateLastRain: Date
    buildDocs: BuildDocsEnum
    doorSize: QuantityValue
    doorCond: DoorCondEnum
    doorDirect: DoorDirectEnum
    doorLoc: DoorLocEnum
    doorMat: DoorMatEnum
    doorMove: DoorMoveEnum
    doorWaterMold: String
    doorType: DoorTypeEnum
    doorCompType: DoorCompTypeEnum
    doorTypeMetal: DoorTypeMetalEnum
    doorTypeWood: DoorTypeWoodEnum
    drawings: DrawingsEnum
    elevator: Integer
    escalator: Integer
    expDuct: QuantityValue
    expPipe: Integer
    extDoor: Integer
    fireplaceType: String
    floorAge: QuantityValue
    floorArea: QuantityValue
    floorCond: FloorCondEnum
    floorCount: Integer
    floorFinishMat: FloorFinishMatEnum
    floorWaterMold: FloorWaterMoldEnum
    floorStruc: FloorStrucEnum
    floorThermalMass: QuantityValue
    freqClean: FreqCleanEnum
    freqCook: Integer
    furniture: FurnitureEnum
    genderRestroom: GenderRestroomEnum
    hallCount: Integer
    handidness: HandidnessEnum
    heatDelivLoc: HeatDelivLocEnum
    heatSysDelivMeth: String
    heatSystemId: Integer
    heightCarperFiber: QuantityValue
    insideLux: QuantityValue
    intWallCond: IntWallCondEnum
    lastClean: Date
    maxOccup: Integer
    mechStruc: MechStrucEnum
    numberPlants: Integer
    numberPets: Integer
    numberResident: Integer
    occupDocument: OccupDocumentEnum
    extWallOrient: ExtWallOrientEnum
    extWindowOrient: ExtWindowOrientEnum
    relHumidityOut: QuantityValue
    presAnimalInsect: String
    quadPos: QuadPosEnum
    relSampLoc: RelSampLocEnum
    roomAirExchRate: QuantityValue
    roomArchitecElem: String
    roomCondt: RoomCondtEnum
    roomCount: Integer
    roomDim: String
    roomDoorDist: String
    roomLoc: RoomLocEnum
    roomMoistDamHist: Integer
    roomNetArea: String
    roomOccup: Integer
    roomSampPos: RoomSampPosEnum
    roomType: RoomTypeEnum
    roomVol: String
    roomWindowCount: Integer
    roomConnected: RoomConnectedEnum
    roomHallway: String
    roomDoorShare: String
    roomWallShare: String
    sampWeather: SampWeatherEnum
    sampFloor: SampFloorEnum
    sampRoomId: Integer
    sampTimeOut: Double
    season: String
    seasonUse: SeasonUseEnum
    shadingDeviceCond: ShadingDeviceCondEnum
    shadingDeviceLoc: String
    shadingDeviceMat: String
    shadDevWaterMold: String
    shadingDeviceType: ShadingDeviceTypeEnum
    specificHumidity: QuantityValue
    specific: SpecificEnum
    tempOut: QuantityValue
    trainLine: TrainLineEnum
    trainStatLoc: TrainStatLocEnum
    trainStopLoc: TrainStopLocEnum
    visMedia: VisMediaEnum
    wallArea: QuantityValue
    wallConstType: WallConstTypeEnum
    wallFinishMat: WallFinishMatEnum
    wallHeight: QuantityValue
    wallLoc: WallLocEnum
    wallWaterMold: String
    wallSurfTreatment: WallSurfTreatmentEnum
    wallTexture: WallTextureEnum
    wallThermalMass: QuantityValue
    waterFeatSize: QuantityValue
    waterFeatType: WaterFeatTypeEnum
    weekday: WeekdayEnum
    windowSize: String
    windowCond: WindowCondEnum
    windowCover: WindowCoverEnum
    windowHorizPos: WindowHorizPosEnum
    windowLoc: WindowLocEnum
    windowMat: WindowMatEnum
    windowOpenFreq: Integer
    windowWaterMold: String
    windowStatus: String
    windowType: WindowTypeEnum
    windowVertPos: WindowVertPosEnum
    sampName: String!
    projectName: String!
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    sampVolWeDnaExt: QuantityValue
    sourceUvig: SourceUvigEnum!
    virusEnrichAppr: VirusEnrichApprEnum!
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String
    complSoftware: String
    complAppr: ComplApprEnum
    sortTech: SortTechEnum
    singleCellLysisAppr: SingleCellLysisApprEnum
    singleCellLysisProt: String
    wgaAmpAppr: String
    wgaAmpKit: String
    binParam: BinParamEnum
    binSoftware: String
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    virIdentSoftware: String!
    predGenomeType: PredGenomeTypeEnum!
    predGenomeStruc: PredGenomeStrucEnum!
    detecType: String!
    otuClassAppr: String
    otuSeqCompAppr: String
    otuDb: String
    hostPredAppr: HostPredApprEnum
    hostPredEstAcc: String
    associatedResource: String
    sop: String
  }

type Core
  {
    sampName: String
    sampTaxonId: String
    projectName: String
    experimentalFactor: String
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    negContType: NegContTypeEnum
    posContType: String
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    subspecfGenLin: String
    ploidy: String
    numReplicons: Integer
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    trophicLevel: TrophicLevelEnum
    propagation: String
    encodedTraits: String
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    sampVolWeDnaExt: QuantityValue
    sourceUvig: SourceUvigEnum
    virusEnrichAppr: VirusEnrichApprEnum
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    targetGene: String
    targetSubfragment: String
    pcrPrimers: String
    mid: String
    adapters: String
    pcrCond: String
    seqMeth: String
    seqQualityCheck: String
    chimeraCheck: String
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String
    complSoftware: String
    complAppr: ComplApprEnum
    contamScore: String
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    sortTech: SortTechEnum
    singleCellLysisAppr: SingleCellLysisApprEnum
    singleCellLysisProt: String
    wgaAmpAppr: String
    wgaAmpKit: String
    binParam: BinParamEnum
    binSoftware: String
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    virIdentSoftware: String
    predGenomeType: PredGenomeTypeEnum
    predGenomeStruc: PredGenomeStrucEnum
    detecType: String
    otuClassAppr: String
    otuSeqCompAppr: String
    otuDb: String
    hostPredAppr: HostPredApprEnum
    hostPredEstAcc: String
    associatedResource: String
    sop: String
  }

type Food-animalAndAnimalFeed
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    sampStorDur: String
    poolDnaExtracts: String
    sampStorLoc: String
    sampTransportCont: SampTransportContEnum
    perturbation: [String]
    collSiteGeoFeat: String!
    foodOrigin: String!
    foodProd: [String]!
    foodProductType: [String]!
    foodSource: String
    iFSACCategory: [String]!
    intendedConsumer: [String]!
    sampPurpose: String!
    animalAm: String
    animalAmDur: String
    animalAmFreq: QuantityValue
    animalAmRoute: String
    animalAmUse: String
    animalBodyCond: AnimalBodyCondEnum
    animalDiet: [String]
    animalFeedEquip: [String]
    animalGroupSize: Integer
    animalHousing: [String]
    animalSex: AnimalSexEnum
    bacterialDensity: QuantityValue
    consFoodStorDur: String
    consFoodStorTemp: String
    consPurchDate: Date
    consQtyPurchased: String
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    enrichmentProtocol: String
    foodAdditive: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodCookingProc: [String]
    foodDisPoint: [String]
    foodDisPointCity: String
    foodIngredient: [String]
    foodPackCapacity: QuantityValue
    foodPackIntegrity: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodPriorContact: [String]
    foodProdSynonym: [String]
    foodProductQual: String
    foodQualityDate: String
    foodSourceAge: QuantityValue
    foodTraceList: FoodTraceListEnum
    foodTravMode: [String]
    foodTravVehic: [String]
    foodTreatProc: [String]
    hACCPTerm: [String]
    libraryPrepKit: String
    lotNumber: [String]
    microbCultMed: String
    partPlantAnimal: [String]
    repositoryName: [String]
    sampCollectMethod: String
    sampPooling: [String]
    sampRepBiol: QuantityValue
    sampRepTech: QuantityValue
    sampSourceMatCat: String
    sampStorDevice: String
    sampStorMedia: String
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    spikeinAMR: [String]
    spikeinAntibiotic: [String]
    spikeinGrowthMed: [String]
    spikeinMetal: [String]
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinStrain: [String]
    studyDesign: [String]
    studyIncDur: QuantityValue
    studyIncTemp: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    timepoint: Double
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
  }

type Food-animalAndAnimalFeedMIGSBacteria implements MIGSBacteria
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    sampStorDur: String
    poolDnaExtracts: String
    sampStorLoc: String
    perturbation: [String]
    collSiteGeoFeat: String!
    foodOrigin: String!
    foodProd: [String]!
    foodProductType: [String]!
    foodSource: String
    iFSACCategory: [String]!
    intendedConsumer: [String]!
    sampPurpose: String!
    animalAm: String
    animalAmDur: String
    animalAmFreq: QuantityValue
    animalAmRoute: String
    animalAmUse: String
    animalBodyCond: AnimalBodyCondEnum
    animalDiet: [String]
    animalFeedEquip: [String]
    animalGroupSize: Integer
    animalHousing: [String]
    animalSex: AnimalSexEnum
    bacterialDensity: QuantityValue
    consFoodStorDur: String
    consFoodStorTemp: String
    consPurchDate: Date
    consQtyPurchased: String
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    enrichmentProtocol: String
    foodAdditive: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodCookingProc: [String]
    foodDisPoint: [String]
    foodDisPointCity: String
    foodIngredient: [String]
    foodPackCapacity: QuantityValue
    foodPackIntegrity: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodPriorContact: [String]
    foodProdSynonym: [String]
    foodProductQual: String
    foodQualityDate: String
    foodSourceAge: QuantityValue
    foodTraceList: FoodTraceListEnum
    foodTravMode: [String]
    foodTravVehic: [String]
    foodTreatProc: [String]
    hACCPTerm: [String]
    libraryPrepKit: String
    lotNumber: [String]
    microbCultMed: String
    partPlantAnimal: [String]
    repositoryName: [String]
    sampCollectMethod: String
    sampPooling: [String]
    sampRepBiol: QuantityValue
    sampRepTech: QuantityValue
    sampSourceMatCat: String
    sampStorDevice: String
    sampStorMedia: String
    sampTransportCont: SampTransportContEnum
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    spikeinAMR: [String]
    spikeinAntibiotic: [String]
    spikeinGrowthMed: [String]
    spikeinMetal: [String]
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinStrain: [String]
    studyDesign: [String]
    studyIncDur: QuantityValue
    studyIncTemp: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    timepoint: Double
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer!
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String!
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    trophicLevel: TrophicLevelEnum
    encodedTraits: String
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Food-animalAndAnimalFeedMIGSEukaryote implements MIGSEukaryote
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    sampStorDur: String
    poolDnaExtracts: String
    sampStorLoc: String
    perturbation: [String]
    collSiteGeoFeat: String!
    foodOrigin: String!
    foodProd: [String]!
    foodProductType: [String]!
    foodSource: String
    iFSACCategory: [String]!
    intendedConsumer: [String]!
    sampPurpose: String!
    animalAm: String
    animalAmDur: String
    animalAmFreq: QuantityValue
    animalAmRoute: String
    animalAmUse: String
    animalBodyCond: AnimalBodyCondEnum
    animalDiet: [String]
    animalFeedEquip: [String]
    animalGroupSize: Integer
    animalHousing: [String]
    animalSex: AnimalSexEnum
    bacterialDensity: QuantityValue
    consFoodStorDur: String
    consFoodStorTemp: String
    consPurchDate: Date
    consQtyPurchased: String
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    enrichmentProtocol: String
    foodAdditive: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodCookingProc: [String]
    foodDisPoint: [String]
    foodDisPointCity: String
    foodIngredient: [String]
    foodPackCapacity: QuantityValue
    foodPackIntegrity: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodPriorContact: [String]
    foodProdSynonym: [String]
    foodProductQual: String
    foodQualityDate: String
    foodSourceAge: QuantityValue
    foodTraceList: FoodTraceListEnum
    foodTravMode: [String]
    foodTravVehic: [String]
    foodTreatProc: [String]
    hACCPTerm: [String]
    libraryPrepKit: String
    lotNumber: [String]
    microbCultMed: String
    partPlantAnimal: [String]
    repositoryName: [String]
    sampCollectMethod: String
    sampPooling: [String]
    sampRepBiol: QuantityValue
    sampRepTech: QuantityValue
    sampSourceMatCat: String
    sampStorDevice: String
    sampStorMedia: String
    sampTransportCont: SampTransportContEnum
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    spikeinAMR: [String]
    spikeinAntibiotic: [String]
    spikeinGrowthMed: [String]
    spikeinMetal: [String]
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinStrain: [String]
    studyDesign: [String]
    studyIncDur: QuantityValue
    studyIncTemp: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    timepoint: Double
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    ploidy: String
    numReplicons: Integer
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    trophicLevel: TrophicLevelEnum
    propagation: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Food-animalAndAnimalFeedMIGSOrg implements MIGSOrg
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    sampStorDur: String
    poolDnaExtracts: String
    sampStorLoc: String
    perturbation: [String]
    collSiteGeoFeat: String!
    foodOrigin: String!
    foodProd: [String]!
    foodProductType: [String]!
    foodSource: String
    iFSACCategory: [String]!
    intendedConsumer: [String]!
    sampPurpose: String!
    animalAm: String
    animalAmDur: String
    animalAmFreq: QuantityValue
    animalAmRoute: String
    animalAmUse: String
    animalBodyCond: AnimalBodyCondEnum
    animalDiet: [String]
    animalFeedEquip: [String]
    animalGroupSize: Integer
    animalHousing: [String]
    animalSex: AnimalSexEnum
    bacterialDensity: QuantityValue
    consFoodStorDur: String
    consFoodStorTemp: String
    consPurchDate: Date
    consQtyPurchased: String
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    enrichmentProtocol: String
    foodAdditive: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodCookingProc: [String]
    foodDisPoint: [String]
    foodDisPointCity: String
    foodIngredient: [String]
    foodPackCapacity: QuantityValue
    foodPackIntegrity: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodPriorContact: [String]
    foodProdSynonym: [String]
    foodProductQual: String
    foodQualityDate: String
    foodSourceAge: QuantityValue
    foodTraceList: FoodTraceListEnum
    foodTravMode: [String]
    foodTravVehic: [String]
    foodTreatProc: [String]
    hACCPTerm: [String]
    libraryPrepKit: String
    lotNumber: [String]
    microbCultMed: String
    partPlantAnimal: [String]
    repositoryName: [String]
    sampCollectMethod: String
    sampPooling: [String]
    sampRepBiol: QuantityValue
    sampRepTech: QuantityValue
    sampSourceMatCat: String
    sampStorDevice: String
    sampStorMedia: String
    sampTransportCont: SampTransportContEnum
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    spikeinAMR: [String]
    spikeinAntibiotic: [String]
    spikeinGrowthMed: [String]
    spikeinMetal: [String]
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinStrain: [String]
    studyDesign: [String]
    studyIncDur: QuantityValue
    studyIncTemp: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    timepoint: Double
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Food-animalAndAnimalFeedMIGSPlant implements MIGSPlant
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    sampStorDur: String
    poolDnaExtracts: String
    sampStorLoc: String
    perturbation: [String]
    collSiteGeoFeat: String!
    foodOrigin: String!
    foodProd: [String]!
    foodProductType: [String]!
    foodSource: String
    iFSACCategory: [String]!
    intendedConsumer: [String]!
    sampPurpose: String!
    animalAm: String
    animalAmDur: String
    animalAmFreq: QuantityValue
    animalAmRoute: String
    animalAmUse: String
    animalBodyCond: AnimalBodyCondEnum
    animalDiet: [String]
    animalFeedEquip: [String]
    animalGroupSize: Integer
    animalHousing: [String]
    animalSex: AnimalSexEnum
    bacterialDensity: QuantityValue
    consFoodStorDur: String
    consFoodStorTemp: String
    consPurchDate: Date
    consQtyPurchased: String
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    enrichmentProtocol: String
    foodAdditive: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodCookingProc: [String]
    foodDisPoint: [String]
    foodDisPointCity: String
    foodIngredient: [String]
    foodPackCapacity: QuantityValue
    foodPackIntegrity: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodPriorContact: [String]
    foodProdSynonym: [String]
    foodProductQual: String
    foodQualityDate: String
    foodSourceAge: QuantityValue
    foodTraceList: FoodTraceListEnum
    foodTravMode: [String]
    foodTravVehic: [String]
    foodTreatProc: [String]
    hACCPTerm: [String]
    libraryPrepKit: String
    lotNumber: [String]
    microbCultMed: String
    partPlantAnimal: [String]
    repositoryName: [String]
    sampCollectMethod: String
    sampPooling: [String]
    sampRepBiol: QuantityValue
    sampRepTech: QuantityValue
    sampSourceMatCat: String
    sampStorDevice: String
    sampStorMedia: String
    sampTransportCont: SampTransportContEnum
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    spikeinAMR: [String]
    spikeinAntibiotic: [String]
    spikeinGrowthMed: [String]
    spikeinMetal: [String]
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinStrain: [String]
    studyDesign: [String]
    studyIncDur: QuantityValue
    studyIncTemp: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    timepoint: Double
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    specificHost: String
    hostSpecRange: Integer
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Food-animalAndAnimalFeedMIGSVirus implements MIGSVirus
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    sampStorDur: String
    poolDnaExtracts: String
    sampStorLoc: String
    perturbation: [String]
    collSiteGeoFeat: String!
    foodOrigin: String!
    foodProd: [String]!
    foodProductType: [String]!
    foodSource: String
    iFSACCategory: [String]!
    intendedConsumer: [String]!
    sampPurpose: String!
    animalAm: String
    animalAmDur: String
    animalAmFreq: QuantityValue
    animalAmRoute: String
    animalAmUse: String
    animalBodyCond: AnimalBodyCondEnum
    animalDiet: [String]
    animalFeedEquip: [String]
    animalGroupSize: Integer
    animalHousing: [String]
    animalSex: AnimalSexEnum
    bacterialDensity: QuantityValue
    consFoodStorDur: String
    consFoodStorTemp: String
    consPurchDate: Date
    consQtyPurchased: String
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    enrichmentProtocol: String
    foodAdditive: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodCookingProc: [String]
    foodDisPoint: [String]
    foodDisPointCity: String
    foodIngredient: [String]
    foodPackCapacity: QuantityValue
    foodPackIntegrity: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodPriorContact: [String]
    foodProdSynonym: [String]
    foodProductQual: String
    foodQualityDate: String
    foodSourceAge: QuantityValue
    foodTraceList: FoodTraceListEnum
    foodTravMode: [String]
    foodTravVehic: [String]
    foodTreatProc: [String]
    hACCPTerm: [String]
    libraryPrepKit: String
    lotNumber: [String]
    microbCultMed: String
    partPlantAnimal: [String]
    repositoryName: [String]
    sampCollectMethod: String
    sampPooling: [String]
    sampRepBiol: QuantityValue
    sampRepTech: QuantityValue
    sampSourceMatCat: String
    sampStorDevice: String
    sampStorMedia: String
    sampTransportCont: SampTransportContEnum
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    spikeinAMR: [String]
    spikeinAntibiotic: [String]
    spikeinGrowthMed: [String]
    spikeinMetal: [String]
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinStrain: [String]
    studyDesign: [String]
    studyIncDur: QuantityValue
    studyIncTemp: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    timepoint: Double
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    virusEnrichAppr: VirusEnrichApprEnum
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Food-animalAndAnimalFeedMIMAG implements MIMAG
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    sampStorDur: String
    poolDnaExtracts: String
    sampStorLoc: String
    perturbation: [String]
    collSiteGeoFeat: String!
    foodOrigin: String!
    foodProd: [String]!
    foodProductType: [String]!
    foodSource: String
    iFSACCategory: [String]!
    intendedConsumer: [String]!
    sampPurpose: String!
    animalAm: String
    animalAmDur: String
    animalAmFreq: QuantityValue
    animalAmRoute: String
    animalAmUse: String
    animalBodyCond: AnimalBodyCondEnum
    animalDiet: [String]
    animalFeedEquip: [String]
    animalGroupSize: Integer
    animalHousing: [String]
    animalSex: AnimalSexEnum
    bacterialDensity: QuantityValue
    consFoodStorDur: String
    consFoodStorTemp: String
    consPurchDate: Date
    consQtyPurchased: String
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    enrichmentProtocol: String
    foodAdditive: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodCookingProc: [String]
    foodDisPoint: [String]
    foodDisPointCity: String
    foodIngredient: [String]
    foodPackCapacity: QuantityValue
    foodPackIntegrity: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodPriorContact: [String]
    foodProdSynonym: [String]
    foodProductQual: String
    foodQualityDate: String
    foodSourceAge: QuantityValue
    foodTraceList: FoodTraceListEnum
    foodTravMode: [String]
    foodTravVehic: [String]
    foodTreatProc: [String]
    hACCPTerm: [String]
    libraryPrepKit: String
    lotNumber: [String]
    microbCultMed: String
    partPlantAnimal: [String]
    repositoryName: [String]
    sampCollectMethod: String
    sampPooling: [String]
    sampRepBiol: QuantityValue
    sampRepTech: QuantityValue
    sampSourceMatCat: String
    sampStorDevice: String
    sampStorMedia: String
    sampTransportCont: SampTransportContEnum
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    spikeinAMR: [String]
    spikeinAntibiotic: [String]
    spikeinGrowthMed: [String]
    spikeinMetal: [String]
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinStrain: [String]
    studyDesign: [String]
    studyIncDur: QuantityValue
    studyIncTemp: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    timepoint: Double
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    binParam: BinParamEnum!
    binSoftware: String!
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    associatedResource: String
    sop: String
  }

type Food-animalAndAnimalFeedMIMARKSSpecimen implements MIMARKSSpecimen
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    sampStorDur: String
    poolDnaExtracts: String
    sampStorLoc: String
    perturbation: [String]
    collSiteGeoFeat: String!
    foodOrigin: String!
    foodProd: [String]!
    foodProductType: [String]!
    foodSource: String
    iFSACCategory: [String]!
    intendedConsumer: [String]!
    sampPurpose: String!
    animalAm: String
    animalAmDur: String
    animalAmFreq: QuantityValue
    animalAmRoute: String
    animalAmUse: String
    animalBodyCond: AnimalBodyCondEnum
    animalDiet: [String]
    animalFeedEquip: [String]
    animalGroupSize: Integer
    animalHousing: [String]
    animalSex: AnimalSexEnum
    bacterialDensity: QuantityValue
    consFoodStorDur: String
    consFoodStorTemp: String
    consPurchDate: Date
    consQtyPurchased: String
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    enrichmentProtocol: String
    foodAdditive: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodCookingProc: [String]
    foodDisPoint: [String]
    foodDisPointCity: String
    foodIngredient: [String]
    foodPackCapacity: QuantityValue
    foodPackIntegrity: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodPriorContact: [String]
    foodProdSynonym: [String]
    foodProductQual: String
    foodQualityDate: String
    foodSourceAge: QuantityValue
    foodTraceList: FoodTraceListEnum
    foodTravMode: [String]
    foodTravVehic: [String]
    foodTreatProc: [String]
    hACCPTerm: [String]
    libraryPrepKit: String
    lotNumber: [String]
    microbCultMed: String
    partPlantAnimal: [String]
    repositoryName: [String]
    sampCollectMethod: String
    sampPooling: [String]
    sampRepBiol: QuantityValue
    sampRepTech: QuantityValue
    sampSourceMatCat: String
    sampStorDevice: String
    sampStorMedia: String
    sampTransportCont: SampTransportContEnum
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    spikeinAMR: [String]
    spikeinAntibiotic: [String]
    spikeinGrowthMed: [String]
    spikeinMetal: [String]
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinStrain: [String]
    studyDesign: [String]
    studyIncDur: QuantityValue
    studyIncTemp: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    timepoint: Double
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    negContType: NegContTypeEnum
    posContType: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    mid: String
    adapters: String
    pcrCond: String
    seqQualityCheck: String
    chimeraCheck: String
    assemblySoftware: String
    associatedResource: String
    sop: String
  }

type Food-animalAndAnimalFeedMIMARKSSurvey implements MIMARKSSurvey
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    sampStorDur: String
    poolDnaExtracts: String
    sampStorLoc: String
    perturbation: [String]
    collSiteGeoFeat: String!
    foodOrigin: String!
    foodProd: [String]!
    foodProductType: [String]!
    foodSource: String
    iFSACCategory: [String]!
    intendedConsumer: [String]!
    sampPurpose: String!
    animalAm: String
    animalAmDur: String
    animalAmFreq: QuantityValue
    animalAmRoute: String
    animalAmUse: String
    animalBodyCond: AnimalBodyCondEnum
    animalDiet: [String]
    animalFeedEquip: [String]
    animalGroupSize: Integer
    animalHousing: [String]
    animalSex: AnimalSexEnum
    bacterialDensity: QuantityValue
    consFoodStorDur: String
    consFoodStorTemp: String
    consPurchDate: Date
    consQtyPurchased: String
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    enrichmentProtocol: String
    foodAdditive: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodCookingProc: [String]
    foodDisPoint: [String]
    foodDisPointCity: String
    foodIngredient: [String]
    foodPackCapacity: QuantityValue
    foodPackIntegrity: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodPriorContact: [String]
    foodProdSynonym: [String]
    foodProductQual: String
    foodQualityDate: String
    foodSourceAge: QuantityValue
    foodTraceList: FoodTraceListEnum
    foodTravMode: [String]
    foodTravVehic: [String]
    foodTreatProc: [String]
    hACCPTerm: [String]
    libraryPrepKit: String
    lotNumber: [String]
    microbCultMed: String
    partPlantAnimal: [String]
    repositoryName: [String]
    sampCollectMethod: String
    sampPooling: [String]
    sampRepBiol: QuantityValue
    sampRepTech: QuantityValue
    sampSourceMatCat: String
    sampStorDevice: String
    sampStorMedia: String
    sampTransportCont: SampTransportContEnum
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    spikeinAMR: [String]
    spikeinAntibiotic: [String]
    spikeinGrowthMed: [String]
    spikeinMetal: [String]
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinStrain: [String]
    studyDesign: [String]
    studyIncDur: QuantityValue
    studyIncTemp: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    timepoint: Double
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    sourceMatId: String
    bioticRelationship: BioticRelationshipEnum
    trophicLevel: TrophicLevelEnum
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    nuclAcidAmp: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    pcrCond: String
    seqQualityCheck: String
    chimeraCheck: String
    associatedResource: String
    sop: String
  }

type Food-animalAndAnimalFeedMIMS implements MIMS
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    sampStorDur: String
    poolDnaExtracts: String
    sampStorLoc: String
    perturbation: [String]
    collSiteGeoFeat: String!
    foodOrigin: String!
    foodProd: [String]!
    foodProductType: [String]!
    foodSource: String
    iFSACCategory: [String]!
    intendedConsumer: [String]!
    sampPurpose: String!
    animalAm: String
    animalAmDur: String
    animalAmFreq: QuantityValue
    animalAmRoute: String
    animalAmUse: String
    animalBodyCond: AnimalBodyCondEnum
    animalDiet: [String]
    animalFeedEquip: [String]
    animalGroupSize: Integer
    animalHousing: [String]
    animalSex: AnimalSexEnum
    bacterialDensity: QuantityValue
    consFoodStorDur: String
    consFoodStorTemp: String
    consPurchDate: Date
    consQtyPurchased: String
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    enrichmentProtocol: String
    foodAdditive: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodCookingProc: [String]
    foodDisPoint: [String]
    foodDisPointCity: String
    foodIngredient: [String]
    foodPackCapacity: QuantityValue
    foodPackIntegrity: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodPriorContact: [String]
    foodProdSynonym: [String]
    foodProductQual: String
    foodQualityDate: String
    foodSourceAge: QuantityValue
    foodTraceList: FoodTraceListEnum
    foodTravMode: [String]
    foodTravVehic: [String]
    foodTreatProc: [String]
    hACCPTerm: [String]
    libraryPrepKit: String
    lotNumber: [String]
    microbCultMed: String
    partPlantAnimal: [String]
    repositoryName: [String]
    sampCollectMethod: String
    sampPooling: [String]
    sampRepBiol: QuantityValue
    sampRepTech: QuantityValue
    sampSourceMatCat: String
    sampStorDevice: String
    sampStorMedia: String
    sampTransportCont: SampTransportContEnum
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    spikeinAMR: [String]
    spikeinAntibiotic: [String]
    spikeinGrowthMed: [String]
    spikeinMetal: [String]
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinStrain: [String]
    studyDesign: [String]
    studyIncDur: QuantityValue
    studyIncTemp: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    timepoint: Double
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    associatedResource: String
    sop: String
  }

type Food-animalAndAnimalFeedMISAG implements MISAG
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    sampStorDur: String
    poolDnaExtracts: String
    sampStorLoc: String
    perturbation: [String]
    collSiteGeoFeat: String!
    foodOrigin: String!
    foodProd: [String]!
    foodProductType: [String]!
    foodSource: String
    iFSACCategory: [String]!
    intendedConsumer: [String]!
    sampPurpose: String!
    animalAm: String
    animalAmDur: String
    animalAmFreq: QuantityValue
    animalAmRoute: String
    animalAmUse: String
    animalBodyCond: AnimalBodyCondEnum
    animalDiet: [String]
    animalFeedEquip: [String]
    animalGroupSize: Integer
    animalHousing: [String]
    animalSex: AnimalSexEnum
    bacterialDensity: QuantityValue
    consFoodStorDur: String
    consFoodStorTemp: String
    consPurchDate: Date
    consQtyPurchased: String
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    enrichmentProtocol: String
    foodAdditive: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodCookingProc: [String]
    foodDisPoint: [String]
    foodDisPointCity: String
    foodIngredient: [String]
    foodPackCapacity: QuantityValue
    foodPackIntegrity: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodPriorContact: [String]
    foodProdSynonym: [String]
    foodProductQual: String
    foodQualityDate: String
    foodSourceAge: QuantityValue
    foodTraceList: FoodTraceListEnum
    foodTravMode: [String]
    foodTravVehic: [String]
    foodTreatProc: [String]
    hACCPTerm: [String]
    libraryPrepKit: String
    lotNumber: [String]
    microbCultMed: String
    partPlantAnimal: [String]
    repositoryName: [String]
    sampCollectMethod: String
    sampPooling: [String]
    sampRepBiol: QuantityValue
    sampRepTech: QuantityValue
    sampSourceMatCat: String
    sampStorDevice: String
    sampStorMedia: String
    sampTransportCont: SampTransportContEnum
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    spikeinAMR: [String]
    spikeinAntibiotic: [String]
    spikeinGrowthMed: [String]
    spikeinMetal: [String]
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinStrain: [String]
    studyDesign: [String]
    studyIncDur: QuantityValue
    studyIncTemp: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    timepoint: Double
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    sortTech: SortTechEnum!
    singleCellLysisAppr: SingleCellLysisApprEnum!
    singleCellLysisProt: String
    wgaAmpAppr: String!
    wgaAmpKit: String
    associatedResource: String
    sop: String
  }

type Food-animalAndAnimalFeedMIUVIG implements MIUVIG
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    sampStorDur: String
    poolDnaExtracts: String
    sampStorLoc: String
    perturbation: [String]
    collSiteGeoFeat: String!
    foodOrigin: String!
    foodProd: [String]!
    foodProductType: [String]!
    foodSource: String
    iFSACCategory: [String]!
    intendedConsumer: [String]!
    sampPurpose: String!
    animalAm: String
    animalAmDur: String
    animalAmFreq: QuantityValue
    animalAmRoute: String
    animalAmUse: String
    animalBodyCond: AnimalBodyCondEnum
    animalDiet: [String]
    animalFeedEquip: [String]
    animalGroupSize: Integer
    animalHousing: [String]
    animalSex: AnimalSexEnum
    bacterialDensity: QuantityValue
    consFoodStorDur: String
    consFoodStorTemp: String
    consPurchDate: Date
    consQtyPurchased: String
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    enrichmentProtocol: String
    foodAdditive: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodCookingProc: [String]
    foodDisPoint: [String]
    foodDisPointCity: String
    foodIngredient: [String]
    foodPackCapacity: QuantityValue
    foodPackIntegrity: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodPriorContact: [String]
    foodProdSynonym: [String]
    foodProductQual: String
    foodQualityDate: String
    foodSourceAge: QuantityValue
    foodTraceList: FoodTraceListEnum
    foodTravMode: [String]
    foodTravVehic: [String]
    foodTreatProc: [String]
    hACCPTerm: [String]
    libraryPrepKit: String
    lotNumber: [String]
    microbCultMed: String
    partPlantAnimal: [String]
    repositoryName: [String]
    sampCollectMethod: String
    sampPooling: [String]
    sampRepBiol: QuantityValue
    sampRepTech: QuantityValue
    sampSourceMatCat: String
    sampStorDevice: String
    sampStorMedia: String
    sampTransportCont: SampTransportContEnum
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    spikeinAMR: [String]
    spikeinAntibiotic: [String]
    spikeinGrowthMed: [String]
    spikeinMetal: [String]
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinStrain: [String]
    studyDesign: [String]
    studyIncDur: QuantityValue
    studyIncTemp: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    timepoint: Double
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    negContType: NegContTypeEnum
    posContType: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sourceUvig: SourceUvigEnum!
    virusEnrichAppr: VirusEnrichApprEnum!
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String
    complSoftware: String
    complAppr: ComplApprEnum
    sortTech: SortTechEnum
    singleCellLysisAppr: SingleCellLysisApprEnum
    singleCellLysisProt: String
    wgaAmpAppr: String
    wgaAmpKit: String
    binParam: BinParamEnum
    binSoftware: String
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    virIdentSoftware: String!
    predGenomeType: PredGenomeTypeEnum!
    predGenomeStruc: PredGenomeStrucEnum!
    detecType: String!
    otuClassAppr: String
    otuSeqCompAppr: String
    otuDb: String
    hostPredAppr: HostPredApprEnum
    hostPredEstAcc: String
    associatedResource: String
    sop: String
  }

type Food-farmEnvironment
  {
    latLon: String!
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    humidity: QuantityValue
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    solarIrradiance: QuantityValue
    ventilationRate: QuantityValue
    sampStorDur: String
    windSpeed: QuantityValue
    salinity: QuantityValue
    previousLandUse: String
    cropRotation: String
    soilTypeMeth: String
    totOrgCMeth: String
    totNitroContMeth: String
    salinityMeth: String
    hostAge: QuantityValue
    hostDryMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostTotMass: QuantityValue
    rootMedCarbon: String
    rootMedMacronutr: String
    rootMedMicronutr: String
    seasonTemp: QuantityValue
    seasonPrecpt: QuantityValue
    totOrgCarb: QuantityValue
    totNitroContent: QuantityValue
    conduc: QuantityValue
    turbidity: QuantityValue
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    ventilationType: String
    windDirection: String
    geneticMod: String
    hostPhenotype: String
    ph: Double
    ancesData: String
    bioticRegm: String!
    chemAdministration: [String]!
    growthHabit: GrowthHabitEnum
    hostGenotype: String
    hostTaxid: String
    mechanicalDamage: [String]
    perturbation: [String]
    rootCond: String
    rootMedPh: Double
    tillage: [TillageEnum]
    phMeth: String
    growthMedium: String
    season: String
    foodProductType: [String]!
    sampType: String!
    farmWaterSource: [FarmWaterSourceEnum]
    plantWaterMethod: String
    airPMConcen: [String]
    animalFeedEquip: [String]
    animalIntrusion: [String]
    animWaterMethod: [String]
    cropYield: String
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    plantPartMaturity: String
    adjacentEnvironment: [String]
    waterSourceAdjac: [String]
    farmEquipShared: [String]
    farmEquipSan: [String]
    farmEquipSanFreq: String
    farmEquip: [String]
    fertilizerAdmin: String
    fertilizerDate: Date
    animalGroupSize: Integer
    animalDiet: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodHarvestProc: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodProdChar: [String]
    prodLabelClaims: [String]
    foodTravMode: [String]
    foodTravVehic: [String]
    foodSource: String
    foodTreatProc: [String]
    extrWeatherEvent: [ExtrWeatherEventEnum]
    dateExtrWeath: [Date]
    hostSubspecfGenlin: [String]
    intendedConsumer: [String]
    libraryPrepKit: String
    airFlowImpede: [String]
    lotNumber: [String]
    seasonHumidity: QuantityValue
    partPlantAnimal: [String]
    plantGrowthMed: PlantGrowthMedEnum
    plantReprodCrop: [PlantReprodCropEnum]
    sampPurpose: String
    repositoryName: [String]
    sampPooling: [String]
    sampSourceMatCat: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    soilConductivity: QuantityValue
    soilCover: String
    soilPH: Double
    relLocation: String
    soilPorosity: String
    soilTextureClass: SoilTextureClassEnum
    soilTextureMeth: String
    soilType: String
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinGrowthMed: [String]
    spikeinStrain: [String]
    spikeinAntibiotic: [String]
    spikeinMetal: [String]
    timepoint: Double
    waterFrequency: String
    waterPH: Double
    waterSourceShared: [WaterSourceSharedEnum]
    enrichmentProtocol: String
    foodQualityDate: String
    iFSACCategory: [String]!
    animalHousing: [String]
    cultIsolDate: Date
    foodCleanProc: [FoodCleanProcEnum]
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    hostDiseaseStat: String
  }

type Food-farmEnvironmentMIGSBacteria implements MIGSBacteria
  {
    latLon: String!
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    humidity: QuantityValue
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    solarIrradiance: QuantityValue
    ventilationRate: QuantityValue
    sampStorDur: String
    windSpeed: QuantityValue
    salinity: QuantityValue
    previousLandUse: String
    cropRotation: String
    soilTypeMeth: String
    totOrgCMeth: String
    totNitroContMeth: String
    salinityMeth: String
    hostAge: QuantityValue
    hostDryMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostTotMass: QuantityValue
    rootMedCarbon: String
    rootMedMacronutr: String
    rootMedMicronutr: String
    seasonTemp: QuantityValue
    seasonPrecpt: QuantityValue
    totOrgCarb: QuantityValue
    totNitroContent: QuantityValue
    conduc: QuantityValue
    turbidity: QuantityValue
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    ventilationType: String
    windDirection: String
    geneticMod: String
    hostPhenotype: String
    ph: Double
    ancesData: String
    bioticRegm: String!
    chemAdministration: [String]!
    growthHabit: GrowthHabitEnum
    hostGenotype: String
    hostTaxid: String
    mechanicalDamage: [String]
    perturbation: [String]
    rootCond: String
    rootMedPh: Double
    tillage: [TillageEnum]
    phMeth: String
    growthMedium: String
    season: String
    foodProductType: [String]!
    sampType: String!
    farmWaterSource: [FarmWaterSourceEnum]
    plantWaterMethod: String
    airPMConcen: [String]
    animalFeedEquip: [String]
    animalIntrusion: [String]
    animWaterMethod: [String]
    cropYield: String
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    plantPartMaturity: String
    adjacentEnvironment: [String]
    waterSourceAdjac: [String]
    farmEquipShared: [String]
    farmEquipSan: [String]
    farmEquipSanFreq: String
    farmEquip: [String]
    fertilizerAdmin: String
    fertilizerDate: Date
    animalGroupSize: Integer
    animalDiet: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodHarvestProc: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodProdChar: [String]
    prodLabelClaims: [String]
    foodTravMode: [String]
    foodTravVehic: [String]
    foodSource: String
    foodTreatProc: [String]
    extrWeatherEvent: [ExtrWeatherEventEnum]
    dateExtrWeath: [Date]
    hostSubspecfGenlin: [String]
    intendedConsumer: [String]
    libraryPrepKit: String
    airFlowImpede: [String]
    lotNumber: [String]
    seasonHumidity: QuantityValue
    partPlantAnimal: [String]
    plantGrowthMed: PlantGrowthMedEnum
    plantReprodCrop: [PlantReprodCropEnum]
    sampPurpose: String
    repositoryName: [String]
    sampPooling: [String]
    sampSourceMatCat: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    soilConductivity: QuantityValue
    soilCover: String
    soilPH: Double
    relLocation: String
    soilPorosity: String
    temp: QuantityValue
    soilTextureClass: SoilTextureClassEnum
    soilTextureMeth: String
    soilType: String
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinGrowthMed: [String]
    spikeinStrain: [String]
    spikeinAntibiotic: [String]
    spikeinMetal: [String]
    timepoint: Double
    waterFrequency: String
    waterPH: Double
    waterSourceShared: [WaterSourceSharedEnum]
    enrichmentProtocol: String
    foodQualityDate: String
    iFSACCategory: [String]!
    animalHousing: [String]
    cultIsolDate: Date
    foodCleanProc: [FoodCleanProcEnum]
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    hostDiseaseStat: String
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer!
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String!
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    trophicLevel: TrophicLevelEnum
    encodedTraits: String
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Food-farmEnvironmentMIGSEukaryote implements MIGSEukaryote
  {
    latLon: String!
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    humidity: QuantityValue
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    solarIrradiance: QuantityValue
    ventilationRate: QuantityValue
    sampStorDur: String
    windSpeed: QuantityValue
    salinity: QuantityValue
    previousLandUse: String
    cropRotation: String
    soilTypeMeth: String
    totOrgCMeth: String
    totNitroContMeth: String
    salinityMeth: String
    hostAge: QuantityValue
    hostDryMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostTotMass: QuantityValue
    rootMedCarbon: String
    rootMedMacronutr: String
    rootMedMicronutr: String
    seasonTemp: QuantityValue
    seasonPrecpt: QuantityValue
    totOrgCarb: QuantityValue
    totNitroContent: QuantityValue
    conduc: QuantityValue
    turbidity: QuantityValue
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    ventilationType: String
    windDirection: String
    geneticMod: String
    hostPhenotype: String
    ph: Double
    ancesData: String
    bioticRegm: String!
    chemAdministration: [String]!
    growthHabit: GrowthHabitEnum
    hostGenotype: String
    hostTaxid: String
    mechanicalDamage: [String]
    perturbation: [String]
    rootCond: String
    rootMedPh: Double
    tillage: [TillageEnum]
    phMeth: String
    growthMedium: String
    season: String
    foodProductType: [String]!
    sampType: String!
    farmWaterSource: [FarmWaterSourceEnum]
    plantWaterMethod: String
    airPMConcen: [String]
    animalFeedEquip: [String]
    animalIntrusion: [String]
    animWaterMethod: [String]
    cropYield: String
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    plantPartMaturity: String
    adjacentEnvironment: [String]
    waterSourceAdjac: [String]
    farmEquipShared: [String]
    farmEquipSan: [String]
    farmEquipSanFreq: String
    farmEquip: [String]
    fertilizerAdmin: String
    fertilizerDate: Date
    animalGroupSize: Integer
    animalDiet: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodHarvestProc: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodProdChar: [String]
    prodLabelClaims: [String]
    foodTravMode: [String]
    foodTravVehic: [String]
    foodSource: String
    foodTreatProc: [String]
    extrWeatherEvent: [ExtrWeatherEventEnum]
    dateExtrWeath: [Date]
    hostSubspecfGenlin: [String]
    intendedConsumer: [String]
    libraryPrepKit: String
    airFlowImpede: [String]
    lotNumber: [String]
    seasonHumidity: QuantityValue
    partPlantAnimal: [String]
    plantGrowthMed: PlantGrowthMedEnum
    plantReprodCrop: [PlantReprodCropEnum]
    sampPurpose: String
    repositoryName: [String]
    sampPooling: [String]
    sampSourceMatCat: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    soilConductivity: QuantityValue
    soilCover: String
    soilPH: Double
    relLocation: String
    soilPorosity: String
    temp: QuantityValue
    soilTextureClass: SoilTextureClassEnum
    soilTextureMeth: String
    soilType: String
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinGrowthMed: [String]
    spikeinStrain: [String]
    spikeinAntibiotic: [String]
    spikeinMetal: [String]
    timepoint: Double
    waterFrequency: String
    waterPH: Double
    waterSourceShared: [WaterSourceSharedEnum]
    enrichmentProtocol: String
    foodQualityDate: String
    iFSACCategory: [String]!
    animalHousing: [String]
    cultIsolDate: Date
    foodCleanProc: [FoodCleanProcEnum]
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    hostDiseaseStat: String
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    ploidy: String
    numReplicons: Integer
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    trophicLevel: TrophicLevelEnum
    propagation: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Food-farmEnvironmentMIGSOrg implements MIGSOrg
  {
    latLon: String!
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    humidity: QuantityValue
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    solarIrradiance: QuantityValue
    ventilationRate: QuantityValue
    sampStorDur: String
    windSpeed: QuantityValue
    salinity: QuantityValue
    previousLandUse: String
    cropRotation: String
    soilTypeMeth: String
    totOrgCMeth: String
    totNitroContMeth: String
    salinityMeth: String
    hostAge: QuantityValue
    hostDryMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostTotMass: QuantityValue
    rootMedCarbon: String
    rootMedMacronutr: String
    rootMedMicronutr: String
    seasonTemp: QuantityValue
    seasonPrecpt: QuantityValue
    totOrgCarb: QuantityValue
    totNitroContent: QuantityValue
    conduc: QuantityValue
    turbidity: QuantityValue
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    ventilationType: String
    windDirection: String
    geneticMod: String
    hostPhenotype: String
    ph: Double
    ancesData: String
    bioticRegm: String!
    chemAdministration: [String]!
    growthHabit: GrowthHabitEnum
    hostGenotype: String
    hostTaxid: String
    mechanicalDamage: [String]
    perturbation: [String]
    rootCond: String
    rootMedPh: Double
    tillage: [TillageEnum]
    phMeth: String
    growthMedium: String
    season: String
    foodProductType: [String]!
    sampType: String!
    farmWaterSource: [FarmWaterSourceEnum]
    plantWaterMethod: String
    airPMConcen: [String]
    animalFeedEquip: [String]
    animalIntrusion: [String]
    animWaterMethod: [String]
    cropYield: String
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    plantPartMaturity: String
    adjacentEnvironment: [String]
    waterSourceAdjac: [String]
    farmEquipShared: [String]
    farmEquipSan: [String]
    farmEquipSanFreq: String
    farmEquip: [String]
    fertilizerAdmin: String
    fertilizerDate: Date
    animalGroupSize: Integer
    animalDiet: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodHarvestProc: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodProdChar: [String]
    prodLabelClaims: [String]
    foodTravMode: [String]
    foodTravVehic: [String]
    foodSource: String
    foodTreatProc: [String]
    extrWeatherEvent: [ExtrWeatherEventEnum]
    dateExtrWeath: [Date]
    hostSubspecfGenlin: [String]
    intendedConsumer: [String]
    libraryPrepKit: String
    airFlowImpede: [String]
    lotNumber: [String]
    seasonHumidity: QuantityValue
    partPlantAnimal: [String]
    plantGrowthMed: PlantGrowthMedEnum
    plantReprodCrop: [PlantReprodCropEnum]
    sampPurpose: String
    repositoryName: [String]
    sampPooling: [String]
    sampSourceMatCat: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    soilConductivity: QuantityValue
    soilCover: String
    soilPH: Double
    relLocation: String
    soilPorosity: String
    temp: QuantityValue
    soilTextureClass: SoilTextureClassEnum
    soilTextureMeth: String
    soilType: String
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinGrowthMed: [String]
    spikeinStrain: [String]
    spikeinAntibiotic: [String]
    spikeinMetal: [String]
    timepoint: Double
    waterFrequency: String
    waterPH: Double
    waterSourceShared: [WaterSourceSharedEnum]
    enrichmentProtocol: String
    foodQualityDate: String
    iFSACCategory: [String]!
    animalHousing: [String]
    cultIsolDate: Date
    foodCleanProc: [FoodCleanProcEnum]
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    hostDiseaseStat: String
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Food-farmEnvironmentMIGSPlant implements MIGSPlant
  {
    latLon: String!
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    humidity: QuantityValue
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    solarIrradiance: QuantityValue
    ventilationRate: QuantityValue
    sampStorDur: String
    windSpeed: QuantityValue
    salinity: QuantityValue
    previousLandUse: String
    cropRotation: String
    soilTypeMeth: String
    totOrgCMeth: String
    totNitroContMeth: String
    salinityMeth: String
    hostAge: QuantityValue
    hostDryMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostTotMass: QuantityValue
    rootMedCarbon: String
    rootMedMacronutr: String
    rootMedMicronutr: String
    seasonTemp: QuantityValue
    seasonPrecpt: QuantityValue
    totOrgCarb: QuantityValue
    totNitroContent: QuantityValue
    conduc: QuantityValue
    turbidity: QuantityValue
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    ventilationType: String
    windDirection: String
    geneticMod: String
    hostPhenotype: String
    ph: Double
    ancesData: String
    bioticRegm: String!
    chemAdministration: [String]!
    growthHabit: GrowthHabitEnum
    hostGenotype: String
    hostTaxid: String
    mechanicalDamage: [String]
    perturbation: [String]
    rootCond: String
    rootMedPh: Double
    tillage: [TillageEnum]
    phMeth: String
    growthMedium: String
    season: String
    foodProductType: [String]!
    sampType: String!
    farmWaterSource: [FarmWaterSourceEnum]
    plantWaterMethod: String
    airPMConcen: [String]
    animalFeedEquip: [String]
    animalIntrusion: [String]
    animWaterMethod: [String]
    cropYield: String
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    plantPartMaturity: String
    adjacentEnvironment: [String]
    waterSourceAdjac: [String]
    farmEquipShared: [String]
    farmEquipSan: [String]
    farmEquipSanFreq: String
    farmEquip: [String]
    fertilizerAdmin: String
    fertilizerDate: Date
    animalGroupSize: Integer
    animalDiet: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodHarvestProc: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodProdChar: [String]
    prodLabelClaims: [String]
    foodTravMode: [String]
    foodTravVehic: [String]
    foodSource: String
    foodTreatProc: [String]
    extrWeatherEvent: [ExtrWeatherEventEnum]
    dateExtrWeath: [Date]
    hostSubspecfGenlin: [String]
    intendedConsumer: [String]
    libraryPrepKit: String
    airFlowImpede: [String]
    lotNumber: [String]
    seasonHumidity: QuantityValue
    partPlantAnimal: [String]
    plantGrowthMed: PlantGrowthMedEnum
    plantReprodCrop: [PlantReprodCropEnum]
    sampPurpose: String
    repositoryName: [String]
    sampPooling: [String]
    sampSourceMatCat: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    soilConductivity: QuantityValue
    soilCover: String
    soilPH: Double
    relLocation: String
    soilPorosity: String
    temp: QuantityValue
    soilTextureClass: SoilTextureClassEnum
    soilTextureMeth: String
    soilType: String
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinGrowthMed: [String]
    spikeinStrain: [String]
    spikeinAntibiotic: [String]
    spikeinMetal: [String]
    timepoint: Double
    waterFrequency: String
    waterPH: Double
    waterSourceShared: [WaterSourceSharedEnum]
    enrichmentProtocol: String
    foodQualityDate: String
    iFSACCategory: [String]!
    animalHousing: [String]
    cultIsolDate: Date
    foodCleanProc: [FoodCleanProcEnum]
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    hostDiseaseStat: String
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    specificHost: String
    hostSpecRange: Integer
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Food-farmEnvironmentMIGSVirus implements MIGSVirus
  {
    latLon: String!
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    humidity: QuantityValue
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    solarIrradiance: QuantityValue
    ventilationRate: QuantityValue
    sampStorDur: String
    windSpeed: QuantityValue
    salinity: QuantityValue
    previousLandUse: String
    cropRotation: String
    soilTypeMeth: String
    totOrgCMeth: String
    totNitroContMeth: String
    salinityMeth: String
    hostAge: QuantityValue
    hostDryMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostTotMass: QuantityValue
    rootMedCarbon: String
    rootMedMacronutr: String
    rootMedMicronutr: String
    seasonTemp: QuantityValue
    seasonPrecpt: QuantityValue
    totOrgCarb: QuantityValue
    totNitroContent: QuantityValue
    conduc: QuantityValue
    turbidity: QuantityValue
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    ventilationType: String
    windDirection: String
    geneticMod: String
    hostPhenotype: String
    ph: Double
    ancesData: String
    bioticRegm: String!
    chemAdministration: [String]!
    growthHabit: GrowthHabitEnum
    hostGenotype: String
    hostTaxid: String
    mechanicalDamage: [String]
    perturbation: [String]
    rootCond: String
    rootMedPh: Double
    tillage: [TillageEnum]
    phMeth: String
    growthMedium: String
    season: String
    foodProductType: [String]!
    sampType: String!
    farmWaterSource: [FarmWaterSourceEnum]
    plantWaterMethod: String
    airPMConcen: [String]
    animalFeedEquip: [String]
    animalIntrusion: [String]
    animWaterMethod: [String]
    cropYield: String
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    plantPartMaturity: String
    adjacentEnvironment: [String]
    waterSourceAdjac: [String]
    farmEquipShared: [String]
    farmEquipSan: [String]
    farmEquipSanFreq: String
    farmEquip: [String]
    fertilizerAdmin: String
    fertilizerDate: Date
    animalGroupSize: Integer
    animalDiet: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodHarvestProc: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodProdChar: [String]
    prodLabelClaims: [String]
    foodTravMode: [String]
    foodTravVehic: [String]
    foodSource: String
    foodTreatProc: [String]
    extrWeatherEvent: [ExtrWeatherEventEnum]
    dateExtrWeath: [Date]
    hostSubspecfGenlin: [String]
    intendedConsumer: [String]
    libraryPrepKit: String
    airFlowImpede: [String]
    lotNumber: [String]
    seasonHumidity: QuantityValue
    partPlantAnimal: [String]
    plantGrowthMed: PlantGrowthMedEnum
    plantReprodCrop: [PlantReprodCropEnum]
    sampPurpose: String
    repositoryName: [String]
    sampPooling: [String]
    sampSourceMatCat: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    soilConductivity: QuantityValue
    soilCover: String
    soilPH: Double
    relLocation: String
    soilPorosity: String
    temp: QuantityValue
    soilTextureClass: SoilTextureClassEnum
    soilTextureMeth: String
    soilType: String
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinGrowthMed: [String]
    spikeinStrain: [String]
    spikeinAntibiotic: [String]
    spikeinMetal: [String]
    timepoint: Double
    waterFrequency: String
    waterPH: Double
    waterSourceShared: [WaterSourceSharedEnum]
    enrichmentProtocol: String
    foodQualityDate: String
    iFSACCategory: [String]!
    animalHousing: [String]
    cultIsolDate: Date
    foodCleanProc: [FoodCleanProcEnum]
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    hostDiseaseStat: String
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    virusEnrichAppr: VirusEnrichApprEnum
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Food-farmEnvironmentMIMAG implements MIMAG
  {
    latLon: String!
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    humidity: QuantityValue
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    solarIrradiance: QuantityValue
    ventilationRate: QuantityValue
    sampStorDur: String
    windSpeed: QuantityValue
    salinity: QuantityValue
    previousLandUse: String
    cropRotation: String
    soilTypeMeth: String
    totOrgCMeth: String
    totNitroContMeth: String
    salinityMeth: String
    hostAge: QuantityValue
    hostDryMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostTotMass: QuantityValue
    rootMedCarbon: String
    rootMedMacronutr: String
    rootMedMicronutr: String
    seasonTemp: QuantityValue
    seasonPrecpt: QuantityValue
    totOrgCarb: QuantityValue
    totNitroContent: QuantityValue
    conduc: QuantityValue
    turbidity: QuantityValue
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    ventilationType: String
    windDirection: String
    geneticMod: String
    hostPhenotype: String
    ph: Double
    ancesData: String
    bioticRegm: String!
    chemAdministration: [String]!
    growthHabit: GrowthHabitEnum
    hostGenotype: String
    hostTaxid: String
    mechanicalDamage: [String]
    perturbation: [String]
    rootCond: String
    rootMedPh: Double
    tillage: [TillageEnum]
    phMeth: String
    growthMedium: String
    season: String
    foodProductType: [String]!
    sampType: String!
    farmWaterSource: [FarmWaterSourceEnum]
    plantWaterMethod: String
    airPMConcen: [String]
    animalFeedEquip: [String]
    animalIntrusion: [String]
    animWaterMethod: [String]
    cropYield: String
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    plantPartMaturity: String
    adjacentEnvironment: [String]
    waterSourceAdjac: [String]
    farmEquipShared: [String]
    farmEquipSan: [String]
    farmEquipSanFreq: String
    farmEquip: [String]
    fertilizerAdmin: String
    fertilizerDate: Date
    animalGroupSize: Integer
    animalDiet: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodHarvestProc: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodProdChar: [String]
    prodLabelClaims: [String]
    foodTravMode: [String]
    foodTravVehic: [String]
    foodSource: String
    foodTreatProc: [String]
    extrWeatherEvent: [ExtrWeatherEventEnum]
    dateExtrWeath: [Date]
    hostSubspecfGenlin: [String]
    intendedConsumer: [String]
    libraryPrepKit: String
    airFlowImpede: [String]
    lotNumber: [String]
    seasonHumidity: QuantityValue
    partPlantAnimal: [String]
    plantGrowthMed: PlantGrowthMedEnum
    plantReprodCrop: [PlantReprodCropEnum]
    sampPurpose: String
    repositoryName: [String]
    sampPooling: [String]
    sampSourceMatCat: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    soilConductivity: QuantityValue
    soilCover: String
    soilPH: Double
    relLocation: String
    soilPorosity: String
    temp: QuantityValue
    soilTextureClass: SoilTextureClassEnum
    soilTextureMeth: String
    soilType: String
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinGrowthMed: [String]
    spikeinStrain: [String]
    spikeinAntibiotic: [String]
    spikeinMetal: [String]
    timepoint: Double
    waterFrequency: String
    waterPH: Double
    waterSourceShared: [WaterSourceSharedEnum]
    enrichmentProtocol: String
    foodQualityDate: String
    iFSACCategory: [String]!
    animalHousing: [String]
    cultIsolDate: Date
    foodCleanProc: [FoodCleanProcEnum]
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    hostDiseaseStat: String
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    binParam: BinParamEnum!
    binSoftware: String!
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    associatedResource: String
    sop: String
  }

type Food-farmEnvironmentMIMARKSSpecimen implements MIMARKSSpecimen
  {
    latLon: String!
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    humidity: QuantityValue
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    solarIrradiance: QuantityValue
    ventilationRate: QuantityValue
    sampStorDur: String
    windSpeed: QuantityValue
    salinity: QuantityValue
    previousLandUse: String
    cropRotation: String
    soilTypeMeth: String
    totOrgCMeth: String
    totNitroContMeth: String
    salinityMeth: String
    hostAge: QuantityValue
    hostDryMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostTotMass: QuantityValue
    rootMedCarbon: String
    rootMedMacronutr: String
    rootMedMicronutr: String
    seasonTemp: QuantityValue
    seasonPrecpt: QuantityValue
    totOrgCarb: QuantityValue
    totNitroContent: QuantityValue
    conduc: QuantityValue
    turbidity: QuantityValue
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    ventilationType: String
    windDirection: String
    geneticMod: String
    hostPhenotype: String
    ph: Double
    ancesData: String
    bioticRegm: String!
    chemAdministration: [String]!
    growthHabit: GrowthHabitEnum
    hostGenotype: String
    hostTaxid: String
    mechanicalDamage: [String]
    perturbation: [String]
    rootCond: String
    rootMedPh: Double
    tillage: [TillageEnum]
    phMeth: String
    growthMedium: String
    season: String
    foodProductType: [String]!
    sampType: String!
    farmWaterSource: [FarmWaterSourceEnum]
    plantWaterMethod: String
    airPMConcen: [String]
    animalFeedEquip: [String]
    animalIntrusion: [String]
    animWaterMethod: [String]
    cropYield: String
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    plantPartMaturity: String
    adjacentEnvironment: [String]
    waterSourceAdjac: [String]
    farmEquipShared: [String]
    farmEquipSan: [String]
    farmEquipSanFreq: String
    farmEquip: [String]
    fertilizerAdmin: String
    fertilizerDate: Date
    animalGroupSize: Integer
    animalDiet: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodHarvestProc: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodProdChar: [String]
    prodLabelClaims: [String]
    foodTravMode: [String]
    foodTravVehic: [String]
    foodSource: String
    foodTreatProc: [String]
    extrWeatherEvent: [ExtrWeatherEventEnum]
    dateExtrWeath: [Date]
    hostSubspecfGenlin: [String]
    intendedConsumer: [String]
    libraryPrepKit: String
    airFlowImpede: [String]
    lotNumber: [String]
    seasonHumidity: QuantityValue
    partPlantAnimal: [String]
    plantGrowthMed: PlantGrowthMedEnum
    plantReprodCrop: [PlantReprodCropEnum]
    sampPurpose: String
    repositoryName: [String]
    sampPooling: [String]
    sampSourceMatCat: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    soilConductivity: QuantityValue
    soilCover: String
    soilPH: Double
    relLocation: String
    soilPorosity: String
    temp: QuantityValue
    soilTextureClass: SoilTextureClassEnum
    soilTextureMeth: String
    soilType: String
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinGrowthMed: [String]
    spikeinStrain: [String]
    spikeinAntibiotic: [String]
    spikeinMetal: [String]
    timepoint: Double
    waterFrequency: String
    waterPH: Double
    waterSourceShared: [WaterSourceSharedEnum]
    enrichmentProtocol: String
    foodQualityDate: String
    iFSACCategory: [String]!
    animalHousing: [String]
    cultIsolDate: Date
    foodCleanProc: [FoodCleanProcEnum]
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    hostDiseaseStat: String
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    mid: String
    adapters: String
    pcrCond: String
    seqQualityCheck: String
    chimeraCheck: String
    assemblySoftware: String
    associatedResource: String
    sop: String
  }

type Food-farmEnvironmentMIMARKSSurvey implements MIMARKSSurvey
  {
    latLon: String!
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    humidity: QuantityValue
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    solarIrradiance: QuantityValue
    ventilationRate: QuantityValue
    sampStorDur: String
    windSpeed: QuantityValue
    salinity: QuantityValue
    previousLandUse: String
    cropRotation: String
    soilTypeMeth: String
    totOrgCMeth: String
    totNitroContMeth: String
    salinityMeth: String
    hostAge: QuantityValue
    hostDryMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostTotMass: QuantityValue
    rootMedCarbon: String
    rootMedMacronutr: String
    rootMedMicronutr: String
    seasonTemp: QuantityValue
    seasonPrecpt: QuantityValue
    totOrgCarb: QuantityValue
    totNitroContent: QuantityValue
    conduc: QuantityValue
    turbidity: QuantityValue
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    ventilationType: String
    windDirection: String
    geneticMod: String
    hostPhenotype: String
    ph: Double
    ancesData: String
    bioticRegm: String!
    chemAdministration: [String]!
    growthHabit: GrowthHabitEnum
    hostGenotype: String
    hostTaxid: String
    mechanicalDamage: [String]
    perturbation: [String]
    rootCond: String
    rootMedPh: Double
    tillage: [TillageEnum]
    phMeth: String
    growthMedium: String
    season: String
    foodProductType: [String]!
    sampType: String!
    farmWaterSource: [FarmWaterSourceEnum]
    plantWaterMethod: String
    airPMConcen: [String]
    animalFeedEquip: [String]
    animalIntrusion: [String]
    animWaterMethod: [String]
    cropYield: String
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    plantPartMaturity: String
    adjacentEnvironment: [String]
    waterSourceAdjac: [String]
    farmEquipShared: [String]
    farmEquipSan: [String]
    farmEquipSanFreq: String
    farmEquip: [String]
    fertilizerAdmin: String
    fertilizerDate: Date
    animalGroupSize: Integer
    animalDiet: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodHarvestProc: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodProdChar: [String]
    prodLabelClaims: [String]
    foodTravMode: [String]
    foodTravVehic: [String]
    foodSource: String
    foodTreatProc: [String]
    extrWeatherEvent: [ExtrWeatherEventEnum]
    dateExtrWeath: [Date]
    hostSubspecfGenlin: [String]
    intendedConsumer: [String]
    libraryPrepKit: String
    airFlowImpede: [String]
    lotNumber: [String]
    seasonHumidity: QuantityValue
    partPlantAnimal: [String]
    plantGrowthMed: PlantGrowthMedEnum
    plantReprodCrop: [PlantReprodCropEnum]
    sampPurpose: String
    repositoryName: [String]
    sampPooling: [String]
    sampSourceMatCat: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    soilConductivity: QuantityValue
    soilCover: String
    soilPH: Double
    relLocation: String
    soilPorosity: String
    temp: QuantityValue
    soilTextureClass: SoilTextureClassEnum
    soilTextureMeth: String
    soilType: String
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinGrowthMed: [String]
    spikeinStrain: [String]
    spikeinAntibiotic: [String]
    spikeinMetal: [String]
    timepoint: Double
    waterFrequency: String
    waterPH: Double
    waterSourceShared: [WaterSourceSharedEnum]
    enrichmentProtocol: String
    foodQualityDate: String
    iFSACCategory: [String]!
    animalHousing: [String]
    cultIsolDate: Date
    foodCleanProc: [FoodCleanProcEnum]
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    hostDiseaseStat: String
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    sourceMatId: String
    bioticRelationship: BioticRelationshipEnum
    trophicLevel: TrophicLevelEnum
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    nuclAcidAmp: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    pcrCond: String
    seqQualityCheck: String
    chimeraCheck: String
    associatedResource: String
    sop: String
  }

type Food-farmEnvironmentMIMS implements MIMS
  {
    latLon: String!
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    humidity: QuantityValue
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    solarIrradiance: QuantityValue
    ventilationRate: QuantityValue
    sampStorDur: String
    windSpeed: QuantityValue
    salinity: QuantityValue
    previousLandUse: String
    cropRotation: String
    soilTypeMeth: String
    totOrgCMeth: String
    totNitroContMeth: String
    salinityMeth: String
    hostAge: QuantityValue
    hostDryMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostTotMass: QuantityValue
    rootMedCarbon: String
    rootMedMacronutr: String
    rootMedMicronutr: String
    seasonTemp: QuantityValue
    seasonPrecpt: QuantityValue
    totOrgCarb: QuantityValue
    totNitroContent: QuantityValue
    conduc: QuantityValue
    turbidity: QuantityValue
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    ventilationType: String
    windDirection: String
    geneticMod: String
    hostPhenotype: String
    ph: Double
    ancesData: String
    bioticRegm: String!
    chemAdministration: [String]!
    growthHabit: GrowthHabitEnum
    hostGenotype: String
    hostTaxid: String
    mechanicalDamage: [String]
    perturbation: [String]
    rootCond: String
    rootMedPh: Double
    tillage: [TillageEnum]
    phMeth: String
    growthMedium: String
    season: String
    foodProductType: [String]!
    sampType: String!
    farmWaterSource: [FarmWaterSourceEnum]
    plantWaterMethod: String
    airPMConcen: [String]
    animalFeedEquip: [String]
    animalIntrusion: [String]
    animWaterMethod: [String]
    cropYield: String
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    plantPartMaturity: String
    adjacentEnvironment: [String]
    waterSourceAdjac: [String]
    farmEquipShared: [String]
    farmEquipSan: [String]
    farmEquipSanFreq: String
    farmEquip: [String]
    fertilizerAdmin: String
    fertilizerDate: Date
    animalGroupSize: Integer
    animalDiet: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodHarvestProc: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodProdChar: [String]
    prodLabelClaims: [String]
    foodTravMode: [String]
    foodTravVehic: [String]
    foodSource: String
    foodTreatProc: [String]
    extrWeatherEvent: [ExtrWeatherEventEnum]
    dateExtrWeath: [Date]
    hostSubspecfGenlin: [String]
    intendedConsumer: [String]
    libraryPrepKit: String
    airFlowImpede: [String]
    lotNumber: [String]
    seasonHumidity: QuantityValue
    partPlantAnimal: [String]
    plantGrowthMed: PlantGrowthMedEnum
    plantReprodCrop: [PlantReprodCropEnum]
    sampPurpose: String
    repositoryName: [String]
    sampPooling: [String]
    sampSourceMatCat: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    soilConductivity: QuantityValue
    soilCover: String
    soilPH: Double
    relLocation: String
    soilPorosity: String
    temp: QuantityValue
    soilTextureClass: SoilTextureClassEnum
    soilTextureMeth: String
    soilType: String
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinGrowthMed: [String]
    spikeinStrain: [String]
    spikeinAntibiotic: [String]
    spikeinMetal: [String]
    timepoint: Double
    waterFrequency: String
    waterPH: Double
    waterSourceShared: [WaterSourceSharedEnum]
    enrichmentProtocol: String
    foodQualityDate: String
    iFSACCategory: [String]!
    animalHousing: [String]
    cultIsolDate: Date
    foodCleanProc: [FoodCleanProcEnum]
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    hostDiseaseStat: String
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    associatedResource: String
    sop: String
  }

type Food-farmEnvironmentMISAG implements MISAG
  {
    latLon: String!
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    humidity: QuantityValue
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    solarIrradiance: QuantityValue
    ventilationRate: QuantityValue
    sampStorDur: String
    windSpeed: QuantityValue
    salinity: QuantityValue
    previousLandUse: String
    cropRotation: String
    soilTypeMeth: String
    totOrgCMeth: String
    totNitroContMeth: String
    salinityMeth: String
    hostAge: QuantityValue
    hostDryMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostTotMass: QuantityValue
    rootMedCarbon: String
    rootMedMacronutr: String
    rootMedMicronutr: String
    seasonTemp: QuantityValue
    seasonPrecpt: QuantityValue
    totOrgCarb: QuantityValue
    totNitroContent: QuantityValue
    conduc: QuantityValue
    turbidity: QuantityValue
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    ventilationType: String
    windDirection: String
    geneticMod: String
    hostPhenotype: String
    ph: Double
    ancesData: String
    bioticRegm: String!
    chemAdministration: [String]!
    growthHabit: GrowthHabitEnum
    hostGenotype: String
    hostTaxid: String
    mechanicalDamage: [String]
    perturbation: [String]
    rootCond: String
    rootMedPh: Double
    tillage: [TillageEnum]
    phMeth: String
    growthMedium: String
    season: String
    foodProductType: [String]!
    sampType: String!
    farmWaterSource: [FarmWaterSourceEnum]
    plantWaterMethod: String
    airPMConcen: [String]
    animalFeedEquip: [String]
    animalIntrusion: [String]
    animWaterMethod: [String]
    cropYield: String
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    plantPartMaturity: String
    adjacentEnvironment: [String]
    waterSourceAdjac: [String]
    farmEquipShared: [String]
    farmEquipSan: [String]
    farmEquipSanFreq: String
    farmEquip: [String]
    fertilizerAdmin: String
    fertilizerDate: Date
    animalGroupSize: Integer
    animalDiet: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodHarvestProc: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodProdChar: [String]
    prodLabelClaims: [String]
    foodTravMode: [String]
    foodTravVehic: [String]
    foodSource: String
    foodTreatProc: [String]
    extrWeatherEvent: [ExtrWeatherEventEnum]
    dateExtrWeath: [Date]
    hostSubspecfGenlin: [String]
    intendedConsumer: [String]
    libraryPrepKit: String
    airFlowImpede: [String]
    lotNumber: [String]
    seasonHumidity: QuantityValue
    partPlantAnimal: [String]
    plantGrowthMed: PlantGrowthMedEnum
    plantReprodCrop: [PlantReprodCropEnum]
    sampPurpose: String
    repositoryName: [String]
    sampPooling: [String]
    sampSourceMatCat: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    soilConductivity: QuantityValue
    soilCover: String
    soilPH: Double
    relLocation: String
    soilPorosity: String
    temp: QuantityValue
    soilTextureClass: SoilTextureClassEnum
    soilTextureMeth: String
    soilType: String
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinGrowthMed: [String]
    spikeinStrain: [String]
    spikeinAntibiotic: [String]
    spikeinMetal: [String]
    timepoint: Double
    waterFrequency: String
    waterPH: Double
    waterSourceShared: [WaterSourceSharedEnum]
    enrichmentProtocol: String
    foodQualityDate: String
    iFSACCategory: [String]!
    animalHousing: [String]
    cultIsolDate: Date
    foodCleanProc: [FoodCleanProcEnum]
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    hostDiseaseStat: String
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    sortTech: SortTechEnum!
    singleCellLysisAppr: SingleCellLysisApprEnum!
    singleCellLysisProt: String
    wgaAmpAppr: String!
    wgaAmpKit: String
    associatedResource: String
    sop: String
  }

type Food-farmEnvironmentMIUVIG implements MIUVIG
  {
    latLon: String!
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    humidity: QuantityValue
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    solarIrradiance: QuantityValue
    ventilationRate: QuantityValue
    sampStorDur: String
    windSpeed: QuantityValue
    salinity: QuantityValue
    previousLandUse: String
    cropRotation: String
    soilTypeMeth: String
    totOrgCMeth: String
    totNitroContMeth: String
    salinityMeth: String
    hostAge: QuantityValue
    hostDryMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostTotMass: QuantityValue
    rootMedCarbon: String
    rootMedMacronutr: String
    rootMedMicronutr: String
    seasonTemp: QuantityValue
    seasonPrecpt: QuantityValue
    totOrgCarb: QuantityValue
    totNitroContent: QuantityValue
    conduc: QuantityValue
    turbidity: QuantityValue
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    ventilationType: String
    windDirection: String
    geneticMod: String
    hostPhenotype: String
    ph: Double
    ancesData: String
    bioticRegm: String!
    chemAdministration: [String]!
    growthHabit: GrowthHabitEnum
    hostGenotype: String
    hostTaxid: String
    mechanicalDamage: [String]
    perturbation: [String]
    rootCond: String
    rootMedPh: Double
    tillage: [TillageEnum]
    phMeth: String
    growthMedium: String
    season: String
    foodProductType: [String]!
    sampType: String!
    farmWaterSource: [FarmWaterSourceEnum]
    plantWaterMethod: String
    airPMConcen: [String]
    animalFeedEquip: [String]
    animalIntrusion: [String]
    animWaterMethod: [String]
    cropYield: String
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    plantPartMaturity: String
    adjacentEnvironment: [String]
    waterSourceAdjac: [String]
    farmEquipShared: [String]
    farmEquipSan: [String]
    farmEquipSanFreq: String
    farmEquip: [String]
    fertilizerAdmin: String
    fertilizerDate: Date
    animalGroupSize: Integer
    animalDiet: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodHarvestProc: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodProdChar: [String]
    prodLabelClaims: [String]
    foodTravMode: [String]
    foodTravVehic: [String]
    foodSource: String
    foodTreatProc: [String]
    extrWeatherEvent: [ExtrWeatherEventEnum]
    dateExtrWeath: [Date]
    hostSubspecfGenlin: [String]
    intendedConsumer: [String]
    libraryPrepKit: String
    airFlowImpede: [String]
    lotNumber: [String]
    seasonHumidity: QuantityValue
    partPlantAnimal: [String]
    plantGrowthMed: PlantGrowthMedEnum
    plantReprodCrop: [PlantReprodCropEnum]
    sampPurpose: String
    repositoryName: [String]
    sampPooling: [String]
    sampSourceMatCat: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    soilConductivity: QuantityValue
    soilCover: String
    soilPH: Double
    relLocation: String
    soilPorosity: String
    temp: QuantityValue
    soilTextureClass: SoilTextureClassEnum
    soilTextureMeth: String
    soilType: String
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinGrowthMed: [String]
    spikeinStrain: [String]
    spikeinAntibiotic: [String]
    spikeinMetal: [String]
    timepoint: Double
    waterFrequency: String
    waterPH: Double
    waterSourceShared: [WaterSourceSharedEnum]
    enrichmentProtocol: String
    foodQualityDate: String
    iFSACCategory: [String]!
    animalHousing: [String]
    cultIsolDate: Date
    foodCleanProc: [FoodCleanProcEnum]
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    hostDiseaseStat: String
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sourceUvig: SourceUvigEnum!
    virusEnrichAppr: VirusEnrichApprEnum!
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String
    complSoftware: String
    complAppr: ComplApprEnum
    sortTech: SortTechEnum
    singleCellLysisAppr: SingleCellLysisApprEnum
    singleCellLysisProt: String
    wgaAmpAppr: String
    wgaAmpKit: String
    binParam: BinParamEnum
    binSoftware: String
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    virIdentSoftware: String!
    predGenomeType: PredGenomeTypeEnum!
    predGenomeStruc: PredGenomeStrucEnum!
    detecType: String!
    otuClassAppr: String
    otuSeqCompAppr: String
    otuDb: String
    hostPredAppr: HostPredApprEnum
    hostPredEstAcc: String
    associatedResource: String
    sop: String
  }

type Food-foodProductionFacility
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    sampStorTemp: QuantityValue
    sampStorDur: String
    roomDim: String
    freqClean: FreqCleanEnum
    sampRoomId: Integer
    poolDnaExtracts: String
    sampStorLoc: String
    surfMaterial: SurfMaterialEnum
    indoorSurf: IndoorSurfEnum
    avgOccup: Double
    sampFloor: SampFloorEnum
    geneticMod: String
    collSiteGeoFeat: String!
    sampSourceMatCat: String!
    sampType: String!
    sampStorMedia: String!
    sampStorDevice: String!
    foodProductType: [String]!
    iFSACCategory: [String]!
    foodProductQual: String!
    foodContactSurf: [String]!
    facilityType: [FacilityTypeEnum]
    foodTravMode: [String]
    foodTravVehic: [String]
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sampCollectMethod: String
    numSampCollect: QuantityValue
    lotNumber: [String]
    hygienicArea: String
    envMonitoringZone: String
    areaSampSize: String
    sampSurfMoisture: [SampSurfMoistureEnum]
    sampLocCondition: SampLocConditionEnum
    biocideUsed: [String]
    sterMethSampRoom: [String]
    enrichmentProtocol: String
    cultTarget: [String]
    microbCultMed: String
    timepoint: Double
    bacterialDensity: QuantityValue
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    sampPooling: [String]
    sampPurpose: String
    sampRepTech: QuantityValue
    sampRepBiol: QuantityValue
    sampTransportCont: SampTransportContEnum
    studyDesign: [String]
    nuclAcidExtKit: [String]
    libraryPrepKit: String
    sequencingKit: String
    sequencingLocation: String
    studyIncTemp: QuantityValue
    studyIncDur: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    foodSource: String
    foodDisPoint: [String]
    foodDisPointCity: String
    foodOrigin: String
    foodProdSynonym: [String]
    foodAdditive: [String]
    foodTraceList: FoodTraceListEnum
    partPlantAnimal: [String]
    foodIngredient: [String]
    specIntendedCons: [String]
    hACCPTerm: [String]
    dietaryClaimUse: [String]
    foodAllergenLabel: [String]
    foodProdChar: [String]
    prodLabelClaims: [String]
    foodNameStatus: String
    foodPreservProc: [String]
    foodCookingProc: [String]
    foodTreatProc: [String]
    foodContainWrap: String
    foodPackCapacity: QuantityValue
    foodPackMedium: [String]
    foodPriorContact: [String]
    foodProd: [String]
    foodQualityDate: String
    repositoryName: [String]
    intendedConsumer: [String]
    foodPackIntegrity: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    subspecfGenLin: String
  }

type Food-foodProductionFacilityMIGSBacteria implements MIGSBacteria
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    sampStorTemp: QuantityValue
    sampStorDur: String
    temp: QuantityValue
    roomDim: String
    freqClean: FreqCleanEnum
    sampRoomId: Integer
    poolDnaExtracts: String
    sampStorLoc: String
    surfMaterial: SurfMaterialEnum
    indoorSurf: IndoorSurfEnum
    avgOccup: Double
    sampFloor: SampFloorEnum
    geneticMod: String
    collSiteGeoFeat: String!
    sampSourceMatCat: String!
    sampType: String!
    sampStorMedia: String!
    sampStorDevice: String!
    foodProductType: [String]!
    iFSACCategory: [String]!
    foodProductQual: String!
    foodContactSurf: [String]!
    facilityType: [FacilityTypeEnum]
    foodTravMode: [String]
    foodTravVehic: [String]
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sampCollectMethod: String
    numSampCollect: QuantityValue
    lotNumber: [String]
    hygienicArea: String
    envMonitoringZone: String
    areaSampSize: String
    sampSurfMoisture: [SampSurfMoistureEnum]
    sampLocCondition: SampLocConditionEnum
    biocideUsed: [String]
    sterMethSampRoom: [String]
    enrichmentProtocol: String
    cultTarget: [String]
    microbCultMed: String
    timepoint: Double
    bacterialDensity: QuantityValue
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    sampPooling: [String]
    sampPurpose: String
    sampRepTech: QuantityValue
    sampRepBiol: QuantityValue
    sampTransportCont: SampTransportContEnum
    studyDesign: [String]
    nuclAcidExtKit: [String]
    libraryPrepKit: String
    sequencingKit: String
    sequencingLocation: String
    studyIncTemp: QuantityValue
    studyIncDur: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    foodSource: String
    foodDisPoint: [String]
    foodDisPointCity: String
    foodOrigin: String
    foodProdSynonym: [String]
    foodAdditive: [String]
    foodTraceList: FoodTraceListEnum
    partPlantAnimal: [String]
    foodIngredient: [String]
    specIntendedCons: [String]
    hACCPTerm: [String]
    dietaryClaimUse: [String]
    foodAllergenLabel: [String]
    foodProdChar: [String]
    prodLabelClaims: [String]
    foodNameStatus: String
    foodPreservProc: [String]
    foodCookingProc: [String]
    foodTreatProc: [String]
    foodContainWrap: String
    foodPackCapacity: QuantityValue
    foodPackMedium: [String]
    foodPriorContact: [String]
    foodProd: [String]
    foodQualityDate: String
    repositoryName: [String]
    intendedConsumer: [String]
    foodPackIntegrity: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    subspecfGenLin: String
    sampTaxonId: String!
    negContType: NegContTypeEnum
    posContType: String
    numReplicons: Integer!
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String!
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    trophicLevel: TrophicLevelEnum
    encodedTraits: String
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Food-foodProductionFacilityMIGSEukaryote implements MIGSEukaryote
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    sampStorTemp: QuantityValue
    sampStorDur: String
    temp: QuantityValue
    roomDim: String
    freqClean: FreqCleanEnum
    sampRoomId: Integer
    poolDnaExtracts: String
    sampStorLoc: String
    surfMaterial: SurfMaterialEnum
    indoorSurf: IndoorSurfEnum
    avgOccup: Double
    sampFloor: SampFloorEnum
    geneticMod: String
    collSiteGeoFeat: String!
    sampSourceMatCat: String!
    sampType: String!
    sampStorMedia: String!
    sampStorDevice: String!
    foodProductType: [String]!
    iFSACCategory: [String]!
    foodProductQual: String!
    foodContactSurf: [String]!
    facilityType: [FacilityTypeEnum]
    foodTravMode: [String]
    foodTravVehic: [String]
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sampCollectMethod: String
    numSampCollect: QuantityValue
    lotNumber: [String]
    hygienicArea: String
    envMonitoringZone: String
    areaSampSize: String
    sampSurfMoisture: [SampSurfMoistureEnum]
    sampLocCondition: SampLocConditionEnum
    biocideUsed: [String]
    sterMethSampRoom: [String]
    enrichmentProtocol: String
    cultTarget: [String]
    microbCultMed: String
    timepoint: Double
    bacterialDensity: QuantityValue
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    sampPooling: [String]
    sampPurpose: String
    sampRepTech: QuantityValue
    sampRepBiol: QuantityValue
    sampTransportCont: SampTransportContEnum
    studyDesign: [String]
    nuclAcidExtKit: [String]
    libraryPrepKit: String
    sequencingKit: String
    sequencingLocation: String
    studyIncTemp: QuantityValue
    studyIncDur: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    foodSource: String
    foodDisPoint: [String]
    foodDisPointCity: String
    foodOrigin: String
    foodProdSynonym: [String]
    foodAdditive: [String]
    foodTraceList: FoodTraceListEnum
    partPlantAnimal: [String]
    foodIngredient: [String]
    specIntendedCons: [String]
    hACCPTerm: [String]
    dietaryClaimUse: [String]
    foodAllergenLabel: [String]
    foodProdChar: [String]
    prodLabelClaims: [String]
    foodNameStatus: String
    foodPreservProc: [String]
    foodCookingProc: [String]
    foodTreatProc: [String]
    foodContainWrap: String
    foodPackCapacity: QuantityValue
    foodPackMedium: [String]
    foodPriorContact: [String]
    foodProd: [String]
    foodQualityDate: String
    repositoryName: [String]
    intendedConsumer: [String]
    foodPackIntegrity: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    subspecfGenLin: String
    sampTaxonId: String!
    negContType: NegContTypeEnum
    posContType: String
    ploidy: String
    numReplicons: Integer
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    trophicLevel: TrophicLevelEnum
    propagation: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Food-foodProductionFacilityMIGSOrg implements MIGSOrg
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    sampStorTemp: QuantityValue
    sampStorDur: String
    temp: QuantityValue
    roomDim: String
    freqClean: FreqCleanEnum
    sampRoomId: Integer
    poolDnaExtracts: String
    sampStorLoc: String
    surfMaterial: SurfMaterialEnum
    indoorSurf: IndoorSurfEnum
    avgOccup: Double
    sampFloor: SampFloorEnum
    geneticMod: String
    collSiteGeoFeat: String!
    sampSourceMatCat: String!
    sampType: String!
    sampStorMedia: String!
    sampStorDevice: String!
    foodProductType: [String]!
    iFSACCategory: [String]!
    foodProductQual: String!
    foodContactSurf: [String]!
    facilityType: [FacilityTypeEnum]
    foodTravMode: [String]
    foodTravVehic: [String]
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sampCollectMethod: String
    numSampCollect: QuantityValue
    lotNumber: [String]
    hygienicArea: String
    envMonitoringZone: String
    areaSampSize: String
    sampSurfMoisture: [SampSurfMoistureEnum]
    sampLocCondition: SampLocConditionEnum
    biocideUsed: [String]
    sterMethSampRoom: [String]
    enrichmentProtocol: String
    cultTarget: [String]
    microbCultMed: String
    timepoint: Double
    bacterialDensity: QuantityValue
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    sampPooling: [String]
    sampPurpose: String
    sampRepTech: QuantityValue
    sampRepBiol: QuantityValue
    sampTransportCont: SampTransportContEnum
    studyDesign: [String]
    nuclAcidExtKit: [String]
    libraryPrepKit: String
    sequencingKit: String
    sequencingLocation: String
    studyIncTemp: QuantityValue
    studyIncDur: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    foodSource: String
    foodDisPoint: [String]
    foodDisPointCity: String
    foodOrigin: String
    foodProdSynonym: [String]
    foodAdditive: [String]
    foodTraceList: FoodTraceListEnum
    partPlantAnimal: [String]
    foodIngredient: [String]
    specIntendedCons: [String]
    hACCPTerm: [String]
    dietaryClaimUse: [String]
    foodAllergenLabel: [String]
    foodProdChar: [String]
    prodLabelClaims: [String]
    foodNameStatus: String
    foodPreservProc: [String]
    foodCookingProc: [String]
    foodTreatProc: [String]
    foodContainWrap: String
    foodPackCapacity: QuantityValue
    foodPackMedium: [String]
    foodPriorContact: [String]
    foodProd: [String]
    foodQualityDate: String
    repositoryName: [String]
    intendedConsumer: [String]
    foodPackIntegrity: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    subspecfGenLin: String
    sampTaxonId: String!
    negContType: NegContTypeEnum
    posContType: String
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Food-foodProductionFacilityMIGSPlant implements MIGSPlant
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    sampStorTemp: QuantityValue
    sampStorDur: String
    temp: QuantityValue
    roomDim: String
    freqClean: FreqCleanEnum
    sampRoomId: Integer
    poolDnaExtracts: String
    sampStorLoc: String
    surfMaterial: SurfMaterialEnum
    indoorSurf: IndoorSurfEnum
    avgOccup: Double
    sampFloor: SampFloorEnum
    geneticMod: String
    collSiteGeoFeat: String!
    sampSourceMatCat: String!
    sampType: String!
    sampStorMedia: String!
    sampStorDevice: String!
    foodProductType: [String]!
    iFSACCategory: [String]!
    foodProductQual: String!
    foodContactSurf: [String]!
    facilityType: [FacilityTypeEnum]
    foodTravMode: [String]
    foodTravVehic: [String]
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sampCollectMethod: String
    numSampCollect: QuantityValue
    lotNumber: [String]
    hygienicArea: String
    envMonitoringZone: String
    areaSampSize: String
    sampSurfMoisture: [SampSurfMoistureEnum]
    sampLocCondition: SampLocConditionEnum
    biocideUsed: [String]
    sterMethSampRoom: [String]
    enrichmentProtocol: String
    cultTarget: [String]
    microbCultMed: String
    timepoint: Double
    bacterialDensity: QuantityValue
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    sampPooling: [String]
    sampPurpose: String
    sampRepTech: QuantityValue
    sampRepBiol: QuantityValue
    sampTransportCont: SampTransportContEnum
    studyDesign: [String]
    nuclAcidExtKit: [String]
    libraryPrepKit: String
    sequencingKit: String
    sequencingLocation: String
    studyIncTemp: QuantityValue
    studyIncDur: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    foodSource: String
    foodDisPoint: [String]
    foodDisPointCity: String
    foodOrigin: String
    foodProdSynonym: [String]
    foodAdditive: [String]
    foodTraceList: FoodTraceListEnum
    partPlantAnimal: [String]
    foodIngredient: [String]
    specIntendedCons: [String]
    hACCPTerm: [String]
    dietaryClaimUse: [String]
    foodAllergenLabel: [String]
    foodProdChar: [String]
    prodLabelClaims: [String]
    foodNameStatus: String
    foodPreservProc: [String]
    foodCookingProc: [String]
    foodTreatProc: [String]
    foodContainWrap: String
    foodPackCapacity: QuantityValue
    foodPackMedium: [String]
    foodPriorContact: [String]
    foodProd: [String]
    foodQualityDate: String
    repositoryName: [String]
    intendedConsumer: [String]
    foodPackIntegrity: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    subspecfGenLin: String
    sampTaxonId: String!
    negContType: NegContTypeEnum
    posContType: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    specificHost: String
    hostSpecRange: Integer
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Food-foodProductionFacilityMIGSVirus implements MIGSVirus
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    sampStorTemp: QuantityValue
    sampStorDur: String
    temp: QuantityValue
    roomDim: String
    freqClean: FreqCleanEnum
    sampRoomId: Integer
    poolDnaExtracts: String
    sampStorLoc: String
    surfMaterial: SurfMaterialEnum
    indoorSurf: IndoorSurfEnum
    avgOccup: Double
    sampFloor: SampFloorEnum
    geneticMod: String
    collSiteGeoFeat: String!
    sampSourceMatCat: String!
    sampType: String!
    sampStorMedia: String!
    sampStorDevice: String!
    foodProductType: [String]!
    iFSACCategory: [String]!
    foodProductQual: String!
    foodContactSurf: [String]!
    facilityType: [FacilityTypeEnum]
    foodTravMode: [String]
    foodTravVehic: [String]
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sampCollectMethod: String
    numSampCollect: QuantityValue
    lotNumber: [String]
    hygienicArea: String
    envMonitoringZone: String
    areaSampSize: String
    sampSurfMoisture: [SampSurfMoistureEnum]
    sampLocCondition: SampLocConditionEnum
    biocideUsed: [String]
    sterMethSampRoom: [String]
    enrichmentProtocol: String
    cultTarget: [String]
    microbCultMed: String
    timepoint: Double
    bacterialDensity: QuantityValue
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    sampPooling: [String]
    sampPurpose: String
    sampRepTech: QuantityValue
    sampRepBiol: QuantityValue
    sampTransportCont: SampTransportContEnum
    studyDesign: [String]
    nuclAcidExtKit: [String]
    libraryPrepKit: String
    sequencingKit: String
    sequencingLocation: String
    studyIncTemp: QuantityValue
    studyIncDur: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    foodSource: String
    foodDisPoint: [String]
    foodDisPointCity: String
    foodOrigin: String
    foodProdSynonym: [String]
    foodAdditive: [String]
    foodTraceList: FoodTraceListEnum
    partPlantAnimal: [String]
    foodIngredient: [String]
    specIntendedCons: [String]
    hACCPTerm: [String]
    dietaryClaimUse: [String]
    foodAllergenLabel: [String]
    foodProdChar: [String]
    prodLabelClaims: [String]
    foodNameStatus: String
    foodPreservProc: [String]
    foodCookingProc: [String]
    foodTreatProc: [String]
    foodContainWrap: String
    foodPackCapacity: QuantityValue
    foodPackMedium: [String]
    foodPriorContact: [String]
    foodProd: [String]
    foodQualityDate: String
    repositoryName: [String]
    intendedConsumer: [String]
    foodPackIntegrity: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    subspecfGenLin: String
    sampTaxonId: String!
    negContType: NegContTypeEnum
    posContType: String
    numReplicons: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    virusEnrichAppr: VirusEnrichApprEnum
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Food-foodProductionFacilityMIMAG implements MIMAG
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    sampStorTemp: QuantityValue
    sampStorDur: String
    temp: QuantityValue
    roomDim: String
    freqClean: FreqCleanEnum
    sampRoomId: Integer
    poolDnaExtracts: String
    sampStorLoc: String
    surfMaterial: SurfMaterialEnum
    indoorSurf: IndoorSurfEnum
    avgOccup: Double
    sampFloor: SampFloorEnum
    geneticMod: String
    collSiteGeoFeat: String!
    sampSourceMatCat: String!
    sampType: String!
    sampStorMedia: String!
    sampStorDevice: String!
    foodProductType: [String]!
    iFSACCategory: [String]!
    foodProductQual: String!
    foodContactSurf: [String]!
    facilityType: [FacilityTypeEnum]
    foodTravMode: [String]
    foodTravVehic: [String]
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sampCollectMethod: String
    numSampCollect: QuantityValue
    lotNumber: [String]
    hygienicArea: String
    envMonitoringZone: String
    areaSampSize: String
    sampSurfMoisture: [SampSurfMoistureEnum]
    sampLocCondition: SampLocConditionEnum
    biocideUsed: [String]
    sterMethSampRoom: [String]
    enrichmentProtocol: String
    cultTarget: [String]
    microbCultMed: String
    timepoint: Double
    bacterialDensity: QuantityValue
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    sampPooling: [String]
    sampPurpose: String
    sampRepTech: QuantityValue
    sampRepBiol: QuantityValue
    sampTransportCont: SampTransportContEnum
    studyDesign: [String]
    nuclAcidExtKit: [String]
    libraryPrepKit: String
    sequencingKit: String
    sequencingLocation: String
    studyIncTemp: QuantityValue
    studyIncDur: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    foodSource: String
    foodDisPoint: [String]
    foodDisPointCity: String
    foodOrigin: String
    foodProdSynonym: [String]
    foodAdditive: [String]
    foodTraceList: FoodTraceListEnum
    partPlantAnimal: [String]
    foodIngredient: [String]
    specIntendedCons: [String]
    hACCPTerm: [String]
    dietaryClaimUse: [String]
    foodAllergenLabel: [String]
    foodProdChar: [String]
    prodLabelClaims: [String]
    foodNameStatus: String
    foodPreservProc: [String]
    foodCookingProc: [String]
    foodTreatProc: [String]
    foodContainWrap: String
    foodPackCapacity: QuantityValue
    foodPackMedium: [String]
    foodPriorContact: [String]
    foodProd: [String]
    foodQualityDate: String
    repositoryName: [String]
    intendedConsumer: [String]
    foodPackIntegrity: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    subspecfGenLin: String
    sampTaxonId: String!
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    binParam: BinParamEnum!
    binSoftware: String!
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    associatedResource: String
    sop: String
  }

type Food-foodProductionFacilityMIMARKSSpecimen implements MIMARKSSpecimen
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    sampStorTemp: QuantityValue
    sampStorDur: String
    temp: QuantityValue
    roomDim: String
    freqClean: FreqCleanEnum
    sampRoomId: Integer
    poolDnaExtracts: String
    sampStorLoc: String
    surfMaterial: SurfMaterialEnum
    indoorSurf: IndoorSurfEnum
    avgOccup: Double
    sampFloor: SampFloorEnum
    geneticMod: String
    collSiteGeoFeat: String!
    sampSourceMatCat: String!
    sampType: String!
    sampStorMedia: String!
    sampStorDevice: String!
    foodProductType: [String]!
    iFSACCategory: [String]!
    foodProductQual: String!
    foodContactSurf: [String]!
    facilityType: [FacilityTypeEnum]
    foodTravMode: [String]
    foodTravVehic: [String]
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sampCollectMethod: String
    numSampCollect: QuantityValue
    lotNumber: [String]
    hygienicArea: String
    envMonitoringZone: String
    areaSampSize: String
    sampSurfMoisture: [SampSurfMoistureEnum]
    sampLocCondition: SampLocConditionEnum
    biocideUsed: [String]
    sterMethSampRoom: [String]
    enrichmentProtocol: String
    cultTarget: [String]
    microbCultMed: String
    timepoint: Double
    bacterialDensity: QuantityValue
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    sampPooling: [String]
    sampPurpose: String
    sampRepTech: QuantityValue
    sampRepBiol: QuantityValue
    sampTransportCont: SampTransportContEnum
    studyDesign: [String]
    nuclAcidExtKit: [String]
    libraryPrepKit: String
    sequencingKit: String
    sequencingLocation: String
    studyIncTemp: QuantityValue
    studyIncDur: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    foodSource: String
    foodDisPoint: [String]
    foodDisPointCity: String
    foodOrigin: String
    foodProdSynonym: [String]
    foodAdditive: [String]
    foodTraceList: FoodTraceListEnum
    partPlantAnimal: [String]
    foodIngredient: [String]
    specIntendedCons: [String]
    hACCPTerm: [String]
    dietaryClaimUse: [String]
    foodAllergenLabel: [String]
    foodProdChar: [String]
    prodLabelClaims: [String]
    foodNameStatus: String
    foodPreservProc: [String]
    foodCookingProc: [String]
    foodTreatProc: [String]
    foodContainWrap: String
    foodPackCapacity: QuantityValue
    foodPackMedium: [String]
    foodPriorContact: [String]
    foodProd: [String]
    foodQualityDate: String
    repositoryName: [String]
    intendedConsumer: [String]
    foodPackIntegrity: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    subspecfGenLin: String
    sampTaxonId: String!
    negContType: NegContTypeEnum
    posContType: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    mid: String
    adapters: String
    pcrCond: String
    seqQualityCheck: String
    chimeraCheck: String
    assemblySoftware: String
    associatedResource: String
    sop: String
  }

type Food-foodProductionFacilityMIMARKSSurvey implements MIMARKSSurvey
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    sampStorTemp: QuantityValue
    sampStorDur: String
    temp: QuantityValue
    roomDim: String
    freqClean: FreqCleanEnum
    sampRoomId: Integer
    poolDnaExtracts: String
    sampStorLoc: String
    surfMaterial: SurfMaterialEnum
    indoorSurf: IndoorSurfEnum
    avgOccup: Double
    sampFloor: SampFloorEnum
    geneticMod: String
    collSiteGeoFeat: String!
    sampSourceMatCat: String!
    sampType: String!
    sampStorMedia: String!
    sampStorDevice: String!
    foodProductType: [String]!
    iFSACCategory: [String]!
    foodProductQual: String!
    foodContactSurf: [String]!
    facilityType: [FacilityTypeEnum]
    foodTravMode: [String]
    foodTravVehic: [String]
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sampCollectMethod: String
    numSampCollect: QuantityValue
    lotNumber: [String]
    hygienicArea: String
    envMonitoringZone: String
    areaSampSize: String
    sampSurfMoisture: [SampSurfMoistureEnum]
    sampLocCondition: SampLocConditionEnum
    biocideUsed: [String]
    sterMethSampRoom: [String]
    enrichmentProtocol: String
    cultTarget: [String]
    microbCultMed: String
    timepoint: Double
    bacterialDensity: QuantityValue
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    sampPooling: [String]
    sampPurpose: String
    sampRepTech: QuantityValue
    sampRepBiol: QuantityValue
    sampTransportCont: SampTransportContEnum
    studyDesign: [String]
    nuclAcidExtKit: [String]
    libraryPrepKit: String
    sequencingKit: String
    sequencingLocation: String
    studyIncTemp: QuantityValue
    studyIncDur: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    foodSource: String
    foodDisPoint: [String]
    foodDisPointCity: String
    foodOrigin: String
    foodProdSynonym: [String]
    foodAdditive: [String]
    foodTraceList: FoodTraceListEnum
    partPlantAnimal: [String]
    foodIngredient: [String]
    specIntendedCons: [String]
    hACCPTerm: [String]
    dietaryClaimUse: [String]
    foodAllergenLabel: [String]
    foodProdChar: [String]
    prodLabelClaims: [String]
    foodNameStatus: String
    foodPreservProc: [String]
    foodCookingProc: [String]
    foodTreatProc: [String]
    foodContainWrap: String
    foodPackCapacity: QuantityValue
    foodPackMedium: [String]
    foodPriorContact: [String]
    foodProd: [String]
    foodQualityDate: String
    repositoryName: [String]
    intendedConsumer: [String]
    foodPackIntegrity: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    subspecfGenLin: String
    sampTaxonId: String!
    negContType: NegContTypeEnum
    posContType: String
    extrachromElements: Integer
    sourceMatId: String
    bioticRelationship: BioticRelationshipEnum
    trophicLevel: TrophicLevelEnum
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    nuclAcidAmp: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    pcrCond: String
    seqQualityCheck: String
    chimeraCheck: String
    associatedResource: String
    sop: String
  }

type Food-foodProductionFacilityMIMS implements MIMS
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    sampStorTemp: QuantityValue
    sampStorDur: String
    temp: QuantityValue
    roomDim: String
    freqClean: FreqCleanEnum
    sampRoomId: Integer
    poolDnaExtracts: String
    sampStorLoc: String
    surfMaterial: SurfMaterialEnum
    indoorSurf: IndoorSurfEnum
    avgOccup: Double
    sampFloor: SampFloorEnum
    geneticMod: String
    collSiteGeoFeat: String!
    sampSourceMatCat: String!
    sampType: String!
    sampStorMedia: String!
    sampStorDevice: String!
    foodProductType: [String]!
    iFSACCategory: [String]!
    foodProductQual: String!
    foodContactSurf: [String]!
    facilityType: [FacilityTypeEnum]
    foodTravMode: [String]
    foodTravVehic: [String]
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sampCollectMethod: String
    numSampCollect: QuantityValue
    lotNumber: [String]
    hygienicArea: String
    envMonitoringZone: String
    areaSampSize: String
    sampSurfMoisture: [SampSurfMoistureEnum]
    sampLocCondition: SampLocConditionEnum
    biocideUsed: [String]
    sterMethSampRoom: [String]
    enrichmentProtocol: String
    cultTarget: [String]
    microbCultMed: String
    timepoint: Double
    bacterialDensity: QuantityValue
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    sampPooling: [String]
    sampPurpose: String
    sampRepTech: QuantityValue
    sampRepBiol: QuantityValue
    sampTransportCont: SampTransportContEnum
    studyDesign: [String]
    nuclAcidExtKit: [String]
    libraryPrepKit: String
    sequencingKit: String
    sequencingLocation: String
    studyIncTemp: QuantityValue
    studyIncDur: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    foodSource: String
    foodDisPoint: [String]
    foodDisPointCity: String
    foodOrigin: String
    foodProdSynonym: [String]
    foodAdditive: [String]
    foodTraceList: FoodTraceListEnum
    partPlantAnimal: [String]
    foodIngredient: [String]
    specIntendedCons: [String]
    hACCPTerm: [String]
    dietaryClaimUse: [String]
    foodAllergenLabel: [String]
    foodProdChar: [String]
    prodLabelClaims: [String]
    foodNameStatus: String
    foodPreservProc: [String]
    foodCookingProc: [String]
    foodTreatProc: [String]
    foodContainWrap: String
    foodPackCapacity: QuantityValue
    foodPackMedium: [String]
    foodPriorContact: [String]
    foodProd: [String]
    foodQualityDate: String
    repositoryName: [String]
    intendedConsumer: [String]
    foodPackIntegrity: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    subspecfGenLin: String
    sampTaxonId: String!
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    associatedResource: String
    sop: String
  }

type Food-foodProductionFacilityMISAG implements MISAG
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    sampStorTemp: QuantityValue
    sampStorDur: String
    temp: QuantityValue
    roomDim: String
    freqClean: FreqCleanEnum
    sampRoomId: Integer
    poolDnaExtracts: String
    sampStorLoc: String
    surfMaterial: SurfMaterialEnum
    indoorSurf: IndoorSurfEnum
    avgOccup: Double
    sampFloor: SampFloorEnum
    geneticMod: String
    collSiteGeoFeat: String!
    sampSourceMatCat: String!
    sampType: String!
    sampStorMedia: String!
    sampStorDevice: String!
    foodProductType: [String]!
    iFSACCategory: [String]!
    foodProductQual: String!
    foodContactSurf: [String]!
    facilityType: [FacilityTypeEnum]
    foodTravMode: [String]
    foodTravVehic: [String]
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sampCollectMethod: String
    numSampCollect: QuantityValue
    lotNumber: [String]
    hygienicArea: String
    envMonitoringZone: String
    areaSampSize: String
    sampSurfMoisture: [SampSurfMoistureEnum]
    sampLocCondition: SampLocConditionEnum
    biocideUsed: [String]
    sterMethSampRoom: [String]
    enrichmentProtocol: String
    cultTarget: [String]
    microbCultMed: String
    timepoint: Double
    bacterialDensity: QuantityValue
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    sampPooling: [String]
    sampPurpose: String
    sampRepTech: QuantityValue
    sampRepBiol: QuantityValue
    sampTransportCont: SampTransportContEnum
    studyDesign: [String]
    nuclAcidExtKit: [String]
    libraryPrepKit: String
    sequencingKit: String
    sequencingLocation: String
    studyIncTemp: QuantityValue
    studyIncDur: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    foodSource: String
    foodDisPoint: [String]
    foodDisPointCity: String
    foodOrigin: String
    foodProdSynonym: [String]
    foodAdditive: [String]
    foodTraceList: FoodTraceListEnum
    partPlantAnimal: [String]
    foodIngredient: [String]
    specIntendedCons: [String]
    hACCPTerm: [String]
    dietaryClaimUse: [String]
    foodAllergenLabel: [String]
    foodProdChar: [String]
    prodLabelClaims: [String]
    foodNameStatus: String
    foodPreservProc: [String]
    foodCookingProc: [String]
    foodTreatProc: [String]
    foodContainWrap: String
    foodPackCapacity: QuantityValue
    foodPackMedium: [String]
    foodPriorContact: [String]
    foodProd: [String]
    foodQualityDate: String
    repositoryName: [String]
    intendedConsumer: [String]
    foodPackIntegrity: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    subspecfGenLin: String
    sampTaxonId: String!
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    sortTech: SortTechEnum!
    singleCellLysisAppr: SingleCellLysisApprEnum!
    singleCellLysisProt: String
    wgaAmpAppr: String!
    wgaAmpKit: String
    associatedResource: String
    sop: String
  }

type Food-foodProductionFacilityMIUVIG implements MIUVIG
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    sampStorTemp: QuantityValue
    sampStorDur: String
    temp: QuantityValue
    roomDim: String
    freqClean: FreqCleanEnum
    sampRoomId: Integer
    poolDnaExtracts: String
    sampStorLoc: String
    surfMaterial: SurfMaterialEnum
    indoorSurf: IndoorSurfEnum
    avgOccup: Double
    sampFloor: SampFloorEnum
    geneticMod: String
    collSiteGeoFeat: String!
    sampSourceMatCat: String!
    sampType: String!
    sampStorMedia: String!
    sampStorDevice: String!
    foodProductType: [String]!
    iFSACCategory: [String]!
    foodProductQual: String!
    foodContactSurf: [String]!
    facilityType: [FacilityTypeEnum]
    foodTravMode: [String]
    foodTravVehic: [String]
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sampCollectMethod: String
    numSampCollect: QuantityValue
    lotNumber: [String]
    hygienicArea: String
    envMonitoringZone: String
    areaSampSize: String
    sampSurfMoisture: [SampSurfMoistureEnum]
    sampLocCondition: SampLocConditionEnum
    biocideUsed: [String]
    sterMethSampRoom: [String]
    enrichmentProtocol: String
    cultTarget: [String]
    microbCultMed: String
    timepoint: Double
    bacterialDensity: QuantityValue
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    sampPooling: [String]
    sampPurpose: String
    sampRepTech: QuantityValue
    sampRepBiol: QuantityValue
    sampTransportCont: SampTransportContEnum
    studyDesign: [String]
    nuclAcidExtKit: [String]
    libraryPrepKit: String
    sequencingKit: String
    sequencingLocation: String
    studyIncTemp: QuantityValue
    studyIncDur: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    foodSource: String
    foodDisPoint: [String]
    foodDisPointCity: String
    foodOrigin: String
    foodProdSynonym: [String]
    foodAdditive: [String]
    foodTraceList: FoodTraceListEnum
    partPlantAnimal: [String]
    foodIngredient: [String]
    specIntendedCons: [String]
    hACCPTerm: [String]
    dietaryClaimUse: [String]
    foodAllergenLabel: [String]
    foodProdChar: [String]
    prodLabelClaims: [String]
    foodNameStatus: String
    foodPreservProc: [String]
    foodCookingProc: [String]
    foodTreatProc: [String]
    foodContainWrap: String
    foodPackCapacity: QuantityValue
    foodPackMedium: [String]
    foodPriorContact: [String]
    foodProd: [String]
    foodQualityDate: String
    repositoryName: [String]
    intendedConsumer: [String]
    foodPackIntegrity: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    subspecfGenLin: String
    sampTaxonId: String!
    negContType: NegContTypeEnum
    posContType: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sourceUvig: SourceUvigEnum!
    virusEnrichAppr: VirusEnrichApprEnum!
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String
    complSoftware: String
    complAppr: ComplApprEnum
    sortTech: SortTechEnum
    singleCellLysisAppr: SingleCellLysisApprEnum
    singleCellLysisProt: String
    wgaAmpAppr: String
    wgaAmpKit: String
    binParam: BinParamEnum
    binSoftware: String
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    virIdentSoftware: String!
    predGenomeType: PredGenomeTypeEnum!
    predGenomeStruc: PredGenomeStrucEnum!
    detecType: String!
    otuClassAppr: String
    otuSeqCompAppr: String
    otuDb: String
    hostPredAppr: HostPredApprEnum
    hostPredEstAcc: String
    associatedResource: String
    sop: String
  }

type Food-humanFoods
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    sampStorDur: String
    poolDnaExtracts: String
    sampStorLoc: String
    geneticMod: String
    perturbation: [String]
    collSiteGeoFeat: String!
    foodProductType: [String]!
    iFSACCategory: [String]!
    fermChemAdd: [QuantityValue]
    fermChemAddPerc: [String]
    fermHeadspaceOxy: String
    fermMedium: String
    fermPH: Double
    fermRelHumidity: QuantityValue
    fermTemp: QuantityValue
    fermTime: String
    fermVessel: String
    bacterialDensity: QuantityValue
    consFoodStorDur: String
    consFoodStorTemp: String
    consPurchDate: Date
    consQtyPurchased: String
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    dietaryClaimUse: [String]
    enrichmentProtocol: String
    foodAdditive: [String]
    foodAllergenLabel: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodCookingProc: [String]
    foodDisPoint: [String]
    foodIngredient: [String]
    foodNameStatus: String
    foodOrigin: String
    foodPackCapacity: QuantityValue
    foodPackIntegrity: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodPriorContact: [String]
    foodProd: [String]
    foodProdSynonym: [String]
    foodProductQual: String
    foodQualityDate: String
    foodSource: String
    foodTraceList: FoodTraceListEnum
    foodTravMode: [String]
    foodTravVehic: [String]
    foodTreatProc: [String]
    hACCPTerm: [String]
    intendedConsumer: [String]
    libraryPrepKit: String
    lotNumber: [String]
    microbCultMed: String
    microbStart: String
    microbStartCount: MicrobStartCountEnum
    microbStartInoc: QuantityValue
    microbStartPrep: String
    microbStartSource: String
    microbStartTaxID: String
    nuclAcidExtKit: [String]
    numSampCollect: QuantityValue
    partPlantAnimal: [String]
    repositoryName: [String]
    sampleCollecMethod: String
    sampPooling: [String]
    sampRepBiol: QuantityValue
    sampRepTech: QuantityValue
    sampSourceMatCat: String
    sampStorDevice: String
    sampStorMedia: String
    sampTransportCont: SampTransportContEnum
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sampPurpose: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    spikeinAMR: [String]
    spikeinAntibiotic: [String]
    spikeinGrowthMed: [String]
    spikeinMetal: [String]
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinStrain: [String]
    studyDesign: [String]
    studyIncDur: QuantityValue
    studyIncTemp: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    timepoint: Double
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
  }

type Food-humanFoodsMIGSBacteria implements MIGSBacteria
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    sampStorDur: String
    poolDnaExtracts: String
    sampStorLoc: String
    geneticMod: String
    perturbation: [String]
    collSiteGeoFeat: String!
    foodProductType: [String]!
    iFSACCategory: [String]!
    fermChemAdd: [QuantityValue]
    fermChemAddPerc: [String]
    fermHeadspaceOxy: String
    fermMedium: String
    fermPH: Double
    fermRelHumidity: QuantityValue
    fermTemp: QuantityValue
    fermTime: String
    fermVessel: String
    bacterialDensity: QuantityValue
    consFoodStorDur: String
    consFoodStorTemp: String
    consPurchDate: Date
    consQtyPurchased: String
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    dietaryClaimUse: [String]
    enrichmentProtocol: String
    foodAdditive: [String]
    foodAllergenLabel: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodCookingProc: [String]
    foodDisPoint: [String]
    foodIngredient: [String]
    foodNameStatus: String
    foodOrigin: String
    foodPackCapacity: QuantityValue
    foodPackIntegrity: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodPriorContact: [String]
    foodProd: [String]
    foodProdSynonym: [String]
    foodProductQual: String
    foodQualityDate: String
    foodSource: String
    foodTraceList: FoodTraceListEnum
    foodTravMode: [String]
    foodTravVehic: [String]
    foodTreatProc: [String]
    hACCPTerm: [String]
    intendedConsumer: [String]
    libraryPrepKit: String
    lotNumber: [String]
    microbCultMed: String
    microbStart: String
    microbStartCount: MicrobStartCountEnum
    microbStartInoc: QuantityValue
    microbStartPrep: String
    microbStartSource: String
    microbStartTaxID: String
    nuclAcidExtKit: [String]
    numSampCollect: QuantityValue
    partPlantAnimal: [String]
    repositoryName: [String]
    sampleCollecMethod: String
    sampPooling: [String]
    sampRepBiol: QuantityValue
    sampRepTech: QuantityValue
    sampSourceMatCat: String
    sampStorDevice: String
    sampStorMedia: String
    sampTransportCont: SampTransportContEnum
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sampPurpose: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    spikeinAMR: [String]
    spikeinAntibiotic: [String]
    spikeinGrowthMed: [String]
    spikeinMetal: [String]
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinStrain: [String]
    studyDesign: [String]
    studyIncDur: QuantityValue
    studyIncTemp: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    timepoint: Double
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer!
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String!
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    trophicLevel: TrophicLevelEnum
    encodedTraits: String
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Food-humanFoodsMIGSEukaryote implements MIGSEukaryote
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    sampStorDur: String
    poolDnaExtracts: String
    sampStorLoc: String
    geneticMod: String
    perturbation: [String]
    collSiteGeoFeat: String!
    foodProductType: [String]!
    iFSACCategory: [String]!
    fermChemAdd: [QuantityValue]
    fermChemAddPerc: [String]
    fermHeadspaceOxy: String
    fermMedium: String
    fermPH: Double
    fermRelHumidity: QuantityValue
    fermTemp: QuantityValue
    fermTime: String
    fermVessel: String
    bacterialDensity: QuantityValue
    consFoodStorDur: String
    consFoodStorTemp: String
    consPurchDate: Date
    consQtyPurchased: String
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    dietaryClaimUse: [String]
    enrichmentProtocol: String
    foodAdditive: [String]
    foodAllergenLabel: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodCookingProc: [String]
    foodDisPoint: [String]
    foodIngredient: [String]
    foodNameStatus: String
    foodOrigin: String
    foodPackCapacity: QuantityValue
    foodPackIntegrity: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodPriorContact: [String]
    foodProd: [String]
    foodProdSynonym: [String]
    foodProductQual: String
    foodQualityDate: String
    foodSource: String
    foodTraceList: FoodTraceListEnum
    foodTravMode: [String]
    foodTravVehic: [String]
    foodTreatProc: [String]
    hACCPTerm: [String]
    intendedConsumer: [String]
    libraryPrepKit: String
    lotNumber: [String]
    microbCultMed: String
    microbStart: String
    microbStartCount: MicrobStartCountEnum
    microbStartInoc: QuantityValue
    microbStartPrep: String
    microbStartSource: String
    microbStartTaxID: String
    nuclAcidExtKit: [String]
    numSampCollect: QuantityValue
    partPlantAnimal: [String]
    repositoryName: [String]
    sampleCollecMethod: String
    sampPooling: [String]
    sampRepBiol: QuantityValue
    sampRepTech: QuantityValue
    sampSourceMatCat: String
    sampStorDevice: String
    sampStorMedia: String
    sampTransportCont: SampTransportContEnum
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sampPurpose: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    spikeinAMR: [String]
    spikeinAntibiotic: [String]
    spikeinGrowthMed: [String]
    spikeinMetal: [String]
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinStrain: [String]
    studyDesign: [String]
    studyIncDur: QuantityValue
    studyIncTemp: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    timepoint: Double
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    ploidy: String
    numReplicons: Integer
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    trophicLevel: TrophicLevelEnum
    propagation: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Food-humanFoodsMIGSOrg implements MIGSOrg
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    sampStorDur: String
    poolDnaExtracts: String
    sampStorLoc: String
    geneticMod: String
    perturbation: [String]
    collSiteGeoFeat: String!
    foodProductType: [String]!
    iFSACCategory: [String]!
    fermChemAdd: [QuantityValue]
    fermChemAddPerc: [String]
    fermHeadspaceOxy: String
    fermMedium: String
    fermPH: Double
    fermRelHumidity: QuantityValue
    fermTemp: QuantityValue
    fermTime: String
    fermVessel: String
    bacterialDensity: QuantityValue
    consFoodStorDur: String
    consFoodStorTemp: String
    consPurchDate: Date
    consQtyPurchased: String
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    dietaryClaimUse: [String]
    enrichmentProtocol: String
    foodAdditive: [String]
    foodAllergenLabel: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodCookingProc: [String]
    foodDisPoint: [String]
    foodIngredient: [String]
    foodNameStatus: String
    foodOrigin: String
    foodPackCapacity: QuantityValue
    foodPackIntegrity: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodPriorContact: [String]
    foodProd: [String]
    foodProdSynonym: [String]
    foodProductQual: String
    foodQualityDate: String
    foodSource: String
    foodTraceList: FoodTraceListEnum
    foodTravMode: [String]
    foodTravVehic: [String]
    foodTreatProc: [String]
    hACCPTerm: [String]
    intendedConsumer: [String]
    libraryPrepKit: String
    lotNumber: [String]
    microbCultMed: String
    microbStart: String
    microbStartCount: MicrobStartCountEnum
    microbStartInoc: QuantityValue
    microbStartPrep: String
    microbStartSource: String
    microbStartTaxID: String
    nuclAcidExtKit: [String]
    numSampCollect: QuantityValue
    partPlantAnimal: [String]
    repositoryName: [String]
    sampleCollecMethod: String
    sampPooling: [String]
    sampRepBiol: QuantityValue
    sampRepTech: QuantityValue
    sampSourceMatCat: String
    sampStorDevice: String
    sampStorMedia: String
    sampTransportCont: SampTransportContEnum
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sampPurpose: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    spikeinAMR: [String]
    spikeinAntibiotic: [String]
    spikeinGrowthMed: [String]
    spikeinMetal: [String]
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinStrain: [String]
    studyDesign: [String]
    studyIncDur: QuantityValue
    studyIncTemp: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    timepoint: Double
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Food-humanFoodsMIGSPlant implements MIGSPlant
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    sampStorDur: String
    poolDnaExtracts: String
    sampStorLoc: String
    geneticMod: String
    perturbation: [String]
    collSiteGeoFeat: String!
    foodProductType: [String]!
    iFSACCategory: [String]!
    fermChemAdd: [QuantityValue]
    fermChemAddPerc: [String]
    fermHeadspaceOxy: String
    fermMedium: String
    fermPH: Double
    fermRelHumidity: QuantityValue
    fermTemp: QuantityValue
    fermTime: String
    fermVessel: String
    bacterialDensity: QuantityValue
    consFoodStorDur: String
    consFoodStorTemp: String
    consPurchDate: Date
    consQtyPurchased: String
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    dietaryClaimUse: [String]
    enrichmentProtocol: String
    foodAdditive: [String]
    foodAllergenLabel: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodCookingProc: [String]
    foodDisPoint: [String]
    foodIngredient: [String]
    foodNameStatus: String
    foodOrigin: String
    foodPackCapacity: QuantityValue
    foodPackIntegrity: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodPriorContact: [String]
    foodProd: [String]
    foodProdSynonym: [String]
    foodProductQual: String
    foodQualityDate: String
    foodSource: String
    foodTraceList: FoodTraceListEnum
    foodTravMode: [String]
    foodTravVehic: [String]
    foodTreatProc: [String]
    hACCPTerm: [String]
    intendedConsumer: [String]
    libraryPrepKit: String
    lotNumber: [String]
    microbCultMed: String
    microbStart: String
    microbStartCount: MicrobStartCountEnum
    microbStartInoc: QuantityValue
    microbStartPrep: String
    microbStartSource: String
    microbStartTaxID: String
    nuclAcidExtKit: [String]
    numSampCollect: QuantityValue
    partPlantAnimal: [String]
    repositoryName: [String]
    sampleCollecMethod: String
    sampPooling: [String]
    sampRepBiol: QuantityValue
    sampRepTech: QuantityValue
    sampSourceMatCat: String
    sampStorDevice: String
    sampStorMedia: String
    sampTransportCont: SampTransportContEnum
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sampPurpose: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    spikeinAMR: [String]
    spikeinAntibiotic: [String]
    spikeinGrowthMed: [String]
    spikeinMetal: [String]
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinStrain: [String]
    studyDesign: [String]
    studyIncDur: QuantityValue
    studyIncTemp: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    timepoint: Double
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    specificHost: String
    hostSpecRange: Integer
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Food-humanFoodsMIGSVirus implements MIGSVirus
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    sampStorDur: String
    poolDnaExtracts: String
    sampStorLoc: String
    geneticMod: String
    perturbation: [String]
    collSiteGeoFeat: String!
    foodProductType: [String]!
    iFSACCategory: [String]!
    fermChemAdd: [QuantityValue]
    fermChemAddPerc: [String]
    fermHeadspaceOxy: String
    fermMedium: String
    fermPH: Double
    fermRelHumidity: QuantityValue
    fermTemp: QuantityValue
    fermTime: String
    fermVessel: String
    bacterialDensity: QuantityValue
    consFoodStorDur: String
    consFoodStorTemp: String
    consPurchDate: Date
    consQtyPurchased: String
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    dietaryClaimUse: [String]
    enrichmentProtocol: String
    foodAdditive: [String]
    foodAllergenLabel: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodCookingProc: [String]
    foodDisPoint: [String]
    foodIngredient: [String]
    foodNameStatus: String
    foodOrigin: String
    foodPackCapacity: QuantityValue
    foodPackIntegrity: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodPriorContact: [String]
    foodProd: [String]
    foodProdSynonym: [String]
    foodProductQual: String
    foodQualityDate: String
    foodSource: String
    foodTraceList: FoodTraceListEnum
    foodTravMode: [String]
    foodTravVehic: [String]
    foodTreatProc: [String]
    hACCPTerm: [String]
    intendedConsumer: [String]
    libraryPrepKit: String
    lotNumber: [String]
    microbCultMed: String
    microbStart: String
    microbStartCount: MicrobStartCountEnum
    microbStartInoc: QuantityValue
    microbStartPrep: String
    microbStartSource: String
    microbStartTaxID: String
    nuclAcidExtKit: [String]
    numSampCollect: QuantityValue
    partPlantAnimal: [String]
    repositoryName: [String]
    sampleCollecMethod: String
    sampPooling: [String]
    sampRepBiol: QuantityValue
    sampRepTech: QuantityValue
    sampSourceMatCat: String
    sampStorDevice: String
    sampStorMedia: String
    sampTransportCont: SampTransportContEnum
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sampPurpose: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    spikeinAMR: [String]
    spikeinAntibiotic: [String]
    spikeinGrowthMed: [String]
    spikeinMetal: [String]
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinStrain: [String]
    studyDesign: [String]
    studyIncDur: QuantityValue
    studyIncTemp: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    timepoint: Double
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    virusEnrichAppr: VirusEnrichApprEnum
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Food-humanFoodsMIMAG implements MIMAG
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    sampStorDur: String
    poolDnaExtracts: String
    sampStorLoc: String
    geneticMod: String
    perturbation: [String]
    collSiteGeoFeat: String!
    foodProductType: [String]!
    iFSACCategory: [String]!
    fermChemAdd: [QuantityValue]
    fermChemAddPerc: [String]
    fermHeadspaceOxy: String
    fermMedium: String
    fermPH: Double
    fermRelHumidity: QuantityValue
    fermTemp: QuantityValue
    fermTime: String
    fermVessel: String
    bacterialDensity: QuantityValue
    consFoodStorDur: String
    consFoodStorTemp: String
    consPurchDate: Date
    consQtyPurchased: String
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    dietaryClaimUse: [String]
    enrichmentProtocol: String
    foodAdditive: [String]
    foodAllergenLabel: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodCookingProc: [String]
    foodDisPoint: [String]
    foodIngredient: [String]
    foodNameStatus: String
    foodOrigin: String
    foodPackCapacity: QuantityValue
    foodPackIntegrity: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodPriorContact: [String]
    foodProd: [String]
    foodProdSynonym: [String]
    foodProductQual: String
    foodQualityDate: String
    foodSource: String
    foodTraceList: FoodTraceListEnum
    foodTravMode: [String]
    foodTravVehic: [String]
    foodTreatProc: [String]
    hACCPTerm: [String]
    intendedConsumer: [String]
    libraryPrepKit: String
    lotNumber: [String]
    microbCultMed: String
    microbStart: String
    microbStartCount: MicrobStartCountEnum
    microbStartInoc: QuantityValue
    microbStartPrep: String
    microbStartSource: String
    microbStartTaxID: String
    nuclAcidExtKit: [String]
    numSampCollect: QuantityValue
    partPlantAnimal: [String]
    repositoryName: [String]
    sampleCollecMethod: String
    sampPooling: [String]
    sampRepBiol: QuantityValue
    sampRepTech: QuantityValue
    sampSourceMatCat: String
    sampStorDevice: String
    sampStorMedia: String
    sampTransportCont: SampTransportContEnum
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sampPurpose: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    spikeinAMR: [String]
    spikeinAntibiotic: [String]
    spikeinGrowthMed: [String]
    spikeinMetal: [String]
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinStrain: [String]
    studyDesign: [String]
    studyIncDur: QuantityValue
    studyIncTemp: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    timepoint: Double
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    binParam: BinParamEnum!
    binSoftware: String!
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    associatedResource: String
    sop: String
  }

type Food-humanFoodsMIMARKSSpecimen implements MIMARKSSpecimen
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    sampStorDur: String
    poolDnaExtracts: String
    sampStorLoc: String
    geneticMod: String
    perturbation: [String]
    collSiteGeoFeat: String!
    foodProductType: [String]!
    iFSACCategory: [String]!
    fermChemAdd: [QuantityValue]
    fermChemAddPerc: [String]
    fermHeadspaceOxy: String
    fermMedium: String
    fermPH: Double
    fermRelHumidity: QuantityValue
    fermTemp: QuantityValue
    fermTime: String
    fermVessel: String
    bacterialDensity: QuantityValue
    consFoodStorDur: String
    consFoodStorTemp: String
    consPurchDate: Date
    consQtyPurchased: String
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    dietaryClaimUse: [String]
    enrichmentProtocol: String
    foodAdditive: [String]
    foodAllergenLabel: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodCookingProc: [String]
    foodDisPoint: [String]
    foodIngredient: [String]
    foodNameStatus: String
    foodOrigin: String
    foodPackCapacity: QuantityValue
    foodPackIntegrity: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodPriorContact: [String]
    foodProd: [String]
    foodProdSynonym: [String]
    foodProductQual: String
    foodQualityDate: String
    foodSource: String
    foodTraceList: FoodTraceListEnum
    foodTravMode: [String]
    foodTravVehic: [String]
    foodTreatProc: [String]
    hACCPTerm: [String]
    intendedConsumer: [String]
    libraryPrepKit: String
    lotNumber: [String]
    microbCultMed: String
    microbStart: String
    microbStartCount: MicrobStartCountEnum
    microbStartInoc: QuantityValue
    microbStartPrep: String
    microbStartSource: String
    microbStartTaxID: String
    nuclAcidExtKit: [String]
    numSampCollect: QuantityValue
    partPlantAnimal: [String]
    repositoryName: [String]
    sampleCollecMethod: String
    sampPooling: [String]
    sampRepBiol: QuantityValue
    sampRepTech: QuantityValue
    sampSourceMatCat: String
    sampStorDevice: String
    sampStorMedia: String
    sampTransportCont: SampTransportContEnum
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sampPurpose: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    spikeinAMR: [String]
    spikeinAntibiotic: [String]
    spikeinGrowthMed: [String]
    spikeinMetal: [String]
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinStrain: [String]
    studyDesign: [String]
    studyIncDur: QuantityValue
    studyIncTemp: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    timepoint: Double
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    negContType: NegContTypeEnum
    posContType: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    mid: String
    adapters: String
    pcrCond: String
    seqQualityCheck: String
    chimeraCheck: String
    assemblySoftware: String
    associatedResource: String
    sop: String
  }

type Food-humanFoodsMIMARKSSurvey implements MIMARKSSurvey
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    sampStorDur: String
    poolDnaExtracts: String
    sampStorLoc: String
    geneticMod: String
    perturbation: [String]
    collSiteGeoFeat: String!
    foodProductType: [String]!
    iFSACCategory: [String]!
    fermChemAdd: [QuantityValue]
    fermChemAddPerc: [String]
    fermHeadspaceOxy: String
    fermMedium: String
    fermPH: Double
    fermRelHumidity: QuantityValue
    fermTemp: QuantityValue
    fermTime: String
    fermVessel: String
    bacterialDensity: QuantityValue
    consFoodStorDur: String
    consFoodStorTemp: String
    consPurchDate: Date
    consQtyPurchased: String
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    dietaryClaimUse: [String]
    enrichmentProtocol: String
    foodAdditive: [String]
    foodAllergenLabel: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodCookingProc: [String]
    foodDisPoint: [String]
    foodIngredient: [String]
    foodNameStatus: String
    foodOrigin: String
    foodPackCapacity: QuantityValue
    foodPackIntegrity: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodPriorContact: [String]
    foodProd: [String]
    foodProdSynonym: [String]
    foodProductQual: String
    foodQualityDate: String
    foodSource: String
    foodTraceList: FoodTraceListEnum
    foodTravMode: [String]
    foodTravVehic: [String]
    foodTreatProc: [String]
    hACCPTerm: [String]
    intendedConsumer: [String]
    libraryPrepKit: String
    lotNumber: [String]
    microbCultMed: String
    microbStart: String
    microbStartCount: MicrobStartCountEnum
    microbStartInoc: QuantityValue
    microbStartPrep: String
    microbStartSource: String
    microbStartTaxID: String
    nuclAcidExtKit: [String]
    numSampCollect: QuantityValue
    partPlantAnimal: [String]
    repositoryName: [String]
    sampleCollecMethod: String
    sampPooling: [String]
    sampRepBiol: QuantityValue
    sampRepTech: QuantityValue
    sampSourceMatCat: String
    sampStorDevice: String
    sampStorMedia: String
    sampTransportCont: SampTransportContEnum
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sampPurpose: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    spikeinAMR: [String]
    spikeinAntibiotic: [String]
    spikeinGrowthMed: [String]
    spikeinMetal: [String]
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinStrain: [String]
    studyDesign: [String]
    studyIncDur: QuantityValue
    studyIncTemp: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    timepoint: Double
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    sourceMatId: String
    bioticRelationship: BioticRelationshipEnum
    trophicLevel: TrophicLevelEnum
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    nuclAcidAmp: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    pcrCond: String
    seqQualityCheck: String
    chimeraCheck: String
    associatedResource: String
    sop: String
  }

type Food-humanFoodsMIMS implements MIMS
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    sampStorDur: String
    poolDnaExtracts: String
    sampStorLoc: String
    geneticMod: String
    perturbation: [String]
    collSiteGeoFeat: String!
    foodProductType: [String]!
    iFSACCategory: [String]!
    fermChemAdd: [QuantityValue]
    fermChemAddPerc: [String]
    fermHeadspaceOxy: String
    fermMedium: String
    fermPH: Double
    fermRelHumidity: QuantityValue
    fermTemp: QuantityValue
    fermTime: String
    fermVessel: String
    bacterialDensity: QuantityValue
    consFoodStorDur: String
    consFoodStorTemp: String
    consPurchDate: Date
    consQtyPurchased: String
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    dietaryClaimUse: [String]
    enrichmentProtocol: String
    foodAdditive: [String]
    foodAllergenLabel: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodCookingProc: [String]
    foodDisPoint: [String]
    foodIngredient: [String]
    foodNameStatus: String
    foodOrigin: String
    foodPackCapacity: QuantityValue
    foodPackIntegrity: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodPriorContact: [String]
    foodProd: [String]
    foodProdSynonym: [String]
    foodProductQual: String
    foodQualityDate: String
    foodSource: String
    foodTraceList: FoodTraceListEnum
    foodTravMode: [String]
    foodTravVehic: [String]
    foodTreatProc: [String]
    hACCPTerm: [String]
    intendedConsumer: [String]
    libraryPrepKit: String
    lotNumber: [String]
    microbCultMed: String
    microbStart: String
    microbStartCount: MicrobStartCountEnum
    microbStartInoc: QuantityValue
    microbStartPrep: String
    microbStartSource: String
    microbStartTaxID: String
    nuclAcidExtKit: [String]
    numSampCollect: QuantityValue
    partPlantAnimal: [String]
    repositoryName: [String]
    sampleCollecMethod: String
    sampPooling: [String]
    sampRepBiol: QuantityValue
    sampRepTech: QuantityValue
    sampSourceMatCat: String
    sampStorDevice: String
    sampStorMedia: String
    sampTransportCont: SampTransportContEnum
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sampPurpose: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    spikeinAMR: [String]
    spikeinAntibiotic: [String]
    spikeinGrowthMed: [String]
    spikeinMetal: [String]
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinStrain: [String]
    studyDesign: [String]
    studyIncDur: QuantityValue
    studyIncTemp: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    timepoint: Double
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    associatedResource: String
    sop: String
  }

type Food-humanFoodsMISAG implements MISAG
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    sampStorDur: String
    poolDnaExtracts: String
    sampStorLoc: String
    geneticMod: String
    perturbation: [String]
    collSiteGeoFeat: String!
    foodProductType: [String]!
    iFSACCategory: [String]!
    fermChemAdd: [QuantityValue]
    fermChemAddPerc: [String]
    fermHeadspaceOxy: String
    fermMedium: String
    fermPH: Double
    fermRelHumidity: QuantityValue
    fermTemp: QuantityValue
    fermTime: String
    fermVessel: String
    bacterialDensity: QuantityValue
    consFoodStorDur: String
    consFoodStorTemp: String
    consPurchDate: Date
    consQtyPurchased: String
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    dietaryClaimUse: [String]
    enrichmentProtocol: String
    foodAdditive: [String]
    foodAllergenLabel: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodCookingProc: [String]
    foodDisPoint: [String]
    foodIngredient: [String]
    foodNameStatus: String
    foodOrigin: String
    foodPackCapacity: QuantityValue
    foodPackIntegrity: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodPriorContact: [String]
    foodProd: [String]
    foodProdSynonym: [String]
    foodProductQual: String
    foodQualityDate: String
    foodSource: String
    foodTraceList: FoodTraceListEnum
    foodTravMode: [String]
    foodTravVehic: [String]
    foodTreatProc: [String]
    hACCPTerm: [String]
    intendedConsumer: [String]
    libraryPrepKit: String
    lotNumber: [String]
    microbCultMed: String
    microbStart: String
    microbStartCount: MicrobStartCountEnum
    microbStartInoc: QuantityValue
    microbStartPrep: String
    microbStartSource: String
    microbStartTaxID: String
    nuclAcidExtKit: [String]
    numSampCollect: QuantityValue
    partPlantAnimal: [String]
    repositoryName: [String]
    sampleCollecMethod: String
    sampPooling: [String]
    sampRepBiol: QuantityValue
    sampRepTech: QuantityValue
    sampSourceMatCat: String
    sampStorDevice: String
    sampStorMedia: String
    sampTransportCont: SampTransportContEnum
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sampPurpose: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    spikeinAMR: [String]
    spikeinAntibiotic: [String]
    spikeinGrowthMed: [String]
    spikeinMetal: [String]
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinStrain: [String]
    studyDesign: [String]
    studyIncDur: QuantityValue
    studyIncTemp: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    timepoint: Double
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    sortTech: SortTechEnum!
    singleCellLysisAppr: SingleCellLysisApprEnum!
    singleCellLysisProt: String
    wgaAmpAppr: String!
    wgaAmpKit: String
    associatedResource: String
    sop: String
  }

type Food-humanFoodsMIUVIG implements MIUVIG
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampCollectDevice: String
    organismCount: [OrganismCountEnum]
    spikeinCount: SpikeinCountEnum
    sampStorTemp: QuantityValue
    sampStorDur: String
    poolDnaExtracts: String
    sampStorLoc: String
    geneticMod: String
    perturbation: [String]
    collSiteGeoFeat: String!
    foodProductType: [String]!
    iFSACCategory: [String]!
    fermChemAdd: [QuantityValue]
    fermChemAddPerc: [String]
    fermHeadspaceOxy: String
    fermMedium: String
    fermPH: Double
    fermRelHumidity: QuantityValue
    fermTemp: QuantityValue
    fermTime: String
    fermVessel: String
    bacterialDensity: QuantityValue
    consFoodStorDur: String
    consFoodStorTemp: String
    consPurchDate: Date
    consQtyPurchased: String
    cultIsolDate: Date
    cultResult: CultResultEnum
    cultResultOrg: [String]
    cultTarget: [String]
    dietaryClaimUse: [String]
    enrichmentProtocol: String
    foodAdditive: [String]
    foodAllergenLabel: [String]
    foodContactSurf: [String]
    foodContainWrap: String
    foodCookingProc: [String]
    foodDisPoint: [String]
    foodIngredient: [String]
    foodNameStatus: String
    foodOrigin: String
    foodPackCapacity: QuantityValue
    foodPackIntegrity: [String]
    foodPackMedium: [String]
    foodPreservProc: [String]
    foodPriorContact: [String]
    foodProd: [String]
    foodProdSynonym: [String]
    foodProductQual: String
    foodQualityDate: String
    foodSource: String
    foodTraceList: FoodTraceListEnum
    foodTravMode: [String]
    foodTravVehic: [String]
    foodTreatProc: [String]
    hACCPTerm: [String]
    intendedConsumer: [String]
    libraryPrepKit: String
    lotNumber: [String]
    microbCultMed: String
    microbStart: String
    microbStartCount: MicrobStartCountEnum
    microbStartInoc: QuantityValue
    microbStartPrep: String
    microbStartSource: String
    microbStartTaxID: String
    nuclAcidExtKit: [String]
    numSampCollect: QuantityValue
    partPlantAnimal: [String]
    repositoryName: [String]
    sampleCollecMethod: String
    sampPooling: [String]
    sampRepBiol: QuantityValue
    sampRepTech: QuantityValue
    sampSourceMatCat: String
    sampStorDevice: String
    sampStorMedia: String
    sampTransportCont: SampTransportContEnum
    sampTransportDur: QuantityValue
    sampTransportTemp: String
    sampPurpose: String
    sequencingKit: String
    sequencingLocation: String
    serovarOrSerotype: [String]
    spikeinAMR: [String]
    spikeinAntibiotic: [String]
    spikeinGrowthMed: [String]
    spikeinMetal: [String]
    spikeinOrg: [String]
    spikeinSerovar: [String]
    spikeinStrain: [String]
    studyDesign: [String]
    studyIncDur: QuantityValue
    studyIncTemp: QuantityValue
    studyTimecourse: QuantityValue
    studyTmnt: [String]
    timepoint: Double
    miscParam: [String]
    sampName: String!
    projectName: String!
    seqMeth: String!
    sampSize: QuantityValue
    experimentalFactor: String
    nuclAcidExt: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    negContType: NegContTypeEnum
    posContType: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sourceUvig: SourceUvigEnum!
    virusEnrichAppr: VirusEnrichApprEnum!
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String
    complSoftware: String
    complAppr: ComplApprEnum
    sortTech: SortTechEnum
    singleCellLysisAppr: SingleCellLysisApprEnum
    singleCellLysisProt: String
    wgaAmpAppr: String
    wgaAmpKit: String
    binParam: BinParamEnum
    binSoftware: String
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    virIdentSoftware: String!
    predGenomeType: PredGenomeTypeEnum!
    predGenomeStruc: PredGenomeStrucEnum!
    detecType: String!
    otuClassAppr: String
    otuSeqCompAppr: String
    otuDb: String
    hostPredAppr: HostPredApprEnum
    hostPredEstAcc: String
    associatedResource: String
    sop: String
  }

type Host-associated
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    ancesData: String
    biolStat: BiolStatEnum
    geneticMod: String
    hostCommonName: String
    sampCaptStatus: SampCaptStatusEnum
    sampDisStage: SampDisStageEnum
    hostTaxid: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostLifeStage: String
    hostSex: HostSexEnum
    chemAdministration: [String]
    hostBodyHabitat: String
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostGrowthCond: String
    hostSubstrate: String
    hostFamilyRelation: [String]
    hostSubspecfGenlin: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostDryMass: QuantityValue
    bloodPressDiast: QuantityValue
    bloodPressSyst: QuantityValue
    hostColor: String
    hostShape: String
    gravidity: String
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
  }

type Host-associatedMIGSBacteria implements MIGSBacteria
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    ancesData: String
    biolStat: BiolStatEnum
    geneticMod: String
    hostCommonName: String
    sampCaptStatus: SampCaptStatusEnum
    sampDisStage: SampDisStageEnum
    hostTaxid: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostLifeStage: String
    hostSex: HostSexEnum
    chemAdministration: [String]
    hostBodyHabitat: String
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostGrowthCond: String
    hostSubstrate: String
    hostFamilyRelation: [String]
    hostSubspecfGenlin: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostDryMass: QuantityValue
    bloodPressDiast: QuantityValue
    bloodPressSyst: QuantityValue
    hostColor: String
    hostShape: String
    gravidity: String
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer!
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String!
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    trophicLevel: TrophicLevelEnum
    encodedTraits: String
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Host-associatedMIGSEukaryote implements MIGSEukaryote
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    ancesData: String
    biolStat: BiolStatEnum
    geneticMod: String
    hostCommonName: String
    sampCaptStatus: SampCaptStatusEnum
    sampDisStage: SampDisStageEnum
    hostTaxid: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostLifeStage: String
    hostSex: HostSexEnum
    chemAdministration: [String]
    hostBodyHabitat: String
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostGrowthCond: String
    hostSubstrate: String
    hostFamilyRelation: [String]
    hostSubspecfGenlin: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostDryMass: QuantityValue
    bloodPressDiast: QuantityValue
    bloodPressSyst: QuantityValue
    hostColor: String
    hostShape: String
    gravidity: String
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    ploidy: String
    numReplicons: Integer
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    trophicLevel: TrophicLevelEnum
    propagation: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Host-associatedMIGSOrg implements MIGSOrg
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    ancesData: String
    biolStat: BiolStatEnum
    geneticMod: String
    hostCommonName: String
    sampCaptStatus: SampCaptStatusEnum
    sampDisStage: SampDisStageEnum
    hostTaxid: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostLifeStage: String
    hostSex: HostSexEnum
    chemAdministration: [String]
    hostBodyHabitat: String
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostGrowthCond: String
    hostSubstrate: String
    hostFamilyRelation: [String]
    hostSubspecfGenlin: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostDryMass: QuantityValue
    bloodPressDiast: QuantityValue
    bloodPressSyst: QuantityValue
    hostColor: String
    hostShape: String
    gravidity: String
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Host-associatedMIGSPlant implements MIGSPlant
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    ancesData: String
    biolStat: BiolStatEnum
    geneticMod: String
    hostCommonName: String
    sampCaptStatus: SampCaptStatusEnum
    sampDisStage: SampDisStageEnum
    hostTaxid: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostLifeStage: String
    hostSex: HostSexEnum
    chemAdministration: [String]
    hostBodyHabitat: String
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostGrowthCond: String
    hostSubstrate: String
    hostFamilyRelation: [String]
    hostSubspecfGenlin: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostDryMass: QuantityValue
    bloodPressDiast: QuantityValue
    bloodPressSyst: QuantityValue
    hostColor: String
    hostShape: String
    gravidity: String
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    specificHost: String
    hostSpecRange: Integer
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Host-associatedMIGSVirus implements MIGSVirus
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    ancesData: String
    biolStat: BiolStatEnum
    geneticMod: String
    hostCommonName: String
    sampCaptStatus: SampCaptStatusEnum
    sampDisStage: SampDisStageEnum
    hostTaxid: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostLifeStage: String
    hostSex: HostSexEnum
    chemAdministration: [String]
    hostBodyHabitat: String
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostGrowthCond: String
    hostSubstrate: String
    hostFamilyRelation: [String]
    hostSubspecfGenlin: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostDryMass: QuantityValue
    bloodPressDiast: QuantityValue
    bloodPressSyst: QuantityValue
    hostColor: String
    hostShape: String
    gravidity: String
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    virusEnrichAppr: VirusEnrichApprEnum
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Host-associatedMIMAG implements MIMAG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    ancesData: String
    biolStat: BiolStatEnum
    geneticMod: String
    hostCommonName: String
    sampCaptStatus: SampCaptStatusEnum
    sampDisStage: SampDisStageEnum
    hostTaxid: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostLifeStage: String
    hostSex: HostSexEnum
    chemAdministration: [String]
    hostBodyHabitat: String
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostGrowthCond: String
    hostSubstrate: String
    hostFamilyRelation: [String]
    hostSubspecfGenlin: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostDryMass: QuantityValue
    bloodPressDiast: QuantityValue
    bloodPressSyst: QuantityValue
    hostColor: String
    hostShape: String
    gravidity: String
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    binParam: BinParamEnum!
    binSoftware: String!
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    associatedResource: String
    sop: String
  }

type Host-associatedMIMARKSSpecimen implements MIMARKSSpecimen
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    ancesData: String
    biolStat: BiolStatEnum
    geneticMod: String
    hostCommonName: String
    sampCaptStatus: SampCaptStatusEnum
    sampDisStage: SampDisStageEnum
    hostTaxid: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostLifeStage: String
    hostSex: HostSexEnum
    chemAdministration: [String]
    hostBodyHabitat: String
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostGrowthCond: String
    hostSubstrate: String
    hostFamilyRelation: [String]
    hostSubspecfGenlin: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostDryMass: QuantityValue
    bloodPressDiast: QuantityValue
    bloodPressSyst: QuantityValue
    hostColor: String
    hostShape: String
    gravidity: String
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    mid: String
    adapters: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    assemblySoftware: String
    associatedResource: String
    sop: String
  }

type Host-associatedMIMARKSSurvey implements MIMARKSSurvey
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    ancesData: String
    biolStat: BiolStatEnum
    geneticMod: String
    hostCommonName: String
    sampCaptStatus: SampCaptStatusEnum
    sampDisStage: SampDisStageEnum
    hostTaxid: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostLifeStage: String
    hostSex: HostSexEnum
    chemAdministration: [String]
    hostBodyHabitat: String
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostGrowthCond: String
    hostSubstrate: String
    hostFamilyRelation: [String]
    hostSubspecfGenlin: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostDryMass: QuantityValue
    bloodPressDiast: QuantityValue
    bloodPressSyst: QuantityValue
    hostColor: String
    hostShape: String
    gravidity: String
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    sourceMatId: String
    bioticRelationship: BioticRelationshipEnum
    trophicLevel: TrophicLevelEnum
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    associatedResource: String
    sop: String
  }

type Host-associatedMIMS implements MIMS
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    ancesData: String
    biolStat: BiolStatEnum
    geneticMod: String
    hostCommonName: String
    sampCaptStatus: SampCaptStatusEnum
    sampDisStage: SampDisStageEnum
    hostTaxid: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostLifeStage: String
    hostSex: HostSexEnum
    chemAdministration: [String]
    hostBodyHabitat: String
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostGrowthCond: String
    hostSubstrate: String
    hostFamilyRelation: [String]
    hostSubspecfGenlin: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostDryMass: QuantityValue
    bloodPressDiast: QuantityValue
    bloodPressSyst: QuantityValue
    hostColor: String
    hostShape: String
    gravidity: String
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    associatedResource: String
    sop: String
  }

type Host-associatedMISAG implements MISAG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    ancesData: String
    biolStat: BiolStatEnum
    geneticMod: String
    hostCommonName: String
    sampCaptStatus: SampCaptStatusEnum
    sampDisStage: SampDisStageEnum
    hostTaxid: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostLifeStage: String
    hostSex: HostSexEnum
    chemAdministration: [String]
    hostBodyHabitat: String
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostGrowthCond: String
    hostSubstrate: String
    hostFamilyRelation: [String]
    hostSubspecfGenlin: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostDryMass: QuantityValue
    bloodPressDiast: QuantityValue
    bloodPressSyst: QuantityValue
    hostColor: String
    hostShape: String
    gravidity: String
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    sortTech: SortTechEnum!
    singleCellLysisAppr: SingleCellLysisApprEnum!
    singleCellLysisProt: String
    wgaAmpAppr: String!
    wgaAmpKit: String
    associatedResource: String
    sop: String
  }

type Host-associatedMIUVIG implements MIUVIG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    ancesData: String
    biolStat: BiolStatEnum
    geneticMod: String
    hostCommonName: String
    sampCaptStatus: SampCaptStatusEnum
    sampDisStage: SampDisStageEnum
    hostTaxid: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostLifeStage: String
    hostSex: HostSexEnum
    chemAdministration: [String]
    hostBodyHabitat: String
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostGrowthCond: String
    hostSubstrate: String
    hostFamilyRelation: [String]
    hostSubspecfGenlin: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostDryMass: QuantityValue
    bloodPressDiast: QuantityValue
    bloodPressSyst: QuantityValue
    hostColor: String
    hostShape: String
    gravidity: String
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    sourceUvig: SourceUvigEnum!
    virusEnrichAppr: VirusEnrichApprEnum!
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String
    complSoftware: String
    complAppr: ComplApprEnum
    sortTech: SortTechEnum
    singleCellLysisAppr: SingleCellLysisApprEnum
    singleCellLysisProt: String
    wgaAmpAppr: String
    wgaAmpKit: String
    binParam: BinParamEnum
    binSoftware: String
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    virIdentSoftware: String!
    predGenomeType: PredGenomeTypeEnum!
    predGenomeStruc: PredGenomeStrucEnum!
    detecType: String!
    otuClassAppr: String
    otuSeqCompAppr: String
    otuDb: String
    hostPredAppr: HostPredApprEnum
    hostPredEstAcc: String
    associatedResource: String
    sop: String
  }

type Human-associated
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    smoker: String
    hostHivStat: String
    drugUsage: [DrugUsageEnum]
    hostBodyMassIndex: QuantityValue
    dietLastSixMonth: String
    weightLoss3Month: String
    ethnicity: [String]
    hostOccupation: Integer
    petFarmAnimal: [String]
    travelOutSixMonth: [String]
    twinSibling: String
    medicHistPerform: String
    studyCompltStat: StudyCompltStatEnum
    pulmonaryDisord: [String]
    noseThroatDisord: [String]
    bloodBloodDisord: [String]
    hostPulse: QuantityValue
    gestationState: String
    maternalHealthStat: String
    foetalHealthStat: String
    amnioticFluidColor: String
    kidneyDisord: [String]
    urogenitTractDisor: [String]
    urineCollectMeth: String
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
  }

type Human-associatedMIGSBacteria implements MIGSBacteria
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    smoker: String
    hostHivStat: String
    drugUsage: [DrugUsageEnum]
    hostBodyMassIndex: QuantityValue
    dietLastSixMonth: String
    weightLoss3Month: String
    ethnicity: [String]
    hostOccupation: Integer
    petFarmAnimal: [String]
    travelOutSixMonth: [String]
    twinSibling: String
    medicHistPerform: String
    studyCompltStat: StudyCompltStatEnum
    pulmonaryDisord: [String]
    noseThroatDisord: [String]
    bloodBloodDisord: [String]
    hostPulse: QuantityValue
    gestationState: String
    maternalHealthStat: String
    foetalHealthStat: String
    amnioticFluidColor: String
    kidneyDisord: [String]
    urogenitTractDisor: [String]
    urineCollectMeth: String
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer!
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String!
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    trophicLevel: TrophicLevelEnum
    encodedTraits: String
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Human-associatedMIGSEukaryote implements MIGSEukaryote
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    smoker: String
    hostHivStat: String
    drugUsage: [DrugUsageEnum]
    hostBodyMassIndex: QuantityValue
    dietLastSixMonth: String
    weightLoss3Month: String
    ethnicity: [String]
    hostOccupation: Integer
    petFarmAnimal: [String]
    travelOutSixMonth: [String]
    twinSibling: String
    medicHistPerform: String
    studyCompltStat: StudyCompltStatEnum
    pulmonaryDisord: [String]
    noseThroatDisord: [String]
    bloodBloodDisord: [String]
    hostPulse: QuantityValue
    gestationState: String
    maternalHealthStat: String
    foetalHealthStat: String
    amnioticFluidColor: String
    kidneyDisord: [String]
    urogenitTractDisor: [String]
    urineCollectMeth: String
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    ploidy: String
    numReplicons: Integer
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    trophicLevel: TrophicLevelEnum
    propagation: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Human-associatedMIGSOrg implements MIGSOrg
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    smoker: String
    hostHivStat: String
    drugUsage: [DrugUsageEnum]
    hostBodyMassIndex: QuantityValue
    dietLastSixMonth: String
    weightLoss3Month: String
    ethnicity: [String]
    hostOccupation: Integer
    petFarmAnimal: [String]
    travelOutSixMonth: [String]
    twinSibling: String
    medicHistPerform: String
    studyCompltStat: StudyCompltStatEnum
    pulmonaryDisord: [String]
    noseThroatDisord: [String]
    bloodBloodDisord: [String]
    hostPulse: QuantityValue
    gestationState: String
    maternalHealthStat: String
    foetalHealthStat: String
    amnioticFluidColor: String
    kidneyDisord: [String]
    urogenitTractDisor: [String]
    urineCollectMeth: String
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Human-associatedMIGSPlant implements MIGSPlant
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    smoker: String
    hostHivStat: String
    drugUsage: [DrugUsageEnum]
    hostBodyMassIndex: QuantityValue
    dietLastSixMonth: String
    weightLoss3Month: String
    ethnicity: [String]
    hostOccupation: Integer
    petFarmAnimal: [String]
    travelOutSixMonth: [String]
    twinSibling: String
    medicHistPerform: String
    studyCompltStat: StudyCompltStatEnum
    pulmonaryDisord: [String]
    noseThroatDisord: [String]
    bloodBloodDisord: [String]
    hostPulse: QuantityValue
    gestationState: String
    maternalHealthStat: String
    foetalHealthStat: String
    amnioticFluidColor: String
    kidneyDisord: [String]
    urogenitTractDisor: [String]
    urineCollectMeth: String
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    specificHost: String
    hostSpecRange: Integer
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Human-associatedMIGSVirus implements MIGSVirus
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    smoker: String
    hostHivStat: String
    drugUsage: [DrugUsageEnum]
    hostBodyMassIndex: QuantityValue
    dietLastSixMonth: String
    weightLoss3Month: String
    ethnicity: [String]
    hostOccupation: Integer
    petFarmAnimal: [String]
    travelOutSixMonth: [String]
    twinSibling: String
    medicHistPerform: String
    studyCompltStat: StudyCompltStatEnum
    pulmonaryDisord: [String]
    noseThroatDisord: [String]
    bloodBloodDisord: [String]
    hostPulse: QuantityValue
    gestationState: String
    maternalHealthStat: String
    foetalHealthStat: String
    amnioticFluidColor: String
    kidneyDisord: [String]
    urogenitTractDisor: [String]
    urineCollectMeth: String
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    virusEnrichAppr: VirusEnrichApprEnum
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Human-associatedMIMAG implements MIMAG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    smoker: String
    hostHivStat: String
    drugUsage: [DrugUsageEnum]
    hostBodyMassIndex: QuantityValue
    dietLastSixMonth: String
    weightLoss3Month: String
    ethnicity: [String]
    hostOccupation: Integer
    petFarmAnimal: [String]
    travelOutSixMonth: [String]
    twinSibling: String
    medicHistPerform: String
    studyCompltStat: StudyCompltStatEnum
    pulmonaryDisord: [String]
    noseThroatDisord: [String]
    bloodBloodDisord: [String]
    hostPulse: QuantityValue
    gestationState: String
    maternalHealthStat: String
    foetalHealthStat: String
    amnioticFluidColor: String
    kidneyDisord: [String]
    urogenitTractDisor: [String]
    urineCollectMeth: String
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    binParam: BinParamEnum!
    binSoftware: String!
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    associatedResource: String
    sop: String
  }

type Human-associatedMIMARKSSpecimen implements MIMARKSSpecimen
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    smoker: String
    hostHivStat: String
    drugUsage: [DrugUsageEnum]
    hostBodyMassIndex: QuantityValue
    dietLastSixMonth: String
    weightLoss3Month: String
    ethnicity: [String]
    hostOccupation: Integer
    petFarmAnimal: [String]
    travelOutSixMonth: [String]
    twinSibling: String
    medicHistPerform: String
    studyCompltStat: StudyCompltStatEnum
    pulmonaryDisord: [String]
    noseThroatDisord: [String]
    bloodBloodDisord: [String]
    hostPulse: QuantityValue
    gestationState: String
    maternalHealthStat: String
    foetalHealthStat: String
    amnioticFluidColor: String
    kidneyDisord: [String]
    urogenitTractDisor: [String]
    urineCollectMeth: String
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    mid: String
    adapters: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    assemblySoftware: String
    associatedResource: String
    sop: String
  }

type Human-associatedMIMARKSSurvey implements MIMARKSSurvey
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    smoker: String
    hostHivStat: String
    drugUsage: [DrugUsageEnum]
    hostBodyMassIndex: QuantityValue
    dietLastSixMonth: String
    weightLoss3Month: String
    ethnicity: [String]
    hostOccupation: Integer
    petFarmAnimal: [String]
    travelOutSixMonth: [String]
    twinSibling: String
    medicHistPerform: String
    studyCompltStat: StudyCompltStatEnum
    pulmonaryDisord: [String]
    noseThroatDisord: [String]
    bloodBloodDisord: [String]
    hostPulse: QuantityValue
    gestationState: String
    maternalHealthStat: String
    foetalHealthStat: String
    amnioticFluidColor: String
    kidneyDisord: [String]
    urogenitTractDisor: [String]
    urineCollectMeth: String
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    sourceMatId: String
    bioticRelationship: BioticRelationshipEnum
    trophicLevel: TrophicLevelEnum
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    associatedResource: String
    sop: String
  }

type Human-associatedMIMS implements MIMS
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    smoker: String
    hostHivStat: String
    drugUsage: [DrugUsageEnum]
    hostBodyMassIndex: QuantityValue
    dietLastSixMonth: String
    weightLoss3Month: String
    ethnicity: [String]
    hostOccupation: Integer
    petFarmAnimal: [String]
    travelOutSixMonth: [String]
    twinSibling: String
    medicHistPerform: String
    studyCompltStat: StudyCompltStatEnum
    pulmonaryDisord: [String]
    noseThroatDisord: [String]
    bloodBloodDisord: [String]
    hostPulse: QuantityValue
    gestationState: String
    maternalHealthStat: String
    foetalHealthStat: String
    amnioticFluidColor: String
    kidneyDisord: [String]
    urogenitTractDisor: [String]
    urineCollectMeth: String
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    associatedResource: String
    sop: String
  }

type Human-associatedMISAG implements MISAG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    smoker: String
    hostHivStat: String
    drugUsage: [DrugUsageEnum]
    hostBodyMassIndex: QuantityValue
    dietLastSixMonth: String
    weightLoss3Month: String
    ethnicity: [String]
    hostOccupation: Integer
    petFarmAnimal: [String]
    travelOutSixMonth: [String]
    twinSibling: String
    medicHistPerform: String
    studyCompltStat: StudyCompltStatEnum
    pulmonaryDisord: [String]
    noseThroatDisord: [String]
    bloodBloodDisord: [String]
    hostPulse: QuantityValue
    gestationState: String
    maternalHealthStat: String
    foetalHealthStat: String
    amnioticFluidColor: String
    kidneyDisord: [String]
    urogenitTractDisor: [String]
    urineCollectMeth: String
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    sortTech: SortTechEnum!
    singleCellLysisAppr: SingleCellLysisApprEnum!
    singleCellLysisProt: String
    wgaAmpAppr: String!
    wgaAmpKit: String
    associatedResource: String
    sop: String
  }

type Human-associatedMIUVIG implements MIUVIG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    smoker: String
    hostHivStat: String
    drugUsage: [DrugUsageEnum]
    hostBodyMassIndex: QuantityValue
    dietLastSixMonth: String
    weightLoss3Month: String
    ethnicity: [String]
    hostOccupation: Integer
    petFarmAnimal: [String]
    travelOutSixMonth: [String]
    twinSibling: String
    medicHistPerform: String
    studyCompltStat: StudyCompltStatEnum
    pulmonaryDisord: [String]
    noseThroatDisord: [String]
    bloodBloodDisord: [String]
    hostPulse: QuantityValue
    gestationState: String
    maternalHealthStat: String
    foetalHealthStat: String
    amnioticFluidColor: String
    kidneyDisord: [String]
    urogenitTractDisor: [String]
    urineCollectMeth: String
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    sourceUvig: SourceUvigEnum!
    virusEnrichAppr: VirusEnrichApprEnum!
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String
    complSoftware: String
    complAppr: ComplApprEnum
    sortTech: SortTechEnum
    singleCellLysisAppr: SingleCellLysisApprEnum
    singleCellLysisProt: String
    wgaAmpAppr: String
    wgaAmpKit: String
    binParam: BinParamEnum
    binSoftware: String
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    virIdentSoftware: String!
    predGenomeType: PredGenomeTypeEnum!
    predGenomeStruc: PredGenomeStrucEnum!
    detecType: String!
    otuClassAppr: String
    otuSeqCompAppr: String
    otuDb: String
    hostPredAppr: HostPredApprEnum
    hostPredEstAcc: String
    associatedResource: String
    sop: String
  }

type Human-gut
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    gastrointestDisord: [String]
    liverDisord: [String]
    specialDiet: [SpecialDietEnum]
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
  }

type Human-gutMIGSBacteria implements MIGSBacteria
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    gastrointestDisord: [String]
    liverDisord: [String]
    specialDiet: [SpecialDietEnum]
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer!
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String!
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    trophicLevel: TrophicLevelEnum
    encodedTraits: String
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Human-gutMIGSEukaryote implements MIGSEukaryote
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    gastrointestDisord: [String]
    liverDisord: [String]
    specialDiet: [SpecialDietEnum]
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    ploidy: String
    numReplicons: Integer
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    trophicLevel: TrophicLevelEnum
    propagation: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Human-gutMIGSOrg implements MIGSOrg
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    gastrointestDisord: [String]
    liverDisord: [String]
    specialDiet: [SpecialDietEnum]
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Human-gutMIGSPlant implements MIGSPlant
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    gastrointestDisord: [String]
    liverDisord: [String]
    specialDiet: [SpecialDietEnum]
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    specificHost: String
    hostSpecRange: Integer
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Human-gutMIGSVirus implements MIGSVirus
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    gastrointestDisord: [String]
    liverDisord: [String]
    specialDiet: [SpecialDietEnum]
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    virusEnrichAppr: VirusEnrichApprEnum
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Human-gutMIMAG implements MIMAG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    gastrointestDisord: [String]
    liverDisord: [String]
    specialDiet: [SpecialDietEnum]
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    binParam: BinParamEnum!
    binSoftware: String!
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    associatedResource: String
    sop: String
  }

type Human-gutMIMARKSSpecimen implements MIMARKSSpecimen
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    gastrointestDisord: [String]
    liverDisord: [String]
    specialDiet: [SpecialDietEnum]
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    mid: String
    adapters: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    assemblySoftware: String
    associatedResource: String
    sop: String
  }

type Human-gutMIMARKSSurvey implements MIMARKSSurvey
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    gastrointestDisord: [String]
    liverDisord: [String]
    specialDiet: [SpecialDietEnum]
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    sourceMatId: String
    bioticRelationship: BioticRelationshipEnum
    trophicLevel: TrophicLevelEnum
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    associatedResource: String
    sop: String
  }

type Human-gutMIMS implements MIMS
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    gastrointestDisord: [String]
    liverDisord: [String]
    specialDiet: [SpecialDietEnum]
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    associatedResource: String
    sop: String
  }

type Human-gutMISAG implements MISAG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    gastrointestDisord: [String]
    liverDisord: [String]
    specialDiet: [SpecialDietEnum]
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    sortTech: SortTechEnum!
    singleCellLysisAppr: SingleCellLysisApprEnum!
    singleCellLysisProt: String
    wgaAmpAppr: String!
    wgaAmpKit: String
    associatedResource: String
    sop: String
  }

type Human-gutMIUVIG implements MIUVIG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    gastrointestDisord: [String]
    liverDisord: [String]
    specialDiet: [SpecialDietEnum]
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    sourceUvig: SourceUvigEnum!
    virusEnrichAppr: VirusEnrichApprEnum!
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String
    complSoftware: String
    complAppr: ComplApprEnum
    sortTech: SortTechEnum
    singleCellLysisAppr: SingleCellLysisApprEnum
    singleCellLysisProt: String
    wgaAmpAppr: String
    wgaAmpKit: String
    binParam: BinParamEnum
    binSoftware: String
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    virIdentSoftware: String!
    predGenomeType: PredGenomeTypeEnum!
    predGenomeStruc: PredGenomeStrucEnum!
    detecType: String!
    otuClassAppr: String
    otuSeqCompAppr: String
    otuDb: String
    hostPredAppr: HostPredApprEnum
    hostPredEstAcc: String
    associatedResource: String
    sop: String
  }

type Human-oral
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    noseThroatDisord: [String]
    timeLastToothbrush: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
  }

type Human-oralMIGSBacteria implements MIGSBacteria
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    noseThroatDisord: [String]
    timeLastToothbrush: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer!
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String!
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    trophicLevel: TrophicLevelEnum
    encodedTraits: String
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Human-oralMIGSEukaryote implements MIGSEukaryote
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    noseThroatDisord: [String]
    timeLastToothbrush: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    ploidy: String
    numReplicons: Integer
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    trophicLevel: TrophicLevelEnum
    propagation: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Human-oralMIGSOrg implements MIGSOrg
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    noseThroatDisord: [String]
    timeLastToothbrush: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Human-oralMIGSPlant implements MIGSPlant
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    noseThroatDisord: [String]
    timeLastToothbrush: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    specificHost: String
    hostSpecRange: Integer
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Human-oralMIGSVirus implements MIGSVirus
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    noseThroatDisord: [String]
    timeLastToothbrush: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    virusEnrichAppr: VirusEnrichApprEnum
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Human-oralMIMAG implements MIMAG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    noseThroatDisord: [String]
    timeLastToothbrush: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    binParam: BinParamEnum!
    binSoftware: String!
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    associatedResource: String
    sop: String
  }

type Human-oralMIMARKSSpecimen implements MIMARKSSpecimen
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    noseThroatDisord: [String]
    timeLastToothbrush: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    mid: String
    adapters: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    assemblySoftware: String
    associatedResource: String
    sop: String
  }

type Human-oralMIMARKSSurvey implements MIMARKSSurvey
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    noseThroatDisord: [String]
    timeLastToothbrush: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    sourceMatId: String
    bioticRelationship: BioticRelationshipEnum
    trophicLevel: TrophicLevelEnum
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    associatedResource: String
    sop: String
  }

type Human-oralMIMS implements MIMS
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    noseThroatDisord: [String]
    timeLastToothbrush: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    associatedResource: String
    sop: String
  }

type Human-oralMISAG implements MISAG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    noseThroatDisord: [String]
    timeLastToothbrush: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    sortTech: SortTechEnum!
    singleCellLysisAppr: SingleCellLysisApprEnum!
    singleCellLysisProt: String
    wgaAmpAppr: String!
    wgaAmpKit: String
    associatedResource: String
    sop: String
  }

type Human-oralMIUVIG implements MIUVIG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    noseThroatDisord: [String]
    timeLastToothbrush: String
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    hostSymbiont: [String]
    sampStoreLoc: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    sourceUvig: SourceUvigEnum!
    virusEnrichAppr: VirusEnrichApprEnum!
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String
    complSoftware: String
    complAppr: ComplApprEnum
    sortTech: SortTechEnum
    singleCellLysisAppr: SingleCellLysisApprEnum
    singleCellLysisProt: String
    wgaAmpAppr: String
    wgaAmpKit: String
    binParam: BinParamEnum
    binSoftware: String
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    virIdentSoftware: String!
    predGenomeType: PredGenomeTypeEnum!
    predGenomeStruc: PredGenomeStrucEnum!
    detecType: String!
    otuClassAppr: String
    otuSeqCompAppr: String
    otuDb: String
    hostPredAppr: HostPredApprEnum
    hostPredEstAcc: String
    associatedResource: String
    sop: String
  }

type Human-skin
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    dermatologyDisord: [String]
    timeSinceLastWash: String
    dominantHand: DominantHandEnum
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
  }

type Human-skinMIGSBacteria implements MIGSBacteria
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    dermatologyDisord: [String]
    timeSinceLastWash: String
    dominantHand: DominantHandEnum
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer!
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String!
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    trophicLevel: TrophicLevelEnum
    encodedTraits: String
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Human-skinMIGSEukaryote implements MIGSEukaryote
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    dermatologyDisord: [String]
    timeSinceLastWash: String
    dominantHand: DominantHandEnum
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    ploidy: String
    numReplicons: Integer
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    trophicLevel: TrophicLevelEnum
    propagation: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Human-skinMIGSOrg implements MIGSOrg
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    dermatologyDisord: [String]
    timeSinceLastWash: String
    dominantHand: DominantHandEnum
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Human-skinMIGSPlant implements MIGSPlant
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    dermatologyDisord: [String]
    timeSinceLastWash: String
    dominantHand: DominantHandEnum
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    specificHost: String
    hostSpecRange: Integer
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Human-skinMIGSVirus implements MIGSVirus
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    dermatologyDisord: [String]
    timeSinceLastWash: String
    dominantHand: DominantHandEnum
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    virusEnrichAppr: VirusEnrichApprEnum
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Human-skinMIMAG implements MIMAG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    dermatologyDisord: [String]
    timeSinceLastWash: String
    dominantHand: DominantHandEnum
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    binParam: BinParamEnum!
    binSoftware: String!
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    associatedResource: String
    sop: String
  }

type Human-skinMIMARKSSpecimen implements MIMARKSSpecimen
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    dermatologyDisord: [String]
    timeSinceLastWash: String
    dominantHand: DominantHandEnum
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    mid: String
    adapters: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    assemblySoftware: String
    associatedResource: String
    sop: String
  }

type Human-skinMIMARKSSurvey implements MIMARKSSurvey
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    dermatologyDisord: [String]
    timeSinceLastWash: String
    dominantHand: DominantHandEnum
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    sourceMatId: String
    bioticRelationship: BioticRelationshipEnum
    trophicLevel: TrophicLevelEnum
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    associatedResource: String
    sop: String
  }

type Human-skinMIMS implements MIMS
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    dermatologyDisord: [String]
    timeSinceLastWash: String
    dominantHand: DominantHandEnum
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    associatedResource: String
    sop: String
  }

type Human-skinMISAG implements MISAG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    dermatologyDisord: [String]
    timeSinceLastWash: String
    dominantHand: DominantHandEnum
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    sortTech: SortTechEnum!
    singleCellLysisAppr: SingleCellLysisApprEnum!
    singleCellLysisProt: String
    wgaAmpAppr: String!
    wgaAmpKit: String
    associatedResource: String
    sop: String
  }

type Human-skinMIUVIG implements MIUVIG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    dermatologyDisord: [String]
    timeSinceLastWash: String
    dominantHand: DominantHandEnum
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    sourceUvig: SourceUvigEnum!
    virusEnrichAppr: VirusEnrichApprEnum!
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String
    complSoftware: String
    complAppr: ComplApprEnum
    sortTech: SortTechEnum
    singleCellLysisAppr: SingleCellLysisApprEnum
    singleCellLysisProt: String
    wgaAmpAppr: String
    wgaAmpKit: String
    binParam: BinParamEnum
    binSoftware: String
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    virIdentSoftware: String!
    predGenomeType: PredGenomeTypeEnum!
    predGenomeStruc: PredGenomeStrucEnum!
    detecType: String!
    otuClassAppr: String
    otuSeqCompAppr: String
    otuDb: String
    hostPredAppr: HostPredApprEnum
    hostPredEstAcc: String
    associatedResource: String
    sop: String
  }

type Human-vaginal
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    menarche: Date
    sexualAct: String
    pregnancy: Date
    douche: Date
    birthControl: String
    menopause: Date
    hrt: Date
    hysterectomy: String
    gynecologicDisord: [String]
    urogenitDisord: [String]
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    sampSalinity: QuantityValue
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreLoc: String
    sampStoreDur: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
  }

type Human-vaginalMIGSBacteria implements MIGSBacteria
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    menarche: Date
    sexualAct: String
    pregnancy: Date
    douche: Date
    birthControl: String
    menopause: Date
    hrt: Date
    hysterectomy: String
    gynecologicDisord: [String]
    urogenitDisord: [String]
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    sampSalinity: QuantityValue
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreLoc: String
    sampStoreDur: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer!
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String!
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    trophicLevel: TrophicLevelEnum
    encodedTraits: String
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Human-vaginalMIGSEukaryote implements MIGSEukaryote
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    menarche: Date
    sexualAct: String
    pregnancy: Date
    douche: Date
    birthControl: String
    menopause: Date
    hrt: Date
    hysterectomy: String
    gynecologicDisord: [String]
    urogenitDisord: [String]
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    sampSalinity: QuantityValue
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreLoc: String
    sampStoreDur: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    ploidy: String
    numReplicons: Integer
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    trophicLevel: TrophicLevelEnum
    propagation: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Human-vaginalMIGSOrg implements MIGSOrg
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    menarche: Date
    sexualAct: String
    pregnancy: Date
    douche: Date
    birthControl: String
    menopause: Date
    hrt: Date
    hysterectomy: String
    gynecologicDisord: [String]
    urogenitDisord: [String]
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    sampSalinity: QuantityValue
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreLoc: String
    sampStoreDur: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Human-vaginalMIGSPlant implements MIGSPlant
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    menarche: Date
    sexualAct: String
    pregnancy: Date
    douche: Date
    birthControl: String
    menopause: Date
    hrt: Date
    hysterectomy: String
    gynecologicDisord: [String]
    urogenitDisord: [String]
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    sampSalinity: QuantityValue
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreLoc: String
    sampStoreDur: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    specificHost: String
    hostSpecRange: Integer
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Human-vaginalMIGSVirus implements MIGSVirus
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    menarche: Date
    sexualAct: String
    pregnancy: Date
    douche: Date
    birthControl: String
    menopause: Date
    hrt: Date
    hysterectomy: String
    gynecologicDisord: [String]
    urogenitDisord: [String]
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    sampSalinity: QuantityValue
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreLoc: String
    sampStoreDur: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    virusEnrichAppr: VirusEnrichApprEnum
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Human-vaginalMIMAG implements MIMAG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    menarche: Date
    sexualAct: String
    pregnancy: Date
    douche: Date
    birthControl: String
    menopause: Date
    hrt: Date
    hysterectomy: String
    gynecologicDisord: [String]
    urogenitDisord: [String]
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    sampSalinity: QuantityValue
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreLoc: String
    sampStoreDur: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    binParam: BinParamEnum!
    binSoftware: String!
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    associatedResource: String
    sop: String
  }

type Human-vaginalMIMARKSSpecimen implements MIMARKSSpecimen
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    menarche: Date
    sexualAct: String
    pregnancy: Date
    douche: Date
    birthControl: String
    menopause: Date
    hrt: Date
    hysterectomy: String
    gynecologicDisord: [String]
    urogenitDisord: [String]
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    sampSalinity: QuantityValue
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreLoc: String
    sampStoreDur: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    mid: String
    adapters: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    assemblySoftware: String
    associatedResource: String
    sop: String
  }

type Human-vaginalMIMARKSSurvey implements MIMARKSSurvey
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    menarche: Date
    sexualAct: String
    pregnancy: Date
    douche: Date
    birthControl: String
    menopause: Date
    hrt: Date
    hysterectomy: String
    gynecologicDisord: [String]
    urogenitDisord: [String]
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    sampSalinity: QuantityValue
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreLoc: String
    sampStoreDur: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    sourceMatId: String
    bioticRelationship: BioticRelationshipEnum
    trophicLevel: TrophicLevelEnum
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    associatedResource: String
    sop: String
  }

type Human-vaginalMIMS implements MIMS
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    menarche: Date
    sexualAct: String
    pregnancy: Date
    douche: Date
    birthControl: String
    menopause: Date
    hrt: Date
    hysterectomy: String
    gynecologicDisord: [String]
    urogenitDisord: [String]
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    sampSalinity: QuantityValue
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreLoc: String
    sampStoreDur: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    associatedResource: String
    sop: String
  }

type Human-vaginalMISAG implements MISAG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    menarche: Date
    sexualAct: String
    pregnancy: Date
    douche: Date
    birthControl: String
    menopause: Date
    hrt: Date
    hysterectomy: String
    gynecologicDisord: [String]
    urogenitDisord: [String]
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    sampSalinity: QuantityValue
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreLoc: String
    sampStoreDur: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    sortTech: SortTechEnum!
    singleCellLysisAppr: SingleCellLysisApprEnum!
    singleCellLysisProt: String
    wgaAmpAppr: String!
    wgaAmpKit: String
    associatedResource: String
    sop: String
  }

type Human-vaginalMIUVIG implements MIUVIG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    menarche: Date
    sexualAct: String
    pregnancy: Date
    douche: Date
    birthControl: String
    menopause: Date
    hrt: Date
    hysterectomy: String
    gynecologicDisord: [String]
    urogenitDisord: [String]
    hostSubjectId: String
    hostAge: QuantityValue
    hostSex: HostSexEnum
    ihmcMedicationCode: [Integer]
    chemAdministration: [String]
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostDiet: [String]
    hostLastMeal: [String]
    hostFamilyRelation: [String]
    hostGenotype: String
    hostPhenotype: String
    hostBodyTemp: QuantityValue
    hostBodyMassIndex: QuantityValue
    ethnicity: [String]
    hostOccupation: Integer
    medicHistPerform: String
    hostPulse: QuantityValue
    perturbation: [String]
    sampSalinity: QuantityValue
    salinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreLoc: String
    sampStoreDur: String
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    sourceUvig: SourceUvigEnum!
    virusEnrichAppr: VirusEnrichApprEnum!
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String
    complSoftware: String
    complAppr: ComplApprEnum
    sortTech: SortTechEnum
    singleCellLysisAppr: SingleCellLysisApprEnum
    singleCellLysisProt: String
    wgaAmpAppr: String
    wgaAmpKit: String
    binParam: BinParamEnum
    binSoftware: String
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    virIdentSoftware: String!
    predGenomeType: PredGenomeTypeEnum!
    predGenomeStruc: PredGenomeStrucEnum!
    detecType: String!
    otuClassAppr: String
    otuSeqCompAppr: String
    otuDb: String
    hostPredAppr: HostPredApprEnum
    hostPredEstAcc: String
    associatedResource: String
    sop: String
  }

type HydrocarbonResources-cores
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue!
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hcr: HcrEnum!
    hcProduced: HcProducedEnum!
    basin: String!
    field: String
    reservoir: String
    hcrTemp: String!
    tvdssOfHcrTemp: QuantityValue
    hcrPressure: String
    tvdssOfHcrPress: QuantityValue
    permeability: String
    porosity: String
    lithology: LithologyEnum
    deposEnv: DeposEnvEnum
    hcrGeolAge: HcrGeolAgeEnum
    owcTvdss: QuantityValue
    hcrFwSalinity: QuantityValue
    sulfateFw: QuantityValue!
    vfaFw: QuantityValue!
    srKerogType: SrKerogTypeEnum
    srLithology: SrLithologyEnum
    srDepEnv: SrDepEnvEnum
    srGeolAge: SrGeolAgeEnum
    sampWellName: String
    win: String
    sampType: String!
    sampSubtype: SampSubtypeEnum
    pressure: QuantityValue
    sampTvdss: String
    sampMd: SampMdEnum
    oxyStatSamp: OxyStatSampEnum
    sampTransportCond: String
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    organismCount: [OrganismCountEnum]
    orgCountQpcrInfo: String
    ph: Double
    salinity: QuantityValue
    alkalinity: QuantityValue
    alkalinityMethod: String
    sulfate: QuantityValue
    sulfide: QuantityValue
    totSulfur: QuantityValue
    nitrate: QuantityValue
    nitrite: QuantityValue
    ammonium: QuantityValue
    totNitro: QuantityValue
    dissIron: QuantityValue
    sodium: QuantityValue
    chloride: QuantityValue
    potassium: QuantityValue
    magnesium: QuantityValue
    calcium: QuantityValue
    totIron: QuantityValue
    dissOrgCarb: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgPhosp: QuantityValue
    totPhosp: QuantityValue
    suspendSolids: [String]
    density: QuantityValue
    dissCarbDioxide: QuantityValue
    dissOxygenFluid: QuantityValue
    vfa: QuantityValue
    benzene: QuantityValue
    toluene: QuantityValue
    ethylbenzene: QuantityValue
    xylene: QuantityValue
    api: QuantityValue!
    tan: QuantityValue
    viscosity: String
    pourPoint: QuantityValue
    saturatesPc: String
    aromaticsPc: String
    resinsPc: String
    asphaltenesPc: String
    miscParam: [String]
    additionalInfo: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
  }

type HydrocarbonResources-coresMIGSBacteria implements MIGSBacteria
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue!
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hcr: HcrEnum!
    hcProduced: HcProducedEnum!
    basin: String!
    field: String
    reservoir: String
    hcrTemp: String!
    tvdssOfHcrTemp: QuantityValue
    hcrPressure: String
    tvdssOfHcrPress: QuantityValue
    permeability: String
    porosity: String
    lithology: LithologyEnum
    deposEnv: DeposEnvEnum
    hcrGeolAge: HcrGeolAgeEnum
    owcTvdss: QuantityValue
    hcrFwSalinity: QuantityValue
    sulfateFw: QuantityValue!
    vfaFw: QuantityValue!
    srKerogType: SrKerogTypeEnum
    srLithology: SrLithologyEnum
    srDepEnv: SrDepEnvEnum
    srGeolAge: SrGeolAgeEnum
    sampWellName: String
    win: String
    sampType: String!
    sampSubtype: SampSubtypeEnum
    pressure: QuantityValue
    sampTvdss: String
    sampMd: SampMdEnum
    oxyStatSamp: OxyStatSampEnum
    sampTransportCond: String
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    organismCount: [OrganismCountEnum]
    orgCountQpcrInfo: String
    ph: Double
    salinity: QuantityValue
    alkalinity: QuantityValue
    alkalinityMethod: String
    sulfate: QuantityValue
    sulfide: QuantityValue
    totSulfur: QuantityValue
    nitrate: QuantityValue
    nitrite: QuantityValue
    ammonium: QuantityValue
    totNitro: QuantityValue
    dissIron: QuantityValue
    sodium: QuantityValue
    chloride: QuantityValue
    potassium: QuantityValue
    magnesium: QuantityValue
    calcium: QuantityValue
    totIron: QuantityValue
    dissOrgCarb: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgPhosp: QuantityValue
    totPhosp: QuantityValue
    suspendSolids: [String]
    density: QuantityValue
    dissCarbDioxide: QuantityValue
    dissOxygenFluid: QuantityValue
    vfa: QuantityValue
    benzene: QuantityValue
    toluene: QuantityValue
    ethylbenzene: QuantityValue
    xylene: QuantityValue
    api: QuantityValue!
    tan: QuantityValue
    viscosity: String
    pourPoint: QuantityValue
    saturatesPc: String
    aromaticsPc: String
    resinsPc: String
    asphaltenesPc: String
    miscParam: [String]
    additionalInfo: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer!
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String!
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    trophicLevel: TrophicLevelEnum
    encodedTraits: String
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type HydrocarbonResources-coresMIGSEukaryote implements MIGSEukaryote
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue!
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hcr: HcrEnum!
    hcProduced: HcProducedEnum!
    basin: String!
    field: String
    reservoir: String
    hcrTemp: String!
    tvdssOfHcrTemp: QuantityValue
    hcrPressure: String
    tvdssOfHcrPress: QuantityValue
    permeability: String
    porosity: String
    lithology: LithologyEnum
    deposEnv: DeposEnvEnum
    hcrGeolAge: HcrGeolAgeEnum
    owcTvdss: QuantityValue
    hcrFwSalinity: QuantityValue
    sulfateFw: QuantityValue!
    vfaFw: QuantityValue!
    srKerogType: SrKerogTypeEnum
    srLithology: SrLithologyEnum
    srDepEnv: SrDepEnvEnum
    srGeolAge: SrGeolAgeEnum
    sampWellName: String
    win: String
    sampType: String!
    sampSubtype: SampSubtypeEnum
    pressure: QuantityValue
    sampTvdss: String
    sampMd: SampMdEnum
    oxyStatSamp: OxyStatSampEnum
    sampTransportCond: String
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    organismCount: [OrganismCountEnum]
    orgCountQpcrInfo: String
    ph: Double
    salinity: QuantityValue
    alkalinity: QuantityValue
    alkalinityMethod: String
    sulfate: QuantityValue
    sulfide: QuantityValue
    totSulfur: QuantityValue
    nitrate: QuantityValue
    nitrite: QuantityValue
    ammonium: QuantityValue
    totNitro: QuantityValue
    dissIron: QuantityValue
    sodium: QuantityValue
    chloride: QuantityValue
    potassium: QuantityValue
    magnesium: QuantityValue
    calcium: QuantityValue
    totIron: QuantityValue
    dissOrgCarb: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgPhosp: QuantityValue
    totPhosp: QuantityValue
    suspendSolids: [String]
    density: QuantityValue
    dissCarbDioxide: QuantityValue
    dissOxygenFluid: QuantityValue
    vfa: QuantityValue
    benzene: QuantityValue
    toluene: QuantityValue
    ethylbenzene: QuantityValue
    xylene: QuantityValue
    api: QuantityValue!
    tan: QuantityValue
    viscosity: String
    pourPoint: QuantityValue
    saturatesPc: String
    aromaticsPc: String
    resinsPc: String
    asphaltenesPc: String
    miscParam: [String]
    additionalInfo: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    ploidy: String
    numReplicons: Integer
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    trophicLevel: TrophicLevelEnum
    propagation: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type HydrocarbonResources-coresMIGSOrg implements MIGSOrg
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue!
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hcr: HcrEnum!
    hcProduced: HcProducedEnum!
    basin: String!
    field: String
    reservoir: String
    hcrTemp: String!
    tvdssOfHcrTemp: QuantityValue
    hcrPressure: String
    tvdssOfHcrPress: QuantityValue
    permeability: String
    porosity: String
    lithology: LithologyEnum
    deposEnv: DeposEnvEnum
    hcrGeolAge: HcrGeolAgeEnum
    owcTvdss: QuantityValue
    hcrFwSalinity: QuantityValue
    sulfateFw: QuantityValue!
    vfaFw: QuantityValue!
    srKerogType: SrKerogTypeEnum
    srLithology: SrLithologyEnum
    srDepEnv: SrDepEnvEnum
    srGeolAge: SrGeolAgeEnum
    sampWellName: String
    win: String
    sampType: String!
    sampSubtype: SampSubtypeEnum
    pressure: QuantityValue
    sampTvdss: String
    sampMd: SampMdEnum
    oxyStatSamp: OxyStatSampEnum
    sampTransportCond: String
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    organismCount: [OrganismCountEnum]
    orgCountQpcrInfo: String
    ph: Double
    salinity: QuantityValue
    alkalinity: QuantityValue
    alkalinityMethod: String
    sulfate: QuantityValue
    sulfide: QuantityValue
    totSulfur: QuantityValue
    nitrate: QuantityValue
    nitrite: QuantityValue
    ammonium: QuantityValue
    totNitro: QuantityValue
    dissIron: QuantityValue
    sodium: QuantityValue
    chloride: QuantityValue
    potassium: QuantityValue
    magnesium: QuantityValue
    calcium: QuantityValue
    totIron: QuantityValue
    dissOrgCarb: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgPhosp: QuantityValue
    totPhosp: QuantityValue
    suspendSolids: [String]
    density: QuantityValue
    dissCarbDioxide: QuantityValue
    dissOxygenFluid: QuantityValue
    vfa: QuantityValue
    benzene: QuantityValue
    toluene: QuantityValue
    ethylbenzene: QuantityValue
    xylene: QuantityValue
    api: QuantityValue!
    tan: QuantityValue
    viscosity: String
    pourPoint: QuantityValue
    saturatesPc: String
    aromaticsPc: String
    resinsPc: String
    asphaltenesPc: String
    miscParam: [String]
    additionalInfo: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type HydrocarbonResources-coresMIGSPlant implements MIGSPlant
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue!
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hcr: HcrEnum!
    hcProduced: HcProducedEnum!
    basin: String!
    field: String
    reservoir: String
    hcrTemp: String!
    tvdssOfHcrTemp: QuantityValue
    hcrPressure: String
    tvdssOfHcrPress: QuantityValue
    permeability: String
    porosity: String
    lithology: LithologyEnum
    deposEnv: DeposEnvEnum
    hcrGeolAge: HcrGeolAgeEnum
    owcTvdss: QuantityValue
    hcrFwSalinity: QuantityValue
    sulfateFw: QuantityValue!
    vfaFw: QuantityValue!
    srKerogType: SrKerogTypeEnum
    srLithology: SrLithologyEnum
    srDepEnv: SrDepEnvEnum
    srGeolAge: SrGeolAgeEnum
    sampWellName: String
    win: String
    sampType: String!
    sampSubtype: SampSubtypeEnum
    pressure: QuantityValue
    sampTvdss: String
    sampMd: SampMdEnum
    oxyStatSamp: OxyStatSampEnum
    sampTransportCond: String
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    organismCount: [OrganismCountEnum]
    orgCountQpcrInfo: String
    ph: Double
    salinity: QuantityValue
    alkalinity: QuantityValue
    alkalinityMethod: String
    sulfate: QuantityValue
    sulfide: QuantityValue
    totSulfur: QuantityValue
    nitrate: QuantityValue
    nitrite: QuantityValue
    ammonium: QuantityValue
    totNitro: QuantityValue
    dissIron: QuantityValue
    sodium: QuantityValue
    chloride: QuantityValue
    potassium: QuantityValue
    magnesium: QuantityValue
    calcium: QuantityValue
    totIron: QuantityValue
    dissOrgCarb: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgPhosp: QuantityValue
    totPhosp: QuantityValue
    suspendSolids: [String]
    density: QuantityValue
    dissCarbDioxide: QuantityValue
    dissOxygenFluid: QuantityValue
    vfa: QuantityValue
    benzene: QuantityValue
    toluene: QuantityValue
    ethylbenzene: QuantityValue
    xylene: QuantityValue
    api: QuantityValue!
    tan: QuantityValue
    viscosity: String
    pourPoint: QuantityValue
    saturatesPc: String
    aromaticsPc: String
    resinsPc: String
    asphaltenesPc: String
    miscParam: [String]
    additionalInfo: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    specificHost: String
    hostSpecRange: Integer
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type HydrocarbonResources-coresMIGSVirus implements MIGSVirus
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue!
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hcr: HcrEnum!
    hcProduced: HcProducedEnum!
    basin: String!
    field: String
    reservoir: String
    hcrTemp: String!
    tvdssOfHcrTemp: QuantityValue
    hcrPressure: String
    tvdssOfHcrPress: QuantityValue
    permeability: String
    porosity: String
    lithology: LithologyEnum
    deposEnv: DeposEnvEnum
    hcrGeolAge: HcrGeolAgeEnum
    owcTvdss: QuantityValue
    hcrFwSalinity: QuantityValue
    sulfateFw: QuantityValue!
    vfaFw: QuantityValue!
    srKerogType: SrKerogTypeEnum
    srLithology: SrLithologyEnum
    srDepEnv: SrDepEnvEnum
    srGeolAge: SrGeolAgeEnum
    sampWellName: String
    win: String
    sampType: String!
    sampSubtype: SampSubtypeEnum
    pressure: QuantityValue
    sampTvdss: String
    sampMd: SampMdEnum
    oxyStatSamp: OxyStatSampEnum
    sampTransportCond: String
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    organismCount: [OrganismCountEnum]
    orgCountQpcrInfo: String
    ph: Double
    salinity: QuantityValue
    alkalinity: QuantityValue
    alkalinityMethod: String
    sulfate: QuantityValue
    sulfide: QuantityValue
    totSulfur: QuantityValue
    nitrate: QuantityValue
    nitrite: QuantityValue
    ammonium: QuantityValue
    totNitro: QuantityValue
    dissIron: QuantityValue
    sodium: QuantityValue
    chloride: QuantityValue
    potassium: QuantityValue
    magnesium: QuantityValue
    calcium: QuantityValue
    totIron: QuantityValue
    dissOrgCarb: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgPhosp: QuantityValue
    totPhosp: QuantityValue
    suspendSolids: [String]
    density: QuantityValue
    dissCarbDioxide: QuantityValue
    dissOxygenFluid: QuantityValue
    vfa: QuantityValue
    benzene: QuantityValue
    toluene: QuantityValue
    ethylbenzene: QuantityValue
    xylene: QuantityValue
    api: QuantityValue!
    tan: QuantityValue
    viscosity: String
    pourPoint: QuantityValue
    saturatesPc: String
    aromaticsPc: String
    resinsPc: String
    asphaltenesPc: String
    miscParam: [String]
    additionalInfo: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    virusEnrichAppr: VirusEnrichApprEnum
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type HydrocarbonResources-coresMIMAG implements MIMAG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue!
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hcr: HcrEnum!
    hcProduced: HcProducedEnum!
    basin: String!
    field: String
    reservoir: String
    hcrTemp: String!
    tvdssOfHcrTemp: QuantityValue
    hcrPressure: String
    tvdssOfHcrPress: QuantityValue
    permeability: String
    porosity: String
    lithology: LithologyEnum
    deposEnv: DeposEnvEnum
    hcrGeolAge: HcrGeolAgeEnum
    owcTvdss: QuantityValue
    hcrFwSalinity: QuantityValue
    sulfateFw: QuantityValue!
    vfaFw: QuantityValue!
    srKerogType: SrKerogTypeEnum
    srLithology: SrLithologyEnum
    srDepEnv: SrDepEnvEnum
    srGeolAge: SrGeolAgeEnum
    sampWellName: String
    win: String
    sampType: String!
    sampSubtype: SampSubtypeEnum
    pressure: QuantityValue
    sampTvdss: String
    sampMd: SampMdEnum
    oxyStatSamp: OxyStatSampEnum
    sampTransportCond: String
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    organismCount: [OrganismCountEnum]
    orgCountQpcrInfo: String
    ph: Double
    salinity: QuantityValue
    alkalinity: QuantityValue
    alkalinityMethod: String
    sulfate: QuantityValue
    sulfide: QuantityValue
    totSulfur: QuantityValue
    nitrate: QuantityValue
    nitrite: QuantityValue
    ammonium: QuantityValue
    totNitro: QuantityValue
    dissIron: QuantityValue
    sodium: QuantityValue
    chloride: QuantityValue
    potassium: QuantityValue
    magnesium: QuantityValue
    calcium: QuantityValue
    totIron: QuantityValue
    dissOrgCarb: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgPhosp: QuantityValue
    totPhosp: QuantityValue
    suspendSolids: [String]
    density: QuantityValue
    dissCarbDioxide: QuantityValue
    dissOxygenFluid: QuantityValue
    vfa: QuantityValue
    benzene: QuantityValue
    toluene: QuantityValue
    ethylbenzene: QuantityValue
    xylene: QuantityValue
    api: QuantityValue!
    tan: QuantityValue
    viscosity: String
    pourPoint: QuantityValue
    saturatesPc: String
    aromaticsPc: String
    resinsPc: String
    asphaltenesPc: String
    miscParam: [String]
    additionalInfo: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    binParam: BinParamEnum!
    binSoftware: String!
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    associatedResource: String
    sop: String
  }

type HydrocarbonResources-coresMIMARKSSpecimen implements MIMARKSSpecimen
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue!
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hcr: HcrEnum!
    hcProduced: HcProducedEnum!
    basin: String!
    field: String
    reservoir: String
    hcrTemp: String!
    tvdssOfHcrTemp: QuantityValue
    hcrPressure: String
    tvdssOfHcrPress: QuantityValue
    permeability: String
    porosity: String
    lithology: LithologyEnum
    deposEnv: DeposEnvEnum
    hcrGeolAge: HcrGeolAgeEnum
    owcTvdss: QuantityValue
    hcrFwSalinity: QuantityValue
    sulfateFw: QuantityValue!
    vfaFw: QuantityValue!
    srKerogType: SrKerogTypeEnum
    srLithology: SrLithologyEnum
    srDepEnv: SrDepEnvEnum
    srGeolAge: SrGeolAgeEnum
    sampWellName: String
    win: String
    sampType: String!
    sampSubtype: SampSubtypeEnum
    pressure: QuantityValue
    sampTvdss: String
    sampMd: SampMdEnum
    oxyStatSamp: OxyStatSampEnum
    sampTransportCond: String
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    organismCount: [OrganismCountEnum]
    orgCountQpcrInfo: String
    ph: Double
    salinity: QuantityValue
    alkalinity: QuantityValue
    alkalinityMethod: String
    sulfate: QuantityValue
    sulfide: QuantityValue
    totSulfur: QuantityValue
    nitrate: QuantityValue
    nitrite: QuantityValue
    ammonium: QuantityValue
    totNitro: QuantityValue
    dissIron: QuantityValue
    sodium: QuantityValue
    chloride: QuantityValue
    potassium: QuantityValue
    magnesium: QuantityValue
    calcium: QuantityValue
    totIron: QuantityValue
    dissOrgCarb: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgPhosp: QuantityValue
    totPhosp: QuantityValue
    suspendSolids: [String]
    density: QuantityValue
    dissCarbDioxide: QuantityValue
    dissOxygenFluid: QuantityValue
    vfa: QuantityValue
    benzene: QuantityValue
    toluene: QuantityValue
    ethylbenzene: QuantityValue
    xylene: QuantityValue
    api: QuantityValue!
    tan: QuantityValue
    viscosity: String
    pourPoint: QuantityValue
    saturatesPc: String
    aromaticsPc: String
    resinsPc: String
    asphaltenesPc: String
    miscParam: [String]
    additionalInfo: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    mid: String
    adapters: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    assemblySoftware: String
    associatedResource: String
    sop: String
  }

type HydrocarbonResources-coresMIMARKSSurvey implements MIMARKSSurvey
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue!
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hcr: HcrEnum!
    hcProduced: HcProducedEnum!
    basin: String!
    field: String
    reservoir: String
    hcrTemp: String!
    tvdssOfHcrTemp: QuantityValue
    hcrPressure: String
    tvdssOfHcrPress: QuantityValue
    permeability: String
    porosity: String
    lithology: LithologyEnum
    deposEnv: DeposEnvEnum
    hcrGeolAge: HcrGeolAgeEnum
    owcTvdss: QuantityValue
    hcrFwSalinity: QuantityValue
    sulfateFw: QuantityValue!
    vfaFw: QuantityValue!
    srKerogType: SrKerogTypeEnum
    srLithology: SrLithologyEnum
    srDepEnv: SrDepEnvEnum
    srGeolAge: SrGeolAgeEnum
    sampWellName: String
    win: String
    sampType: String!
    sampSubtype: SampSubtypeEnum
    pressure: QuantityValue
    sampTvdss: String
    sampMd: SampMdEnum
    oxyStatSamp: OxyStatSampEnum
    sampTransportCond: String
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    organismCount: [OrganismCountEnum]
    orgCountQpcrInfo: String
    ph: Double
    salinity: QuantityValue
    alkalinity: QuantityValue
    alkalinityMethod: String
    sulfate: QuantityValue
    sulfide: QuantityValue
    totSulfur: QuantityValue
    nitrate: QuantityValue
    nitrite: QuantityValue
    ammonium: QuantityValue
    totNitro: QuantityValue
    dissIron: QuantityValue
    sodium: QuantityValue
    chloride: QuantityValue
    potassium: QuantityValue
    magnesium: QuantityValue
    calcium: QuantityValue
    totIron: QuantityValue
    dissOrgCarb: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgPhosp: QuantityValue
    totPhosp: QuantityValue
    suspendSolids: [String]
    density: QuantityValue
    dissCarbDioxide: QuantityValue
    dissOxygenFluid: QuantityValue
    vfa: QuantityValue
    benzene: QuantityValue
    toluene: QuantityValue
    ethylbenzene: QuantityValue
    xylene: QuantityValue
    api: QuantityValue!
    tan: QuantityValue
    viscosity: String
    pourPoint: QuantityValue
    saturatesPc: String
    aromaticsPc: String
    resinsPc: String
    asphaltenesPc: String
    miscParam: [String]
    additionalInfo: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    sourceMatId: String
    bioticRelationship: BioticRelationshipEnum
    trophicLevel: TrophicLevelEnum
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    associatedResource: String
    sop: String
  }

type HydrocarbonResources-coresMIMS implements MIMS
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue!
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hcr: HcrEnum!
    hcProduced: HcProducedEnum!
    basin: String!
    field: String
    reservoir: String
    hcrTemp: String!
    tvdssOfHcrTemp: QuantityValue
    hcrPressure: String
    tvdssOfHcrPress: QuantityValue
    permeability: String
    porosity: String
    lithology: LithologyEnum
    deposEnv: DeposEnvEnum
    hcrGeolAge: HcrGeolAgeEnum
    owcTvdss: QuantityValue
    hcrFwSalinity: QuantityValue
    sulfateFw: QuantityValue!
    vfaFw: QuantityValue!
    srKerogType: SrKerogTypeEnum
    srLithology: SrLithologyEnum
    srDepEnv: SrDepEnvEnum
    srGeolAge: SrGeolAgeEnum
    sampWellName: String
    win: String
    sampType: String!
    sampSubtype: SampSubtypeEnum
    pressure: QuantityValue
    sampTvdss: String
    sampMd: SampMdEnum
    oxyStatSamp: OxyStatSampEnum
    sampTransportCond: String
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    organismCount: [OrganismCountEnum]
    orgCountQpcrInfo: String
    ph: Double
    salinity: QuantityValue
    alkalinity: QuantityValue
    alkalinityMethod: String
    sulfate: QuantityValue
    sulfide: QuantityValue
    totSulfur: QuantityValue
    nitrate: QuantityValue
    nitrite: QuantityValue
    ammonium: QuantityValue
    totNitro: QuantityValue
    dissIron: QuantityValue
    sodium: QuantityValue
    chloride: QuantityValue
    potassium: QuantityValue
    magnesium: QuantityValue
    calcium: QuantityValue
    totIron: QuantityValue
    dissOrgCarb: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgPhosp: QuantityValue
    totPhosp: QuantityValue
    suspendSolids: [String]
    density: QuantityValue
    dissCarbDioxide: QuantityValue
    dissOxygenFluid: QuantityValue
    vfa: QuantityValue
    benzene: QuantityValue
    toluene: QuantityValue
    ethylbenzene: QuantityValue
    xylene: QuantityValue
    api: QuantityValue!
    tan: QuantityValue
    viscosity: String
    pourPoint: QuantityValue
    saturatesPc: String
    aromaticsPc: String
    resinsPc: String
    asphaltenesPc: String
    miscParam: [String]
    additionalInfo: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    associatedResource: String
    sop: String
  }

type HydrocarbonResources-coresMISAG implements MISAG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue!
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hcr: HcrEnum!
    hcProduced: HcProducedEnum!
    basin: String!
    field: String
    reservoir: String
    hcrTemp: String!
    tvdssOfHcrTemp: QuantityValue
    hcrPressure: String
    tvdssOfHcrPress: QuantityValue
    permeability: String
    porosity: String
    lithology: LithologyEnum
    deposEnv: DeposEnvEnum
    hcrGeolAge: HcrGeolAgeEnum
    owcTvdss: QuantityValue
    hcrFwSalinity: QuantityValue
    sulfateFw: QuantityValue!
    vfaFw: QuantityValue!
    srKerogType: SrKerogTypeEnum
    srLithology: SrLithologyEnum
    srDepEnv: SrDepEnvEnum
    srGeolAge: SrGeolAgeEnum
    sampWellName: String
    win: String
    sampType: String!
    sampSubtype: SampSubtypeEnum
    pressure: QuantityValue
    sampTvdss: String
    sampMd: SampMdEnum
    oxyStatSamp: OxyStatSampEnum
    sampTransportCond: String
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    organismCount: [OrganismCountEnum]
    orgCountQpcrInfo: String
    ph: Double
    salinity: QuantityValue
    alkalinity: QuantityValue
    alkalinityMethod: String
    sulfate: QuantityValue
    sulfide: QuantityValue
    totSulfur: QuantityValue
    nitrate: QuantityValue
    nitrite: QuantityValue
    ammonium: QuantityValue
    totNitro: QuantityValue
    dissIron: QuantityValue
    sodium: QuantityValue
    chloride: QuantityValue
    potassium: QuantityValue
    magnesium: QuantityValue
    calcium: QuantityValue
    totIron: QuantityValue
    dissOrgCarb: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgPhosp: QuantityValue
    totPhosp: QuantityValue
    suspendSolids: [String]
    density: QuantityValue
    dissCarbDioxide: QuantityValue
    dissOxygenFluid: QuantityValue
    vfa: QuantityValue
    benzene: QuantityValue
    toluene: QuantityValue
    ethylbenzene: QuantityValue
    xylene: QuantityValue
    api: QuantityValue!
    tan: QuantityValue
    viscosity: String
    pourPoint: QuantityValue
    saturatesPc: String
    aromaticsPc: String
    resinsPc: String
    asphaltenesPc: String
    miscParam: [String]
    additionalInfo: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    sortTech: SortTechEnum!
    singleCellLysisAppr: SingleCellLysisApprEnum!
    singleCellLysisProt: String
    wgaAmpAppr: String!
    wgaAmpKit: String
    associatedResource: String
    sop: String
  }

type HydrocarbonResources-coresMIUVIG implements MIUVIG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue!
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hcr: HcrEnum!
    hcProduced: HcProducedEnum!
    basin: String!
    field: String
    reservoir: String
    hcrTemp: String!
    tvdssOfHcrTemp: QuantityValue
    hcrPressure: String
    tvdssOfHcrPress: QuantityValue
    permeability: String
    porosity: String
    lithology: LithologyEnum
    deposEnv: DeposEnvEnum
    hcrGeolAge: HcrGeolAgeEnum
    owcTvdss: QuantityValue
    hcrFwSalinity: QuantityValue
    sulfateFw: QuantityValue!
    vfaFw: QuantityValue!
    srKerogType: SrKerogTypeEnum
    srLithology: SrLithologyEnum
    srDepEnv: SrDepEnvEnum
    srGeolAge: SrGeolAgeEnum
    sampWellName: String
    win: String
    sampType: String!
    sampSubtype: SampSubtypeEnum
    pressure: QuantityValue
    sampTvdss: String
    sampMd: SampMdEnum
    oxyStatSamp: OxyStatSampEnum
    sampTransportCond: String
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    organismCount: [OrganismCountEnum]
    orgCountQpcrInfo: String
    ph: Double
    salinity: QuantityValue
    alkalinity: QuantityValue
    alkalinityMethod: String
    sulfate: QuantityValue
    sulfide: QuantityValue
    totSulfur: QuantityValue
    nitrate: QuantityValue
    nitrite: QuantityValue
    ammonium: QuantityValue
    totNitro: QuantityValue
    dissIron: QuantityValue
    sodium: QuantityValue
    chloride: QuantityValue
    potassium: QuantityValue
    magnesium: QuantityValue
    calcium: QuantityValue
    totIron: QuantityValue
    dissOrgCarb: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgPhosp: QuantityValue
    totPhosp: QuantityValue
    suspendSolids: [String]
    density: QuantityValue
    dissCarbDioxide: QuantityValue
    dissOxygenFluid: QuantityValue
    vfa: QuantityValue
    benzene: QuantityValue
    toluene: QuantityValue
    ethylbenzene: QuantityValue
    xylene: QuantityValue
    api: QuantityValue!
    tan: QuantityValue
    viscosity: String
    pourPoint: QuantityValue
    saturatesPc: String
    aromaticsPc: String
    resinsPc: String
    asphaltenesPc: String
    miscParam: [String]
    additionalInfo: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    sourceUvig: SourceUvigEnum!
    virusEnrichAppr: VirusEnrichApprEnum!
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String
    complSoftware: String
    complAppr: ComplApprEnum
    sortTech: SortTechEnum
    singleCellLysisAppr: SingleCellLysisApprEnum
    singleCellLysisProt: String
    wgaAmpAppr: String
    wgaAmpKit: String
    binParam: BinParamEnum
    binSoftware: String
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    virIdentSoftware: String!
    predGenomeType: PredGenomeTypeEnum!
    predGenomeStruc: PredGenomeStrucEnum!
    detecType: String!
    otuClassAppr: String
    otuSeqCompAppr: String
    otuDb: String
    hostPredAppr: HostPredApprEnum
    hostPredEstAcc: String
    associatedResource: String
    sop: String
  }

type HydrocarbonResources-fluidsSwabs
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue!
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hcr: HcrEnum!
    hcProduced: HcProducedEnum!
    basin: String!
    field: String
    reservoir: String
    hcrTemp: String
    tvdssOfHcrTemp: QuantityValue
    hcrPressure: String
    tvdssOfHcrPress: QuantityValue
    lithology: LithologyEnum
    deposEnv: DeposEnvEnum
    hcrGeolAge: HcrGeolAgeEnum
    hcrFwSalinity: QuantityValue
    sulfateFw: QuantityValue
    vfaFw: QuantityValue
    prodStartDate: Date
    prodRate: QuantityValue
    waterProdRate: QuantityValue
    waterCut: QuantityValue!
    iwf: QuantityValue!
    addRecovMethod: String!
    iwBtDateWell: Date
    biocide: String
    biocideAdminMethod: String
    chemTreatment: String
    chemTreatMethod: String
    sampLocCorrRate: String
    sampWellName: String
    win: String
    sampType: String!
    sampSubtype: SampSubtypeEnum
    sampCollectPoint: SampCollectPointEnum!
    pressure: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    sampPreserv: String
    sampTransportCond: String
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    organismCount: [OrganismCountEnum]
    orgCountQpcrInfo: String
    ph: Double
    salinity: QuantityValue
    alkalinity: QuantityValue
    alkalinityMethod: String
    sulfate: QuantityValue!
    sulfide: QuantityValue!
    totSulfur: QuantityValue
    nitrate: QuantityValue!
    nitrite: QuantityValue
    ammonium: QuantityValue
    totNitro: QuantityValue
    dissIron: QuantityValue
    sodium: QuantityValue
    chloride: QuantityValue
    potassium: QuantityValue
    magnesium: QuantityValue
    calcium: QuantityValue
    totIron: QuantityValue
    dissOrgCarb: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgPhosp: QuantityValue
    totPhosp: QuantityValue
    suspendSolids: [String]
    density: QuantityValue
    dissCarbDioxide: QuantityValue
    dissOxygenFluid: QuantityValue
    vfa: QuantityValue
    benzene: QuantityValue
    toluene: QuantityValue
    ethylbenzene: QuantityValue
    xylene: QuantityValue
    api: QuantityValue!
    tan: QuantityValue
    viscosity: String
    pourPoint: QuantityValue
    saturatesPc: String
    aromaticsPc: String
    resinsPc: String
    asphaltenesPc: String
    miscParam: [String]
    additionalInfo: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
  }

type HydrocarbonResources-fluidsSwabsMIGSBacteria implements MIGSBacteria
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue!
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hcr: HcrEnum!
    hcProduced: HcProducedEnum!
    basin: String!
    field: String
    reservoir: String
    hcrTemp: String
    tvdssOfHcrTemp: QuantityValue
    hcrPressure: String
    tvdssOfHcrPress: QuantityValue
    lithology: LithologyEnum
    deposEnv: DeposEnvEnum
    hcrGeolAge: HcrGeolAgeEnum
    hcrFwSalinity: QuantityValue
    sulfateFw: QuantityValue
    vfaFw: QuantityValue
    prodStartDate: Date
    prodRate: QuantityValue
    waterProdRate: QuantityValue
    waterCut: QuantityValue!
    iwf: QuantityValue!
    addRecovMethod: String!
    iwBtDateWell: Date
    biocide: String
    biocideAdminMethod: String
    chemTreatment: String
    chemTreatMethod: String
    sampLocCorrRate: String
    sampWellName: String
    win: String
    sampType: String!
    sampSubtype: SampSubtypeEnum
    sampCollectPoint: SampCollectPointEnum!
    pressure: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    sampPreserv: String
    sampTransportCond: String
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    organismCount: [OrganismCountEnum]
    orgCountQpcrInfo: String
    ph: Double
    salinity: QuantityValue
    alkalinity: QuantityValue
    alkalinityMethod: String
    sulfate: QuantityValue!
    sulfide: QuantityValue!
    totSulfur: QuantityValue
    nitrate: QuantityValue!
    nitrite: QuantityValue
    ammonium: QuantityValue
    totNitro: QuantityValue
    dissIron: QuantityValue
    sodium: QuantityValue
    chloride: QuantityValue
    potassium: QuantityValue
    magnesium: QuantityValue
    calcium: QuantityValue
    totIron: QuantityValue
    dissOrgCarb: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgPhosp: QuantityValue
    totPhosp: QuantityValue
    suspendSolids: [String]
    density: QuantityValue
    dissCarbDioxide: QuantityValue
    dissOxygenFluid: QuantityValue
    vfa: QuantityValue
    benzene: QuantityValue
    toluene: QuantityValue
    ethylbenzene: QuantityValue
    xylene: QuantityValue
    api: QuantityValue!
    tan: QuantityValue
    viscosity: String
    pourPoint: QuantityValue
    saturatesPc: String
    aromaticsPc: String
    resinsPc: String
    asphaltenesPc: String
    miscParam: [String]
    additionalInfo: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer!
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String!
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    trophicLevel: TrophicLevelEnum
    encodedTraits: String
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type HydrocarbonResources-fluidsSwabsMIGSEukaryote implements MIGSEukaryote
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue!
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hcr: HcrEnum!
    hcProduced: HcProducedEnum!
    basin: String!
    field: String
    reservoir: String
    hcrTemp: String
    tvdssOfHcrTemp: QuantityValue
    hcrPressure: String
    tvdssOfHcrPress: QuantityValue
    lithology: LithologyEnum
    deposEnv: DeposEnvEnum
    hcrGeolAge: HcrGeolAgeEnum
    hcrFwSalinity: QuantityValue
    sulfateFw: QuantityValue
    vfaFw: QuantityValue
    prodStartDate: Date
    prodRate: QuantityValue
    waterProdRate: QuantityValue
    waterCut: QuantityValue!
    iwf: QuantityValue!
    addRecovMethod: String!
    iwBtDateWell: Date
    biocide: String
    biocideAdminMethod: String
    chemTreatment: String
    chemTreatMethod: String
    sampLocCorrRate: String
    sampWellName: String
    win: String
    sampType: String!
    sampSubtype: SampSubtypeEnum
    sampCollectPoint: SampCollectPointEnum!
    pressure: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    sampPreserv: String
    sampTransportCond: String
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    organismCount: [OrganismCountEnum]
    orgCountQpcrInfo: String
    ph: Double
    salinity: QuantityValue
    alkalinity: QuantityValue
    alkalinityMethod: String
    sulfate: QuantityValue!
    sulfide: QuantityValue!
    totSulfur: QuantityValue
    nitrate: QuantityValue!
    nitrite: QuantityValue
    ammonium: QuantityValue
    totNitro: QuantityValue
    dissIron: QuantityValue
    sodium: QuantityValue
    chloride: QuantityValue
    potassium: QuantityValue
    magnesium: QuantityValue
    calcium: QuantityValue
    totIron: QuantityValue
    dissOrgCarb: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgPhosp: QuantityValue
    totPhosp: QuantityValue
    suspendSolids: [String]
    density: QuantityValue
    dissCarbDioxide: QuantityValue
    dissOxygenFluid: QuantityValue
    vfa: QuantityValue
    benzene: QuantityValue
    toluene: QuantityValue
    ethylbenzene: QuantityValue
    xylene: QuantityValue
    api: QuantityValue!
    tan: QuantityValue
    viscosity: String
    pourPoint: QuantityValue
    saturatesPc: String
    aromaticsPc: String
    resinsPc: String
    asphaltenesPc: String
    miscParam: [String]
    additionalInfo: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    ploidy: String
    numReplicons: Integer
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    trophicLevel: TrophicLevelEnum
    propagation: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type HydrocarbonResources-fluidsSwabsMIGSOrg implements MIGSOrg
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue!
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hcr: HcrEnum!
    hcProduced: HcProducedEnum!
    basin: String!
    field: String
    reservoir: String
    hcrTemp: String
    tvdssOfHcrTemp: QuantityValue
    hcrPressure: String
    tvdssOfHcrPress: QuantityValue
    lithology: LithologyEnum
    deposEnv: DeposEnvEnum
    hcrGeolAge: HcrGeolAgeEnum
    hcrFwSalinity: QuantityValue
    sulfateFw: QuantityValue
    vfaFw: QuantityValue
    prodStartDate: Date
    prodRate: QuantityValue
    waterProdRate: QuantityValue
    waterCut: QuantityValue!
    iwf: QuantityValue!
    addRecovMethod: String!
    iwBtDateWell: Date
    biocide: String
    biocideAdminMethod: String
    chemTreatment: String
    chemTreatMethod: String
    sampLocCorrRate: String
    sampWellName: String
    win: String
    sampType: String!
    sampSubtype: SampSubtypeEnum
    sampCollectPoint: SampCollectPointEnum!
    pressure: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    sampPreserv: String
    sampTransportCond: String
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    organismCount: [OrganismCountEnum]
    orgCountQpcrInfo: String
    ph: Double
    salinity: QuantityValue
    alkalinity: QuantityValue
    alkalinityMethod: String
    sulfate: QuantityValue!
    sulfide: QuantityValue!
    totSulfur: QuantityValue
    nitrate: QuantityValue!
    nitrite: QuantityValue
    ammonium: QuantityValue
    totNitro: QuantityValue
    dissIron: QuantityValue
    sodium: QuantityValue
    chloride: QuantityValue
    potassium: QuantityValue
    magnesium: QuantityValue
    calcium: QuantityValue
    totIron: QuantityValue
    dissOrgCarb: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgPhosp: QuantityValue
    totPhosp: QuantityValue
    suspendSolids: [String]
    density: QuantityValue
    dissCarbDioxide: QuantityValue
    dissOxygenFluid: QuantityValue
    vfa: QuantityValue
    benzene: QuantityValue
    toluene: QuantityValue
    ethylbenzene: QuantityValue
    xylene: QuantityValue
    api: QuantityValue!
    tan: QuantityValue
    viscosity: String
    pourPoint: QuantityValue
    saturatesPc: String
    aromaticsPc: String
    resinsPc: String
    asphaltenesPc: String
    miscParam: [String]
    additionalInfo: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type HydrocarbonResources-fluidsSwabsMIGSPlant implements MIGSPlant
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue!
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hcr: HcrEnum!
    hcProduced: HcProducedEnum!
    basin: String!
    field: String
    reservoir: String
    hcrTemp: String
    tvdssOfHcrTemp: QuantityValue
    hcrPressure: String
    tvdssOfHcrPress: QuantityValue
    lithology: LithologyEnum
    deposEnv: DeposEnvEnum
    hcrGeolAge: HcrGeolAgeEnum
    hcrFwSalinity: QuantityValue
    sulfateFw: QuantityValue
    vfaFw: QuantityValue
    prodStartDate: Date
    prodRate: QuantityValue
    waterProdRate: QuantityValue
    waterCut: QuantityValue!
    iwf: QuantityValue!
    addRecovMethod: String!
    iwBtDateWell: Date
    biocide: String
    biocideAdminMethod: String
    chemTreatment: String
    chemTreatMethod: String
    sampLocCorrRate: String
    sampWellName: String
    win: String
    sampType: String!
    sampSubtype: SampSubtypeEnum
    sampCollectPoint: SampCollectPointEnum!
    pressure: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    sampPreserv: String
    sampTransportCond: String
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    organismCount: [OrganismCountEnum]
    orgCountQpcrInfo: String
    ph: Double
    salinity: QuantityValue
    alkalinity: QuantityValue
    alkalinityMethod: String
    sulfate: QuantityValue!
    sulfide: QuantityValue!
    totSulfur: QuantityValue
    nitrate: QuantityValue!
    nitrite: QuantityValue
    ammonium: QuantityValue
    totNitro: QuantityValue
    dissIron: QuantityValue
    sodium: QuantityValue
    chloride: QuantityValue
    potassium: QuantityValue
    magnesium: QuantityValue
    calcium: QuantityValue
    totIron: QuantityValue
    dissOrgCarb: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgPhosp: QuantityValue
    totPhosp: QuantityValue
    suspendSolids: [String]
    density: QuantityValue
    dissCarbDioxide: QuantityValue
    dissOxygenFluid: QuantityValue
    vfa: QuantityValue
    benzene: QuantityValue
    toluene: QuantityValue
    ethylbenzene: QuantityValue
    xylene: QuantityValue
    api: QuantityValue!
    tan: QuantityValue
    viscosity: String
    pourPoint: QuantityValue
    saturatesPc: String
    aromaticsPc: String
    resinsPc: String
    asphaltenesPc: String
    miscParam: [String]
    additionalInfo: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    specificHost: String
    hostSpecRange: Integer
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type HydrocarbonResources-fluidsSwabsMIGSVirus implements MIGSVirus
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue!
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hcr: HcrEnum!
    hcProduced: HcProducedEnum!
    basin: String!
    field: String
    reservoir: String
    hcrTemp: String
    tvdssOfHcrTemp: QuantityValue
    hcrPressure: String
    tvdssOfHcrPress: QuantityValue
    lithology: LithologyEnum
    deposEnv: DeposEnvEnum
    hcrGeolAge: HcrGeolAgeEnum
    hcrFwSalinity: QuantityValue
    sulfateFw: QuantityValue
    vfaFw: QuantityValue
    prodStartDate: Date
    prodRate: QuantityValue
    waterProdRate: QuantityValue
    waterCut: QuantityValue!
    iwf: QuantityValue!
    addRecovMethod: String!
    iwBtDateWell: Date
    biocide: String
    biocideAdminMethod: String
    chemTreatment: String
    chemTreatMethod: String
    sampLocCorrRate: String
    sampWellName: String
    win: String
    sampType: String!
    sampSubtype: SampSubtypeEnum
    sampCollectPoint: SampCollectPointEnum!
    pressure: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    sampPreserv: String
    sampTransportCond: String
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    organismCount: [OrganismCountEnum]
    orgCountQpcrInfo: String
    ph: Double
    salinity: QuantityValue
    alkalinity: QuantityValue
    alkalinityMethod: String
    sulfate: QuantityValue!
    sulfide: QuantityValue!
    totSulfur: QuantityValue
    nitrate: QuantityValue!
    nitrite: QuantityValue
    ammonium: QuantityValue
    totNitro: QuantityValue
    dissIron: QuantityValue
    sodium: QuantityValue
    chloride: QuantityValue
    potassium: QuantityValue
    magnesium: QuantityValue
    calcium: QuantityValue
    totIron: QuantityValue
    dissOrgCarb: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgPhosp: QuantityValue
    totPhosp: QuantityValue
    suspendSolids: [String]
    density: QuantityValue
    dissCarbDioxide: QuantityValue
    dissOxygenFluid: QuantityValue
    vfa: QuantityValue
    benzene: QuantityValue
    toluene: QuantityValue
    ethylbenzene: QuantityValue
    xylene: QuantityValue
    api: QuantityValue!
    tan: QuantityValue
    viscosity: String
    pourPoint: QuantityValue
    saturatesPc: String
    aromaticsPc: String
    resinsPc: String
    asphaltenesPc: String
    miscParam: [String]
    additionalInfo: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    virusEnrichAppr: VirusEnrichApprEnum
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type HydrocarbonResources-fluidsSwabsMIMAG implements MIMAG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue!
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hcr: HcrEnum!
    hcProduced: HcProducedEnum!
    basin: String!
    field: String
    reservoir: String
    hcrTemp: String
    tvdssOfHcrTemp: QuantityValue
    hcrPressure: String
    tvdssOfHcrPress: QuantityValue
    lithology: LithologyEnum
    deposEnv: DeposEnvEnum
    hcrGeolAge: HcrGeolAgeEnum
    hcrFwSalinity: QuantityValue
    sulfateFw: QuantityValue
    vfaFw: QuantityValue
    prodStartDate: Date
    prodRate: QuantityValue
    waterProdRate: QuantityValue
    waterCut: QuantityValue!
    iwf: QuantityValue!
    addRecovMethod: String!
    iwBtDateWell: Date
    biocide: String
    biocideAdminMethod: String
    chemTreatment: String
    chemTreatMethod: String
    sampLocCorrRate: String
    sampWellName: String
    win: String
    sampType: String!
    sampSubtype: SampSubtypeEnum
    sampCollectPoint: SampCollectPointEnum!
    pressure: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    sampPreserv: String
    sampTransportCond: String
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    organismCount: [OrganismCountEnum]
    orgCountQpcrInfo: String
    ph: Double
    salinity: QuantityValue
    alkalinity: QuantityValue
    alkalinityMethod: String
    sulfate: QuantityValue!
    sulfide: QuantityValue!
    totSulfur: QuantityValue
    nitrate: QuantityValue!
    nitrite: QuantityValue
    ammonium: QuantityValue
    totNitro: QuantityValue
    dissIron: QuantityValue
    sodium: QuantityValue
    chloride: QuantityValue
    potassium: QuantityValue
    magnesium: QuantityValue
    calcium: QuantityValue
    totIron: QuantityValue
    dissOrgCarb: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgPhosp: QuantityValue
    totPhosp: QuantityValue
    suspendSolids: [String]
    density: QuantityValue
    dissCarbDioxide: QuantityValue
    dissOxygenFluid: QuantityValue
    vfa: QuantityValue
    benzene: QuantityValue
    toluene: QuantityValue
    ethylbenzene: QuantityValue
    xylene: QuantityValue
    api: QuantityValue!
    tan: QuantityValue
    viscosity: String
    pourPoint: QuantityValue
    saturatesPc: String
    aromaticsPc: String
    resinsPc: String
    asphaltenesPc: String
    miscParam: [String]
    additionalInfo: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    binParam: BinParamEnum!
    binSoftware: String!
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    associatedResource: String
    sop: String
  }

type HydrocarbonResources-fluidsSwabsMIMARKSSpecimen implements MIMARKSSpecimen
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue!
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hcr: HcrEnum!
    hcProduced: HcProducedEnum!
    basin: String!
    field: String
    reservoir: String
    hcrTemp: String
    tvdssOfHcrTemp: QuantityValue
    hcrPressure: String
    tvdssOfHcrPress: QuantityValue
    lithology: LithologyEnum
    deposEnv: DeposEnvEnum
    hcrGeolAge: HcrGeolAgeEnum
    hcrFwSalinity: QuantityValue
    sulfateFw: QuantityValue
    vfaFw: QuantityValue
    prodStartDate: Date
    prodRate: QuantityValue
    waterProdRate: QuantityValue
    waterCut: QuantityValue!
    iwf: QuantityValue!
    addRecovMethod: String!
    iwBtDateWell: Date
    biocide: String
    biocideAdminMethod: String
    chemTreatment: String
    chemTreatMethod: String
    sampLocCorrRate: String
    sampWellName: String
    win: String
    sampType: String!
    sampSubtype: SampSubtypeEnum
    sampCollectPoint: SampCollectPointEnum!
    pressure: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    sampPreserv: String
    sampTransportCond: String
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    organismCount: [OrganismCountEnum]
    orgCountQpcrInfo: String
    ph: Double
    salinity: QuantityValue
    alkalinity: QuantityValue
    alkalinityMethod: String
    sulfate: QuantityValue!
    sulfide: QuantityValue!
    totSulfur: QuantityValue
    nitrate: QuantityValue!
    nitrite: QuantityValue
    ammonium: QuantityValue
    totNitro: QuantityValue
    dissIron: QuantityValue
    sodium: QuantityValue
    chloride: QuantityValue
    potassium: QuantityValue
    magnesium: QuantityValue
    calcium: QuantityValue
    totIron: QuantityValue
    dissOrgCarb: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgPhosp: QuantityValue
    totPhosp: QuantityValue
    suspendSolids: [String]
    density: QuantityValue
    dissCarbDioxide: QuantityValue
    dissOxygenFluid: QuantityValue
    vfa: QuantityValue
    benzene: QuantityValue
    toluene: QuantityValue
    ethylbenzene: QuantityValue
    xylene: QuantityValue
    api: QuantityValue!
    tan: QuantityValue
    viscosity: String
    pourPoint: QuantityValue
    saturatesPc: String
    aromaticsPc: String
    resinsPc: String
    asphaltenesPc: String
    miscParam: [String]
    additionalInfo: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    mid: String
    adapters: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    assemblySoftware: String
    associatedResource: String
    sop: String
  }

type HydrocarbonResources-fluidsSwabsMIMARKSSurvey implements MIMARKSSurvey
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue!
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hcr: HcrEnum!
    hcProduced: HcProducedEnum!
    basin: String!
    field: String
    reservoir: String
    hcrTemp: String
    tvdssOfHcrTemp: QuantityValue
    hcrPressure: String
    tvdssOfHcrPress: QuantityValue
    lithology: LithologyEnum
    deposEnv: DeposEnvEnum
    hcrGeolAge: HcrGeolAgeEnum
    hcrFwSalinity: QuantityValue
    sulfateFw: QuantityValue
    vfaFw: QuantityValue
    prodStartDate: Date
    prodRate: QuantityValue
    waterProdRate: QuantityValue
    waterCut: QuantityValue!
    iwf: QuantityValue!
    addRecovMethod: String!
    iwBtDateWell: Date
    biocide: String
    biocideAdminMethod: String
    chemTreatment: String
    chemTreatMethod: String
    sampLocCorrRate: String
    sampWellName: String
    win: String
    sampType: String!
    sampSubtype: SampSubtypeEnum
    sampCollectPoint: SampCollectPointEnum!
    pressure: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    sampPreserv: String
    sampTransportCond: String
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    organismCount: [OrganismCountEnum]
    orgCountQpcrInfo: String
    ph: Double
    salinity: QuantityValue
    alkalinity: QuantityValue
    alkalinityMethod: String
    sulfate: QuantityValue!
    sulfide: QuantityValue!
    totSulfur: QuantityValue
    nitrate: QuantityValue!
    nitrite: QuantityValue
    ammonium: QuantityValue
    totNitro: QuantityValue
    dissIron: QuantityValue
    sodium: QuantityValue
    chloride: QuantityValue
    potassium: QuantityValue
    magnesium: QuantityValue
    calcium: QuantityValue
    totIron: QuantityValue
    dissOrgCarb: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgPhosp: QuantityValue
    totPhosp: QuantityValue
    suspendSolids: [String]
    density: QuantityValue
    dissCarbDioxide: QuantityValue
    dissOxygenFluid: QuantityValue
    vfa: QuantityValue
    benzene: QuantityValue
    toluene: QuantityValue
    ethylbenzene: QuantityValue
    xylene: QuantityValue
    api: QuantityValue!
    tan: QuantityValue
    viscosity: String
    pourPoint: QuantityValue
    saturatesPc: String
    aromaticsPc: String
    resinsPc: String
    asphaltenesPc: String
    miscParam: [String]
    additionalInfo: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    sourceMatId: String
    bioticRelationship: BioticRelationshipEnum
    trophicLevel: TrophicLevelEnum
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    associatedResource: String
    sop: String
  }

type HydrocarbonResources-fluidsSwabsMIMS implements MIMS
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue!
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hcr: HcrEnum!
    hcProduced: HcProducedEnum!
    basin: String!
    field: String
    reservoir: String
    hcrTemp: String
    tvdssOfHcrTemp: QuantityValue
    hcrPressure: String
    tvdssOfHcrPress: QuantityValue
    lithology: LithologyEnum
    deposEnv: DeposEnvEnum
    hcrGeolAge: HcrGeolAgeEnum
    hcrFwSalinity: QuantityValue
    sulfateFw: QuantityValue
    vfaFw: QuantityValue
    prodStartDate: Date
    prodRate: QuantityValue
    waterProdRate: QuantityValue
    waterCut: QuantityValue!
    iwf: QuantityValue!
    addRecovMethod: String!
    iwBtDateWell: Date
    biocide: String
    biocideAdminMethod: String
    chemTreatment: String
    chemTreatMethod: String
    sampLocCorrRate: String
    sampWellName: String
    win: String
    sampType: String!
    sampSubtype: SampSubtypeEnum
    sampCollectPoint: SampCollectPointEnum!
    pressure: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    sampPreserv: String
    sampTransportCond: String
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    organismCount: [OrganismCountEnum]
    orgCountQpcrInfo: String
    ph: Double
    salinity: QuantityValue
    alkalinity: QuantityValue
    alkalinityMethod: String
    sulfate: QuantityValue!
    sulfide: QuantityValue!
    totSulfur: QuantityValue
    nitrate: QuantityValue!
    nitrite: QuantityValue
    ammonium: QuantityValue
    totNitro: QuantityValue
    dissIron: QuantityValue
    sodium: QuantityValue
    chloride: QuantityValue
    potassium: QuantityValue
    magnesium: QuantityValue
    calcium: QuantityValue
    totIron: QuantityValue
    dissOrgCarb: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgPhosp: QuantityValue
    totPhosp: QuantityValue
    suspendSolids: [String]
    density: QuantityValue
    dissCarbDioxide: QuantityValue
    dissOxygenFluid: QuantityValue
    vfa: QuantityValue
    benzene: QuantityValue
    toluene: QuantityValue
    ethylbenzene: QuantityValue
    xylene: QuantityValue
    api: QuantityValue!
    tan: QuantityValue
    viscosity: String
    pourPoint: QuantityValue
    saturatesPc: String
    aromaticsPc: String
    resinsPc: String
    asphaltenesPc: String
    miscParam: [String]
    additionalInfo: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    associatedResource: String
    sop: String
  }

type HydrocarbonResources-fluidsSwabsMISAG implements MISAG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue!
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hcr: HcrEnum!
    hcProduced: HcProducedEnum!
    basin: String!
    field: String
    reservoir: String
    hcrTemp: String
    tvdssOfHcrTemp: QuantityValue
    hcrPressure: String
    tvdssOfHcrPress: QuantityValue
    lithology: LithologyEnum
    deposEnv: DeposEnvEnum
    hcrGeolAge: HcrGeolAgeEnum
    hcrFwSalinity: QuantityValue
    sulfateFw: QuantityValue
    vfaFw: QuantityValue
    prodStartDate: Date
    prodRate: QuantityValue
    waterProdRate: QuantityValue
    waterCut: QuantityValue!
    iwf: QuantityValue!
    addRecovMethod: String!
    iwBtDateWell: Date
    biocide: String
    biocideAdminMethod: String
    chemTreatment: String
    chemTreatMethod: String
    sampLocCorrRate: String
    sampWellName: String
    win: String
    sampType: String!
    sampSubtype: SampSubtypeEnum
    sampCollectPoint: SampCollectPointEnum!
    pressure: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    sampPreserv: String
    sampTransportCond: String
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    organismCount: [OrganismCountEnum]
    orgCountQpcrInfo: String
    ph: Double
    salinity: QuantityValue
    alkalinity: QuantityValue
    alkalinityMethod: String
    sulfate: QuantityValue!
    sulfide: QuantityValue!
    totSulfur: QuantityValue
    nitrate: QuantityValue!
    nitrite: QuantityValue
    ammonium: QuantityValue
    totNitro: QuantityValue
    dissIron: QuantityValue
    sodium: QuantityValue
    chloride: QuantityValue
    potassium: QuantityValue
    magnesium: QuantityValue
    calcium: QuantityValue
    totIron: QuantityValue
    dissOrgCarb: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgPhosp: QuantityValue
    totPhosp: QuantityValue
    suspendSolids: [String]
    density: QuantityValue
    dissCarbDioxide: QuantityValue
    dissOxygenFluid: QuantityValue
    vfa: QuantityValue
    benzene: QuantityValue
    toluene: QuantityValue
    ethylbenzene: QuantityValue
    xylene: QuantityValue
    api: QuantityValue!
    tan: QuantityValue
    viscosity: String
    pourPoint: QuantityValue
    saturatesPc: String
    aromaticsPc: String
    resinsPc: String
    asphaltenesPc: String
    miscParam: [String]
    additionalInfo: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    sortTech: SortTechEnum!
    singleCellLysisAppr: SingleCellLysisApprEnum!
    singleCellLysisProt: String
    wgaAmpAppr: String!
    wgaAmpKit: String
    associatedResource: String
    sop: String
  }

type HydrocarbonResources-fluidsSwabsMIUVIG implements MIUVIG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue!
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    hcr: HcrEnum!
    hcProduced: HcProducedEnum!
    basin: String!
    field: String
    reservoir: String
    hcrTemp: String
    tvdssOfHcrTemp: QuantityValue
    hcrPressure: String
    tvdssOfHcrPress: QuantityValue
    lithology: LithologyEnum
    deposEnv: DeposEnvEnum
    hcrGeolAge: HcrGeolAgeEnum
    hcrFwSalinity: QuantityValue
    sulfateFw: QuantityValue
    vfaFw: QuantityValue
    prodStartDate: Date
    prodRate: QuantityValue
    waterProdRate: QuantityValue
    waterCut: QuantityValue!
    iwf: QuantityValue!
    addRecovMethod: String!
    iwBtDateWell: Date
    biocide: String
    biocideAdminMethod: String
    chemTreatment: String
    chemTreatMethod: String
    sampLocCorrRate: String
    sampWellName: String
    win: String
    sampType: String!
    sampSubtype: SampSubtypeEnum
    sampCollectPoint: SampCollectPointEnum!
    pressure: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    sampPreserv: String
    sampTransportCond: String
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    organismCount: [OrganismCountEnum]
    orgCountQpcrInfo: String
    ph: Double
    salinity: QuantityValue
    alkalinity: QuantityValue
    alkalinityMethod: String
    sulfate: QuantityValue!
    sulfide: QuantityValue!
    totSulfur: QuantityValue
    nitrate: QuantityValue!
    nitrite: QuantityValue
    ammonium: QuantityValue
    totNitro: QuantityValue
    dissIron: QuantityValue
    sodium: QuantityValue
    chloride: QuantityValue
    potassium: QuantityValue
    magnesium: QuantityValue
    calcium: QuantityValue
    totIron: QuantityValue
    dissOrgCarb: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgPhosp: QuantityValue
    totPhosp: QuantityValue
    suspendSolids: [String]
    density: QuantityValue
    dissCarbDioxide: QuantityValue
    dissOxygenFluid: QuantityValue
    vfa: QuantityValue
    benzene: QuantityValue
    toluene: QuantityValue
    ethylbenzene: QuantityValue
    xylene: QuantityValue
    api: QuantityValue!
    tan: QuantityValue
    viscosity: String
    pourPoint: QuantityValue
    saturatesPc: String
    aromaticsPc: String
    resinsPc: String
    asphaltenesPc: String
    miscParam: [String]
    additionalInfo: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    sourceUvig: SourceUvigEnum!
    virusEnrichAppr: VirusEnrichApprEnum!
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String
    complSoftware: String
    complAppr: ComplApprEnum
    sortTech: SortTechEnum
    singleCellLysisAppr: SingleCellLysisApprEnum
    singleCellLysisProt: String
    wgaAmpAppr: String
    wgaAmpKit: String
    binParam: BinParamEnum
    binSoftware: String
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    virIdentSoftware: String!
    predGenomeType: PredGenomeTypeEnum!
    predGenomeStruc: PredGenomeStrucEnum!
    detecType: String!
    otuClassAppr: String
    otuSeqCompAppr: String
    otuDb: String
    hostPredAppr: HostPredApprEnum
    hostPredEstAcc: String
    associatedResource: String
    sop: String
  }

type MicrobialMatBiofilm
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    bacteriaCarbProd: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    glucosidaseAct: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    methane: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    partOrgCarb: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    potassium: QuantityValue
    pressure: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    totCarb: QuantityValue
    totNitroContent: QuantityValue
    totOrgCarb: QuantityValue
    turbidity: QuantityValue
    waterContent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
  }

type MicrobialMatBiofilmMIGSBacteria implements MIGSBacteria
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    bacteriaCarbProd: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    glucosidaseAct: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    methane: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    partOrgCarb: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    potassium: QuantityValue
    pressure: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    totCarb: QuantityValue
    totNitroContent: QuantityValue
    totOrgCarb: QuantityValue
    turbidity: QuantityValue
    waterContent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer!
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String!
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    trophicLevel: TrophicLevelEnum
    encodedTraits: String
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type MicrobialMatBiofilmMIGSEukaryote implements MIGSEukaryote
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    bacteriaCarbProd: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    glucosidaseAct: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    methane: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    partOrgCarb: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    potassium: QuantityValue
    pressure: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    totCarb: QuantityValue
    totNitroContent: QuantityValue
    totOrgCarb: QuantityValue
    turbidity: QuantityValue
    waterContent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    ploidy: String
    numReplicons: Integer
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    trophicLevel: TrophicLevelEnum
    propagation: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type MicrobialMatBiofilmMIGSOrg implements MIGSOrg
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    bacteriaCarbProd: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    glucosidaseAct: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    methane: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    partOrgCarb: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    potassium: QuantityValue
    pressure: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    totCarb: QuantityValue
    totNitroContent: QuantityValue
    totOrgCarb: QuantityValue
    turbidity: QuantityValue
    waterContent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type MicrobialMatBiofilmMIGSPlant implements MIGSPlant
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    bacteriaCarbProd: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    glucosidaseAct: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    methane: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    partOrgCarb: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    potassium: QuantityValue
    pressure: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    totCarb: QuantityValue
    totNitroContent: QuantityValue
    totOrgCarb: QuantityValue
    turbidity: QuantityValue
    waterContent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    specificHost: String
    hostSpecRange: Integer
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type MicrobialMatBiofilmMIGSVirus implements MIGSVirus
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    bacteriaCarbProd: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    glucosidaseAct: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    methane: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    partOrgCarb: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    potassium: QuantityValue
    pressure: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    totCarb: QuantityValue
    totNitroContent: QuantityValue
    totOrgCarb: QuantityValue
    turbidity: QuantityValue
    waterContent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    virusEnrichAppr: VirusEnrichApprEnum
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type MicrobialMatBiofilmMIMAG implements MIMAG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    bacteriaCarbProd: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    glucosidaseAct: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    methane: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    partOrgCarb: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    potassium: QuantityValue
    pressure: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    totCarb: QuantityValue
    totNitroContent: QuantityValue
    totOrgCarb: QuantityValue
    turbidity: QuantityValue
    waterContent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    binParam: BinParamEnum!
    binSoftware: String!
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    associatedResource: String
    sop: String
  }

type MicrobialMatBiofilmMIMARKSSpecimen implements MIMARKSSpecimen
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    bacteriaCarbProd: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    glucosidaseAct: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    methane: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    partOrgCarb: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    potassium: QuantityValue
    pressure: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    totCarb: QuantityValue
    totNitroContent: QuantityValue
    totOrgCarb: QuantityValue
    turbidity: QuantityValue
    waterContent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    mid: String
    adapters: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    assemblySoftware: String
    associatedResource: String
    sop: String
  }

type MicrobialMatBiofilmMIMARKSSurvey implements MIMARKSSurvey
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    bacteriaCarbProd: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    glucosidaseAct: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    methane: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    partOrgCarb: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    potassium: QuantityValue
    pressure: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    totCarb: QuantityValue
    totNitroContent: QuantityValue
    totOrgCarb: QuantityValue
    turbidity: QuantityValue
    waterContent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    sourceMatId: String
    bioticRelationship: BioticRelationshipEnum
    trophicLevel: TrophicLevelEnum
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    associatedResource: String
    sop: String
  }

type MicrobialMatBiofilmMIMS implements MIMS
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    bacteriaCarbProd: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    glucosidaseAct: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    methane: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    partOrgCarb: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    potassium: QuantityValue
    pressure: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    totCarb: QuantityValue
    totNitroContent: QuantityValue
    totOrgCarb: QuantityValue
    turbidity: QuantityValue
    waterContent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    associatedResource: String
    sop: String
  }

type MicrobialMatBiofilmMISAG implements MISAG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    bacteriaCarbProd: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    glucosidaseAct: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    methane: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    partOrgCarb: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    potassium: QuantityValue
    pressure: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    totCarb: QuantityValue
    totNitroContent: QuantityValue
    totOrgCarb: QuantityValue
    turbidity: QuantityValue
    waterContent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    sortTech: SortTechEnum!
    singleCellLysisAppr: SingleCellLysisApprEnum!
    singleCellLysisProt: String
    wgaAmpAppr: String!
    wgaAmpKit: String
    associatedResource: String
    sop: String
  }

type MicrobialMatBiofilmMIUVIG implements MIUVIG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    bacteriaCarbProd: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    glucosidaseAct: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    methane: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    partOrgCarb: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    potassium: QuantityValue
    pressure: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    totCarb: QuantityValue
    totNitroContent: QuantityValue
    totOrgCarb: QuantityValue
    turbidity: QuantityValue
    waterContent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    sourceUvig: SourceUvigEnum!
    virusEnrichAppr: VirusEnrichApprEnum!
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String
    complSoftware: String
    complAppr: ComplApprEnum
    sortTech: SortTechEnum
    singleCellLysisAppr: SingleCellLysisApprEnum
    singleCellLysisProt: String
    wgaAmpAppr: String
    wgaAmpKit: String
    binParam: BinParamEnum
    binSoftware: String
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    virIdentSoftware: String!
    predGenomeType: PredGenomeTypeEnum!
    predGenomeStruc: PredGenomeStrucEnum!
    detecType: String!
    otuClassAppr: String
    otuSeqCompAppr: String
    otuDb: String
    hostPredAppr: HostPredApprEnum
    hostPredEstAcc: String
    associatedResource: String
    sop: String
  }

interface MIGSBacteria
  {
    sampName: String!
    sampTaxonId: String!
    projectName: String!
    experimentalFactor: String
    latLon: String!
    geoLocName: String!
    collectionDate: Date!
    negContType: NegContTypeEnum
    posContType: String
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    subspecfGenLin: String
    numReplicons: Integer!
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String!
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    trophicLevel: TrophicLevelEnum
    encodedTraits: String
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    sampVolWeDnaExt: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

interface MIGSEukaryote
  {
    sampName: String!
    sampTaxonId: String!
    projectName: String!
    experimentalFactor: String
    latLon: String!
    geoLocName: String!
    collectionDate: Date!
    negContType: NegContTypeEnum
    posContType: String
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    subspecfGenLin: String
    ploidy: String
    numReplicons: Integer
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    trophicLevel: TrophicLevelEnum
    propagation: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    sampVolWeDnaExt: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

interface MIGSOrg
  {
    sampName: String!
    sampTaxonId: String!
    projectName: String!
    experimentalFactor: String
    latLon: String!
    geoLocName: String!
    collectionDate: Date!
    negContType: NegContTypeEnum
    posContType: String
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    subspecfGenLin: String
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    sampVolWeDnaExt: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

interface MIGSPlant
  {
    sampName: String!
    sampTaxonId: String!
    projectName: String!
    experimentalFactor: String
    latLon: String!
    geoLocName: String!
    collectionDate: Date!
    negContType: NegContTypeEnum
    posContType: String
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    subspecfGenLin: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    specificHost: String
    hostSpecRange: Integer
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    sampVolWeDnaExt: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

interface MIGSVirus
  {
    sampName: String!
    sampTaxonId: String!
    projectName: String!
    experimentalFactor: String
    latLon: String!
    geoLocName: String!
    collectionDate: Date!
    negContType: NegContTypeEnum
    posContType: String
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    subspecfGenLin: String
    numReplicons: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    sampVolWeDnaExt: QuantityValue
    virusEnrichAppr: VirusEnrichApprEnum
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

interface MIMAG
  {
    sampName: String!
    sampTaxonId: String!
    projectName: String!
    experimentalFactor: String
    latLon: String!
    geoLocName: String!
    collectionDate: Date!
    negContType: NegContTypeEnum
    posContType: String
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    sampVolWeDnaExt: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    binParam: BinParamEnum!
    binSoftware: String!
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    associatedResource: String
    sop: String
  }

interface MIMARKSSpecimen
  {
    sampName: String!
    sampTaxonId: String!
    projectName: String!
    experimentalFactor: String
    latLon: String!
    geoLocName: String!
    collectionDate: Date!
    negContType: NegContTypeEnum
    posContType: String
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    sampVolWeDnaExt: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    mid: String
    adapters: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    assemblySoftware: String
    associatedResource: String
    sop: String
  }

interface MIMARKSSurvey
  {
    sampName: String!
    sampTaxonId: String!
    projectName: String!
    experimentalFactor: String
    latLon: String!
    geoLocName: String!
    collectionDate: Date!
    negContType: NegContTypeEnum
    posContType: String
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    subspecfGenLin: String
    extrachromElements: Integer
    sourceMatId: String
    bioticRelationship: BioticRelationshipEnum
    trophicLevel: TrophicLevelEnum
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    sampVolWeDnaExt: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    associatedResource: String
    sop: String
  }

interface MIMS
  {
    sampName: String!
    sampTaxonId: String!
    projectName: String!
    experimentalFactor: String
    latLon: String!
    geoLocName: String!
    collectionDate: Date!
    negContType: NegContTypeEnum
    posContType: String
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    sampVolWeDnaExt: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    associatedResource: String
    sop: String
  }

interface MISAG
  {
    sampName: String!
    sampTaxonId: String!
    projectName: String!
    experimentalFactor: String
    latLon: String!
    geoLocName: String!
    collectionDate: Date!
    negContType: NegContTypeEnum
    posContType: String
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    sampVolWeDnaExt: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    sortTech: SortTechEnum!
    singleCellLysisAppr: SingleCellLysisApprEnum!
    singleCellLysisProt: String
    wgaAmpAppr: String!
    wgaAmpKit: String
    associatedResource: String
    sop: String
  }

type MiscellaneousNaturalOrArtificialEnvironment
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    ammonium: QuantityValue
    biomass: [String]
    bromide: QuantityValue
    calcium: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    miscParam: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    perturbation: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    potassium: QuantityValue
    pressure: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    waterCurrent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
  }

type MiscellaneousNaturalOrArtificialEnvironmentMIGSBacteria implements MIGSBacteria
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    ammonium: QuantityValue
    biomass: [String]
    bromide: QuantityValue
    calcium: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    miscParam: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    perturbation: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    potassium: QuantityValue
    pressure: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    waterCurrent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer!
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String!
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    trophicLevel: TrophicLevelEnum
    encodedTraits: String
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type MiscellaneousNaturalOrArtificialEnvironmentMIGSEukaryote implements MIGSEukaryote
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    ammonium: QuantityValue
    biomass: [String]
    bromide: QuantityValue
    calcium: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    miscParam: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    perturbation: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    potassium: QuantityValue
    pressure: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    waterCurrent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    ploidy: String
    numReplicons: Integer
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    trophicLevel: TrophicLevelEnum
    propagation: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type MiscellaneousNaturalOrArtificialEnvironmentMIGSOrg implements MIGSOrg
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    ammonium: QuantityValue
    biomass: [String]
    bromide: QuantityValue
    calcium: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    miscParam: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    perturbation: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    potassium: QuantityValue
    pressure: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    waterCurrent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type MiscellaneousNaturalOrArtificialEnvironmentMIGSPlant implements MIGSPlant
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    ammonium: QuantityValue
    biomass: [String]
    bromide: QuantityValue
    calcium: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    miscParam: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    perturbation: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    potassium: QuantityValue
    pressure: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    waterCurrent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    specificHost: String
    hostSpecRange: Integer
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type MiscellaneousNaturalOrArtificialEnvironmentMIGSVirus implements MIGSVirus
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    ammonium: QuantityValue
    biomass: [String]
    bromide: QuantityValue
    calcium: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    miscParam: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    perturbation: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    potassium: QuantityValue
    pressure: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    waterCurrent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    virusEnrichAppr: VirusEnrichApprEnum
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type MiscellaneousNaturalOrArtificialEnvironmentMIMAG implements MIMAG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    ammonium: QuantityValue
    biomass: [String]
    bromide: QuantityValue
    calcium: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    miscParam: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    perturbation: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    potassium: QuantityValue
    pressure: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    waterCurrent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    binParam: BinParamEnum!
    binSoftware: String!
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    associatedResource: String
    sop: String
  }

type MiscellaneousNaturalOrArtificialEnvironmentMIMARKSSpecimen implements MIMARKSSpecimen
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    ammonium: QuantityValue
    biomass: [String]
    bromide: QuantityValue
    calcium: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    miscParam: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    perturbation: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    potassium: QuantityValue
    pressure: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    waterCurrent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    mid: String
    adapters: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    assemblySoftware: String
    associatedResource: String
    sop: String
  }

type MiscellaneousNaturalOrArtificialEnvironmentMIMARKSSurvey implements MIMARKSSurvey
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    ammonium: QuantityValue
    biomass: [String]
    bromide: QuantityValue
    calcium: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    miscParam: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    perturbation: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    potassium: QuantityValue
    pressure: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    waterCurrent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    sourceMatId: String
    bioticRelationship: BioticRelationshipEnum
    trophicLevel: TrophicLevelEnum
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    associatedResource: String
    sop: String
  }

type MiscellaneousNaturalOrArtificialEnvironmentMIMS implements MIMS
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    ammonium: QuantityValue
    biomass: [String]
    bromide: QuantityValue
    calcium: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    miscParam: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    perturbation: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    potassium: QuantityValue
    pressure: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    waterCurrent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    associatedResource: String
    sop: String
  }

type MiscellaneousNaturalOrArtificialEnvironmentMISAG implements MISAG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    ammonium: QuantityValue
    biomass: [String]
    bromide: QuantityValue
    calcium: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    miscParam: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    perturbation: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    potassium: QuantityValue
    pressure: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    waterCurrent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    sortTech: SortTechEnum!
    singleCellLysisAppr: SingleCellLysisApprEnum!
    singleCellLysisProt: String
    wgaAmpAppr: String!
    wgaAmpKit: String
    associatedResource: String
    sop: String
  }

type MiscellaneousNaturalOrArtificialEnvironmentMIUVIG implements MIUVIG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    ammonium: QuantityValue
    biomass: [String]
    bromide: QuantityValue
    calcium: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    miscParam: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    perturbation: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    potassium: QuantityValue
    pressure: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    waterCurrent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    sourceUvig: SourceUvigEnum!
    virusEnrichAppr: VirusEnrichApprEnum!
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String
    complSoftware: String
    complAppr: ComplApprEnum
    sortTech: SortTechEnum
    singleCellLysisAppr: SingleCellLysisApprEnum
    singleCellLysisProt: String
    wgaAmpAppr: String
    wgaAmpKit: String
    binParam: BinParamEnum
    binSoftware: String
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    virIdentSoftware: String!
    predGenomeType: PredGenomeTypeEnum!
    predGenomeStruc: PredGenomeStrucEnum!
    detecType: String!
    otuClassAppr: String
    otuSeqCompAppr: String
    otuDb: String
    hostPredAppr: HostPredApprEnum
    hostPredEstAcc: String
    associatedResource: String
    sop: String
  }

interface MIUVIG
  {
    sampName: String!
    sampTaxonId: String!
    projectName: String!
    experimentalFactor: String
    latLon: String!
    geoLocName: String!
    collectionDate: Date!
    negContType: NegContTypeEnum
    posContType: String
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    sampVolWeDnaExt: QuantityValue
    sourceUvig: SourceUvigEnum!
    virusEnrichAppr: VirusEnrichApprEnum!
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String
    complSoftware: String
    complAppr: ComplApprEnum
    sortTech: SortTechEnum
    singleCellLysisAppr: SingleCellLysisApprEnum
    singleCellLysisProt: String
    wgaAmpAppr: String
    wgaAmpKit: String
    binParam: BinParamEnum
    binSoftware: String
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    virIdentSoftware: String!
    predGenomeType: PredGenomeTypeEnum!
    predGenomeStruc: PredGenomeStrucEnum!
    detecType: String!
    otuClassAppr: String
    otuSeqCompAppr: String
    otuDb: String
    hostPredAppr: HostPredApprEnum
    hostPredEstAcc: String
    associatedResource: String
    sop: String
  }

type Plant-associated
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    airTempRegm: [String]
    ancesData: String
    antibioticRegm: [String]
    biolStat: BiolStatEnum
    bioticRegm: String
    chemAdministration: [String]
    chemMutagen: [String]
    climateEnvironment: [String]
    cultRootMed: String
    fertilizerRegm: [String]
    fungicideRegm: [String]
    gaseousEnvironment: [String]
    geneticMod: String
    gravity: [String]
    growthFacil: String
    growthHabit: GrowthHabitEnum
    growthHormoneRegm: [String]
    herbicideRegm: [String]
    hostAge: QuantityValue
    hostCommonName: String
    hostDryMass: QuantityValue
    hostGenotype: String
    hostHeight: QuantityValue
    hostSubspecfGenlin: [String]
    hostLength: QuantityValue
    hostLifeStage: String
    hostPhenotype: String
    hostTaxid: String
    hostTotMass: QuantityValue
    hostWetMass: QuantityValue
    humidityRegm: [String]
    lightRegm: String
    mechanicalDamage: [String]
    mineralNutrRegm: [String]
    miscParam: [String]
    nonMinNutrRegm: [String]
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    phRegm: [String]
    perturbation: [String]
    pesticideRegm: [String]
    plantGrowthMed: PlantGrowthMedEnum
    plantProduct: String
    plantSex: PlantSexEnum
    plantStruc: String
    radiationRegm: [String]
    rainfallRegm: [String]
    rootCond: String
    rootMedCarbon: String
    rootMedMacronutr: String
    rootMedMicronutr: String
    rootMedSuppl: String
    rootMedPh: Double
    rootMedRegl: String
    rootMedSolid: String
    saltRegm: [String]
    sampCaptStatus: SampCaptStatusEnum
    sampDisStage: SampDisStageEnum
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    seasonEnvironment: [String]
    standingWaterRegm: [String]
    tissCultGrowthMed: String
    waterTempRegm: [String]
    wateringRegm: [String]
    hostSymbiont: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
  }

type Plant-associatedMIGSBacteria implements MIGSBacteria
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    airTempRegm: [String]
    ancesData: String
    antibioticRegm: [String]
    biolStat: BiolStatEnum
    bioticRegm: String
    chemAdministration: [String]
    chemMutagen: [String]
    climateEnvironment: [String]
    cultRootMed: String
    fertilizerRegm: [String]
    fungicideRegm: [String]
    gaseousEnvironment: [String]
    geneticMod: String
    gravity: [String]
    growthFacil: String
    growthHabit: GrowthHabitEnum
    growthHormoneRegm: [String]
    herbicideRegm: [String]
    hostAge: QuantityValue
    hostCommonName: String
    hostDryMass: QuantityValue
    hostGenotype: String
    hostHeight: QuantityValue
    hostSubspecfGenlin: [String]
    hostLength: QuantityValue
    hostLifeStage: String
    hostPhenotype: String
    hostTaxid: String
    hostTotMass: QuantityValue
    hostWetMass: QuantityValue
    humidityRegm: [String]
    lightRegm: String
    mechanicalDamage: [String]
    mineralNutrRegm: [String]
    nonMinNutrRegm: [String]
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    phRegm: [String]
    perturbation: [String]
    pesticideRegm: [String]
    plantGrowthMed: PlantGrowthMedEnum
    plantProduct: String
    plantSex: PlantSexEnum
    plantStruc: String
    radiationRegm: [String]
    rainfallRegm: [String]
    rootCond: String
    rootMedCarbon: String
    rootMedMacronutr: String
    rootMedMicronutr: String
    rootMedSuppl: String
    rootMedPh: Double
    rootMedRegl: String
    rootMedSolid: String
    saltRegm: [String]
    sampCaptStatus: SampCaptStatusEnum
    sampDisStage: SampDisStageEnum
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    seasonEnvironment: [String]
    standingWaterRegm: [String]
    tissCultGrowthMed: String
    waterTempRegm: [String]
    wateringRegm: [String]
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer!
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String!
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    trophicLevel: TrophicLevelEnum
    encodedTraits: String
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Plant-associatedMIGSEukaryote implements MIGSEukaryote
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    airTempRegm: [String]
    ancesData: String
    antibioticRegm: [String]
    biolStat: BiolStatEnum
    bioticRegm: String
    chemAdministration: [String]
    chemMutagen: [String]
    climateEnvironment: [String]
    cultRootMed: String
    fertilizerRegm: [String]
    fungicideRegm: [String]
    gaseousEnvironment: [String]
    geneticMod: String
    gravity: [String]
    growthFacil: String
    growthHabit: GrowthHabitEnum
    growthHormoneRegm: [String]
    herbicideRegm: [String]
    hostAge: QuantityValue
    hostCommonName: String
    hostDryMass: QuantityValue
    hostGenotype: String
    hostHeight: QuantityValue
    hostSubspecfGenlin: [String]
    hostLength: QuantityValue
    hostLifeStage: String
    hostPhenotype: String
    hostTaxid: String
    hostTotMass: QuantityValue
    hostWetMass: QuantityValue
    humidityRegm: [String]
    lightRegm: String
    mechanicalDamage: [String]
    mineralNutrRegm: [String]
    nonMinNutrRegm: [String]
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    phRegm: [String]
    perturbation: [String]
    pesticideRegm: [String]
    plantGrowthMed: PlantGrowthMedEnum
    plantProduct: String
    plantSex: PlantSexEnum
    plantStruc: String
    radiationRegm: [String]
    rainfallRegm: [String]
    rootCond: String
    rootMedCarbon: String
    rootMedMacronutr: String
    rootMedMicronutr: String
    rootMedSuppl: String
    rootMedPh: Double
    rootMedRegl: String
    rootMedSolid: String
    saltRegm: [String]
    sampCaptStatus: SampCaptStatusEnum
    sampDisStage: SampDisStageEnum
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    seasonEnvironment: [String]
    standingWaterRegm: [String]
    tissCultGrowthMed: String
    waterTempRegm: [String]
    wateringRegm: [String]
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    ploidy: String
    numReplicons: Integer
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    trophicLevel: TrophicLevelEnum
    propagation: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Plant-associatedMIGSOrg implements MIGSOrg
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    airTempRegm: [String]
    ancesData: String
    antibioticRegm: [String]
    biolStat: BiolStatEnum
    bioticRegm: String
    chemAdministration: [String]
    chemMutagen: [String]
    climateEnvironment: [String]
    cultRootMed: String
    fertilizerRegm: [String]
    fungicideRegm: [String]
    gaseousEnvironment: [String]
    geneticMod: String
    gravity: [String]
    growthFacil: String
    growthHabit: GrowthHabitEnum
    growthHormoneRegm: [String]
    herbicideRegm: [String]
    hostAge: QuantityValue
    hostCommonName: String
    hostDryMass: QuantityValue
    hostGenotype: String
    hostHeight: QuantityValue
    hostSubspecfGenlin: [String]
    hostLength: QuantityValue
    hostLifeStage: String
    hostPhenotype: String
    hostTaxid: String
    hostTotMass: QuantityValue
    hostWetMass: QuantityValue
    humidityRegm: [String]
    lightRegm: String
    mechanicalDamage: [String]
    mineralNutrRegm: [String]
    nonMinNutrRegm: [String]
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    phRegm: [String]
    perturbation: [String]
    pesticideRegm: [String]
    plantGrowthMed: PlantGrowthMedEnum
    plantProduct: String
    plantSex: PlantSexEnum
    plantStruc: String
    radiationRegm: [String]
    rainfallRegm: [String]
    rootCond: String
    rootMedCarbon: String
    rootMedMacronutr: String
    rootMedMicronutr: String
    rootMedSuppl: String
    rootMedPh: Double
    rootMedRegl: String
    rootMedSolid: String
    saltRegm: [String]
    sampCaptStatus: SampCaptStatusEnum
    sampDisStage: SampDisStageEnum
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    seasonEnvironment: [String]
    standingWaterRegm: [String]
    tissCultGrowthMed: String
    waterTempRegm: [String]
    wateringRegm: [String]
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Plant-associatedMIGSPlant implements MIGSPlant
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    airTempRegm: [String]
    ancesData: String
    antibioticRegm: [String]
    biolStat: BiolStatEnum
    bioticRegm: String
    chemAdministration: [String]
    chemMutagen: [String]
    climateEnvironment: [String]
    cultRootMed: String
    fertilizerRegm: [String]
    fungicideRegm: [String]
    gaseousEnvironment: [String]
    geneticMod: String
    gravity: [String]
    growthFacil: String
    growthHabit: GrowthHabitEnum
    growthHormoneRegm: [String]
    herbicideRegm: [String]
    hostAge: QuantityValue
    hostCommonName: String
    hostDryMass: QuantityValue
    hostGenotype: String
    hostHeight: QuantityValue
    hostSubspecfGenlin: [String]
    hostLength: QuantityValue
    hostLifeStage: String
    hostPhenotype: String
    hostTaxid: String
    hostTotMass: QuantityValue
    hostWetMass: QuantityValue
    humidityRegm: [String]
    lightRegm: String
    mechanicalDamage: [String]
    mineralNutrRegm: [String]
    nonMinNutrRegm: [String]
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    phRegm: [String]
    perturbation: [String]
    pesticideRegm: [String]
    plantGrowthMed: PlantGrowthMedEnum
    plantProduct: String
    plantSex: PlantSexEnum
    plantStruc: String
    radiationRegm: [String]
    rainfallRegm: [String]
    rootCond: String
    rootMedCarbon: String
    rootMedMacronutr: String
    rootMedMicronutr: String
    rootMedSuppl: String
    rootMedPh: Double
    rootMedRegl: String
    rootMedSolid: String
    saltRegm: [String]
    sampCaptStatus: SampCaptStatusEnum
    sampDisStage: SampDisStageEnum
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    seasonEnvironment: [String]
    standingWaterRegm: [String]
    tissCultGrowthMed: String
    waterTempRegm: [String]
    wateringRegm: [String]
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    specificHost: String
    hostSpecRange: Integer
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Plant-associatedMIGSVirus implements MIGSVirus
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    airTempRegm: [String]
    ancesData: String
    antibioticRegm: [String]
    biolStat: BiolStatEnum
    bioticRegm: String
    chemAdministration: [String]
    chemMutagen: [String]
    climateEnvironment: [String]
    cultRootMed: String
    fertilizerRegm: [String]
    fungicideRegm: [String]
    gaseousEnvironment: [String]
    geneticMod: String
    gravity: [String]
    growthFacil: String
    growthHabit: GrowthHabitEnum
    growthHormoneRegm: [String]
    herbicideRegm: [String]
    hostAge: QuantityValue
    hostCommonName: String
    hostDryMass: QuantityValue
    hostGenotype: String
    hostHeight: QuantityValue
    hostSubspecfGenlin: [String]
    hostLength: QuantityValue
    hostLifeStage: String
    hostPhenotype: String
    hostTaxid: String
    hostTotMass: QuantityValue
    hostWetMass: QuantityValue
    humidityRegm: [String]
    lightRegm: String
    mechanicalDamage: [String]
    mineralNutrRegm: [String]
    nonMinNutrRegm: [String]
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    phRegm: [String]
    perturbation: [String]
    pesticideRegm: [String]
    plantGrowthMed: PlantGrowthMedEnum
    plantProduct: String
    plantSex: PlantSexEnum
    plantStruc: String
    radiationRegm: [String]
    rainfallRegm: [String]
    rootCond: String
    rootMedCarbon: String
    rootMedMacronutr: String
    rootMedMicronutr: String
    rootMedSuppl: String
    rootMedPh: Double
    rootMedRegl: String
    rootMedSolid: String
    saltRegm: [String]
    sampCaptStatus: SampCaptStatusEnum
    sampDisStage: SampDisStageEnum
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    seasonEnvironment: [String]
    standingWaterRegm: [String]
    tissCultGrowthMed: String
    waterTempRegm: [String]
    wateringRegm: [String]
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    virusEnrichAppr: VirusEnrichApprEnum
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Plant-associatedMIMAG implements MIMAG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    airTempRegm: [String]
    ancesData: String
    antibioticRegm: [String]
    biolStat: BiolStatEnum
    bioticRegm: String
    chemAdministration: [String]
    chemMutagen: [String]
    climateEnvironment: [String]
    cultRootMed: String
    fertilizerRegm: [String]
    fungicideRegm: [String]
    gaseousEnvironment: [String]
    geneticMod: String
    gravity: [String]
    growthFacil: String
    growthHabit: GrowthHabitEnum
    growthHormoneRegm: [String]
    herbicideRegm: [String]
    hostAge: QuantityValue
    hostCommonName: String
    hostDryMass: QuantityValue
    hostGenotype: String
    hostHeight: QuantityValue
    hostSubspecfGenlin: [String]
    hostLength: QuantityValue
    hostLifeStage: String
    hostPhenotype: String
    hostTaxid: String
    hostTotMass: QuantityValue
    hostWetMass: QuantityValue
    humidityRegm: [String]
    lightRegm: String
    mechanicalDamage: [String]
    mineralNutrRegm: [String]
    nonMinNutrRegm: [String]
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    phRegm: [String]
    perturbation: [String]
    pesticideRegm: [String]
    plantGrowthMed: PlantGrowthMedEnum
    plantProduct: String
    plantSex: PlantSexEnum
    plantStruc: String
    radiationRegm: [String]
    rainfallRegm: [String]
    rootCond: String
    rootMedCarbon: String
    rootMedMacronutr: String
    rootMedMicronutr: String
    rootMedSuppl: String
    rootMedPh: Double
    rootMedRegl: String
    rootMedSolid: String
    saltRegm: [String]
    sampCaptStatus: SampCaptStatusEnum
    sampDisStage: SampDisStageEnum
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    seasonEnvironment: [String]
    standingWaterRegm: [String]
    tissCultGrowthMed: String
    waterTempRegm: [String]
    wateringRegm: [String]
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    binParam: BinParamEnum!
    binSoftware: String!
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    associatedResource: String
    sop: String
  }

type Plant-associatedMIMARKSSpecimen implements MIMARKSSpecimen
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    airTempRegm: [String]
    ancesData: String
    antibioticRegm: [String]
    biolStat: BiolStatEnum
    bioticRegm: String
    chemAdministration: [String]
    chemMutagen: [String]
    climateEnvironment: [String]
    cultRootMed: String
    fertilizerRegm: [String]
    fungicideRegm: [String]
    gaseousEnvironment: [String]
    geneticMod: String
    gravity: [String]
    growthFacil: String
    growthHabit: GrowthHabitEnum
    growthHormoneRegm: [String]
    herbicideRegm: [String]
    hostAge: QuantityValue
    hostCommonName: String
    hostDryMass: QuantityValue
    hostGenotype: String
    hostHeight: QuantityValue
    hostSubspecfGenlin: [String]
    hostLength: QuantityValue
    hostLifeStage: String
    hostPhenotype: String
    hostTaxid: String
    hostTotMass: QuantityValue
    hostWetMass: QuantityValue
    humidityRegm: [String]
    lightRegm: String
    mechanicalDamage: [String]
    mineralNutrRegm: [String]
    nonMinNutrRegm: [String]
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    phRegm: [String]
    perturbation: [String]
    pesticideRegm: [String]
    plantGrowthMed: PlantGrowthMedEnum
    plantProduct: String
    plantSex: PlantSexEnum
    plantStruc: String
    radiationRegm: [String]
    rainfallRegm: [String]
    rootCond: String
    rootMedCarbon: String
    rootMedMacronutr: String
    rootMedMicronutr: String
    rootMedSuppl: String
    rootMedPh: Double
    rootMedRegl: String
    rootMedSolid: String
    saltRegm: [String]
    sampCaptStatus: SampCaptStatusEnum
    sampDisStage: SampDisStageEnum
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    seasonEnvironment: [String]
    standingWaterRegm: [String]
    tissCultGrowthMed: String
    waterTempRegm: [String]
    wateringRegm: [String]
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    mid: String
    adapters: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    assemblySoftware: String
    associatedResource: String
    sop: String
  }

type Plant-associatedMIMARKSSurvey implements MIMARKSSurvey
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    airTempRegm: [String]
    ancesData: String
    antibioticRegm: [String]
    biolStat: BiolStatEnum
    bioticRegm: String
    chemAdministration: [String]
    chemMutagen: [String]
    climateEnvironment: [String]
    cultRootMed: String
    fertilizerRegm: [String]
    fungicideRegm: [String]
    gaseousEnvironment: [String]
    geneticMod: String
    gravity: [String]
    growthFacil: String
    growthHabit: GrowthHabitEnum
    growthHormoneRegm: [String]
    herbicideRegm: [String]
    hostAge: QuantityValue
    hostCommonName: String
    hostDryMass: QuantityValue
    hostGenotype: String
    hostHeight: QuantityValue
    hostSubspecfGenlin: [String]
    hostLength: QuantityValue
    hostLifeStage: String
    hostPhenotype: String
    hostTaxid: String
    hostTotMass: QuantityValue
    hostWetMass: QuantityValue
    humidityRegm: [String]
    lightRegm: String
    mechanicalDamage: [String]
    mineralNutrRegm: [String]
    nonMinNutrRegm: [String]
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    phRegm: [String]
    perturbation: [String]
    pesticideRegm: [String]
    plantGrowthMed: PlantGrowthMedEnum
    plantProduct: String
    plantSex: PlantSexEnum
    plantStruc: String
    radiationRegm: [String]
    rainfallRegm: [String]
    rootCond: String
    rootMedCarbon: String
    rootMedMacronutr: String
    rootMedMicronutr: String
    rootMedSuppl: String
    rootMedPh: Double
    rootMedRegl: String
    rootMedSolid: String
    saltRegm: [String]
    sampCaptStatus: SampCaptStatusEnum
    sampDisStage: SampDisStageEnum
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    seasonEnvironment: [String]
    standingWaterRegm: [String]
    tissCultGrowthMed: String
    waterTempRegm: [String]
    wateringRegm: [String]
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    sourceMatId: String
    bioticRelationship: BioticRelationshipEnum
    trophicLevel: TrophicLevelEnum
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    associatedResource: String
    sop: String
  }

type Plant-associatedMIMS implements MIMS
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    airTempRegm: [String]
    ancesData: String
    antibioticRegm: [String]
    biolStat: BiolStatEnum
    bioticRegm: String
    chemAdministration: [String]
    chemMutagen: [String]
    climateEnvironment: [String]
    cultRootMed: String
    fertilizerRegm: [String]
    fungicideRegm: [String]
    gaseousEnvironment: [String]
    geneticMod: String
    gravity: [String]
    growthFacil: String
    growthHabit: GrowthHabitEnum
    growthHormoneRegm: [String]
    herbicideRegm: [String]
    hostAge: QuantityValue
    hostCommonName: String
    hostDryMass: QuantityValue
    hostGenotype: String
    hostHeight: QuantityValue
    hostSubspecfGenlin: [String]
    hostLength: QuantityValue
    hostLifeStage: String
    hostPhenotype: String
    hostTaxid: String
    hostTotMass: QuantityValue
    hostWetMass: QuantityValue
    humidityRegm: [String]
    lightRegm: String
    mechanicalDamage: [String]
    mineralNutrRegm: [String]
    nonMinNutrRegm: [String]
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    phRegm: [String]
    perturbation: [String]
    pesticideRegm: [String]
    plantGrowthMed: PlantGrowthMedEnum
    plantProduct: String
    plantSex: PlantSexEnum
    plantStruc: String
    radiationRegm: [String]
    rainfallRegm: [String]
    rootCond: String
    rootMedCarbon: String
    rootMedMacronutr: String
    rootMedMicronutr: String
    rootMedSuppl: String
    rootMedPh: Double
    rootMedRegl: String
    rootMedSolid: String
    saltRegm: [String]
    sampCaptStatus: SampCaptStatusEnum
    sampDisStage: SampDisStageEnum
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    seasonEnvironment: [String]
    standingWaterRegm: [String]
    tissCultGrowthMed: String
    waterTempRegm: [String]
    wateringRegm: [String]
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    associatedResource: String
    sop: String
  }

type Plant-associatedMISAG implements MISAG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    airTempRegm: [String]
    ancesData: String
    antibioticRegm: [String]
    biolStat: BiolStatEnum
    bioticRegm: String
    chemAdministration: [String]
    chemMutagen: [String]
    climateEnvironment: [String]
    cultRootMed: String
    fertilizerRegm: [String]
    fungicideRegm: [String]
    gaseousEnvironment: [String]
    geneticMod: String
    gravity: [String]
    growthFacil: String
    growthHabit: GrowthHabitEnum
    growthHormoneRegm: [String]
    herbicideRegm: [String]
    hostAge: QuantityValue
    hostCommonName: String
    hostDryMass: QuantityValue
    hostGenotype: String
    hostHeight: QuantityValue
    hostSubspecfGenlin: [String]
    hostLength: QuantityValue
    hostLifeStage: String
    hostPhenotype: String
    hostTaxid: String
    hostTotMass: QuantityValue
    hostWetMass: QuantityValue
    humidityRegm: [String]
    lightRegm: String
    mechanicalDamage: [String]
    mineralNutrRegm: [String]
    nonMinNutrRegm: [String]
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    phRegm: [String]
    perturbation: [String]
    pesticideRegm: [String]
    plantGrowthMed: PlantGrowthMedEnum
    plantProduct: String
    plantSex: PlantSexEnum
    plantStruc: String
    radiationRegm: [String]
    rainfallRegm: [String]
    rootCond: String
    rootMedCarbon: String
    rootMedMacronutr: String
    rootMedMicronutr: String
    rootMedSuppl: String
    rootMedPh: Double
    rootMedRegl: String
    rootMedSolid: String
    saltRegm: [String]
    sampCaptStatus: SampCaptStatusEnum
    sampDisStage: SampDisStageEnum
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    seasonEnvironment: [String]
    standingWaterRegm: [String]
    tissCultGrowthMed: String
    waterTempRegm: [String]
    wateringRegm: [String]
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    sortTech: SortTechEnum!
    singleCellLysisAppr: SingleCellLysisApprEnum!
    singleCellLysisProt: String
    wgaAmpAppr: String!
    wgaAmpKit: String
    associatedResource: String
    sop: String
  }

type Plant-associatedMIUVIG implements MIUVIG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    airTempRegm: [String]
    ancesData: String
    antibioticRegm: [String]
    biolStat: BiolStatEnum
    bioticRegm: String
    chemAdministration: [String]
    chemMutagen: [String]
    climateEnvironment: [String]
    cultRootMed: String
    fertilizerRegm: [String]
    fungicideRegm: [String]
    gaseousEnvironment: [String]
    geneticMod: String
    gravity: [String]
    growthFacil: String
    growthHabit: GrowthHabitEnum
    growthHormoneRegm: [String]
    herbicideRegm: [String]
    hostAge: QuantityValue
    hostCommonName: String
    hostDryMass: QuantityValue
    hostGenotype: String
    hostHeight: QuantityValue
    hostSubspecfGenlin: [String]
    hostLength: QuantityValue
    hostLifeStage: String
    hostPhenotype: String
    hostTaxid: String
    hostTotMass: QuantityValue
    hostWetMass: QuantityValue
    humidityRegm: [String]
    lightRegm: String
    mechanicalDamage: [String]
    mineralNutrRegm: [String]
    nonMinNutrRegm: [String]
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    phRegm: [String]
    perturbation: [String]
    pesticideRegm: [String]
    plantGrowthMed: PlantGrowthMedEnum
    plantProduct: String
    plantSex: PlantSexEnum
    plantStruc: String
    radiationRegm: [String]
    rainfallRegm: [String]
    rootCond: String
    rootMedCarbon: String
    rootMedMacronutr: String
    rootMedMicronutr: String
    rootMedSuppl: String
    rootMedPh: Double
    rootMedRegl: String
    rootMedSolid: String
    saltRegm: [String]
    sampCaptStatus: SampCaptStatusEnum
    sampDisStage: SampDisStageEnum
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    seasonEnvironment: [String]
    standingWaterRegm: [String]
    tissCultGrowthMed: String
    waterTempRegm: [String]
    wateringRegm: [String]
    hostSymbiont: [String]
    miscParam: [String]
    sampName: String!
    projectName: String!
    hostDiseaseStat: String
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    sourceUvig: SourceUvigEnum!
    virusEnrichAppr: VirusEnrichApprEnum!
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String
    complSoftware: String
    complAppr: ComplApprEnum
    sortTech: SortTechEnum
    singleCellLysisAppr: SingleCellLysisApprEnum
    singleCellLysisProt: String
    wgaAmpAppr: String
    wgaAmpKit: String
    binParam: BinParamEnum
    binSoftware: String
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    virIdentSoftware: String!
    predGenomeType: PredGenomeTypeEnum!
    predGenomeStruc: PredGenomeStrucEnum!
    detecType: String!
    otuClassAppr: String
    otuSeqCompAppr: String
    otuDb: String
    hostPredAppr: HostPredApprEnum
    hostPredEstAcc: String
    associatedResource: String
    sop: String
  }

type QuantityValue
  {
    hasUnit: String
    hasNumericValue: Double
    hasRawValue: String
  }

type Sediment
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    bacteriaCarbProd: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    glucosidaseAct: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    methane: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    particleClass: [String]
    partOrgCarb: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    porosity: String
    potassium: QuantityValue
    pressure: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    sedimentType: SedimentTypeEnum
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    tidalStage: TidalStageEnum
    totCarb: QuantityValue
    totDepthWaterCol: QuantityValue
    totNitroContent: QuantityValue
    totOrgCarb: QuantityValue
    turbidity: QuantityValue
    waterContent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
  }

type SedimentMIGSBacteria implements MIGSBacteria
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    bacteriaCarbProd: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    glucosidaseAct: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    methane: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    particleClass: [String]
    partOrgCarb: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    porosity: String
    potassium: QuantityValue
    pressure: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    sedimentType: SedimentTypeEnum
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    tidalStage: TidalStageEnum
    totCarb: QuantityValue
    totDepthWaterCol: QuantityValue
    totNitroContent: QuantityValue
    totOrgCarb: QuantityValue
    turbidity: QuantityValue
    waterContent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer!
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String!
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    trophicLevel: TrophicLevelEnum
    encodedTraits: String
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type SedimentMIGSEukaryote implements MIGSEukaryote
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    bacteriaCarbProd: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    glucosidaseAct: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    methane: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    particleClass: [String]
    partOrgCarb: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    porosity: String
    potassium: QuantityValue
    pressure: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    sedimentType: SedimentTypeEnum
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    tidalStage: TidalStageEnum
    totCarb: QuantityValue
    totDepthWaterCol: QuantityValue
    totNitroContent: QuantityValue
    totOrgCarb: QuantityValue
    turbidity: QuantityValue
    waterContent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    ploidy: String
    numReplicons: Integer
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    trophicLevel: TrophicLevelEnum
    propagation: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type SedimentMIGSOrg implements MIGSOrg
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    bacteriaCarbProd: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    glucosidaseAct: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    methane: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    particleClass: [String]
    partOrgCarb: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    porosity: String
    potassium: QuantityValue
    pressure: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    sedimentType: SedimentTypeEnum
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    tidalStage: TidalStageEnum
    totCarb: QuantityValue
    totDepthWaterCol: QuantityValue
    totNitroContent: QuantityValue
    totOrgCarb: QuantityValue
    turbidity: QuantityValue
    waterContent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type SedimentMIGSPlant implements MIGSPlant
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    bacteriaCarbProd: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    glucosidaseAct: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    methane: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    particleClass: [String]
    partOrgCarb: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    porosity: String
    potassium: QuantityValue
    pressure: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    sedimentType: SedimentTypeEnum
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    tidalStage: TidalStageEnum
    totCarb: QuantityValue
    totDepthWaterCol: QuantityValue
    totNitroContent: QuantityValue
    totOrgCarb: QuantityValue
    turbidity: QuantityValue
    waterContent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    specificHost: String
    hostSpecRange: Integer
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type SedimentMIGSVirus implements MIGSVirus
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    bacteriaCarbProd: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    glucosidaseAct: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    methane: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    particleClass: [String]
    partOrgCarb: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    porosity: String
    potassium: QuantityValue
    pressure: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    sedimentType: SedimentTypeEnum
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    tidalStage: TidalStageEnum
    totCarb: QuantityValue
    totDepthWaterCol: QuantityValue
    totNitroContent: QuantityValue
    totOrgCarb: QuantityValue
    turbidity: QuantityValue
    waterContent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    virusEnrichAppr: VirusEnrichApprEnum
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type SedimentMIMAG implements MIMAG
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    bacteriaCarbProd: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    glucosidaseAct: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    methane: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    particleClass: [String]
    partOrgCarb: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    porosity: String
    potassium: QuantityValue
    pressure: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    sedimentType: SedimentTypeEnum
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    tidalStage: TidalStageEnum
    totCarb: QuantityValue
    totDepthWaterCol: QuantityValue
    totNitroContent: QuantityValue
    totOrgCarb: QuantityValue
    turbidity: QuantityValue
    waterContent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    binParam: BinParamEnum!
    binSoftware: String!
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    associatedResource: String
    sop: String
  }

type SedimentMIMARKSSpecimen implements MIMARKSSpecimen
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    bacteriaCarbProd: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    glucosidaseAct: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    methane: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    particleClass: [String]
    partOrgCarb: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    porosity: String
    potassium: QuantityValue
    pressure: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    sedimentType: SedimentTypeEnum
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    tidalStage: TidalStageEnum
    totCarb: QuantityValue
    totDepthWaterCol: QuantityValue
    totNitroContent: QuantityValue
    totOrgCarb: QuantityValue
    turbidity: QuantityValue
    waterContent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    mid: String
    adapters: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    assemblySoftware: String
    associatedResource: String
    sop: String
  }

type SedimentMIMARKSSurvey implements MIMARKSSurvey
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    bacteriaCarbProd: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    glucosidaseAct: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    methane: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    particleClass: [String]
    partOrgCarb: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    porosity: String
    potassium: QuantityValue
    pressure: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    sedimentType: SedimentTypeEnum
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    tidalStage: TidalStageEnum
    totCarb: QuantityValue
    totDepthWaterCol: QuantityValue
    totNitroContent: QuantityValue
    totOrgCarb: QuantityValue
    turbidity: QuantityValue
    waterContent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    sourceMatId: String
    bioticRelationship: BioticRelationshipEnum
    trophicLevel: TrophicLevelEnum
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    associatedResource: String
    sop: String
  }

type SedimentMIMS implements MIMS
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    bacteriaCarbProd: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    glucosidaseAct: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    methane: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    particleClass: [String]
    partOrgCarb: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    porosity: String
    potassium: QuantityValue
    pressure: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    sedimentType: SedimentTypeEnum
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    tidalStage: TidalStageEnum
    totCarb: QuantityValue
    totDepthWaterCol: QuantityValue
    totNitroContent: QuantityValue
    totOrgCarb: QuantityValue
    turbidity: QuantityValue
    waterContent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    associatedResource: String
    sop: String
  }

type SedimentMISAG implements MISAG
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    bacteriaCarbProd: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    glucosidaseAct: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    methane: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    particleClass: [String]
    partOrgCarb: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    porosity: String
    potassium: QuantityValue
    pressure: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    sedimentType: SedimentTypeEnum
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    tidalStage: TidalStageEnum
    totCarb: QuantityValue
    totDepthWaterCol: QuantityValue
    totNitroContent: QuantityValue
    totOrgCarb: QuantityValue
    turbidity: QuantityValue
    waterContent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    sortTech: SortTechEnum!
    singleCellLysisAppr: SingleCellLysisApprEnum!
    singleCellLysisProt: String
    wgaAmpAppr: String!
    wgaAmpKit: String
    associatedResource: String
    sop: String
  }

type SedimentMIUVIG implements MIUVIG
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    bacteriaCarbProd: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    glucosidaseAct: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    methane: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    particleClass: [String]
    partOrgCarb: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    porosity: String
    potassium: QuantityValue
    pressure: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    sedimentType: SedimentTypeEnum
    silicate: QuantityValue
    sodium: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    tidalStage: TidalStageEnum
    totCarb: QuantityValue
    totDepthWaterCol: QuantityValue
    totNitroContent: QuantityValue
    totOrgCarb: QuantityValue
    turbidity: QuantityValue
    waterContent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    sourceUvig: SourceUvigEnum!
    virusEnrichAppr: VirusEnrichApprEnum!
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String
    complSoftware: String
    complAppr: ComplApprEnum
    sortTech: SortTechEnum
    singleCellLysisAppr: SingleCellLysisApprEnum
    singleCellLysisProt: String
    wgaAmpAppr: String
    wgaAmpKit: String
    binParam: BinParamEnum
    binSoftware: String
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    virIdentSoftware: String!
    predGenomeType: PredGenomeTypeEnum!
    predGenomeStruc: PredGenomeStrucEnum!
    detecType: String!
    otuClassAppr: String
    otuSeqCompAppr: String
    otuDb: String
    hostPredAppr: HostPredApprEnum
    hostPredEstAcc: String
    associatedResource: String
    sop: String
  }

type Soil
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue!
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    curLandUse: CurLandUseEnum
    curVegetation: String
    curVegetationMeth: String
    previousLandUse: String
    prevLandUseMeth: String
    cropRotation: String
    agrochemAddition: [String]
    tillage: [TillageEnum]
    fire: Date
    flooding: Date
    extremeEvent: Date
    soilHorizon: SoilHorizonEnum
    horizonMeth: String
    sieving: String
    waterContent: QuantityValue
    waterContSoilMeth: String
    poolDnaExtracts: String
    storeCond: String
    linkClimateInfo: String
    annualTemp: QuantityValue
    seasonTemp: QuantityValue
    annualPrecpt: QuantityValue
    seasonPrecpt: QuantityValue
    linkClassInfo: String
    faoClass: FaoClassEnum
    localClass: String
    localClassMeth: String
    orgNitro: QuantityValue
    soilType: String
    soilTypeMeth: String
    slopeGradient: QuantityValue
    slopeAspect: QuantityValue
    profilePosition: ProfilePositionEnum
    drainageClass: DrainageClassEnum
    soilTextMeasure: QuantityValue
    soilTextureMeth: String
    ph: Double
    phMeth: String
    orgMatter: QuantityValue
    totOrgCarb: QuantityValue
    totOrgCMeth: String
    totNitroContent: QuantityValue
    totNitroContMeth: String
    microbialBiomass: QuantityValue
    microBiomassMeth: String
    linkAdditAnalys: String
    salinityMeth: String
    heavyMetals: [String]
    heavyMetalsMeth: String
    alSat: QuantityValue
    alSatMeth: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
  }

type SoilMIGSBacteria implements MIGSBacteria
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue!
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    curLandUse: CurLandUseEnum
    curVegetation: String
    curVegetationMeth: String
    previousLandUse: String
    prevLandUseMeth: String
    cropRotation: String
    agrochemAddition: [String]
    tillage: [TillageEnum]
    fire: Date
    flooding: Date
    extremeEvent: Date
    soilHorizon: SoilHorizonEnum
    horizonMeth: String
    sieving: String
    waterContent: QuantityValue
    waterContSoilMeth: String
    poolDnaExtracts: String
    storeCond: String
    linkClimateInfo: String
    annualTemp: QuantityValue
    seasonTemp: QuantityValue
    annualPrecpt: QuantityValue
    seasonPrecpt: QuantityValue
    linkClassInfo: String
    faoClass: FaoClassEnum
    localClass: String
    localClassMeth: String
    orgNitro: QuantityValue
    soilType: String
    soilTypeMeth: String
    slopeGradient: QuantityValue
    slopeAspect: QuantityValue
    profilePosition: ProfilePositionEnum
    drainageClass: DrainageClassEnum
    soilTextMeasure: QuantityValue
    soilTextureMeth: String
    ph: Double
    phMeth: String
    orgMatter: QuantityValue
    totOrgCarb: QuantityValue
    totOrgCMeth: String
    totNitroContent: QuantityValue
    totNitroContMeth: String
    microbialBiomass: QuantityValue
    microBiomassMeth: String
    linkAdditAnalys: String
    salinityMeth: String
    heavyMetals: [String]
    heavyMetalsMeth: String
    alSat: QuantityValue
    alSatMeth: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer!
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String!
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    trophicLevel: TrophicLevelEnum
    encodedTraits: String
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type SoilMIGSEukaryote implements MIGSEukaryote
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue!
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    curLandUse: CurLandUseEnum
    curVegetation: String
    curVegetationMeth: String
    previousLandUse: String
    prevLandUseMeth: String
    cropRotation: String
    agrochemAddition: [String]
    tillage: [TillageEnum]
    fire: Date
    flooding: Date
    extremeEvent: Date
    soilHorizon: SoilHorizonEnum
    horizonMeth: String
    sieving: String
    waterContent: QuantityValue
    waterContSoilMeth: String
    poolDnaExtracts: String
    storeCond: String
    linkClimateInfo: String
    annualTemp: QuantityValue
    seasonTemp: QuantityValue
    annualPrecpt: QuantityValue
    seasonPrecpt: QuantityValue
    linkClassInfo: String
    faoClass: FaoClassEnum
    localClass: String
    localClassMeth: String
    orgNitro: QuantityValue
    soilType: String
    soilTypeMeth: String
    slopeGradient: QuantityValue
    slopeAspect: QuantityValue
    profilePosition: ProfilePositionEnum
    drainageClass: DrainageClassEnum
    soilTextMeasure: QuantityValue
    soilTextureMeth: String
    ph: Double
    phMeth: String
    orgMatter: QuantityValue
    totOrgCarb: QuantityValue
    totOrgCMeth: String
    totNitroContent: QuantityValue
    totNitroContMeth: String
    microbialBiomass: QuantityValue
    microBiomassMeth: String
    linkAdditAnalys: String
    salinityMeth: String
    heavyMetals: [String]
    heavyMetalsMeth: String
    alSat: QuantityValue
    alSatMeth: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    ploidy: String
    numReplicons: Integer
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    trophicLevel: TrophicLevelEnum
    propagation: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type SoilMIGSOrg implements MIGSOrg
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue!
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    curLandUse: CurLandUseEnum
    curVegetation: String
    curVegetationMeth: String
    previousLandUse: String
    prevLandUseMeth: String
    cropRotation: String
    agrochemAddition: [String]
    tillage: [TillageEnum]
    fire: Date
    flooding: Date
    extremeEvent: Date
    soilHorizon: SoilHorizonEnum
    horizonMeth: String
    sieving: String
    waterContent: QuantityValue
    waterContSoilMeth: String
    poolDnaExtracts: String
    storeCond: String
    linkClimateInfo: String
    annualTemp: QuantityValue
    seasonTemp: QuantityValue
    annualPrecpt: QuantityValue
    seasonPrecpt: QuantityValue
    linkClassInfo: String
    faoClass: FaoClassEnum
    localClass: String
    localClassMeth: String
    orgNitro: QuantityValue
    soilType: String
    soilTypeMeth: String
    slopeGradient: QuantityValue
    slopeAspect: QuantityValue
    profilePosition: ProfilePositionEnum
    drainageClass: DrainageClassEnum
    soilTextMeasure: QuantityValue
    soilTextureMeth: String
    ph: Double
    phMeth: String
    orgMatter: QuantityValue
    totOrgCarb: QuantityValue
    totOrgCMeth: String
    totNitroContent: QuantityValue
    totNitroContMeth: String
    microbialBiomass: QuantityValue
    microBiomassMeth: String
    linkAdditAnalys: String
    salinityMeth: String
    heavyMetals: [String]
    heavyMetalsMeth: String
    alSat: QuantityValue
    alSatMeth: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type SoilMIGSPlant implements MIGSPlant
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue!
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    curLandUse: CurLandUseEnum
    curVegetation: String
    curVegetationMeth: String
    previousLandUse: String
    prevLandUseMeth: String
    cropRotation: String
    agrochemAddition: [String]
    tillage: [TillageEnum]
    fire: Date
    flooding: Date
    extremeEvent: Date
    soilHorizon: SoilHorizonEnum
    horizonMeth: String
    sieving: String
    waterContent: QuantityValue
    waterContSoilMeth: String
    poolDnaExtracts: String
    storeCond: String
    linkClimateInfo: String
    annualTemp: QuantityValue
    seasonTemp: QuantityValue
    annualPrecpt: QuantityValue
    seasonPrecpt: QuantityValue
    linkClassInfo: String
    faoClass: FaoClassEnum
    localClass: String
    localClassMeth: String
    orgNitro: QuantityValue
    soilType: String
    soilTypeMeth: String
    slopeGradient: QuantityValue
    slopeAspect: QuantityValue
    profilePosition: ProfilePositionEnum
    drainageClass: DrainageClassEnum
    soilTextMeasure: QuantityValue
    soilTextureMeth: String
    ph: Double
    phMeth: String
    orgMatter: QuantityValue
    totOrgCarb: QuantityValue
    totOrgCMeth: String
    totNitroContent: QuantityValue
    totNitroContMeth: String
    microbialBiomass: QuantityValue
    microBiomassMeth: String
    linkAdditAnalys: String
    salinityMeth: String
    heavyMetals: [String]
    heavyMetalsMeth: String
    alSat: QuantityValue
    alSatMeth: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    specificHost: String
    hostSpecRange: Integer
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type SoilMIGSVirus implements MIGSVirus
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue!
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    curLandUse: CurLandUseEnum
    curVegetation: String
    curVegetationMeth: String
    previousLandUse: String
    prevLandUseMeth: String
    cropRotation: String
    agrochemAddition: [String]
    tillage: [TillageEnum]
    fire: Date
    flooding: Date
    extremeEvent: Date
    soilHorizon: SoilHorizonEnum
    horizonMeth: String
    sieving: String
    waterContent: QuantityValue
    waterContSoilMeth: String
    poolDnaExtracts: String
    storeCond: String
    linkClimateInfo: String
    annualTemp: QuantityValue
    seasonTemp: QuantityValue
    annualPrecpt: QuantityValue
    seasonPrecpt: QuantityValue
    linkClassInfo: String
    faoClass: FaoClassEnum
    localClass: String
    localClassMeth: String
    orgNitro: QuantityValue
    soilType: String
    soilTypeMeth: String
    slopeGradient: QuantityValue
    slopeAspect: QuantityValue
    profilePosition: ProfilePositionEnum
    drainageClass: DrainageClassEnum
    soilTextMeasure: QuantityValue
    soilTextureMeth: String
    ph: Double
    phMeth: String
    orgMatter: QuantityValue
    totOrgCarb: QuantityValue
    totOrgCMeth: String
    totNitroContent: QuantityValue
    totNitroContMeth: String
    microbialBiomass: QuantityValue
    microBiomassMeth: String
    linkAdditAnalys: String
    salinityMeth: String
    heavyMetals: [String]
    heavyMetalsMeth: String
    alSat: QuantityValue
    alSatMeth: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    virusEnrichAppr: VirusEnrichApprEnum
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type SoilMIMAG implements MIMAG
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue!
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    curLandUse: CurLandUseEnum
    curVegetation: String
    curVegetationMeth: String
    previousLandUse: String
    prevLandUseMeth: String
    cropRotation: String
    agrochemAddition: [String]
    tillage: [TillageEnum]
    fire: Date
    flooding: Date
    extremeEvent: Date
    soilHorizon: SoilHorizonEnum
    horizonMeth: String
    sieving: String
    waterContent: QuantityValue
    waterContSoilMeth: String
    poolDnaExtracts: String
    storeCond: String
    linkClimateInfo: String
    annualTemp: QuantityValue
    seasonTemp: QuantityValue
    annualPrecpt: QuantityValue
    seasonPrecpt: QuantityValue
    linkClassInfo: String
    faoClass: FaoClassEnum
    localClass: String
    localClassMeth: String
    orgNitro: QuantityValue
    soilType: String
    soilTypeMeth: String
    slopeGradient: QuantityValue
    slopeAspect: QuantityValue
    profilePosition: ProfilePositionEnum
    drainageClass: DrainageClassEnum
    soilTextMeasure: QuantityValue
    soilTextureMeth: String
    ph: Double
    phMeth: String
    orgMatter: QuantityValue
    totOrgCarb: QuantityValue
    totOrgCMeth: String
    totNitroContent: QuantityValue
    totNitroContMeth: String
    microbialBiomass: QuantityValue
    microBiomassMeth: String
    linkAdditAnalys: String
    salinityMeth: String
    heavyMetals: [String]
    heavyMetalsMeth: String
    alSat: QuantityValue
    alSatMeth: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    binParam: BinParamEnum!
    binSoftware: String!
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    associatedResource: String
    sop: String
  }

type SoilMIMARKSSpecimen implements MIMARKSSpecimen
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue!
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    curLandUse: CurLandUseEnum
    curVegetation: String
    curVegetationMeth: String
    previousLandUse: String
    prevLandUseMeth: String
    cropRotation: String
    agrochemAddition: [String]
    tillage: [TillageEnum]
    fire: Date
    flooding: Date
    extremeEvent: Date
    soilHorizon: SoilHorizonEnum
    horizonMeth: String
    sieving: String
    waterContent: QuantityValue
    waterContSoilMeth: String
    poolDnaExtracts: String
    storeCond: String
    linkClimateInfo: String
    annualTemp: QuantityValue
    seasonTemp: QuantityValue
    annualPrecpt: QuantityValue
    seasonPrecpt: QuantityValue
    linkClassInfo: String
    faoClass: FaoClassEnum
    localClass: String
    localClassMeth: String
    orgNitro: QuantityValue
    soilType: String
    soilTypeMeth: String
    slopeGradient: QuantityValue
    slopeAspect: QuantityValue
    profilePosition: ProfilePositionEnum
    drainageClass: DrainageClassEnum
    soilTextMeasure: QuantityValue
    soilTextureMeth: String
    ph: Double
    phMeth: String
    orgMatter: QuantityValue
    totOrgCarb: QuantityValue
    totOrgCMeth: String
    totNitroContent: QuantityValue
    totNitroContMeth: String
    microbialBiomass: QuantityValue
    microBiomassMeth: String
    linkAdditAnalys: String
    salinityMeth: String
    heavyMetals: [String]
    heavyMetalsMeth: String
    alSat: QuantityValue
    alSatMeth: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    mid: String
    adapters: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    assemblySoftware: String
    associatedResource: String
    sop: String
  }

type SoilMIMARKSSurvey implements MIMARKSSurvey
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue!
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    curLandUse: CurLandUseEnum
    curVegetation: String
    curVegetationMeth: String
    previousLandUse: String
    prevLandUseMeth: String
    cropRotation: String
    agrochemAddition: [String]
    tillage: [TillageEnum]
    fire: Date
    flooding: Date
    extremeEvent: Date
    soilHorizon: SoilHorizonEnum
    horizonMeth: String
    sieving: String
    waterContent: QuantityValue
    waterContSoilMeth: String
    poolDnaExtracts: String
    storeCond: String
    linkClimateInfo: String
    annualTemp: QuantityValue
    seasonTemp: QuantityValue
    annualPrecpt: QuantityValue
    seasonPrecpt: QuantityValue
    linkClassInfo: String
    faoClass: FaoClassEnum
    localClass: String
    localClassMeth: String
    orgNitro: QuantityValue
    soilType: String
    soilTypeMeth: String
    slopeGradient: QuantityValue
    slopeAspect: QuantityValue
    profilePosition: ProfilePositionEnum
    drainageClass: DrainageClassEnum
    soilTextMeasure: QuantityValue
    soilTextureMeth: String
    ph: Double
    phMeth: String
    orgMatter: QuantityValue
    totOrgCarb: QuantityValue
    totOrgCMeth: String
    totNitroContent: QuantityValue
    totNitroContMeth: String
    microbialBiomass: QuantityValue
    microBiomassMeth: String
    linkAdditAnalys: String
    salinityMeth: String
    heavyMetals: [String]
    heavyMetalsMeth: String
    alSat: QuantityValue
    alSatMeth: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    sourceMatId: String
    bioticRelationship: BioticRelationshipEnum
    trophicLevel: TrophicLevelEnum
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    associatedResource: String
    sop: String
  }

type SoilMIMS implements MIMS
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue!
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    curLandUse: CurLandUseEnum
    curVegetation: String
    curVegetationMeth: String
    previousLandUse: String
    prevLandUseMeth: String
    cropRotation: String
    agrochemAddition: [String]
    tillage: [TillageEnum]
    fire: Date
    flooding: Date
    extremeEvent: Date
    soilHorizon: SoilHorizonEnum
    horizonMeth: String
    sieving: String
    waterContent: QuantityValue
    waterContSoilMeth: String
    poolDnaExtracts: String
    storeCond: String
    linkClimateInfo: String
    annualTemp: QuantityValue
    seasonTemp: QuantityValue
    annualPrecpt: QuantityValue
    seasonPrecpt: QuantityValue
    linkClassInfo: String
    faoClass: FaoClassEnum
    localClass: String
    localClassMeth: String
    orgNitro: QuantityValue
    soilType: String
    soilTypeMeth: String
    slopeGradient: QuantityValue
    slopeAspect: QuantityValue
    profilePosition: ProfilePositionEnum
    drainageClass: DrainageClassEnum
    soilTextMeasure: QuantityValue
    soilTextureMeth: String
    ph: Double
    phMeth: String
    orgMatter: QuantityValue
    totOrgCarb: QuantityValue
    totOrgCMeth: String
    totNitroContent: QuantityValue
    totNitroContMeth: String
    microbialBiomass: QuantityValue
    microBiomassMeth: String
    linkAdditAnalys: String
    salinityMeth: String
    heavyMetals: [String]
    heavyMetalsMeth: String
    alSat: QuantityValue
    alSatMeth: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    associatedResource: String
    sop: String
  }

type SoilMISAG implements MISAG
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue!
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    curLandUse: CurLandUseEnum
    curVegetation: String
    curVegetationMeth: String
    previousLandUse: String
    prevLandUseMeth: String
    cropRotation: String
    agrochemAddition: [String]
    tillage: [TillageEnum]
    fire: Date
    flooding: Date
    extremeEvent: Date
    soilHorizon: SoilHorizonEnum
    horizonMeth: String
    sieving: String
    waterContent: QuantityValue
    waterContSoilMeth: String
    poolDnaExtracts: String
    storeCond: String
    linkClimateInfo: String
    annualTemp: QuantityValue
    seasonTemp: QuantityValue
    annualPrecpt: QuantityValue
    seasonPrecpt: QuantityValue
    linkClassInfo: String
    faoClass: FaoClassEnum
    localClass: String
    localClassMeth: String
    orgNitro: QuantityValue
    soilType: String
    soilTypeMeth: String
    slopeGradient: QuantityValue
    slopeAspect: QuantityValue
    profilePosition: ProfilePositionEnum
    drainageClass: DrainageClassEnum
    soilTextMeasure: QuantityValue
    soilTextureMeth: String
    ph: Double
    phMeth: String
    orgMatter: QuantityValue
    totOrgCarb: QuantityValue
    totOrgCMeth: String
    totNitroContent: QuantityValue
    totNitroContMeth: String
    microbialBiomass: QuantityValue
    microBiomassMeth: String
    linkAdditAnalys: String
    salinityMeth: String
    heavyMetals: [String]
    heavyMetalsMeth: String
    alSat: QuantityValue
    alSatMeth: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    sortTech: SortTechEnum!
    singleCellLysisAppr: SingleCellLysisApprEnum!
    singleCellLysisProt: String
    wgaAmpAppr: String!
    wgaAmpKit: String
    associatedResource: String
    sop: String
  }

type SoilMIUVIG implements MIUVIG
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue!
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    curLandUse: CurLandUseEnum
    curVegetation: String
    curVegetationMeth: String
    previousLandUse: String
    prevLandUseMeth: String
    cropRotation: String
    agrochemAddition: [String]
    tillage: [TillageEnum]
    fire: Date
    flooding: Date
    extremeEvent: Date
    soilHorizon: SoilHorizonEnum
    horizonMeth: String
    sieving: String
    waterContent: QuantityValue
    waterContSoilMeth: String
    poolDnaExtracts: String
    storeCond: String
    linkClimateInfo: String
    annualTemp: QuantityValue
    seasonTemp: QuantityValue
    annualPrecpt: QuantityValue
    seasonPrecpt: QuantityValue
    linkClassInfo: String
    faoClass: FaoClassEnum
    localClass: String
    localClassMeth: String
    orgNitro: QuantityValue
    soilType: String
    soilTypeMeth: String
    slopeGradient: QuantityValue
    slopeAspect: QuantityValue
    profilePosition: ProfilePositionEnum
    drainageClass: DrainageClassEnum
    soilTextMeasure: QuantityValue
    soilTextureMeth: String
    ph: Double
    phMeth: String
    orgMatter: QuantityValue
    totOrgCarb: QuantityValue
    totOrgCMeth: String
    totNitroContent: QuantityValue
    totNitroContMeth: String
    microbialBiomass: QuantityValue
    microBiomassMeth: String
    linkAdditAnalys: String
    salinityMeth: String
    heavyMetals: [String]
    heavyMetalsMeth: String
    alSat: QuantityValue
    alSatMeth: String
    miscParam: [String]
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    sourceUvig: SourceUvigEnum!
    virusEnrichAppr: VirusEnrichApprEnum!
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String
    complSoftware: String
    complAppr: ComplApprEnum
    sortTech: SortTechEnum
    singleCellLysisAppr: SingleCellLysisApprEnum
    singleCellLysisProt: String
    wgaAmpAppr: String
    wgaAmpKit: String
    binParam: BinParamEnum
    binSoftware: String
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    virIdentSoftware: String!
    predGenomeType: PredGenomeTypeEnum!
    predGenomeStruc: PredGenomeStrucEnum!
    detecType: String!
    otuClassAppr: String
    otuSeqCompAppr: String
    otuDb: String
    hostPredAppr: HostPredApprEnum
    hostPredEstAcc: String
    associatedResource: String
    sop: String
  }

type Symbiont-associated
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampleName: String!
    hostSubjectId: String
    hostCommonName: String
    hostTaxid: String
    hostDependence: String!
    typeOfSymbiosis: TypeOfSymbiosisEnum
    symLifeCycleType: String!
    hostLifeStage: String!
    hostAge: QuantityValue
    hostSex: HostSexEnum
    modeTransmission: ModeTransmissionEnum
    routeTransmission: RouteTransmissionEnum
    hostBodyHabitat: String
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostGrowthCond: String
    hostSubstrate: String
    hostFamilyRelationship: String
    hostInfraSpecificName: String
    hostInfraSpecificRank: String
    hostGenotype: String
    hostPhenotype: String
    hostDryMass: QuantityValue
    hostColor: String
    hostShape: String
    gravidity: String
    hostNumber: String
    hostSymbiont: [String]
    hostSpecificity: HostSpecificityEnum
    symbiontHostRole: SymbiontHostRoleEnum
    hostCellularLoc: HostCellularLocEnum
    associationDuration: QuantityValue
    hostOfHostCoinf: String
    hostOfHostName: String
    hostOfHostEnvLoc: [String]
    hostOfHostEnvMed: String
    hostOfHostTaxid: Integer
    hostOfHostSubId: String
    hostOfHostDisease: [String]
    hostOfHostFamRel: [String]
    hostOfHostInfname: String
    hostOfHostInfrank: String
    hostOfHostGeno: String
    hostOfHostPheno: String
    hostOfHostGravid: String
    hostOfHostTotmass: QuantityValue
    chemAdministration: [String]
    perturbation: [String]
    sampSalinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreSol: String
    miscParam: [String]
    projectName: String!
    sourceMatId: String
    sampVolWeDnaExt: QuantityValue
  }

type Symbiont-associatedMIGSBacteria implements MIGSBacteria
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampleName: String!
    hostSubjectId: String
    hostCommonName: String
    hostTaxid: String
    hostDependence: String!
    typeOfSymbiosis: TypeOfSymbiosisEnum
    symLifeCycleType: String!
    hostLifeStage: String!
    hostAge: QuantityValue
    hostSex: HostSexEnum
    modeTransmission: ModeTransmissionEnum
    routeTransmission: RouteTransmissionEnum
    hostBodyHabitat: String
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostGrowthCond: String
    hostSubstrate: String
    hostFamilyRelationship: String
    hostInfraSpecificName: String
    hostInfraSpecificRank: String
    hostGenotype: String
    hostPhenotype: String
    hostDryMass: QuantityValue
    hostColor: String
    hostShape: String
    gravidity: String
    hostNumber: String
    hostSymbiont: [String]
    hostSpecificity: HostSpecificityEnum
    symbiontHostRole: SymbiontHostRoleEnum
    hostCellularLoc: HostCellularLocEnum
    associationDuration: QuantityValue
    hostOfHostCoinf: String
    hostOfHostName: String
    hostOfHostEnvLoc: [String]
    hostOfHostEnvMed: String
    hostOfHostTaxid: Integer
    hostOfHostSubId: String
    hostOfHostDisease: [String]
    hostOfHostFamRel: [String]
    hostOfHostInfname: String
    hostOfHostInfrank: String
    hostOfHostGeno: String
    hostOfHostPheno: String
    hostOfHostGravid: String
    hostOfHostTotmass: QuantityValue
    chemAdministration: [String]
    perturbation: [String]
    sampSalinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreSol: String
    miscParam: [String]
    projectName: String!
    sourceMatId: String
    sampVolWeDnaExt: QuantityValue
    sampName: String!
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer!
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String!
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    trophicLevel: TrophicLevelEnum
    encodedTraits: String
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Symbiont-associatedMIGSEukaryote implements MIGSEukaryote
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampleName: String!
    hostSubjectId: String
    hostCommonName: String
    hostTaxid: String
    hostDependence: String!
    typeOfSymbiosis: TypeOfSymbiosisEnum
    symLifeCycleType: String!
    hostLifeStage: String!
    hostAge: QuantityValue
    hostSex: HostSexEnum
    modeTransmission: ModeTransmissionEnum
    routeTransmission: RouteTransmissionEnum
    hostBodyHabitat: String
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostGrowthCond: String
    hostSubstrate: String
    hostFamilyRelationship: String
    hostInfraSpecificName: String
    hostInfraSpecificRank: String
    hostGenotype: String
    hostPhenotype: String
    hostDryMass: QuantityValue
    hostColor: String
    hostShape: String
    gravidity: String
    hostNumber: String
    hostSymbiont: [String]
    hostSpecificity: HostSpecificityEnum
    symbiontHostRole: SymbiontHostRoleEnum
    hostCellularLoc: HostCellularLocEnum
    associationDuration: QuantityValue
    hostOfHostCoinf: String
    hostOfHostName: String
    hostOfHostEnvLoc: [String]
    hostOfHostEnvMed: String
    hostOfHostTaxid: Integer
    hostOfHostSubId: String
    hostOfHostDisease: [String]
    hostOfHostFamRel: [String]
    hostOfHostInfname: String
    hostOfHostInfrank: String
    hostOfHostGeno: String
    hostOfHostPheno: String
    hostOfHostGravid: String
    hostOfHostTotmass: QuantityValue
    chemAdministration: [String]
    perturbation: [String]
    sampSalinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreSol: String
    miscParam: [String]
    projectName: String!
    sourceMatId: String
    sampVolWeDnaExt: QuantityValue
    sampName: String!
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    ploidy: String
    numReplicons: Integer
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    trophicLevel: TrophicLevelEnum
    propagation: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Symbiont-associatedMIGSOrg implements MIGSOrg
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampleName: String!
    hostSubjectId: String
    hostCommonName: String
    hostTaxid: String
    hostDependence: String!
    typeOfSymbiosis: TypeOfSymbiosisEnum
    symLifeCycleType: String!
    hostLifeStage: String!
    hostAge: QuantityValue
    hostSex: HostSexEnum
    modeTransmission: ModeTransmissionEnum
    routeTransmission: RouteTransmissionEnum
    hostBodyHabitat: String
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostGrowthCond: String
    hostSubstrate: String
    hostFamilyRelationship: String
    hostInfraSpecificName: String
    hostInfraSpecificRank: String
    hostGenotype: String
    hostPhenotype: String
    hostDryMass: QuantityValue
    hostColor: String
    hostShape: String
    gravidity: String
    hostNumber: String
    hostSymbiont: [String]
    hostSpecificity: HostSpecificityEnum
    symbiontHostRole: SymbiontHostRoleEnum
    hostCellularLoc: HostCellularLocEnum
    associationDuration: QuantityValue
    hostOfHostCoinf: String
    hostOfHostName: String
    hostOfHostEnvLoc: [String]
    hostOfHostEnvMed: String
    hostOfHostTaxid: Integer
    hostOfHostSubId: String
    hostOfHostDisease: [String]
    hostOfHostFamRel: [String]
    hostOfHostInfname: String
    hostOfHostInfrank: String
    hostOfHostGeno: String
    hostOfHostPheno: String
    hostOfHostGravid: String
    hostOfHostTotmass: QuantityValue
    chemAdministration: [String]
    perturbation: [String]
    sampSalinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreSol: String
    miscParam: [String]
    projectName: String!
    sourceMatId: String
    sampVolWeDnaExt: QuantityValue
    sampName: String!
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Symbiont-associatedMIGSPlant implements MIGSPlant
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampleName: String!
    hostSubjectId: String
    hostCommonName: String
    hostTaxid: String
    hostDependence: String!
    typeOfSymbiosis: TypeOfSymbiosisEnum
    symLifeCycleType: String!
    hostLifeStage: String!
    hostAge: QuantityValue
    hostSex: HostSexEnum
    modeTransmission: ModeTransmissionEnum
    routeTransmission: RouteTransmissionEnum
    hostBodyHabitat: String
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostGrowthCond: String
    hostSubstrate: String
    hostFamilyRelationship: String
    hostInfraSpecificName: String
    hostInfraSpecificRank: String
    hostGenotype: String
    hostPhenotype: String
    hostDryMass: QuantityValue
    hostColor: String
    hostShape: String
    gravidity: String
    hostNumber: String
    hostSymbiont: [String]
    hostSpecificity: HostSpecificityEnum
    symbiontHostRole: SymbiontHostRoleEnum
    hostCellularLoc: HostCellularLocEnum
    associationDuration: QuantityValue
    hostOfHostCoinf: String
    hostOfHostName: String
    hostOfHostEnvLoc: [String]
    hostOfHostEnvMed: String
    hostOfHostTaxid: Integer
    hostOfHostSubId: String
    hostOfHostDisease: [String]
    hostOfHostFamRel: [String]
    hostOfHostInfname: String
    hostOfHostInfrank: String
    hostOfHostGeno: String
    hostOfHostPheno: String
    hostOfHostGravid: String
    hostOfHostTotmass: QuantityValue
    chemAdministration: [String]
    perturbation: [String]
    sampSalinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreSol: String
    miscParam: [String]
    projectName: String!
    sourceMatId: String
    sampVolWeDnaExt: QuantityValue
    sampName: String!
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    estimatedSize: String
    refBiomaterial: String
    specificHost: String
    hostSpecRange: Integer
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Symbiont-associatedMIGSVirus implements MIGSVirus
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampleName: String!
    hostSubjectId: String
    hostCommonName: String
    hostTaxid: String
    hostDependence: String!
    typeOfSymbiosis: TypeOfSymbiosisEnum
    symLifeCycleType: String!
    hostLifeStage: String!
    hostAge: QuantityValue
    hostSex: HostSexEnum
    modeTransmission: ModeTransmissionEnum
    routeTransmission: RouteTransmissionEnum
    hostBodyHabitat: String
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostGrowthCond: String
    hostSubstrate: String
    hostFamilyRelationship: String
    hostInfraSpecificName: String
    hostInfraSpecificRank: String
    hostGenotype: String
    hostPhenotype: String
    hostDryMass: QuantityValue
    hostColor: String
    hostShape: String
    gravidity: String
    hostNumber: String
    hostSymbiont: [String]
    hostSpecificity: HostSpecificityEnum
    symbiontHostRole: SymbiontHostRoleEnum
    hostCellularLoc: HostCellularLocEnum
    associationDuration: QuantityValue
    hostOfHostCoinf: String
    hostOfHostName: String
    hostOfHostEnvLoc: [String]
    hostOfHostEnvMed: String
    hostOfHostTaxid: Integer
    hostOfHostSubId: String
    hostOfHostDisease: [String]
    hostOfHostFamRel: [String]
    hostOfHostInfname: String
    hostOfHostInfrank: String
    hostOfHostGeno: String
    hostOfHostPheno: String
    hostOfHostGravid: String
    hostOfHostTotmass: QuantityValue
    chemAdministration: [String]
    perturbation: [String]
    sampSalinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreSol: String
    miscParam: [String]
    projectName: String!
    sourceMatId: String
    sampVolWeDnaExt: QuantityValue
    sampName: String!
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer
    estimatedSize: String
    refBiomaterial: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    virusEnrichAppr: VirusEnrichApprEnum
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type Symbiont-associatedMIMAG implements MIMAG
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampleName: String!
    hostSubjectId: String
    hostCommonName: String
    hostTaxid: String
    hostDependence: String!
    typeOfSymbiosis: TypeOfSymbiosisEnum
    symLifeCycleType: String!
    hostLifeStage: String!
    hostAge: QuantityValue
    hostSex: HostSexEnum
    modeTransmission: ModeTransmissionEnum
    routeTransmission: RouteTransmissionEnum
    hostBodyHabitat: String
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostGrowthCond: String
    hostSubstrate: String
    hostFamilyRelationship: String
    hostInfraSpecificName: String
    hostInfraSpecificRank: String
    hostGenotype: String
    hostPhenotype: String
    hostDryMass: QuantityValue
    hostColor: String
    hostShape: String
    gravidity: String
    hostNumber: String
    hostSymbiont: [String]
    hostSpecificity: HostSpecificityEnum
    symbiontHostRole: SymbiontHostRoleEnum
    hostCellularLoc: HostCellularLocEnum
    associationDuration: QuantityValue
    hostOfHostCoinf: String
    hostOfHostName: String
    hostOfHostEnvLoc: [String]
    hostOfHostEnvMed: String
    hostOfHostTaxid: Integer
    hostOfHostSubId: String
    hostOfHostDisease: [String]
    hostOfHostFamRel: [String]
    hostOfHostInfname: String
    hostOfHostInfrank: String
    hostOfHostGeno: String
    hostOfHostPheno: String
    hostOfHostGravid: String
    hostOfHostTotmass: QuantityValue
    chemAdministration: [String]
    perturbation: [String]
    sampSalinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreSol: String
    miscParam: [String]
    projectName: String!
    sourceMatId: String
    sampVolWeDnaExt: QuantityValue
    sampName: String!
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    binParam: BinParamEnum!
    binSoftware: String!
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    associatedResource: String
    sop: String
  }

type Symbiont-associatedMIMARKSSpecimen implements MIMARKSSpecimen
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampleName: String!
    hostSubjectId: String
    hostCommonName: String
    hostTaxid: String
    hostDependence: String!
    typeOfSymbiosis: TypeOfSymbiosisEnum
    symLifeCycleType: String!
    hostLifeStage: String!
    hostAge: QuantityValue
    hostSex: HostSexEnum
    modeTransmission: ModeTransmissionEnum
    routeTransmission: RouteTransmissionEnum
    hostBodyHabitat: String
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostGrowthCond: String
    hostSubstrate: String
    hostFamilyRelationship: String
    hostInfraSpecificName: String
    hostInfraSpecificRank: String
    hostGenotype: String
    hostPhenotype: String
    hostDryMass: QuantityValue
    hostColor: String
    hostShape: String
    gravidity: String
    hostNumber: String
    hostSymbiont: [String]
    hostSpecificity: HostSpecificityEnum
    symbiontHostRole: SymbiontHostRoleEnum
    hostCellularLoc: HostCellularLocEnum
    associationDuration: QuantityValue
    hostOfHostCoinf: String
    hostOfHostName: String
    hostOfHostEnvLoc: [String]
    hostOfHostEnvMed: String
    hostOfHostTaxid: Integer
    hostOfHostSubId: String
    hostOfHostDisease: [String]
    hostOfHostFamRel: [String]
    hostOfHostInfname: String
    hostOfHostInfrank: String
    hostOfHostGeno: String
    hostOfHostPheno: String
    hostOfHostGravid: String
    hostOfHostTotmass: QuantityValue
    chemAdministration: [String]
    perturbation: [String]
    sampSalinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreSol: String
    miscParam: [String]
    projectName: String!
    sourceMatId: String
    sampVolWeDnaExt: QuantityValue
    sampName: String!
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    mid: String
    adapters: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    assemblySoftware: String
    associatedResource: String
    sop: String
  }

type Symbiont-associatedMIMARKSSurvey implements MIMARKSSurvey
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampleName: String!
    hostSubjectId: String
    hostCommonName: String
    hostTaxid: String
    hostDependence: String!
    typeOfSymbiosis: TypeOfSymbiosisEnum
    symLifeCycleType: String!
    hostLifeStage: String!
    hostAge: QuantityValue
    hostSex: HostSexEnum
    modeTransmission: ModeTransmissionEnum
    routeTransmission: RouteTransmissionEnum
    hostBodyHabitat: String
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostGrowthCond: String
    hostSubstrate: String
    hostFamilyRelationship: String
    hostInfraSpecificName: String
    hostInfraSpecificRank: String
    hostGenotype: String
    hostPhenotype: String
    hostDryMass: QuantityValue
    hostColor: String
    hostShape: String
    gravidity: String
    hostNumber: String
    hostSymbiont: [String]
    hostSpecificity: HostSpecificityEnum
    symbiontHostRole: SymbiontHostRoleEnum
    hostCellularLoc: HostCellularLocEnum
    associationDuration: QuantityValue
    hostOfHostCoinf: String
    hostOfHostName: String
    hostOfHostEnvLoc: [String]
    hostOfHostEnvMed: String
    hostOfHostTaxid: Integer
    hostOfHostSubId: String
    hostOfHostDisease: [String]
    hostOfHostFamRel: [String]
    hostOfHostInfname: String
    hostOfHostInfrank: String
    hostOfHostGeno: String
    hostOfHostPheno: String
    hostOfHostGravid: String
    hostOfHostTotmass: QuantityValue
    chemAdministration: [String]
    perturbation: [String]
    sampSalinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreSol: String
    miscParam: [String]
    projectName: String!
    sourceMatId: String
    sampVolWeDnaExt: QuantityValue
    sampName: String!
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    bioticRelationship: BioticRelationshipEnum
    trophicLevel: TrophicLevelEnum
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    associatedResource: String
    sop: String
  }

type Symbiont-associatedMIMS implements MIMS
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampleName: String!
    hostSubjectId: String
    hostCommonName: String
    hostTaxid: String
    hostDependence: String!
    typeOfSymbiosis: TypeOfSymbiosisEnum
    symLifeCycleType: String!
    hostLifeStage: String!
    hostAge: QuantityValue
    hostSex: HostSexEnum
    modeTransmission: ModeTransmissionEnum
    routeTransmission: RouteTransmissionEnum
    hostBodyHabitat: String
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostGrowthCond: String
    hostSubstrate: String
    hostFamilyRelationship: String
    hostInfraSpecificName: String
    hostInfraSpecificRank: String
    hostGenotype: String
    hostPhenotype: String
    hostDryMass: QuantityValue
    hostColor: String
    hostShape: String
    gravidity: String
    hostNumber: String
    hostSymbiont: [String]
    hostSpecificity: HostSpecificityEnum
    symbiontHostRole: SymbiontHostRoleEnum
    hostCellularLoc: HostCellularLocEnum
    associationDuration: QuantityValue
    hostOfHostCoinf: String
    hostOfHostName: String
    hostOfHostEnvLoc: [String]
    hostOfHostEnvMed: String
    hostOfHostTaxid: Integer
    hostOfHostSubId: String
    hostOfHostDisease: [String]
    hostOfHostFamRel: [String]
    hostOfHostInfname: String
    hostOfHostInfrank: String
    hostOfHostGeno: String
    hostOfHostPheno: String
    hostOfHostGravid: String
    hostOfHostTotmass: QuantityValue
    chemAdministration: [String]
    perturbation: [String]
    sampSalinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreSol: String
    miscParam: [String]
    projectName: String!
    sourceMatId: String
    sampVolWeDnaExt: QuantityValue
    sampName: String!
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    associatedResource: String
    sop: String
  }

type Symbiont-associatedMISAG implements MISAG
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampleName: String!
    hostSubjectId: String
    hostCommonName: String
    hostTaxid: String
    hostDependence: String!
    typeOfSymbiosis: TypeOfSymbiosisEnum
    symLifeCycleType: String!
    hostLifeStage: String!
    hostAge: QuantityValue
    hostSex: HostSexEnum
    modeTransmission: ModeTransmissionEnum
    routeTransmission: RouteTransmissionEnum
    hostBodyHabitat: String
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostGrowthCond: String
    hostSubstrate: String
    hostFamilyRelationship: String
    hostInfraSpecificName: String
    hostInfraSpecificRank: String
    hostGenotype: String
    hostPhenotype: String
    hostDryMass: QuantityValue
    hostColor: String
    hostShape: String
    gravidity: String
    hostNumber: String
    hostSymbiont: [String]
    hostSpecificity: HostSpecificityEnum
    symbiontHostRole: SymbiontHostRoleEnum
    hostCellularLoc: HostCellularLocEnum
    associationDuration: QuantityValue
    hostOfHostCoinf: String
    hostOfHostName: String
    hostOfHostEnvLoc: [String]
    hostOfHostEnvMed: String
    hostOfHostTaxid: Integer
    hostOfHostSubId: String
    hostOfHostDisease: [String]
    hostOfHostFamRel: [String]
    hostOfHostInfname: String
    hostOfHostInfrank: String
    hostOfHostGeno: String
    hostOfHostPheno: String
    hostOfHostGravid: String
    hostOfHostTotmass: QuantityValue
    chemAdministration: [String]
    perturbation: [String]
    sampSalinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreSol: String
    miscParam: [String]
    projectName: String!
    sourceMatId: String
    sampVolWeDnaExt: QuantityValue
    sampName: String!
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    sortTech: SortTechEnum!
    singleCellLysisAppr: SingleCellLysisApprEnum!
    singleCellLysisProt: String
    wgaAmpAppr: String!
    wgaAmpKit: String
    associatedResource: String
    sop: String
  }

type Symbiont-associatedMIUVIG implements MIUVIG
  {
    latLon: String!
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String!
    collectionDate: Date!
    envBroadScale: String!
    envLocalScale: String!
    envMedium: String!
    sampleName: String!
    hostSubjectId: String
    hostCommonName: String
    hostTaxid: String
    hostDependence: String!
    typeOfSymbiosis: TypeOfSymbiosisEnum
    symLifeCycleType: String!
    hostLifeStage: String!
    hostAge: QuantityValue
    hostSex: HostSexEnum
    modeTransmission: ModeTransmissionEnum
    routeTransmission: RouteTransmissionEnum
    hostBodyHabitat: String
    hostBodySite: String
    hostBodyProduct: String
    hostTotMass: QuantityValue
    hostHeight: QuantityValue
    hostLength: QuantityValue
    hostGrowthCond: String
    hostSubstrate: String
    hostFamilyRelationship: String
    hostInfraSpecificName: String
    hostInfraSpecificRank: String
    hostGenotype: String
    hostPhenotype: String
    hostDryMass: QuantityValue
    hostColor: String
    hostShape: String
    gravidity: String
    hostNumber: String
    hostSymbiont: [String]
    hostSpecificity: HostSpecificityEnum
    symbiontHostRole: SymbiontHostRoleEnum
    hostCellularLoc: HostCellularLocEnum
    associationDuration: QuantityValue
    hostOfHostCoinf: String
    hostOfHostName: String
    hostOfHostEnvLoc: [String]
    hostOfHostEnvMed: String
    hostOfHostTaxid: Integer
    hostOfHostSubId: String
    hostOfHostDisease: [String]
    hostOfHostFamRel: [String]
    hostOfHostInfname: String
    hostOfHostInfrank: String
    hostOfHostGeno: String
    hostOfHostPheno: String
    hostOfHostGravid: String
    hostOfHostTotmass: QuantityValue
    chemAdministration: [String]
    perturbation: [String]
    sampSalinity: QuantityValue
    oxyStatSamp: OxyStatSampEnum
    organismCount: [OrganismCountEnum]
    sampStoreTemp: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreSol: String
    miscParam: [String]
    projectName: String!
    sourceMatId: String
    sampVolWeDnaExt: QuantityValue
    sampName: String!
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    estimatedSize: String
    refBiomaterial: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    sourceUvig: SourceUvigEnum!
    virusEnrichAppr: VirusEnrichApprEnum!
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String
    complSoftware: String
    complAppr: ComplApprEnum
    sortTech: SortTechEnum
    singleCellLysisAppr: SingleCellLysisApprEnum
    singleCellLysisProt: String
    wgaAmpAppr: String
    wgaAmpKit: String
    binParam: BinParamEnum
    binSoftware: String
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    virIdentSoftware: String!
    predGenomeType: PredGenomeTypeEnum!
    predGenomeStruc: PredGenomeStrucEnum!
    detecType: String!
    otuClassAppr: String
    otuSeqCompAppr: String
    otuDb: String
    hostPredAppr: HostPredApprEnum
    hostPredEstAcc: String
    associatedResource: String
    sop: String
  }

type WastewaterSludge
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    biochemOxygenDem: QuantityValue
    chemAdministration: [String]
    chemOxygenDem: QuantityValue
    efficiencyPercent: QuantityValue
    emulsions: [String]
    gaseousSubstances: [String]
    industEffPercent: QuantityValue
    inorgParticles: [String]
    miscParam: [String]
    nitrate: QuantityValue
    orgParticles: [String]
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    perturbation: [String]
    phosphate: QuantityValue
    preTreatment: String
    primaryTreatment: String
    reactorType: String
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    secondaryTreatment: String
    sewageType: String
    sludgeRetentTime: QuantityValue
    sodium: QuantityValue
    solubleInorgMat: [String]
    solubleOrgMat: [String]
    suspendSolids: [String]
    tertiaryTreatment: String
    totNitro: QuantityValue
    totPhosphate: QuantityValue
    wastewaterType: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
  }

type WastewaterSludgeMIGSBacteria implements MIGSBacteria
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    biochemOxygenDem: QuantityValue
    chemAdministration: [String]
    chemOxygenDem: QuantityValue
    efficiencyPercent: QuantityValue
    emulsions: [String]
    gaseousSubstances: [String]
    industEffPercent: QuantityValue
    inorgParticles: [String]
    miscParam: [String]
    nitrate: QuantityValue
    orgParticles: [String]
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    perturbation: [String]
    phosphate: QuantityValue
    preTreatment: String
    primaryTreatment: String
    reactorType: String
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    secondaryTreatment: String
    sewageType: String
    sludgeRetentTime: QuantityValue
    sodium: QuantityValue
    solubleInorgMat: [String]
    solubleOrgMat: [String]
    suspendSolids: [String]
    tertiaryTreatment: String
    totNitro: QuantityValue
    totPhosphate: QuantityValue
    wastewaterType: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer!
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String!
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    trophicLevel: TrophicLevelEnum
    encodedTraits: String
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type WastewaterSludgeMIGSEukaryote implements MIGSEukaryote
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    biochemOxygenDem: QuantityValue
    chemAdministration: [String]
    chemOxygenDem: QuantityValue
    efficiencyPercent: QuantityValue
    emulsions: [String]
    gaseousSubstances: [String]
    industEffPercent: QuantityValue
    inorgParticles: [String]
    miscParam: [String]
    nitrate: QuantityValue
    orgParticles: [String]
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    perturbation: [String]
    phosphate: QuantityValue
    preTreatment: String
    primaryTreatment: String
    reactorType: String
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    secondaryTreatment: String
    sewageType: String
    sludgeRetentTime: QuantityValue
    sodium: QuantityValue
    solubleInorgMat: [String]
    solubleOrgMat: [String]
    suspendSolids: [String]
    tertiaryTreatment: String
    totNitro: QuantityValue
    totPhosphate: QuantityValue
    wastewaterType: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    ploidy: String
    numReplicons: Integer
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    trophicLevel: TrophicLevelEnum
    propagation: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type WastewaterSludgeMIGSOrg implements MIGSOrg
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    biochemOxygenDem: QuantityValue
    chemAdministration: [String]
    chemOxygenDem: QuantityValue
    efficiencyPercent: QuantityValue
    emulsions: [String]
    gaseousSubstances: [String]
    industEffPercent: QuantityValue
    inorgParticles: [String]
    miscParam: [String]
    nitrate: QuantityValue
    orgParticles: [String]
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    perturbation: [String]
    phosphate: QuantityValue
    preTreatment: String
    primaryTreatment: String
    reactorType: String
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    secondaryTreatment: String
    sewageType: String
    sludgeRetentTime: QuantityValue
    sodium: QuantityValue
    solubleInorgMat: [String]
    solubleOrgMat: [String]
    suspendSolids: [String]
    tertiaryTreatment: String
    totNitro: QuantityValue
    totPhosphate: QuantityValue
    wastewaterType: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type WastewaterSludgeMIGSPlant implements MIGSPlant
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    biochemOxygenDem: QuantityValue
    chemAdministration: [String]
    chemOxygenDem: QuantityValue
    efficiencyPercent: QuantityValue
    emulsions: [String]
    gaseousSubstances: [String]
    industEffPercent: QuantityValue
    inorgParticles: [String]
    miscParam: [String]
    nitrate: QuantityValue
    orgParticles: [String]
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    perturbation: [String]
    phosphate: QuantityValue
    preTreatment: String
    primaryTreatment: String
    reactorType: String
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    secondaryTreatment: String
    sewageType: String
    sludgeRetentTime: QuantityValue
    sodium: QuantityValue
    solubleInorgMat: [String]
    solubleOrgMat: [String]
    suspendSolids: [String]
    tertiaryTreatment: String
    totNitro: QuantityValue
    totPhosphate: QuantityValue
    wastewaterType: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    specificHost: String
    hostSpecRange: Integer
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type WastewaterSludgeMIGSVirus implements MIGSVirus
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    biochemOxygenDem: QuantityValue
    chemAdministration: [String]
    chemOxygenDem: QuantityValue
    efficiencyPercent: QuantityValue
    emulsions: [String]
    gaseousSubstances: [String]
    industEffPercent: QuantityValue
    inorgParticles: [String]
    miscParam: [String]
    nitrate: QuantityValue
    orgParticles: [String]
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    perturbation: [String]
    phosphate: QuantityValue
    preTreatment: String
    primaryTreatment: String
    reactorType: String
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    secondaryTreatment: String
    sewageType: String
    sludgeRetentTime: QuantityValue
    sodium: QuantityValue
    solubleInorgMat: [String]
    solubleOrgMat: [String]
    suspendSolids: [String]
    tertiaryTreatment: String
    totNitro: QuantityValue
    totPhosphate: QuantityValue
    wastewaterType: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    virusEnrichAppr: VirusEnrichApprEnum
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type WastewaterSludgeMIMAG implements MIMAG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    biochemOxygenDem: QuantityValue
    chemAdministration: [String]
    chemOxygenDem: QuantityValue
    efficiencyPercent: QuantityValue
    emulsions: [String]
    gaseousSubstances: [String]
    industEffPercent: QuantityValue
    inorgParticles: [String]
    miscParam: [String]
    nitrate: QuantityValue
    orgParticles: [String]
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    perturbation: [String]
    phosphate: QuantityValue
    preTreatment: String
    primaryTreatment: String
    reactorType: String
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    secondaryTreatment: String
    sewageType: String
    sludgeRetentTime: QuantityValue
    sodium: QuantityValue
    solubleInorgMat: [String]
    solubleOrgMat: [String]
    suspendSolids: [String]
    tertiaryTreatment: String
    totNitro: QuantityValue
    totPhosphate: QuantityValue
    wastewaterType: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    binParam: BinParamEnum!
    binSoftware: String!
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    associatedResource: String
    sop: String
  }

type WastewaterSludgeMIMARKSSpecimen implements MIMARKSSpecimen
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    biochemOxygenDem: QuantityValue
    chemAdministration: [String]
    chemOxygenDem: QuantityValue
    efficiencyPercent: QuantityValue
    emulsions: [String]
    gaseousSubstances: [String]
    industEffPercent: QuantityValue
    inorgParticles: [String]
    miscParam: [String]
    nitrate: QuantityValue
    orgParticles: [String]
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    perturbation: [String]
    phosphate: QuantityValue
    preTreatment: String
    primaryTreatment: String
    reactorType: String
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    secondaryTreatment: String
    sewageType: String
    sludgeRetentTime: QuantityValue
    sodium: QuantityValue
    solubleInorgMat: [String]
    solubleOrgMat: [String]
    suspendSolids: [String]
    tertiaryTreatment: String
    totNitro: QuantityValue
    totPhosphate: QuantityValue
    wastewaterType: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    mid: String
    adapters: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    assemblySoftware: String
    associatedResource: String
    sop: String
  }

type WastewaterSludgeMIMARKSSurvey implements MIMARKSSurvey
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    biochemOxygenDem: QuantityValue
    chemAdministration: [String]
    chemOxygenDem: QuantityValue
    efficiencyPercent: QuantityValue
    emulsions: [String]
    gaseousSubstances: [String]
    industEffPercent: QuantityValue
    inorgParticles: [String]
    miscParam: [String]
    nitrate: QuantityValue
    orgParticles: [String]
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    perturbation: [String]
    phosphate: QuantityValue
    preTreatment: String
    primaryTreatment: String
    reactorType: String
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    secondaryTreatment: String
    sewageType: String
    sludgeRetentTime: QuantityValue
    sodium: QuantityValue
    solubleInorgMat: [String]
    solubleOrgMat: [String]
    suspendSolids: [String]
    tertiaryTreatment: String
    totNitro: QuantityValue
    totPhosphate: QuantityValue
    wastewaterType: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    sourceMatId: String
    bioticRelationship: BioticRelationshipEnum
    trophicLevel: TrophicLevelEnum
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    associatedResource: String
    sop: String
  }

type WastewaterSludgeMIMS implements MIMS
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    biochemOxygenDem: QuantityValue
    chemAdministration: [String]
    chemOxygenDem: QuantityValue
    efficiencyPercent: QuantityValue
    emulsions: [String]
    gaseousSubstances: [String]
    industEffPercent: QuantityValue
    inorgParticles: [String]
    miscParam: [String]
    nitrate: QuantityValue
    orgParticles: [String]
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    perturbation: [String]
    phosphate: QuantityValue
    preTreatment: String
    primaryTreatment: String
    reactorType: String
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    secondaryTreatment: String
    sewageType: String
    sludgeRetentTime: QuantityValue
    sodium: QuantityValue
    solubleInorgMat: [String]
    solubleOrgMat: [String]
    suspendSolids: [String]
    tertiaryTreatment: String
    totNitro: QuantityValue
    totPhosphate: QuantityValue
    wastewaterType: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    associatedResource: String
    sop: String
  }

type WastewaterSludgeMISAG implements MISAG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    biochemOxygenDem: QuantityValue
    chemAdministration: [String]
    chemOxygenDem: QuantityValue
    efficiencyPercent: QuantityValue
    emulsions: [String]
    gaseousSubstances: [String]
    industEffPercent: QuantityValue
    inorgParticles: [String]
    miscParam: [String]
    nitrate: QuantityValue
    orgParticles: [String]
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    perturbation: [String]
    phosphate: QuantityValue
    preTreatment: String
    primaryTreatment: String
    reactorType: String
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    secondaryTreatment: String
    sewageType: String
    sludgeRetentTime: QuantityValue
    sodium: QuantityValue
    solubleInorgMat: [String]
    solubleOrgMat: [String]
    suspendSolids: [String]
    tertiaryTreatment: String
    totNitro: QuantityValue
    totPhosphate: QuantityValue
    wastewaterType: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    sortTech: SortTechEnum!
    singleCellLysisAppr: SingleCellLysisApprEnum!
    singleCellLysisProt: String
    wgaAmpAppr: String!
    wgaAmpKit: String
    associatedResource: String
    sop: String
  }

type WastewaterSludgeMIUVIG implements MIUVIG
  {
    latLon: String
    depth: QuantityValue
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    biochemOxygenDem: QuantityValue
    chemAdministration: [String]
    chemOxygenDem: QuantityValue
    efficiencyPercent: QuantityValue
    emulsions: [String]
    gaseousSubstances: [String]
    industEffPercent: QuantityValue
    inorgParticles: [String]
    miscParam: [String]
    nitrate: QuantityValue
    orgParticles: [String]
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    perturbation: [String]
    phosphate: QuantityValue
    preTreatment: String
    primaryTreatment: String
    reactorType: String
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    secondaryTreatment: String
    sewageType: String
    sludgeRetentTime: QuantityValue
    sodium: QuantityValue
    solubleInorgMat: [String]
    solubleOrgMat: [String]
    suspendSolids: [String]
    tertiaryTreatment: String
    totNitro: QuantityValue
    totPhosphate: QuantityValue
    wastewaterType: String
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    sourceUvig: SourceUvigEnum!
    virusEnrichAppr: VirusEnrichApprEnum!
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String
    complSoftware: String
    complAppr: ComplApprEnum
    sortTech: SortTechEnum
    singleCellLysisAppr: SingleCellLysisApprEnum
    singleCellLysisProt: String
    wgaAmpAppr: String
    wgaAmpKit: String
    binParam: BinParamEnum
    binSoftware: String
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    virIdentSoftware: String!
    predGenomeType: PredGenomeTypeEnum!
    predGenomeStruc: PredGenomeStrucEnum!
    detecType: String!
    otuClassAppr: String
    otuSeqCompAppr: String
    otuDb: String
    hostPredAppr: HostPredApprEnum
    hostPredEstAcc: String
    associatedResource: String
    sop: String
  }

type Water
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkalinityMethod: String
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    atmosphericData: [String]
    bacteriaCarbProd: QuantityValue
    bacProd: QuantityValue
    bacResp: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    conduc: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgNitro: QuantityValue
    dissInorgPhosp: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    downPar: QuantityValue
    fluor: QuantityValue
    glucosidaseAct: QuantityValue
    lightIntensity: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    partOrgCarb: QuantityValue
    partOrgNitro: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    photonFlux: QuantityValue
    potassium: QuantityValue
    pressure: QuantityValue
    primaryProd: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    sodium: QuantityValue
    solubleReactPhosp: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    suspendPartMatter: QuantityValue
    tidalStage: TidalStageEnum
    totDepthWaterCol: QuantityValue
    totDissNitro: QuantityValue
    totInorgNitro: QuantityValue
    totNitro: QuantityValue
    totPartCarb: QuantityValue
    totPhosp: QuantityValue
    turbidity: QuantityValue
    waterCurrent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
  }

type WaterMIGSBacteria implements MIGSBacteria
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkalinityMethod: String
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    atmosphericData: [String]
    bacteriaCarbProd: QuantityValue
    bacProd: QuantityValue
    bacResp: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    conduc: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgNitro: QuantityValue
    dissInorgPhosp: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    downPar: QuantityValue
    fluor: QuantityValue
    glucosidaseAct: QuantityValue
    lightIntensity: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    partOrgCarb: QuantityValue
    partOrgNitro: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    photonFlux: QuantityValue
    potassium: QuantityValue
    pressure: QuantityValue
    primaryProd: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    sodium: QuantityValue
    solubleReactPhosp: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    suspendPartMatter: QuantityValue
    tidalStage: TidalStageEnum
    totDepthWaterCol: QuantityValue
    totDissNitro: QuantityValue
    totInorgNitro: QuantityValue
    totNitro: QuantityValue
    totPartCarb: QuantityValue
    totPhosp: QuantityValue
    turbidity: QuantityValue
    waterCurrent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer!
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String!
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    trophicLevel: TrophicLevelEnum
    encodedTraits: String
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type WaterMIGSEukaryote implements MIGSEukaryote
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkalinityMethod: String
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    atmosphericData: [String]
    bacteriaCarbProd: QuantityValue
    bacProd: QuantityValue
    bacResp: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    conduc: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgNitro: QuantityValue
    dissInorgPhosp: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    downPar: QuantityValue
    fluor: QuantityValue
    glucosidaseAct: QuantityValue
    lightIntensity: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    partOrgCarb: QuantityValue
    partOrgNitro: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    photonFlux: QuantityValue
    potassium: QuantityValue
    pressure: QuantityValue
    primaryProd: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    sodium: QuantityValue
    solubleReactPhosp: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    suspendPartMatter: QuantityValue
    tidalStage: TidalStageEnum
    totDepthWaterCol: QuantityValue
    totDissNitro: QuantityValue
    totInorgNitro: QuantityValue
    totNitro: QuantityValue
    totPartCarb: QuantityValue
    totPhosp: QuantityValue
    turbidity: QuantityValue
    waterCurrent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    ploidy: String
    numReplicons: Integer
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    trophicLevel: TrophicLevelEnum
    propagation: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type WaterMIGSOrg implements MIGSOrg
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkalinityMethod: String
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    atmosphericData: [String]
    bacteriaCarbProd: QuantityValue
    bacProd: QuantityValue
    bacResp: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    conduc: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgNitro: QuantityValue
    dissInorgPhosp: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    downPar: QuantityValue
    fluor: QuantityValue
    glucosidaseAct: QuantityValue
    lightIntensity: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    partOrgCarb: QuantityValue
    partOrgNitro: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    photonFlux: QuantityValue
    potassium: QuantityValue
    pressure: QuantityValue
    primaryProd: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    sodium: QuantityValue
    solubleReactPhosp: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    suspendPartMatter: QuantityValue
    tidalStage: TidalStageEnum
    totDepthWaterCol: QuantityValue
    totDissNitro: QuantityValue
    totInorgNitro: QuantityValue
    totNitro: QuantityValue
    totPartCarb: QuantityValue
    totPhosp: QuantityValue
    turbidity: QuantityValue
    waterCurrent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type WaterMIGSPlant implements MIGSPlant
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkalinityMethod: String
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    atmosphericData: [String]
    bacteriaCarbProd: QuantityValue
    bacProd: QuantityValue
    bacResp: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    conduc: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgNitro: QuantityValue
    dissInorgPhosp: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    downPar: QuantityValue
    fluor: QuantityValue
    glucosidaseAct: QuantityValue
    lightIntensity: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    partOrgCarb: QuantityValue
    partOrgNitro: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    photonFlux: QuantityValue
    potassium: QuantityValue
    pressure: QuantityValue
    primaryProd: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    sodium: QuantityValue
    solubleReactPhosp: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    suspendPartMatter: QuantityValue
    tidalStage: TidalStageEnum
    totDepthWaterCol: QuantityValue
    totDissNitro: QuantityValue
    totInorgNitro: QuantityValue
    totNitro: QuantityValue
    totPartCarb: QuantityValue
    totPhosp: QuantityValue
    turbidity: QuantityValue
    waterCurrent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    specificHost: String
    hostSpecRange: Integer
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type WaterMIGSVirus implements MIGSVirus
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkalinityMethod: String
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    atmosphericData: [String]
    bacteriaCarbProd: QuantityValue
    bacProd: QuantityValue
    bacResp: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    conduc: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgNitro: QuantityValue
    dissInorgPhosp: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    downPar: QuantityValue
    fluor: QuantityValue
    glucosidaseAct: QuantityValue
    lightIntensity: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    partOrgCarb: QuantityValue
    partOrgNitro: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    photonFlux: QuantityValue
    potassium: QuantityValue
    pressure: QuantityValue
    primaryProd: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    sodium: QuantityValue
    solubleReactPhosp: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    suspendPartMatter: QuantityValue
    tidalStage: TidalStageEnum
    totDepthWaterCol: QuantityValue
    totDissNitro: QuantityValue
    totInorgNitro: QuantityValue
    totNitro: QuantityValue
    totPartCarb: QuantityValue
    totPhosp: QuantityValue
    turbidity: QuantityValue
    waterCurrent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    numReplicons: Integer
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    propagation: String!
    encodedTraits: String
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    virusEnrichAppr: VirusEnrichApprEnum
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    complScore: String
    complSoftware: String
    associatedResource: String
    sop: String
  }

type WaterMIMAG implements MIMAG
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkalinityMethod: String
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    atmosphericData: [String]
    bacteriaCarbProd: QuantityValue
    bacProd: QuantityValue
    bacResp: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    conduc: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgNitro: QuantityValue
    dissInorgPhosp: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    downPar: QuantityValue
    fluor: QuantityValue
    glucosidaseAct: QuantityValue
    lightIntensity: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    partOrgCarb: QuantityValue
    partOrgNitro: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    photonFlux: QuantityValue
    potassium: QuantityValue
    pressure: QuantityValue
    primaryProd: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    sodium: QuantityValue
    solubleReactPhosp: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    suspendPartMatter: QuantityValue
    tidalStage: TidalStageEnum
    totDepthWaterCol: QuantityValue
    totDissNitro: QuantityValue
    totInorgNitro: QuantityValue
    totNitro: QuantityValue
    totPartCarb: QuantityValue
    totPhosp: QuantityValue
    turbidity: QuantityValue
    waterCurrent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    binParam: BinParamEnum!
    binSoftware: String!
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    associatedResource: String
    sop: String
  }

type WaterMIMARKSSpecimen implements MIMARKSSpecimen
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkalinityMethod: String
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    atmosphericData: [String]
    bacteriaCarbProd: QuantityValue
    bacProd: QuantityValue
    bacResp: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    conduc: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgNitro: QuantityValue
    dissInorgPhosp: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    downPar: QuantityValue
    fluor: QuantityValue
    glucosidaseAct: QuantityValue
    lightIntensity: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    partOrgCarb: QuantityValue
    partOrgNitro: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    photonFlux: QuantityValue
    potassium: QuantityValue
    pressure: QuantityValue
    primaryProd: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    sodium: QuantityValue
    solubleReactPhosp: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    suspendPartMatter: QuantityValue
    tidalStage: TidalStageEnum
    totDepthWaterCol: QuantityValue
    totDissNitro: QuantityValue
    totInorgNitro: QuantityValue
    totNitro: QuantityValue
    totPartCarb: QuantityValue
    totPhosp: QuantityValue
    turbidity: QuantityValue
    waterCurrent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    mid: String
    adapters: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    assemblySoftware: String
    associatedResource: String
    sop: String
  }

type WaterMIMARKSSurvey implements MIMARKSSurvey
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkalinityMethod: String
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    atmosphericData: [String]
    bacteriaCarbProd: QuantityValue
    bacProd: QuantityValue
    bacResp: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    conduc: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgNitro: QuantityValue
    dissInorgPhosp: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    downPar: QuantityValue
    fluor: QuantityValue
    glucosidaseAct: QuantityValue
    lightIntensity: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    partOrgCarb: QuantityValue
    partOrgNitro: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    photonFlux: QuantityValue
    potassium: QuantityValue
    pressure: QuantityValue
    primaryProd: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    sodium: QuantityValue
    solubleReactPhosp: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    suspendPartMatter: QuantityValue
    tidalStage: TidalStageEnum
    totDepthWaterCol: QuantityValue
    totDissNitro: QuantityValue
    totInorgNitro: QuantityValue
    totNitro: QuantityValue
    totPartCarb: QuantityValue
    totPhosp: QuantityValue
    turbidity: QuantityValue
    waterCurrent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    subspecfGenLin: String
    extrachromElements: Integer
    sourceMatId: String
    bioticRelationship: BioticRelationshipEnum
    trophicLevel: TrophicLevelEnum
    relToOxygen: RelToOxygenEnum
    isolGrowthCondt: String!
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    targetGene: String!
    targetSubfragment: String
    pcrPrimers: String
    pcrCond: String
    seqMeth: String!
    seqQualityCheck: String
    chimeraCheck: String
    associatedResource: String
    sop: String
  }

type WaterMIMS implements MIMS
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkalinityMethod: String
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    atmosphericData: [String]
    bacteriaCarbProd: QuantityValue
    bacProd: QuantityValue
    bacResp: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    conduc: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgNitro: QuantityValue
    dissInorgPhosp: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    downPar: QuantityValue
    fluor: QuantityValue
    glucosidaseAct: QuantityValue
    lightIntensity: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    partOrgCarb: QuantityValue
    partOrgNitro: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    photonFlux: QuantityValue
    potassium: QuantityValue
    pressure: QuantityValue
    primaryProd: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    sodium: QuantityValue
    solubleReactPhosp: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    suspendPartMatter: QuantityValue
    tidalStage: TidalStageEnum
    totDepthWaterCol: QuantityValue
    totDissNitro: QuantityValue
    totInorgNitro: QuantityValue
    totNitro: QuantityValue
    totPartCarb: QuantityValue
    totPhosp: QuantityValue
    turbidity: QuantityValue
    waterCurrent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    assemblyQual: AssemblyQualEnum
    assemblyName: String
    assemblySoftware: String
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    associatedResource: String
    sop: String
  }

type WaterMISAG implements MISAG
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkalinityMethod: String
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    atmosphericData: [String]
    bacteriaCarbProd: QuantityValue
    bacProd: QuantityValue
    bacResp: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    conduc: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgNitro: QuantityValue
    dissInorgPhosp: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    downPar: QuantityValue
    fluor: QuantityValue
    glucosidaseAct: QuantityValue
    lightIntensity: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    partOrgCarb: QuantityValue
    partOrgNitro: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    photonFlux: QuantityValue
    potassium: QuantityValue
    pressure: QuantityValue
    primaryProd: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    sodium: QuantityValue
    solubleReactPhosp: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    suspendPartMatter: QuantityValue
    tidalStage: TidalStageEnum
    totDepthWaterCol: QuantityValue
    totDissNitro: QuantityValue
    totInorgNitro: QuantityValue
    totNitro: QuantityValue
    totPartCarb: QuantityValue
    totPhosp: QuantityValue
    turbidity: QuantityValue
    waterCurrent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    refBiomaterial: String
    sourceMatId: String
    relToOxygen: RelToOxygenEnum
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum!
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    x16sRecover: String
    x16sRecoverSoftware: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String!
    complSoftware: String!
    complAppr: ComplApprEnum
    contamScore: String!
    contamScreenInput: String
    contamScreenParam: String
    decontamSoftware: DecontamSoftwareEnum
    sortTech: SortTechEnum!
    singleCellLysisAppr: SingleCellLysisApprEnum!
    singleCellLysisProt: String
    wgaAmpAppr: String!
    wgaAmpKit: String
    associatedResource: String
    sop: String
  }

type WaterMIUVIG implements MIUVIG
  {
    latLon: String
    depth: QuantityValue!
    alt: QuantityValue
    elev: QuantityValue
    temp: QuantityValue
    geoLocName: String
    collectionDate: Date
    envBroadScale: String
    envLocalScale: String
    envMedium: String
    alkalinity: QuantityValue
    alkalinityMethod: String
    alkylDiethers: QuantityValue
    aminopeptAct: QuantityValue
    ammonium: QuantityValue
    atmosphericData: [String]
    bacteriaCarbProd: QuantityValue
    bacProd: QuantityValue
    bacResp: QuantityValue
    biomass: [String]
    bishomohopanol: QuantityValue
    bromide: QuantityValue
    calcium: QuantityValue
    carbNitroRatio: QuantityValue
    chemAdministration: [String]
    chloride: QuantityValue
    chlorophyll: QuantityValue
    conduc: QuantityValue
    density: QuantityValue
    dietherLipids: [String]
    dissCarbDioxide: QuantityValue
    dissHydrogen: QuantityValue
    dissInorgCarb: QuantityValue
    dissInorgNitro: QuantityValue
    dissInorgPhosp: QuantityValue
    dissOrgCarb: QuantityValue
    dissOrgNitro: QuantityValue
    dissOxygen: QuantityValue
    downPar: QuantityValue
    fluor: QuantityValue
    glucosidaseAct: QuantityValue
    lightIntensity: QuantityValue
    magnesium: QuantityValue
    meanFrictVel: QuantityValue
    meanPeakFrictVel: QuantityValue
    miscParam: [String]
    nAlkanes: [String]
    nitrate: QuantityValue
    nitrite: QuantityValue
    nitro: QuantityValue
    orgCarb: QuantityValue
    orgMatter: QuantityValue
    orgNitro: QuantityValue
    organismCount: [OrganismCountEnum]
    oxyStatSamp: OxyStatSampEnum
    ph: Double
    partOrgCarb: QuantityValue
    partOrgNitro: QuantityValue
    perturbation: [String]
    petroleumHydrocarb: QuantityValue
    phaeopigments: [String]
    phosphate: QuantityValue
    phosplipidFattAcid: [String]
    photonFlux: QuantityValue
    potassium: QuantityValue
    pressure: QuantityValue
    primaryProd: QuantityValue
    redoxPotential: QuantityValue
    salinity: QuantityValue
    sampStoreDur: String
    sampStoreLoc: String
    sampStoreTemp: QuantityValue
    silicate: QuantityValue
    sizeFracLow: QuantityValue
    sizeFracUp: QuantityValue
    sodium: QuantityValue
    solubleReactPhosp: QuantityValue
    sulfate: QuantityValue
    sulfide: QuantityValue
    suspendPartMatter: QuantityValue
    tidalStage: TidalStageEnum
    totDepthWaterCol: QuantityValue
    totDissNitro: QuantityValue
    totInorgNitro: QuantityValue
    totNitro: QuantityValue
    totPartCarb: QuantityValue
    totPhosp: QuantityValue
    turbidity: QuantityValue
    waterCurrent: QuantityValue
    sampName: String!
    projectName: String!
    sampVolWeDnaExt: QuantityValue
    sampTaxonId: String!
    experimentalFactor: String
    negContType: NegContTypeEnum
    posContType: String
    estimatedSize: String
    refBiomaterial: String
    sourceMatId: String
    pathogenicity: String
    bioticRelationship: BioticRelationshipEnum
    specificHost: String
    hostSpecRange: Integer
    hostDiseaseStat: String
    sampCollecDevice: String
    sampCollecMethod: String
    sampMatProcess: String
    sizeFrac: String
    sampSize: QuantityValue
    sourceUvig: SourceUvigEnum!
    virusEnrichAppr: VirusEnrichApprEnum!
    nuclAcidExt: String
    nuclAcidAmp: String
    libSize: Integer
    libReadsSeqd: Integer
    libLayout: LibLayoutEnum
    libVector: String
    libScreen: String
    mid: String
    adapters: String
    seqMeth: String!
    taxIdent: TaxIdentEnum
    assemblyQual: AssemblyQualEnum!
    assemblyName: String
    assemblySoftware: String!
    annot: String
    numberContig: Integer!
    featPred: String
    refDb: String
    simSearchMeth: String
    taxClass: String
    trnas: Integer
    trnaExtSoftware: String
    complScore: String
    complSoftware: String
    complAppr: ComplApprEnum
    sortTech: SortTechEnum
    singleCellLysisAppr: SingleCellLysisApprEnum
    singleCellLysisProt: String
    wgaAmpAppr: String
    wgaAmpKit: String
    binParam: BinParamEnum
    binSoftware: String
    reassemblyBin: String
    magCovSoftware: MagCovSoftwareEnum
    virIdentSoftware: String!
    predGenomeType: PredGenomeTypeEnum!
    predGenomeStruc: PredGenomeStrucEnum!
    detecType: String!
    otuClassAppr: String
    otuSeqCompAppr: String
    otuDb: String
    hostPredAppr: HostPredApprEnum
    hostPredEstAcc: String
    associatedResource: String
    sop: String
  }

